@@ -24,64 +24,6 @@
 
 #include "flaimsys.h"
 
-// Global data
-
-char F_Base64Encoder::m_ucEncodeTable[ 64] =
-{
-	ASCII_UPPER_A, ASCII_UPPER_B, ASCII_UPPER_C, ASCII_UPPER_D,
-	ASCII_UPPER_E, ASCII_UPPER_F, ASCII_UPPER_G, ASCII_UPPER_H,
-	ASCII_UPPER_I, ASCII_UPPER_J, ASCII_UPPER_K, ASCII_UPPER_L,
-	ASCII_UPPER_M, ASCII_UPPER_N, ASCII_UPPER_O, ASCII_UPPER_P,
-	ASCII_UPPER_Q, ASCII_UPPER_R, ASCII_UPPER_S, ASCII_UPPER_T,
-	ASCII_UPPER_U, ASCII_UPPER_V, ASCII_UPPER_W, ASCII_UPPER_X,
-	ASCII_UPPER_Y, ASCII_UPPER_Z, ASCII_LOWER_A, ASCII_LOWER_B,
-	ASCII_LOWER_C, ASCII_LOWER_D, ASCII_LOWER_E, ASCII_LOWER_F,
-	ASCII_LOWER_G, ASCII_LOWER_H, ASCII_LOWER_I, ASCII_LOWER_J,
-	ASCII_LOWER_K, ASCII_LOWER_L, ASCII_LOWER_M, ASCII_LOWER_N,
-	ASCII_LOWER_O, ASCII_LOWER_P, ASCII_LOWER_Q, ASCII_LOWER_R,
-	ASCII_LOWER_S, ASCII_LOWER_T, ASCII_LOWER_U, ASCII_LOWER_V,
-	ASCII_LOWER_W, ASCII_LOWER_X, ASCII_LOWER_Y, ASCII_LOWER_Z,
-	ASCII_ZERO,    ASCII_ONE,     ASCII_TWO,     ASCII_THREE,
-	ASCII_FOUR,    ASCII_FIVE,    ASCII_SIX,     ASCII_SEVEN,
-	ASCII_EIGHT,   ASCII_NINE,   ASCII_PLUS,     ASCII_SLASH
-};
-
-FLMBYTE F_Base64Decoder::m_ucDecodeTable[ 256] =
-{
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 0   .. 7
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 8   .. 15
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 16  .. 23
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 24  .. 31
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 32  .. 39
-	0xFF, 0xFF, 0xFF, 0x3E, 0xFF, 0xFF, 0xFF, 0x3F,		// 40  .. 47
-	0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3A, 0x3B,		// 48  .. 55
-	0x3C, 0x3D, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0xFF,		// 56  .. 63
-	0xFF, 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06,		// 64  .. 71
-	0x07, 0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E,		// 72  .. 79
-	0x0F, 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16,		// 80  .. 87
-	0x17, 0x18, 0x19, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 88  .. 95
-	0xFF, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F, 0x20,		// 96  .. 103
-	0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28,		// 104 .. 111
-	0x29, 0x2A, 0x2B, 0x2C, 0x2D, 0x2E, 0x2F, 0x30,		// 112 .. 119
-	0x31, 0x32, 0x33, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 120 .. 127
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 128 .. 135
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 136 .. 143
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 144 .. 151
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 152 .. 159
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 160 .. 167
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 168 .. 175
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 176 .. 183
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 184 .. 191
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 192 .. 199
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 200 .. 207
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 208 .. 215
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 216 .. 223
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 224 .. 231
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 232 .. 239
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 240 .. 247
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF		// 248 .. 255
-};
-
 #ifdef FLM_USE_NICI
 	FSTATIC void GetIV(
 		FLMBYTE *		pucIV,
@@ -169,10 +111,10 @@ RCODE F_CCS::wrapKey(
 		goto Exit;
 	}
 	
-	f_memset( &wKey, 0, sizeof(NICI_ATTRIBUTE));
+	f_memset( &wKey, 0, sizeof( NICI_ATTRIBUTE));
 
 	wKey.type = NICI_A_KEY_TYPE;
-	if( CCS_GetAttributeValue(context, wrappingKeyHandle, &wKey, 1) != 0)
+	if( CCS_GetAttributeValue( context, wrappingKeyHandle, &wKey, 1) != 0)
 	{
 		rc = RC_SET( FERR_NICI_ATTRIBUTE_VALUE);
 		goto Exit;
@@ -194,7 +136,7 @@ RCODE F_CCS::wrapKey(
 			algorithm.parameter = parm;
 			algorithm.parameter->count = 1;
 			algorithm.parameter->parms[0].parmType = NICI_P_IV;
-			algorithm.parameter->parms[0].u.b.len = IV_SZ; /* 16-byte IV */
+			algorithm.parameter->parms[0].u.b.len = IV_SZ;
 			algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 			break;
 		}
@@ -207,7 +149,7 @@ RCODE F_CCS::wrapKey(
 			algorithm.parameter = parm;
 			algorithm.parameter->count = 1;
 			algorithm.parameter->parms[0].parmType = NICI_P_IV;
-			algorithm.parameter->parms[0].u.b.len = IV_SZ8; /* 8-byte IV */
+			algorithm.parameter->parms[0].u.b.len = IV_SZ8;
 			algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 			break;
 		}
@@ -222,7 +164,7 @@ RCODE F_CCS::wrapKey(
 			algorithm.parameter = parm;
 			algorithm.parameter->count = 1;
 			algorithm.parameter->parms[0].parmType = NICI_P_IV;
-			algorithm.parameter->parms[0].u.b.len = IV_SZ8; /* 8-byte IV */
+			algorithm.parameter->parms[0].u.b.len = IV_SZ8;
 			algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 			break;
 		}
@@ -268,7 +210,6 @@ Exit:
 	return( rc);
 }
 
-
 /****************************************************************************
 Desc:
 ****************************************************************************/
@@ -303,7 +244,7 @@ RCODE F_CCS::unwrapKey(
 
 	// Create NICI Context
 	
-	if( CCS_CreateContext(0, &context) != 0)
+	if( CCS_CreateContext( 0, &context) != 0)
 	{
 		rc = RC_SET( FERR_NICI_CONTEXT);
 		goto Exit;
@@ -312,7 +253,7 @@ RCODE F_CCS::unwrapKey(
 	if( CCS_UnwrapKey( context, wrappingKeyHandle, pucWrappedKey,
 		ui32WrappedKeyLength, &m_keyHandle) != 0)
 	{
-		rc = RC_SET( FERR_NICI_UNWRAPKEY_FAILED);
+		rc = RC_SET_AND_ASSERT( FERR_NICI_UNWRAPKEY_FAILED);
 		goto Exit;
 	}
 
@@ -493,7 +434,7 @@ RCODE F_CCS::generateEncryptionKeyDES3( void)
 	keyAttr[2].u.f.value = N_TRUE;
 	keyAttr[2].u.f.valueInfo = 0;
 
-	// Generate a AES key
+	// Generate a DES3 key
 	
 	if( CCS_GenerateKey( context, &algorithm, keyAttr, 3,
 		(NICI_BBOOL *)&keySizeChanged, &m_keyHandle, NICI_H_INVALID) != 0)
@@ -841,7 +782,7 @@ RCODE F_CCS::encryptToStoreAES(
 	algorithm.parameter = parm;
 	algorithm.parameter->count = 1;
 	algorithm.parameter->parms[0].parmType = NICI_P_IV;
-	algorithm.parameter->parms[0].u.b.len = IV_SZ; /* 16-byte IV */
+	algorithm.parameter->parms[0].u.b.len = IV_SZ;
 	algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 
 	if( CCS_DataEncryptInit(context, &algorithm, m_keyHandle) != 0)
@@ -904,7 +845,7 @@ RCODE F_CCS::decryptFromStoreAES(
 	algorithm.parameter = parm;
 	algorithm.parameter->count = 1;
 	algorithm.parameter->parms[0].parmType = NICI_P_IV;
-	algorithm.parameter->parms[0].u.b.len = IV_SZ; /* 16-byte IV */
+	algorithm.parameter->parms[0].u.b.len = IV_SZ;
 	algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 
 	// Init encryption
@@ -969,7 +910,7 @@ RCODE F_CCS::encryptToStoreDES3(
 	algorithm.parameter = parm;
 	algorithm.parameter->count = 1;
 	algorithm.parameter->parms[0].parmType = NICI_P_IV;
-	algorithm.parameter->parms[0].u.b.len = IV_SZ8; /* 8-byte IV */
+	algorithm.parameter->parms[0].u.b.len = IV_SZ8;
 	algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 
 	// Init encryption
@@ -1036,7 +977,7 @@ RCODE F_CCS::decryptFromStoreDES3(
 	algorithm.parameter = parm;
 	algorithm.parameter->count = 1;
 	algorithm.parameter->parms[0].parmType = NICI_P_IV;
-	algorithm.parameter->parms[0].u.b.len = IV_SZ8; /* 8-byte IV */
+	algorithm.parameter->parms[0].u.b.len = IV_SZ8;
 	algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 
 	// Init encryption
@@ -1101,7 +1042,7 @@ RCODE F_CCS::encryptToStoreDES(
 	algorithm.parameter = parm;
 	algorithm.parameter->count = 1;
 	algorithm.parameter->parms[0].parmType = NICI_P_IV;
-	algorithm.parameter->parms[0].u.b.len = IV_SZ8; /* 8-byte IV */
+	algorithm.parameter->parms[0].u.b.len = IV_SZ8;
 	algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 
 	// Init encryption
@@ -1168,7 +1109,7 @@ RCODE F_CCS::decryptFromStoreDES(
 	algorithm.parameter = parm;
 	algorithm.parameter->count = 1;
 	algorithm.parameter->parms[0].parmType = NICI_P_IV;
-	algorithm.parameter->parms[0].u.b.len = IV_SZ8; /* 8-byte IV */
+	algorithm.parameter->parms[0].u.b.len = IV_SZ8;
 	algorithm.parameter->parms[0].u.b.ptr = m_pucIV;
 
 	// Init encryption
@@ -1235,7 +1176,7 @@ Exit:
 }
 
 /****************************************************************************
-Desc:	Pick a wrapping key that we can use to wrap &
+Desc:	Pick a wrapping key that we can use to wrap and
 		unwrap the encryption key with.
 ****************************************************************************/
 RCODE F_CCS::getWrappingKey(
@@ -1327,12 +1268,13 @@ RCODE F_CCS::getKeyToStore(
 	void *					pvB64Buffer = NULL;
 	FLMUINT32				ui32PaddedLength;
 	NICI_CC_HANDLE			context = 0;
-	F_Base64Encoder *		pB64Encoder = NULL;
+	IF_PosIStream *		pBufferIStream = NULL;
+	IF_IStream *			pB64Encoder = NULL;
 	FLMBYTE *				pucWrappedKey = NULL;
 	FLMUINT32				ui32WrappedKeyLen = 0;
 	char *					pszFormattedEncKeyPasswd = NULL;
 	NICI_OBJECT_HANDLE	wrappingKeyHandle = 0;
-	FLMUINT32				ui32B64Length;
+	FLMUINT					uiB64Length;
 
 	*ppucKeyInfo = NULL;
 	*pui32BufLen = 0;
@@ -1383,7 +1325,7 @@ RCODE F_CCS::getKeyToStore(
 
 	// The shrouded or wrapped key will be stored in m_pKey.
 	
-	ui32PaddedLength = (ui32WrappedKeyLen + sizeof( FLMBOOL) +
+	ui32PaddedLength = (ui32WrappedKeyLen + sizeof( FLMUINT32) +
 								sizeof( FLMUINT32) + IV_SZ );
 
 	// Make sure our buffer size is padded to a 16 byte boundary.
@@ -1411,15 +1353,13 @@ RCODE F_CCS::getKeyToStore(
 	// Save a flag indicating whether the key is wrapped or encoded in
 	// a password.
 	
-	UD2FBA( (pszEncKeyPasswd && pszEncKeyPasswd[0]) 
-						? (FLMUINT)TRUE 
-						: (FLMUINT)FALSE, pucPtr);
-	pucPtr += sizeof(FLMBOOL);
+	UD2FBA( (pszEncKeyPasswd && pszEncKeyPasswd[0]) ? 1 : 0, pucPtr); 
+	pucPtr += sizeof( FLMUINT32);
 
 	// Copy the key length.
 	
 	UD2FBA(ui32WrappedKeyLen, pucPtr);
-	pucPtr += sizeof(FLMUINT32);
+	pucPtr += sizeof( FLMUINT32);
 
 	// Copy the IV too.
 	
@@ -1444,32 +1384,41 @@ RCODE F_CCS::getKeyToStore(
 	{
 		// The resulting length will not be more than doubled.
 		
-		ui32B64Length = ui32PaddedLength * 2;
-		if( RC_BAD( rc = f_calloc( ui32B64Length, &pvB64Buffer)))
+		uiB64Length = (FLMUINT)(ui32PaddedLength * 2);
+		if( RC_BAD( rc = f_calloc( uiB64Length, &pvB64Buffer)))
 		{
 			goto ExitCtx;
 		}
-
-		if( (pB64Encoder = f_new F_Base64Encoder( FALSE)) == NULL)
-		{
-			rc = RC_SET( FERR_MEM);
-			goto ExitCtx;
-		}
-
-		// Only encode the data.
 		
-		if (RC_BAD( rc = pB64Encoder->read( pucTmp, ui32PaddedLength,
-			pvB64Buffer, ui32PaddedLength, &ui32B64Length)))
+		if( RC_BAD( rc = FlmOpenBufferIStream( (const char *)pucTmp, 
+			ui32PaddedLength, &pBufferIStream)))
 		{
-			goto ExitCtx;
+			goto Exit;
+		}
+		
+		if( RC_BAD( rc = FlmOpenBase64EncoderIStream( pBufferIStream, 
+			FALSE, &pB64Encoder)))
+		{
+			goto Exit;
 		}
 
-		flmAssert( ui32B64Length < (ui32PaddedLength * 2));
+		if (RC_BAD( rc = pB64Encoder->read( pvB64Buffer, 
+			0xFFFFFFFF, &uiB64Length)))
+		{
+			if( rc != NE_FLM_EOF_HIT)
+			{
+				goto ExitCtx;
+			}
+			
+			rc = NE_FLM_OK;
+		}
 
-		((FLMBYTE *)pvB64Buffer)[ ui32B64Length] = '\0';
+		flmAssert( uiB64Length < (FLMUINT)(ui32PaddedLength * 2));
+
+		((FLMBYTE *)pvB64Buffer)[ uiB64Length] = '\0';
 		*ppucKeyInfo = (FLMBYTE *)pvB64Buffer;
 		pvB64Buffer = NULL;
-		*pui32BufLen = ui32B64Length;
+		*pui32BufLen = (FLMUINT32)uiB64Length;
 	}
 	else
 	{
@@ -1500,7 +1449,12 @@ Exit:
 
 	if (pB64Encoder)
 	{
-		delete pB64Encoder;
+		pB64Encoder->Release();
+	}
+	
+	if (pBufferIStream)
+	{
+		pBufferIStream->Release();
 	}
 
 	if (pucWrappedKey)
@@ -1543,8 +1497,7 @@ RCODE F_CCS::setKeyFromStore(
 	FLMBYTE *				pucTmp;
 	FLMBYTE *				pucBuffer = NULL;
 	FLMBOOL					bShrouded = FALSE;
-	FLMUINT32				ui32Length;
-	F_Base64Decoder *		pB64Decoder = NULL;
+	FLMUINT					uiLength;
 	FLMBYTE *				pucKeyBuf = NULL;
 	char *					pszFormattedEncKeyPasswd = NULL;
 	NICI_OBJECT_HANDLE	wrappingKeyHandle = 0;
@@ -1558,31 +1511,37 @@ RCODE F_CCS::setKeyFromStore(
 
 	if (bBase64Encoded)
 	{
-
-		// Need a temporary buffer to translate the Base64 encoded buffer into
-
-		if (RC_BAD( rc = f_alloc( ui32BufLen, &pucKeyBuf)))
+		F_BufferIStream			bufferStream;
 		{
-			goto Exit;
+			F_Base64DecoderIStream	B64Decoder;
+	
+			// Need a temporary buffer to translate the Base64 encoded buffer into
+	
+			if (RC_BAD( rc = f_alloc( ui32BufLen, &pucKeyBuf)))
+			{
+				goto Exit;
+			}
+	
+			if (RC_BAD( rc = bufferStream.openStream( (const char *)pTmpKey, (FLMUINT)ui32BufLen)))
+			{
+				goto Exit;
+			}
+			if (RC_BAD( rc = B64Decoder.openStream( &bufferStream)))
+			{
+				goto Exit;
+			}
+	
+			// Buffer is Base64 encoded.  We must first decode it.
+			
+			// Decode the buffer
+			
+			if( RC_BAD( rc = B64Decoder.read(
+				(void *)pucKeyBuf, ui32BufLen, &uiLength)))
+			{
+				goto Exit;
+			}
+			pucTmp = pucKeyBuf;
 		}
-
-		// Buffer is Base64 encoded.  We must first decode it.
-		
-		pB64Decoder = f_new F_Base64Decoder;
-		if (pB64Decoder == NULL)
-		{
-			rc = RC_SET( FERR_MEM);
-			goto Exit;
-		}
-
-		// Decode the buffer
-		
-		if( RC_BAD( rc = pB64Decoder->read(	pTmpKey, ui32BufLen,
-			(void *)pucKeyBuf, ui32BufLen, &ui32Length)))
-		{
-			goto Exit;
-		}
-		pucTmp = pucKeyBuf;
 	}
 	else
 	{
@@ -1594,12 +1553,12 @@ RCODE F_CCS::setKeyFromStore(
 	// Extract the fields from the buffer
 	
 	bShrouded = FB2UD( pucTmp);
-	pucTmp += sizeof(FLMUINT);
+	pucTmp += sizeof( FLMUINT32);
 
 	// Actual length - note that the passed buffer is padded to 16 byte boundary.
 	
-	ui32Length = FB2UD( pucTmp);
-	pucTmp += sizeof(FLMUINT32);
+	uiLength = FB2UD( pucTmp);
+	pucTmp += sizeof( FLMUINT32);
 
 	// Get the IV
 	
@@ -1608,12 +1567,12 @@ RCODE F_CCS::setKeyFromStore(
 
 	// Need another temporary buffer to hold the encrypted / shrouded key.
 	
-	if (RC_BAD( rc = f_alloc( ui32Length, &pucBuffer)))
+	if (RC_BAD( rc = f_alloc( uiLength, &pucBuffer)))
 	{
 		goto Exit;
 	}
 
-	f_memcpy( pucBuffer, pucTmp, ui32Length);
+	f_memcpy( pucBuffer, pucTmp, uiLength);
 
 	if (bShrouded)
 	{
@@ -1630,7 +1589,7 @@ RCODE F_CCS::setKeyFromStore(
 		// to machines with different byte ordering.
 		
 		if( RC_BAD( rc = f_calloc( f_strlen(pszEncKeyPasswd) +
-			(f_strlen(pszEncKeyPasswd) % 2) + 2, &pszFormattedEncKeyPasswd)))
+			(f_strlen( pszEncKeyPasswd) % 2) + 2, &pszFormattedEncKeyPasswd)))
 		{
 			goto Exit;
 		}
@@ -1640,7 +1599,7 @@ RCODE F_CCS::setKeyFromStore(
 		// Unshroud the key using the password.
 		// Key handle is always kept in m_keyHandle.
 		
-		if( RC_BAD( rc = injectKey( pucBuffer, ui32Length,
+		if( RC_BAD( rc = injectKey( pucBuffer, (FLMUINT32)uiLength,
 			(FLMUNICODE *)pszFormattedEncKeyPasswd)))
 		{
 			goto Exit;
@@ -1655,7 +1614,7 @@ RCODE F_CCS::setKeyFromStore(
 
 		// Unwrap the key.  The Key handle is always store in m_keyHandle.
 		
-		if (RC_BAD( rc = unwrapKey( pucBuffer, ui32Length, wrappingKeyHandle)))
+		if (RC_BAD( rc = unwrapKey( pucBuffer, (FLMUINT32)uiLength, wrappingKeyHandle)))
 		{
 			goto Exit;
 		}
@@ -1668,10 +1627,6 @@ RCODE F_CCS::setKeyFromStore(
 Exit:
 
 #ifdef FLM_USE_NICI
-	if (pB64Decoder)
-	{
-		delete pB64Decoder;
-	}
 
 	if (pucBuffer)
 	{
@@ -2110,7 +2065,6 @@ RCODE F_CCS::injectKey(
 	{
 		case NICI_K_AES:
 		{
-			/* Set key attributes */
 			uiIndx = 0;
 			keyAttr[uiIndx].type = NICI_A_KEY_TYPE;
 			keyAttr[uiIndx].u.f.hasValue = 1;
@@ -2156,7 +2110,6 @@ RCODE F_CCS::injectKey(
 		}
 		case NICI_K_DES3X:
 		{
-			/* Set key attributes */
 			uiIndx = 0;
 			keyAttr[uiIndx].type = NICI_A_KEY_TYPE;
 			keyAttr[uiIndx].u.f.hasValue = 1;
@@ -2234,262 +2187,6 @@ Exit:
 	return(rc);
 }
 
-
-/*****************************************************************************
-Desc:	Reads decoded binary from the base64 ASCII source buffer.
-*****************************************************************************/
-RCODE F_Base64Decoder::read(
-	FLMBYTE *				psSource,
-	FLMUINT					uiSourceLen,
-	void *					pvBuffer,
-	FLMUINT32				ui32BytesToRead,
-	FLMUINT32 *				pui32BytesRead)
-{
-	RCODE			rc = FERR_OK;
-	FLMBYTE *	pucOutBuf = (FLMBYTE *)pvBuffer;
-	FLMBYTE		ucQuadBuffer[ 4];
-	FLMBYTE *	pTmp = psSource;
-	FLMUINT		uiOffset = 0;
-	FLMUINT		uiBytesToCopy;
-
-	if( pui32BytesRead)
-	{
-		*pui32BytesRead = 0;
-	}
-
-	if( !psSource)
-	{
-		rc = RC_SET( FERR_EOF_HIT);
-		goto Exit;
-	}
-
-	while( ui32BytesToRead)
-	{
-		if( !m_uiAvailBytes)
-		{
-			m_uiBufOffset = 0;
-
-			for( uiOffset = 0; uiOffset < 4;)
-			{
-				if (pTmp > psSource + uiSourceLen)
-				{
-					if( uiOffset)
-					{
-						rc = RC_SET( FERR_BAD_BASE64_ENCODING);
-					}
-					goto Exit;
-				}
-				else
-				{
-					ucQuadBuffer[ uiOffset] = *pTmp;
-					pTmp++;
-				}
-
-				if( m_ucDecodeTable[ ucQuadBuffer[ uiOffset]] == 0xFF)
-				{
-					FLMBYTE	ucTmp = ucQuadBuffer[ uiOffset];
-
-					if( ucTmp == ASCII_TAB || ucTmp == ASCII_SPACE ||
-						ucTmp == ASCII_NEWLINE || ucTmp == ASCII_CR)
-					{
-						continue;
-					}
-
-					rc = RC_SET( FERR_BAD_BASE64_ENCODING);
-					goto Exit;
-				}
-
-				uiOffset++;
-			}
-
-			m_ucBuffer[ 0] =
-				(m_ucDecodeTable[ ucQuadBuffer[ 0]] << 2) |
-				(m_ucDecodeTable[ ucQuadBuffer[ 1]] >> 4);
-			m_uiAvailBytes++;
-
-			if( ucQuadBuffer[ 2] != '=')
-			{
-				m_ucBuffer[ 1] =
-					(m_ucDecodeTable[ ucQuadBuffer[ 1]] << 4) |
-					(m_ucDecodeTable[ ucQuadBuffer[ 2]] >> 2);
-				m_uiAvailBytes++;
-			}
-
-			if( ucQuadBuffer[ 3] != '=')
-			{
-				m_ucBuffer[ 2] =
-					(m_ucDecodeTable[ ucQuadBuffer[ 2]] << 6) |
-					m_ucDecodeTable[ ucQuadBuffer[ 3]];
-				m_uiAvailBytes++;
-			}
-		}
-
-		uiBytesToCopy = f_min( m_uiAvailBytes, ui32BytesToRead);
-
-		if( pucOutBuf)
-		{
-			f_memcpy( pucOutBuf, &m_ucBuffer[ m_uiBufOffset], uiBytesToCopy);
-		}
-
-		ui32BytesToRead -= (FLMUINT32)uiOffset;
-		m_uiAvailBytes -= uiBytesToCopy;
-		m_uiBufOffset += uiBytesToCopy;
-		pucOutBuf += uiBytesToCopy;
-
-		if( pui32BytesRead)
-		{
-			*pui32BytesRead += (FLMUINT32)uiBytesToCopy;
-		}
-	}
-
-Exit:
-
-	return( rc);
-}
-
-/*****************************************************************************
-Desc:	Reads ASCII base64 encoded binary from the source buffer.
-*****************************************************************************/
-RCODE F_Base64Encoder::read(
-	FLMBYTE *				psSource,
-	FLMUINT					uiSourceLen,
-	void *					pvBuffer,
-	FLMUINT32				ui32BytesToRead,
-	FLMUINT32 *				pui32BytesRead)
-{
-	RCODE			rc = FERR_OK;
-	FLMBYTE *	pucOutBuf = (FLMBYTE *)pvBuffer;
-	FLMUINT		uiBytesToCopy = 0;
-	FLMUINT		uiBytesToEncode = 0;
-	FLMBYTE		ucTriBuffer[ 3];
-	FLMBYTE *	pTmp = psSource;
-
-	if( *pui32BytesRead)
-	{
-		*pui32BytesRead = 0;
-	}
-
-	if( !psSource)
-	{
-		rc = RC_SET( FERR_EOF_HIT);
-		goto Exit;
-	}
-
-	while( ui32BytesToRead)
-	{
-		if( !m_uiAvailBytes)
-		{
-			// Reset the buffer
-			
-			f_memset( ucTriBuffer, 0, 3);
-
-			if( m_bInputExhausted)
-			{
-				rc = RC_SET( FERR_EOF_HIT);
-				goto Exit;
-			}
-
-			if (pTmp > psSource + uiSourceLen)
-			{
-				m_bInputExhausted = TRUE;
-			}
-			else if ((psSource + uiSourceLen) - pTmp >= 3)
-			{
-				f_memcpy( ucTriBuffer, pTmp, 3);
-				pTmp += 3;
-				uiBytesToEncode = 3;
-			}
-			else
-			{
-				uiBytesToEncode = (psSource + uiSourceLen) - pTmp;
-				f_memcpy( ucTriBuffer, pTmp, uiBytesToEncode);
-				pTmp += uiBytesToEncode;
-				m_bInputExhausted = TRUE;
-			}
-
-			if( uiBytesToEncode)
-			{
-				m_ucBuffer[ m_uiAvailBytes++] =
-					m_ucEncodeTable[ ucTriBuffer[ 0] >> 2];
-
-				m_ucBuffer[ m_uiAvailBytes++] =
-					m_ucEncodeTable[ ((ucTriBuffer[ 0] & 0x03) << 4) |
-					(ucTriBuffer[ 1] >> 4)];
-
-				if( uiBytesToEncode >= 2)
-				{
-					m_ucBuffer[ m_uiAvailBytes++] =
-						m_ucEncodeTable[ ((ucTriBuffer[ 1] & 0x0F) << 2) |
-						(ucTriBuffer[ 2] >> 6)];
-				}
-				else
-				{
-					m_ucBuffer[ m_uiAvailBytes++] = ASCII_EQUAL;
-				}
-
-				if( uiBytesToEncode == 3)
-				{
-					m_ucBuffer[ m_uiAvailBytes++] =
-						m_ucEncodeTable[ ucTriBuffer[ 2] & 0x3F];
-				}
-				else
-				{
-					m_ucBuffer[ m_uiAvailBytes++] = ASCII_EQUAL;
-				}
-
-				m_uiBase64Count += 4;
-			}
-
-			if( m_bLineBreaks)
-			{
-				if( (m_uiBase64Count % 72) == 0 ||
-					(m_bInputExhausted && !m_bPriorLineEnd))
-				{
-#if defined( FLM_OSX)
-					m_ucBuffer[ m_uiAvailBytes++] = ASCII_CR;
-#elif defined( FLM_UNIX)
-					m_ucBuffer[ m_uiAvailBytes++] = ASCII_NEWLINE;
-#else
-					m_ucBuffer[ m_uiAvailBytes++] = ASCII_CR;
-					m_ucBuffer[ m_uiAvailBytes++] = ASCII_NEWLINE;
-#endif
-					m_bPriorLineEnd = TRUE;
-				}
-				else
-				{
-					m_bPriorLineEnd = FALSE;
-				}
-			}
-
-			if( !m_uiAvailBytes)
-			{
-				rc = RC_SET( FERR_EOF_HIT);
-				goto Exit;
-			}
-		}
-
-		uiBytesToCopy = m_uiAvailBytes;
-
-		if( pucOutBuf != NULL)
-		{
-			f_memcpy( pucOutBuf, &m_ucBuffer[ 0], uiBytesToCopy);
-			pucOutBuf += uiBytesToCopy;
-		}
-
-		ui32BytesToRead -= (FLMUINT32)uiBytesToEncode;
-		m_uiAvailBytes -= uiBytesToCopy;
-
-		if( pui32BytesRead)
-		{
-			*pui32BytesRead += (FLMUINT32)uiBytesToCopy;
-		}
-	}
-
-Exit:
-
-	return( rc);
-}
-
 /****************************************************************************
 Desc: flmDecryptBuffer - assumes aes
 ****************************************************************************/
@@ -2559,7 +2256,7 @@ RCODE flmDecryptBuffer(
 	algorithm.parameter = parm;
 	algorithm.parameter->count = 1;
 	algorithm.parameter->parms[0].parmType = NICI_P_IV;
-	algorithm.parameter->parms[0].u.b.len = IV_SZ; /* 16-byte IV */
+	algorithm.parameter->parms[0].u.b.len = IV_SZ;
 	algorithm.parameter->parms[0].u.b.ptr = pucIV;
 
 	// Init encryption
@@ -2594,8 +2291,7 @@ Desc:
 ****************************************************************************/
 RCODE flmEncryptBuffer(
 	FLMBYTE *				pucBuffer,
-	FLMUINT *				puiBufLen
-	)
+	FLMUINT *				puiBufLen)
 {
 	RCODE							rc = FERR_OK;
 
@@ -2614,7 +2310,8 @@ RCODE flmEncryptBuffer(
 	FLMBYTE						oid_aes[] = {IDV_AES128CBC};
 	FLMBYTE						pucIV[ IV_SZ];
 
-	/* Create NICI Context */
+	// Create NICI Context
+	
 	if (CCS_CreateContext(0, &context) != 0)
 	{
 		rc = RC_SET( FERR_NICI_CONTEXT);
@@ -2657,12 +2354,13 @@ RCODE flmEncryptBuffer(
 	algorithm.parameter = parm;
 	algorithm.parameter->count = 1;
 	algorithm.parameter->parms[0].parmType = NICI_P_IV;
-	algorithm.parameter->parms[0].u.b.len = IV_SZ; /* 16-byte IV */
+	algorithm.parameter->parms[0].u.b.len = IV_SZ;
 	algorithm.parameter->parms[0].u.b.ptr = pucIV;
 
 	GetIV(pucIV, IV_SZ);
 
-	/* init encryption */
+	// Init encryption
+	
 	if (CCS_DataEncryptInit(context, &algorithm, serverKeyHdl) != 0)
 	{
 		rc = RC_SET( FERR_NICI_ENC_INIT_FAILED);
@@ -2719,64 +2417,15 @@ FSTATIC void GetIV(
 #endif
 
 /*****************************************************************************
-Desc:		Add a globally shared reference to this object.
+Desc:
 *****************************************************************************/
-FLMUINT F_CCS::AddRef()
+#if defined( FLM_USE_NICI) && !defined( FLM_UNIX)
+int CCSX_SetNewIV(
+	int				,	// MODULEID,
+	FLMUINT32		,	// hContext,
+	pnuint8			,	// IV,
+	nuint32)				// IVLen
 {
-	FLMUINT		uiRefCnt = 0;
-
-#ifdef ATOMIC_INCDEC_SUPPORT
-	uiRefCnt = (FLMUINT)ftkAtomicIncrement( &m_ui32RefCnt);
-#else
-
-	f_mutexLock( m_hMutex);
-	uiRefCnt = ++m_ui32RefCnt;
-	f_mutexUnlock( m_hMutex);
-
-#endif
-
-
-	return( uiRefCnt);
-}
-
-/*****************************************************************************
-Desc:		Removes a globally shared reference to this object.
-*****************************************************************************/
-FLMUINT F_CCS::Release()
-{
-	FLMUINT		uiRefCnt = 0;
-
-#ifdef ATOMIC_INCDEC_SUPPORT
-	uiRefCnt = (FLMUINT)ftkAtomicDecrement( &m_ui32RefCnt);
-#else
-
-	f_mutexLock( m_hMutex);
-	uiRefCnt = --m_ui32RefCnt;
-	f_mutexUnlock( m_hMutex);
-
-#endif
-
-
-	if( !uiRefCnt)
-	{
-		delete this;
-	}
-
-	return( uiRefCnt);
-}
-
-
-
-#ifdef FLM_USE_NICI
-#ifndef FLM_UNIX
-int	CCSX_SetNewIV(
-	int				,//MODULEID,
-	FLMUINT32		,//hContext,
-	pnuint8			,//IV,
-	nuint32			//IVLen
-	)
-{
-	return(NICI_E_FUNCTION_NOT_SUPPORTED);
+	return( NICI_E_FUNCTION_NOT_SUPPORTED);
 }
 #endif
-#endif
