@@ -42,7 +42,7 @@ FSTATIC RCODE flmCopyDb(
 	void *				UserData);
 
 FSTATIC RCODE flmCopyFile(
-	F_FileSystemImp *	pFileSystem,
+	IF_FileSystem *	pFileSystem,
 	FLMUINT				uiStartOffset,
 	FLMUINT				uiEndOffset,
 	DB_COPY_INFO *		pDbCopyInfo,
@@ -55,7 +55,7 @@ FSTATIC RCODE flmCopyFile(
 /*******************************************************************************
 Desc:	Copies a database, including roll-forward log files.
 *******************************************************************************/
-RCODE FlmDbCopy(
+FLMEXP RCODE FLMAPI FlmDbCopy(
 	const char *		pszSrcDbName,
 	const char *		pszSrcDataDir,
 	const char *		pszSrcRflDir,
@@ -79,6 +79,8 @@ RCODE FlmDbCopy(
 	{
 		goto Exit;
 	}
+	
+	gv_FlmSysData.pFileHdlCache->closeUnusedFiles();	
 
 	// Open the database so we can force a checkpoint.
 
@@ -157,30 +159,34 @@ FSTATIC RCODE flmCopyDb(
 {
 	RCODE						rc = FERR_OK;
 	DB_COPY_INFO			DbCopyInfo;
-	F_SuperFileHdl			SrcSFileHdl;
-	F_SuperFileHdl			DestSFileHdl;
+	F_SuperFileHdl *		pSrcSFileHdl = NULL;
+	F_SuperFileHdl *		pDestSFileHdl = NULL;
+	F_SuperFileClient *	pSrcSFileClient = NULL;
+	F_SuperFileClient *	pDestSFileClient = NULL;
 	FLMUINT					uiFileNumber;
 	FLMUINT					uiHighFileNumber;
 	FLMUINT					uiHighLogFileNumber;
-	FLMUINT					uiFileSize;
-	FFILE *					pFile;
+	FLMUINT64				ui64FileSize;
+	FFILE *					pFile = NULL;
 	FLMBOOL					bMutexLocked = FALSE;
-	F_FileHdlImp *			pLockFileHdl = NULL;
-	F_FileHdlImp *			pTmpFileHdl = NULL;
-	F_DirHdl *				pDirHdl = NULL;
+	IF_FileHdl *			pLockFileHdl = NULL;
+	IF_FileHdl *			pTmpFileHdl = NULL;
+	IF_DirHdl *				pDirHdl = NULL;
 	FLMBOOL					bFileLocked = FALSE;
 	FLMBOOL					bWriteLocked = FALSE;
-	ServerLockObject *	pWriteLockObj = NULL;
-	ServerLockObject *	pFileLockObj = NULL;
+	IF_LockObject *		pWriteLockObj = NULL;
+	IF_LockObject *		pFileLockObj = NULL;
 	COPIED_NAME *			pCopiedList = NULL;
 	FLMBOOL					bUsedFFile = FALSE;
 	FLMBYTE *				pucInMemLogHdr = NULL;
-	FLOCK_INFO				LockInfo;
+	eLockType				currLockType;
+	FLMUINT					uiLockThreadId;
 	char *					pszActualSrcRflPath = NULL;
 	char *					pszSrcPrefix = NULL;
 	char *					pszActualDestRflPath = NULL;
 	char *					pszDestPrefix = NULL;
 	FLMBOOL					bCreatedDestRflDir = FALSE;
+	F_SEM						hWaitSem = F_SEM_NULL;
 
 	f_memset( &DbCopyInfo, 0, sizeof( DbCopyInfo));
 
@@ -191,7 +197,14 @@ FSTATIC RCODE flmCopyDb(
 	{
 		goto Exit;
 	}
+	
+	// Allocate a semaphore
 
+	if( RC_BAD( rc = f_semCreate( &hWaitSem)))
+	{
+		goto Exit;
+	}
+	
 	// Allocate memory for paths we don't want to push onto the stack.
 
 	if (RC_BAD( rc = f_calloc( 
@@ -206,13 +219,30 @@ FSTATIC RCODE flmCopyDb(
 
 	// Set up the super file object for the source database.
 	// Must at least open the control file.
-
-	if (RC_BAD( rc = SrcSFileHdl.Setup( NULL, pszSrcDbName, pszSrcDataDir)))
+	
+	if( (pSrcSFileClient = f_new F_SuperFileClient) == NULL)
+	{
+		rc = RC_SET( FERR_MEM);
+		goto Exit;
+	}
+	
+	if( RC_BAD( rc = pSrcSFileClient->setup(
+		pszSrcDbName, pszSrcDataDir, uiDbVersion)))
 	{
 		goto Exit;
 	}
+	
+	if( (pSrcSFileHdl = f_new F_SuperFileHdl) == NULL)
+	{
+		rc = RC_SET( FERR_MEM);
+		goto Exit;
+	}
 
-	SrcSFileHdl.SetDbVersion( uiDbVersion);
+	if( RC_BAD( rc = pSrcSFileHdl->setup( pSrcSFileClient, 
+		gv_FlmSysData.pFileHdlCache, gv_FlmSysData.uiFileOpenFlags, 0)))
+	{
+		goto Exit;
+	}
 
 	// Lock the destination database, if not already locked.
 	// This is so we can overwrite it without necessarily
@@ -266,14 +296,15 @@ FSTATIC RCODE flmCopyDb(
 
 		// Lock the destination file object and transaction
 		// object, if not already locked.
-
-		pFile->pFileLockObj->GetLockInfo( (FLMINT)0, &LockInfo);
-		if ((LockInfo.eCurrLockType != FLM_LOCK_EXCLUSIVE) ||
-			 (LockInfo.uiThreadId != f_threadId()))
+		
+		pFile->pFileLockObj->getLockInfo( 0, &currLockType, &uiLockThreadId, NULL);
+		if (currLockType != FLM_LOCK_EXCLUSIVE || uiLockThreadId != f_threadId())
 		{
 			pFileLockObj = pFile->pFileLockObj;
 			pFileLockObj->AddRef();
-			if (RC_BAD( rc = pFileLockObj->Lock( TRUE, NULL, FALSE, TRUE, 15, 0)))
+			
+			if (RC_BAD( rc = pFileLockObj->lock( hWaitSem,
+				TRUE, FLM_NO_TIMEOUT, 0)))
 			{
 				goto Exit;
 			}
@@ -282,39 +313,51 @@ FSTATIC RCODE flmCopyDb(
 
 		// Lock the write object, if not already locked
 
-		pFile->pWriteLockObj->GetLockInfo( (FLMINT)0, &LockInfo);
-		if ((LockInfo.eCurrLockType != FLM_LOCK_EXCLUSIVE) ||
-			 (LockInfo.uiThreadId != (FLMUINT)f_threadId()))
+		pFile->pWriteLockObj->getLockInfo( 0, &currLockType, &uiLockThreadId, NULL);
+		if( currLockType != FLM_LOCK_EXCLUSIVE || 
+			 uiLockThreadId != f_threadId())
 		{
 			pWriteLockObj = pFile->pWriteLockObj;
 			pWriteLockObj->AddRef();
 
 			// Only contention here is with the checkpoint thread - wait
 			// forever until the checkpoint thread gives it up.
-
-			if (RC_BAD( rc = dbWriteLock( pFile)))
+			
+			if( RC_BAD( rc = pWriteLockObj->lock( hWaitSem, 
+				TRUE, FLM_NO_TIMEOUT, 0)))
 			{
 				goto Exit;
 			}
+
 			bWriteLocked = TRUE;
 		}
 	}
 
 	// Set up the super file object for the destination database.
-
-	if (RC_BAD( rc = DestSFileHdl.Setup( NULL, pszDestDbName,
-											pszDestDataDir)))
+	
+	if( (pDestSFileClient = f_new F_SuperFileClient) == NULL)
+	{
+		rc = RC_SET( FERR_MEM);
+		goto Exit;
+	}
+	
+	if( RC_BAD( rc = pDestSFileClient->setup( 
+		pszDestDbName, pszDestDataDir, uiDbVersion)))
 	{
 		goto Exit;
 	}
 
-	DestSFileHdl.SetDbVersion( uiDbVersion);
-
-	// Setup the ECache manager
-
-	if( pFile && pFile->pECacheMgr)
+	if( (pDestSFileHdl = f_new F_SuperFileHdl) == NULL)
 	{
-		DestSFileHdl.setECacheMgr( pFile->pECacheMgr);
+		rc = RC_SET( FERR_MEM);
+		goto Exit;
+	}
+	
+	if( RC_BAD( rc = pDestSFileHdl->setup( pDestSFileClient, 
+		gv_FlmSysData.pFileHdlCache, gv_FlmSysData.uiFileOpenFlags,
+		gv_FlmSysData.uiFileCreateFlags)))
+	{
+		goto Exit;
 	}
 
 	// See how many files we have and calculate the total size.
@@ -322,12 +365,12 @@ FSTATIC RCODE flmCopyDb(
 	uiHighFileNumber = 0;
 	for (;;)
 	{
-		if ((RC_BAD( rc = SrcSFileHdl.GetFileSize( 
-			uiHighFileNumber, &uiFileSize))) || !uiFileSize )
+		if( RC_BAD( rc = pSrcSFileHdl->getFileSize( 
+			uiHighFileNumber, &ui64FileSize)) || !ui64FileSize)
 		{
 			if (rc == FERR_IO_PATH_NOT_FOUND ||
 				 rc == FERR_IO_INVALID_PATH ||
-				 !uiFileSize)
+				 !ui64FileSize)
 			{
 				// If the control file doesn't exist, we will return
 				// path not found.
@@ -343,7 +386,7 @@ FSTATIC RCODE flmCopyDb(
 			goto Exit;
 		}
 
-		DbCopyInfo.ui64BytesToCopy += (FLMUINT64)uiFileSize;
+		DbCopyInfo.ui64BytesToCopy += ui64FileSize;
 		if (uiHighFileNumber == MAX_DATA_BLOCK_FILE_NUMBER( uiDbVersion))
 		{
 			break;
@@ -357,12 +400,12 @@ FSTATIC RCODE flmCopyDb(
 	uiHighLogFileNumber = FIRST_LOG_BLOCK_FILE_NUMBER( uiDbVersion);
 	for (;;)
 	{
-		if ((RC_BAD( rc = SrcSFileHdl.GetFileSize( 
-			uiHighLogFileNumber, &uiFileSize))) || !uiFileSize)
+		if ((RC_BAD( rc = pSrcSFileHdl->getFileSize( 
+			uiHighLogFileNumber, &ui64FileSize))) || !ui64FileSize)
 		{
 			if (rc == FERR_IO_PATH_NOT_FOUND ||
 				 rc == FERR_IO_INVALID_PATH ||
-				 !uiFileSize)
+				 !ui64FileSize)
 			{
 				if (uiHighLogFileNumber ==
 							FIRST_LOG_BLOCK_FILE_NUMBER( uiDbVersion))
@@ -379,7 +422,7 @@ FSTATIC RCODE flmCopyDb(
 			goto Exit;
 		}
 
-		DbCopyInfo.ui64BytesToCopy += (FLMUINT64)uiFileSize;
+		DbCopyInfo.ui64BytesToCopy += ui64FileSize;
 		if (uiHighLogFileNumber == MAX_LOG_BLOCK_FILE_NUMBER( uiDbVersion))
 		{
 			break;
@@ -389,7 +432,7 @@ FSTATIC RCODE flmCopyDb(
 
 	// Get the sizes of the roll-forward log files
 
-	if( uiDbVersion < FLM_VER_4_3)
+	if( uiDbVersion < FLM_FILE_FORMAT_VER_4_3)
 	{
 		// For pre-4.3 versions, only need to copy one RFL file.
 
@@ -399,10 +442,9 @@ FSTATIC RCODE flmCopyDb(
 			goto Exit;
 		}
 
-		if (RC_BAD( rc = gv_FlmSysData.pFileSystem->Open( 
-							pszActualSrcRflPath,
-							F_IO_RDWR | F_IO_SH_DENYNONE | F_IO_DIRECT,
-							(F_FileHdl **)&pTmpFileHdl)))
+		if( RC_BAD( rc = gv_FlmSysData.pFileSystem->openFile( 
+				pszActualSrcRflPath, gv_FlmSysData.uiFileOpenFlags,
+				&pTmpFileHdl)))
 		{
 			if (rc == FERR_IO_PATH_NOT_FOUND ||
 				 rc == FERR_IO_INVALID_PATH)
@@ -416,13 +458,13 @@ FSTATIC RCODE flmCopyDb(
 		}
 		else
 		{
-			if (RC_BAD( rc = pTmpFileHdl->Size( &uiFileSize)))
+			if (RC_BAD( rc = pTmpFileHdl->size( &ui64FileSize)))
 			{
 				goto Exit;
 			}
 
-			DbCopyInfo.ui64BytesToCopy += (FLMUINT64)uiFileSize;
-			pTmpFileHdl->Close();
+			DbCopyInfo.ui64BytesToCopy += ui64FileSize;
+			
 			pTmpFileHdl->Release();
 			pTmpFileHdl = NULL;
 		}
@@ -435,7 +477,7 @@ FSTATIC RCODE flmCopyDb(
 			goto Exit;
 		}
 
-		if (RC_BAD( rc = gv_FlmSysData.pFileSystem->OpenDir(
+		if (RC_BAD( rc = gv_FlmSysData.pFileSystem->openDir(
 									pszActualSrcRflPath, (char *)"*", &pDirHdl)))
 		{
 			goto Exit;
@@ -443,7 +485,7 @@ FSTATIC RCODE flmCopyDb(
 
 		for (;;)
 		{
-			if( RC_BAD( rc = pDirHdl->Next()))
+			if( RC_BAD( rc = pDirHdl->next()))
 			{
 				if (rc == FERR_IO_NO_MORE_FILES)
 				{
@@ -459,9 +501,9 @@ FSTATIC RCODE flmCopyDb(
 			// If the current file is an RFL file, increment ui64BytesToCopy
 
 			if( rflGetFileNum( uiDbVersion, pszSrcPrefix,
-				pDirHdl->CurrentItemName(), &uiFileNumber))
+				pDirHdl->currentItemName(), &uiFileNumber))
 			{
-				DbCopyInfo.ui64BytesToCopy += (FLMUINT64)pDirHdl->CurrentItemSize();
+				DbCopyInfo.ui64BytesToCopy += pDirHdl->currentItemSize();
 			}
 		}
 
@@ -471,8 +513,8 @@ FSTATIC RCODE flmCopyDb(
 
 	// Close all file handles in the source and destination
 
-	SrcSFileHdl.ReleaseFiles( TRUE);
-	DestSFileHdl.ReleaseFiles( TRUE);
+	pSrcSFileHdl->releaseFiles();
+	pDestSFileHdl->releaseFiles();
 
 	// Copy the database files.
 
@@ -481,19 +523,19 @@ FSTATIC RCODE flmCopyDb(
 
 		// Get the source file path and destination file path.
 
-		if( RC_BAD( rc = SrcSFileHdl.GetFilePath( 
+		if( RC_BAD( rc = pSrcSFileHdl->getFilePath( 
 			uiFileNumber, DbCopyInfo.szSrcFileName)))
 		{
 			goto Exit;
 		}
-		if( RC_BAD( rc = DestSFileHdl.GetFilePath( 
+		if( RC_BAD( rc = pDestSFileHdl->getFilePath( 
 			uiFileNumber, DbCopyInfo.szDestFileName)))
 		{
 			goto Exit;
 		}
 
-		// For file #0, don't copy first 2K - it will be set up to show
-		// maintenance in progress.  Then the first 2K will be copied
+		// For the control file, don't copy first 2K - it will be set up 
+		// to show maintenance in progress.  Then the first 2K will be copied
 		// later.
 
 		if (!uiFileNumber)
@@ -529,13 +571,13 @@ FSTATIC RCODE flmCopyDb(
 
 		// Get the source file path and destination file path.
 
-		if (RC_BAD( rc = SrcSFileHdl.GetFilePath( uiFileNumber,
+		if (RC_BAD( rc = pSrcSFileHdl->getFilePath( uiFileNumber,
 									DbCopyInfo.szSrcFileName)))
 		{
 			goto Exit;
 		}
 
-		if (RC_BAD( rc = DestSFileHdl.GetFilePath( uiFileNumber,	
+		if (RC_BAD( rc = pDestSFileHdl->getFilePath( uiFileNumber,	
 			DbCopyInfo.szDestFileName)))
 		{
 			goto Exit;
@@ -553,7 +595,7 @@ FSTATIC RCODE flmCopyDb(
 
 	// Copy the RFL files
 
-	if( uiDbVersion < FLM_VER_4_3)
+	if( uiDbVersion < FLM_FILE_FORMAT_VER_4_3)
 	{
 		// Get the source file path and the destination file path.
 
@@ -594,18 +636,19 @@ FSTATIC RCODE flmCopyDb(
 			goto Exit;
 		}
 
-		if( RC_OK( gv_FlmSysData.pFileSystem->Exists( pszActualDestRflPath)))
+		if( RC_OK( gv_FlmSysData.pFileSystem->doesFileExist( 
+			pszActualDestRflPath)))
 		{
-			if( gv_FlmSysData.pFileSystem->IsDir( pszActualDestRflPath))
+			if( gv_FlmSysData.pFileSystem->isDir( pszActualDestRflPath))
 			{
 				// Remove the existing directory and all files, etc.
 
-				(void)gv_FlmSysData.pFileSystem->RemoveDir( 
+				(void)gv_FlmSysData.pFileSystem->removeDir( 
 					pszActualDestRflPath, TRUE);
 			}
 			else
 			{
-				(void)gv_FlmSysData.pFileSystem->Delete( pszActualDestRflPath);
+				(void)gv_FlmSysData.pFileSystem->deleteFile( pszActualDestRflPath);
 			}
 		}
 
@@ -616,14 +659,14 @@ FSTATIC RCODE flmCopyDb(
 		// when we try to create the destination files (below), the FLAIM file
 		// file system code will try to create any necessary directories.
 
-		(void)gv_FlmSysData.pFileSystem->CreateDir( pszActualDestRflPath);
+		(void)gv_FlmSysData.pFileSystem->createDir( pszActualDestRflPath);
 		bCreatedDestRflDir = TRUE;
 
 		// Copy the RFL files.  NOTE:  We need to copy all of the RFL files
 		// in the source RFL directory so that they will be available
 		// when performing a database restore operation.
 
-		if (RC_BAD( rc = gv_FlmSysData.pFileSystem->OpenDir(
+		if (RC_BAD( rc = gv_FlmSysData.pFileSystem->openDir(
 									pszActualSrcRflPath, (char *)"*", &pDirHdl)))
 		{
 			goto Exit;
@@ -631,7 +674,7 @@ FSTATIC RCODE flmCopyDb(
 
 		for (;;)
 		{
-			if( RC_BAD( rc = pDirHdl->Next()))
+			if( RC_BAD( rc = pDirHdl->next()))
 			{
 				if (rc == FERR_IO_NO_MORE_FILES)
 				{
@@ -647,7 +690,7 @@ FSTATIC RCODE flmCopyDb(
 			// If the current file is an RFL file, copy it to the destination
 
 			if( rflGetFileNum( uiDbVersion, pszSrcPrefix,
-				pDirHdl->CurrentItemName(), &uiFileNumber))
+				pDirHdl->currentItemName(), &uiFileNumber))
 			{
 				// Get the source file path and the destination file path.
 
@@ -682,12 +725,12 @@ FSTATIC RCODE flmCopyDb(
 
 	// Do one final copy on the control file to copy just the first 2K
 
-	if (RC_BAD( rc = SrcSFileHdl.GetFilePath( 0, DbCopyInfo.szSrcFileName)))
+	if (RC_BAD( rc = pSrcSFileHdl->getFilePath( 0, DbCopyInfo.szSrcFileName)))
 	{
 		goto Exit;
 	}
 
-	if (RC_BAD( rc = DestSFileHdl.GetFilePath( 0, DbCopyInfo.szDestFileName)))
+	if (RC_BAD( rc = pDestSFileHdl->getFilePath( 0, DbCopyInfo.szDestFileName)))
 	{
 		goto Exit;
 	}
@@ -723,11 +766,13 @@ Exit:
 		bMutexLocked = FALSE;
 	}
 
-	/* Unlock the file, if it is locked. */
-
 	if (bWriteLocked)
 	{
-		dbWriteUnlock( pFile);
+		if( RC_BAD( rc = pWriteLockObj->unlock()))
+		{
+			goto Exit;
+		}
+		
 		bWriteLocked = FALSE;
 	}
 
@@ -735,11 +780,12 @@ Exit:
 	{
 		RCODE	rc3;
 
-		if (RC_BAD( rc3 = pFileLockObj->Unlock( TRUE, NULL)))
+		if (RC_BAD( rc3 = pFileLockObj->unlock()))
 		{
 			if (RC_OK( rc))
 				rc = rc3;
 		}
+		
 		bFileLocked = FALSE;
 	}
 
@@ -757,7 +803,6 @@ Exit:
 
 	if (pLockFileHdl)
 	{
-		(void)pLockFileHdl->Close();
 		pLockFileHdl->Release();
 		pLockFileHdl = NULL;
 	}
@@ -784,7 +829,7 @@ Exit:
 
 		if (RC_BAD( rc))
 		{
-			(void)gv_FlmSysData.pFileSystem->Delete( pCopiedList->szPath);
+			(void)gv_FlmSysData.pFileSystem->deleteFile( pCopiedList->szPath);
 		}
 
 		f_free( &pCopiedList);
@@ -793,13 +838,38 @@ Exit:
 
 	if( RC_BAD( rc) && bCreatedDestRflDir)
 	{
-		(void)gv_FlmSysData.pFileSystem->RemoveDir( pszActualDestRflPath);
+		(void)gv_FlmSysData.pFileSystem->removeDir( pszActualDestRflPath);
 	}
 
 	if( pszActualSrcRflPath)
 	{
 		f_free( &pszActualSrcRflPath);
 	}
+	
+	if( hWaitSem != F_SEM_NULL)
+	{
+		f_semDestroy( &hWaitSem);
+	}
+	
+	if( pSrcSFileHdl)
+	{
+		pSrcSFileHdl->Release();
+	}
+	
+	if( pSrcSFileClient)
+	{
+		pSrcSFileClient->Release();
+	}
+	
+	if( pDestSFileHdl)
+	{
+		pDestSFileHdl->Release();
+	}
+	
+	if( pDestSFileClient)
+	{
+		pDestSFileClient->Release();
+	}
 
 	return( rc);
 }
@@ -808,7 +878,7 @@ Exit:
 Desc:	Copy a file that is one of the files of the database.
 *****************************************************************************/
 FSTATIC RCODE flmCopyFile(
-	F_FileSystemImp *		pFileSystem,
+	IF_FileSystem *		pFileSystem,
 	FLMUINT					uiStartOffset,
 	FLMUINT					uiEndOffset,
 	DB_COPY_INFO *			pDbCopyInfo,
@@ -820,22 +890,22 @@ FSTATIC RCODE flmCopyFile(
 {
 	RCODE				rc = FERR_OK;
 	FLMBYTE *		pucBuffer = NULL;
-	F_FileHdlImp *	pSrcFileHdl = NULL;
-	F_FileHdlImp *	pDestFileHdl = NULL;
+	IF_FileHdl *	pSrcFileHdl = NULL;
+	IF_FileHdl *	pDestFileHdl = NULL;
 	FLMUINT			uiBufferSize = 32768;
 	FLMUINT			uiBytesToRead;
 	FLMUINT			uiBytesRead;
 	FLMUINT			uiBytesWritten;
 	FLMUINT			uiOffset;
-	FLMBYTE			ucLogHdr [LOG_HEADER_SIZE];
+	FLMBYTE *		pucLogHdr = NULL;
 	FLMUINT			uiNewChecksum;
 	FLMBOOL			bCreatedDestFile = FALSE;
 
 	// Open the source file.
 
-	if( RC_BAD( rc = gv_FlmSysData.pFileSystem->Open( pDbCopyInfo->szSrcFileName,
-		F_IO_RDWR | F_IO_SH_DENYNONE | F_IO_DIRECT, 
-		(F_FileHdl **)&pSrcFileHdl)))
+	if( RC_BAD( rc = gv_FlmSysData.pFileSystem->openFile( 
+		pDbCopyInfo->szSrcFileName, gv_FlmSysData.uiFileOpenFlags, 
+		&pSrcFileHdl)))
 	{
 		goto Exit;
 	}
@@ -843,9 +913,9 @@ FSTATIC RCODE flmCopyFile(
 	// First attempt to open the destination file.  If it does
 	// not exist, attempt to create it.
 
-	if (RC_BAD( rc = gv_FlmSysData.pFileSystem->Open( pDbCopyInfo->szDestFileName,
-							F_IO_RDWR | F_IO_SH_DENYNONE | F_IO_DIRECT, 
-							(F_FileHdl **)&pDestFileHdl)))
+	if (RC_BAD( rc = gv_FlmSysData.pFileSystem->openFile( 
+		pDbCopyInfo->szDestFileName, gv_FlmSysData.uiFileOpenFlags,
+		&pDestFileHdl)))
 	{
 		if (rc != FERR_IO_PATH_NOT_FOUND &&
 			 rc != FERR_IO_INVALID_PATH)
@@ -853,19 +923,25 @@ FSTATIC RCODE flmCopyFile(
 			goto Exit;
 		}
 
-		if( RC_BAD( rc = gv_FlmSysData.pFileSystem->Create( pDbCopyInfo->szDestFileName,
-								F_IO_RDWR | F_IO_EXCL | F_IO_SH_DENYNONE |
-								F_IO_CREATE_DIR | F_IO_DIRECT, 
-								(F_FileHdl **)&pDestFileHdl)))
+		if( RC_BAD( rc = gv_FlmSysData.pFileSystem->createFile( 
+			pDbCopyInfo->szDestFileName, gv_FlmSysData.uiFileCreateFlags, 
+			&pDestFileHdl)))
 		{
 			goto Exit;
 		}
 		bCreatedDestFile = TRUE;
 	}
 								
-	// Allocate a buffer for reading and writing.
+	// Allocate a buffer for reading and writing
 
-	if (RC_BAD( rc = f_alloc( uiBufferSize, &pucBuffer)))
+	if( RC_BAD( rc = f_allocAlignedBuffer( uiBufferSize, &pucBuffer)))
+	{
+		goto Exit;
+	}
+
+	// Allocate a buffer for the log header
+
+	if( RC_BAD( rc = f_allocAlignedBuffer( 2048, &pucLogHdr)))
 	{
 		goto Exit;
 	}
@@ -880,8 +956,7 @@ FSTATIC RCODE flmCopyFile(
 	{
 		// Read the first 2K of the source file.
 
-		if (RC_BAD( rc = pSrcFileHdl->SectorRead( 0L, 2048,
-									pucBuffer, &uiBytesRead)))
+		if (RC_BAD( rc = pSrcFileHdl->read( 0, 2048, pucBuffer, &uiBytesRead)))
 		{
 			if (rc == FERR_IO_END_OF_FILE)
 			{
@@ -897,44 +972,39 @@ FSTATIC RCODE flmCopyFile(
 
 		if (uiBytesRead < 2048)
 		{
-			f_memset( &pucBuffer [uiBytesRead], 0, (int)(2048 - uiBytesRead));
+			f_memset( &pucBuffer[ uiBytesRead], 0, (int)(2048 - uiBytesRead));
 		}
 
 		// Attempt to read the log header from the destination file.
 		// It is OK if we can't read it, because if we created the
 		// destination file, these bytes may not be present.
 
-		if ((bCreatedDestFile) ||
-			 (RC_BAD( pDestFileHdl->Read( 16L, LOG_HEADER_SIZE,
-											ucLogHdr, &uiBytesRead))))
+		if( bCreatedDestFile ||
+			 RC_BAD( pDestFileHdl->read( 0, 2048, pucLogHdr, &uiBytesRead)))
 		{
-			f_memset( ucLogHdr, 0, sizeof(ucLogHdr));
+			f_memset( pucLogHdr, 0, sizeof( 2048));
 		}
 
-		/*
-		Set the transaction ID to zero.  MUST ALSO SET THE TRANS ACTIVE FLAG
-		TO FALSE - OTHERWISE READERS WILL ATTEMPT TO DECREMENT THE
-		TRANSACTION ID AND WILL END UP WITH 0xFFFFFFFF - very bad!
-		We must use zero, because it is the only transaction ID that will not
-		appear on ANY block.
-		*/
+		// Set the transaction ID to zero.  MUST ALSO SET THE TRANS ACTIVE FLAG
+		// TO FALSE - OTHERWISE READERS WILL ATTEMPT TO DECREMENT THE
+		// TRANSACTION ID AND WILL END UP WITH 0xFFFFFFFF - very bad!
+		// We must use zero, because it is the only transaction ID that will not
+		// appear on ANY block.
 
-		UD2FBA( 0L, &ucLogHdr [LOG_CURR_TRANS_ID]);
+		UD2FBA( 0, &pucLogHdr[ 16 + LOG_CURR_TRANS_ID]);
 
-		/*
-		Recalculate the log header checksum so that readers will not get a
-		checksum error.
-		*/
+		// Recalculate the log header checksum so that readers will not get a
+		// checksum error.
 
-		uiNewChecksum = lgHdrCheckSum( ucLogHdr, FALSE);
-		UW2FBA( (FLMUINT16)uiNewChecksum, &ucLogHdr [LOG_HDR_CHECKSUM]);
-		f_memcpy( &pucBuffer [16], ucLogHdr, LOG_HEADER_SIZE);
+		uiNewChecksum = lgHdrCheckSum( &pucLogHdr[ 16], FALSE);
+		UW2FBA( (FLMUINT16)uiNewChecksum, &pucLogHdr[ 16 + LOG_HDR_CHECKSUM]);
+		f_memcpy( &pucBuffer[ 16], &pucLogHdr[ 16], LOG_HEADER_SIZE);
 
 		// Write this "special" first 2K into the destination file.
 		// The real first 2K from the source file will be copied in
 		// at a later time.
 
-		if (RC_BAD( rc = pDestFileHdl->Write( 0L, 2048, 
+		if (RC_BAD( rc = pDestFileHdl->write( 0, 2048, 
 			pucBuffer, &uiBytesWritten)))
 		{
 			goto Exit;
@@ -946,7 +1016,7 @@ FSTATIC RCODE flmCopyFile(
 
 		if (pucInMemLogHdr)
 		{
-			f_memcpy( pucInMemLogHdr, ucLogHdr, LOG_HEADER_SIZE);
+			f_memcpy( pucInMemLogHdr, &pucLogHdr[ 16], LOG_HEADER_SIZE);
 		}
 	}
 
@@ -963,7 +1033,7 @@ FSTATIC RCODE flmCopyFile(
 
 		// Read data from source file.
 
-		if (RC_BAD( rc = pSrcFileHdl->SectorRead( uiOffset, uiBytesToRead,
+		if (RC_BAD( rc = pSrcFileHdl->read( uiOffset, uiBytesToRead,
 									pucBuffer, &uiBytesRead)))
 		{
 			if (rc == FERR_IO_END_OF_FILE)
@@ -982,7 +1052,7 @@ FSTATIC RCODE flmCopyFile(
 
 		// Write data to destination file.
 
-		if (RC_BAD( rc = pDestFileHdl->Write( uiOffset,
+		if (RC_BAD( rc = pDestFileHdl->write( uiOffset,
 									uiBytesRead, pucBuffer, &uiBytesWritten)))
 		{
 			goto Exit;
@@ -996,7 +1066,7 @@ FSTATIC RCODE flmCopyFile(
 			 (uiOffset <= 16) &&
 			 (uiOffset + uiBytesWritten >= 16 + LOG_HEADER_SIZE))
 		{
-			f_memcpy( pucInMemLogHdr, &pucBuffer [16 - uiOffset],
+			f_memcpy( pucInMemLogHdr, &pucBuffer[ 16 - uiOffset],
 								LOG_HEADER_SIZE);
 		}
 
@@ -1020,7 +1090,9 @@ FSTATIC RCODE flmCopyFile(
 		// than we asked for.
 
 		if (uiOffset >= uiEndOffset || uiBytesRead < uiBytesToRead)
+		{
 			break;
+		}
 	}
 
 	// If we overwrote the destination file, as opposed to creating
@@ -1029,7 +1101,7 @@ FSTATIC RCODE flmCopyFile(
 
 	if (!bCreatedDestFile && bOkToTruncate)
 	{
-		if (RC_BAD( rc = pDestFileHdl->Truncate( uiOffset)))
+		if (RC_BAD( rc = pDestFileHdl->truncateFile( uiOffset)))
 		{
 			goto Exit;
 		}
@@ -1056,28 +1128,33 @@ FSTATIC RCODE flmCopyFile(
 
 Exit:
 
-	if (pucBuffer)
+	if( pucBuffer)
 	{
-		f_free( &pucBuffer);
+		f_freeAlignedBuffer( &pucBuffer);
 	}
 
-	if (pSrcFileHdl)
+	if( pucLogHdr)
+	{
+		f_freeAlignedBuffer( &pucLogHdr);
+	}
+
+	if( pSrcFileHdl)
 	{
 		pSrcFileHdl->Release();
 	}
 
-	if (pDestFileHdl)
+	if( pDestFileHdl)
 	{
-		pDestFileHdl->Flush();
+		pDestFileHdl->flush();
 		pDestFileHdl->Release();
 	}
 
 	// Attempt to delete the destination file if
 	// we didn't successfully copy it.
 
-	if (RC_BAD( rc))
+	if( RC_BAD( rc))
 	{
-		(void)pFileSystem->Delete( pDbCopyInfo->szDestFileName);
+		(void)pFileSystem->deleteFile( pDbCopyInfo->szDestFileName);
 	}
 
 	return( rc);
