@@ -28,153 +28,141 @@
 
 #include "flaim.h"
 
-#if defined( FLM_DEBUG) && !defined( FLM_HPUX)
-	#define f_new			new( __FILE__, __LINE__)
-#else
-	#define f_new			new
+#if defined( FLM_WIN)
+	// Conversion from XXX to YYY, possible loss of data
+	#pragma warning( disable : 4244) 
+
+	// Local variable XXX may be used without having been initialized
+	#pragma warning( disable : 4701)
+
+	// Function XXX not inlined
+	#pragma warning( disable : 4710) 
+
+	// Unreferenced inline function has been removed
+	#pragma warning (disable : 4514)
+#endif
+	
+#if defined( FLM_WATCOM_NLM)
+
+	// Disable "Warning! W549: col(XX) 'sizeof' operand contains
+	// compiler generated information"
+	
+	#pragma warning 549 9
 #endif
 
-#ifdef FLM_DEBUG
-	#define RC_SET( rc) \
-		flmMakeErr(rc, __FILE__, __LINE__)
-
-	RCODE	flmMakeErr(
-		RCODE				rc,
-		const char *	pszFile,
-		int				iLine);
-#else
-	#define RC_SET(rc)		(rc)
-#endif
-
-class FResultSet;
-class F_Thread;
 class HRequest;
 class F_Session;
 class F_SessionMgr;
-class F_XMLImport;
-class F_XMLExport;
 class F_HashTable;
-class F_FileHdlMgr;
-class F_FileSystemImp;
-class ServerLockManager;
-class F_ThreadMgr;
 class FCS_ISTM;
 class FCS_OSTM;
 class FCS_DIS;
 class FCS_DOS;
 class F_Rfl;
-class F_FileIdList;
-class F_IOBufferMgr;
-class F_IOBuffer;
-class ServerLockObject;
 class F_SuperFileHdl;
-class FlmECache;
-class F_FileHdlImp;
 class FlmBlobImp;
-class F_SlabManager;
-class F_FixedAlloc;
-class F_BufferAlloc;
 class F_CCS;
 
-typedef struct Kref_Entry *			KREF_ENTRY_p;
-typedef struct Kref_Cntrl *			KREF_CNTRL_p;
-typedef struct F_Event *				FEVENT_p;
-typedef struct FBucket *				FBUCKET_p;
-typedef struct Itt *						ITT_p;
-typedef struct Ixd *						IXD_p;
-typedef struct Ifd *						IFD_p;
-typedef struct Cdl *						CDL_p;
-typedef struct FDict *					FDICT_p;
-typedef struct FNotify *				FNOTIFY_p;
-typedef struct File_Hdr *				FILE_HDR_p;
-typedef struct Log_Hdr *				LOG_HDR_p;
-typedef struct FFile *					FFILE_p;
-typedef struct FDb *						FDB_p;
-typedef struct FlmBlob_Tag *			FBLOB_p;
-typedef struct FlmBlobInfo *			FBLOBINFO_p;
-typedef struct Din_State *				DIN_STATE_p;
-typedef struct Btsk *					BTSK_p;
-typedef struct SCache_Mgr *			SCACHE_MGR_p;
-typedef struct CP_Info *				CP_INFO_p;
-typedef struct RCache_Mgr_Tag *		RCACHE_MGR_p;
-typedef struct CS_Context *			CS_CONTEXT_p;
-typedef struct F_BkgndIx *				F_BKGND_IX_p;
-typedef struct QueryHdrTag *			QUERY_HDR_p;
-
-FLMUINT flmStrHashBucket(
-	const char *		pszStr,
-	FBUCKET_p			pHashTbl,
-	FLMUINT				uiNumBuckets);
-
-#include "ftk.h"
-#include "ftkmem.h"
-#include "ftknsem.h"
-#include "ftksem.h"
-#include "ftkwptxt.h"
-#include "ftkthrd.h"
 #include "fstructs.h"
-#include "fddpcode.h"
-#include "flist.h"
-#include "fmutxref.h"
-#include "ffilehdl.h"
+#include "fdict.h"
 #include "flmstat.h"
-#include "fbuff.h"
 #include "rfl.h"
-#include "fsrvlock.h"
 #include "filesys.h"
 #include "fquery.h"
 #include "fscursor.h"
-#include "flog.h"
-#include "frset.h"
 #include "flmimon.h"
-#include "fdir.h"
-#include "ffilesys.h"
 #include "flmstat.h"
 #include "fcs.h"
 #include "fsv.h"
-#include "fxml.h"
 #include "furl.h"
-#include "ecache.h"
-#include "fsuperfl.h"
-#include "f64bitfh.h"
-#include "fdynsset.h"
-#include "frestore.h"
-#include "fobjtrck.h"
-#include "ftrace.h"
-#include "gddiff.h"
-#include "flfixed.h"
 #include "f_nici.h"
 
 #include "fpackon.h"
 // IMPORTANT NOTE: No other include files should follow this one except
 // for fpackoff.h
 
-#if defined( FLM_NLM) && !defined( __MWERKS__)
-	// Turn off  "Warning! W007: col(80) "&array" may not produce intended result
-	#pragma warning 007 9
-	#pragma warning 731 9
-#endif
+// Bit patterns for codes in internal text type
 
-#if defined( FLM_NLM)
+#define ASCII_CHAR_CODE					0x00		// 0nnnnnnn
+#define ASCII_CHAR_MASK					0x80  	// 10000000
+#define CHAR_SET_CODE	 				0x80		// 10nnnnnn
+#define CHAR_SET_MASK	 				0xC0		// 11000000
+#define WHITE_SPACE_CODE				0xC0		// 110nnnnn
+#define WHITE_SPACE_MASK				0xE0		// 11100000
 
-	#define os_malloc(size) \
-		Alloc( (size), gv_lAllocRTag)
+// UNK_GT_255 is an outdated code not part of 3x or newer
 
-	void * nlm_realloc(
-		void	*	pMemory,
-		size_t	newSize);
+#define UNK_GT_255_CODE					0xE0		// 11100nnn
+#define UNK_GT_255_MASK					0xF8		// 11111000
+#define UNK_EQ_1_CODE	 				0xF0		// 11110nnn
+#define UNK_EQ_1_MASK	 				0xF8		// 11111000
 
-	#define os_realloc		nlm_realloc
+// UNK_LE_255 is an outdated code not part of 3x or newer
 
-	#define os_free			Free
+#define UNK_LE_255_CODE					0xF8		// 11111nnn
+#define UNK_LE_255_MASK					0xF8		// 11111000
+#define EXT_CHAR_CODE	 				0xE8		// 11101000
+#define OEM_CODE			 				0xE9		// 11101001
+#define UNICODE_CODE						0xEA		// 11101010
 
-#else
+// Text type defines
 
-	#define os_malloc			malloc
-	#define os_realloc		realloc
-	#define os_free			free
+#define WP60_TYPE							1
+#define NATIVE_TYPE						2
 
-#endif
+// Misc. character constants
+
+#define HARD_HYPHEN		 				3
+#define HARD_HYPHEN_EOL	 				4
+#define HARD_HYPHEN_EOP	 				5
+#define HARD_RETURN		 				7
+#define NATIVE_TAB		 				12
+#define NATIVE_LINEFEED	 				13
+#define UNICODE_UNCONVERTABLE_CHAR	0x03
+
+// Collation bits
+
+#define HAD_SUB_COLLATION				0x01		// Set if had sub-collating values-diacritics
+#define HAD_LOWER_CASE					0x02		// Set if you hit a lowercase character
+#define COMPOUND_MARKER					0x02		// Compound key marker between each piece
+#define END_COMPOUND_MARKER			0x01		// Last of all compound markers - for post
+#define NULL_KEY_MARKER					0x03
+#define COLL_FIRST_SUBSTRING			0x03		// First substring marker
+#define COLL_MARKER 						0x04		// Marks place of sub-collation
+#define SC_LOWER							0x00		// Only lowercase characters exist
+#define SC_MIXED							0x01		// Lower/uppercase flags follow in next byte
+#define SC_UPPER							0x02		// Only upper characters exist
+#define SC_SUB_COL						0x03		// Sub-collation follows (diacritics|extCh)
+#define UNK_UNICODE_CODE				0xFFFE	// Used for collation
+#define COLL_TRUNCATED					0x0C		// This key piece has been truncated from original
+#define MAX_COL_OPCODE					COLL_TRUNCATED
+
+// Numeric collation
+
+#define SIG_POS							0x80
+#define COLLATED_DIGIT_OFFSET			0x05
+#define COLLATED_NUM_EXP_BIAS 		64
+#define MIN_7BIT_EXP						0x08
+#define MAX_7BIT_EXP						0x78
+
+/****************************************************************************
+Desc:
+****************************************************************************/
+#define flmTextObjType(c) ( 										\
+	(((c & ASCII_CHAR_MASK) == ASCII_CHAR_CODE) 				\
+	 ? ASCII_CHAR_CODE 												\
+	 : (((c & WHITE_SPACE_MASK) == WHITE_SPACE_CODE) 		\
+			? WHITE_SPACE_CODE 										\
+			: (((c & UNK_EQ_1_MASK) == UNK_EQ_1_CODE) 		\
+				 ? UNK_EQ_1_CODE 										\
+				 : (((c & CHAR_SET_MASK) == CHAR_SET_CODE) 	\
+						 ? CHAR_SET_CODE 								\
+						 : c 												\
+					 ) 													\
+				) 															\
+		 ) 																\
+	) 																		\
+)
 
 /****************************************************************************
 										General FLAIM
@@ -182,18 +170,6 @@ FLMUINT flmStrHashBucket(
 This first section contains general FLAIM defines and macros
 ****************************************************************************/
 
-RCODE f_netwareStartup( void);
-
-void f_netwareShutdown( void);
-
-void f_memoryInit( void);
-
-void f_memoryCleanup( void);
-
-RCODE nssInitialize( void);
-
-void nssUninitialize( void);
-
 #define MIN_BLOCK_SIZE		4096
 #define MAX_BLOCK_SIZE		8192
 
@@ -243,10 +219,6 @@ This section contains prototypes, defines, ... that are used within FLAIM's
 GEDCOM code.
 ****************************************************************************/
 
-void GedSmartPoolInit(
-	POOL *			pPool,
-	POOL_STATS *	pPoolStats); 
-
 // Defines for 'nth' parmeter, GedSibGraft(), GedChildGraft()
 #define GED_LAST			32767          // last sib/child
 #define GED_FIRST       (-GED_LAST)    // first sib/child
@@ -258,15 +230,15 @@ void GedSmartPoolInit(
 #define GED_MAXTAGLEN   127            // maximum significant tag length
 
 RCODE GedToTree(
-	POOL *			pPool,
-	F_FileHdl *		pFileHdl,
+	F_Pool *			pPool,
+	IF_FileHdl *	pFileHdl,
 	char **			pBuf,
 	FLMUINT			uiBufSize,
 	NODE **			root,
 	F_NameTable *	pNameTable);
 
 void * GedAllocSpace(
-	POOL *			pPool,
+	F_Pool *			pPool,
 	NODE *			nd,
 	FLMUINT			uiValType,
 	FLMUINT			uiLen,
@@ -280,7 +252,7 @@ RCODE GedBinToText(
 	FLMUINT 	*		lenRV);
 
 NODE * GedNodeCopy(
-	POOL *			pPool,
+	F_Pool *			pPool,
 	NODE *			node,
 	NODE *			childList,
 	NODE *			sibList );
@@ -295,12 +267,6 @@ RCODE GedNumToText(
 	FLMBYTE *			txt,
 	FLMUINT 	*			txtLenRV);
 
-RCODE GedTextToBin(
-	const FLMBYTE *	txt,
-	FLMUINT				len,
-	FLMBYTE *			bin,
-	FLMUINT  *			lenRV);
-
 RCODE GedTextToNum(
 	const FLMBYTE *	txt,
 	FLMUINT				len,
@@ -314,7 +280,7 @@ void gedSetRecSource(
 	FLMUINT				uiDrn);
 
 RCODE gedCreateSourceNode(
-	POOL *				pPool,
+	F_Pool *				pPool,
 	FLMUINT  			uiFieldNum,
 	HFDB 					hDb,
 	FLMUINT				uiContainer,
@@ -334,7 +300,7 @@ NODE * GedClip(
 	NODE *      		self);
 
 NODE * GedCopy(
-	POOL *       		pPool,
+	F_Pool *       	pPool,
 	FLMUINT     		uiTreeCount,
 	NODE *      		oldTree);
 
@@ -371,6 +337,10 @@ RCODE GedGetINT(
 	NODE *      		node,
 	FLMINT *				piNumberRV);
 
+RCODE GedGetINT64(
+	NODE *      		node,
+	FLMINT64 *			pi64NumberRV);
+
 RCODE GedGetINT32(
 	NODE *      		node,
 	FLMINT32 *			pi32NumberRV);
@@ -383,6 +353,10 @@ RCODE GedGetUINT(
 	NODE *      		node,
 	FLMUINT *			puiNumberRV);
 
+RCODE GedGetUINT64(
+	NODE *      		node,
+	FLMUINT64 *			pui64NumberRV);
+
 RCODE GedGetUINT32(
 	NODE *      		node,
 	FLMUINT32 *			pui32NumberRV);
@@ -399,7 +373,7 @@ NODE * GedParent(
 	NODE *      		self);
 
 RCODE GedPutBINARY(
-	POOL *      		pPool,
+	F_Pool *      		pPool,
 	NODE *      		node,
 	const void *      pvData,
 	FLMUINT     		uiLength,
@@ -407,45 +381,59 @@ RCODE GedPutBINARY(
 	FLMUINT				uiEncSize = 0);
 
 RCODE GedPutRecId(
-	POOL *       		pPool,
+	F_Pool *       	pPool,
 	NODE **				ppNd,
 	FLMUINT     		uiRecId);
 
 RCODE GedPutRecPtr(
-	POOL *       		pPool,
+	F_Pool *       	pPool,
 	NODE *      		node,
 	FLMUINT     		uiDRN,
 	FLMUINT				uiEncId = 0,
 	FLMUINT				uiEncSize = 0);
 
 RCODE GedPutNATIVE(
-	POOL *       		pPool,
+	F_Pool *       	pPool,
 	NODE *      		node,
 	const char *   	pszNativeStr,
 	FLMUINT				uiEncId = 0,
 	FLMUINT				uiEncSize = 0);
 
 RCODE GedPutINT(
-	POOL *       		pPool,
+	F_Pool *       	pPool,
 	NODE *      		nd,
 	FLMINT	   		iNumber,
 	FLMUINT				uiEncId = 0,
 	FLMUINT				uiEncSize = 0);
 
 RCODE GedPutUINT(
-	POOL *       		pPool,
+	F_Pool *       	pPool,
 	NODE *      		nd,
 	FLMUINT				uiNumber,
 	FLMUINT				uiEncId = 0,
 	FLMUINT				uiEncSize = 0);
 
+RCODE GedPutUINT64(
+	F_Pool *       	pPool,
+	NODE *      		nd,
+	FLMUINT64			ui64Number,
+	FLMUINT				uiEncId = 0,
+	FLMUINT				uiEncSize = 0);
+
+RCODE GedPutINT64(
+	F_Pool *       	pPool,
+	NODE *      		nd,
+	FLMINT64				i64Number,
+	FLMUINT				uiEncId = 0,
+	FLMUINT				uiEncSize = 0);
+
 RCODE GedGetUNICODE(
 	NODE *      		node,
 	FLMUNICODE *		pUnicode,
 	FLMUINT *			puiBufferLen);
 
 RCODE GedPutUNICODE(
-	POOL *       			pPool,
+	F_Pool *       		pPool,
 	NODE *      			node,
 	const FLMUNICODE *	pUnicode,
 	FLMUINT					uiEncId = 0,
@@ -480,7 +468,7 @@ RCODE GedWalk(
 	void *      		xyz);
 
 NODE * GedNodeCreate(
-	POOL *       		pPool,
+	F_Pool *       	pPool,
 	FLMUINT     		uiTagNum,
 	FLMUINT     		uiId,
 	RCODE *				rcRV);
@@ -532,13 +520,19 @@ RCODE GedGetRecSource(
 	FLMUINT *   		puiContainer,
 	FLMUINT *   		puiRecId);
 
-#define FLM_MAX_NIB_CNT		11
-
 RCODE flmBcd2Num(
 	FLMUINT				uiValueType,
 	FLMUINT				uiValueLength,
-	const FLMBYTE *	pucValue,				
-	BCD_TYPE  *			bcd);
+	const FLMBYTE *	pucValue,
+	FLMUINT *			puiNum,
+	FLMBOOL *			pbNegFlag);
+
+RCODE flmBcd2Num64(
+	FLMUINT				uiValueType,
+	FLMUINT				uiValueLength,
+	const FLMBYTE *	pucValue,
+	FLMUINT64 *			pui64Num,
+	FLMBOOL *			pbNegFlag);
 
 /****************************************************************************
 Desc:		These functions are used to parse GEDCOM buffers/files. They 
@@ -556,7 +550,7 @@ FLMINT gedNextChar(
 
 FLMINT gedReadChar( 
 	 GED_STREAM *		pStream, 
-	 FLMUINT				uiFilePos);
+	 FLMUINT64			ui64FilePos);
 
 FLMUINT gedCopyTag( 
 	 GED_STREAM *		pStream, 
@@ -573,17 +567,17 @@ FLMINT gedCopyValue(
 #define KY_CONTEXT_LEN			3			// Length of each context index
 
 FINLINE RCODE KYFlushKeys(
-	FDB_p					pDb);
+	FDB *					pDb);
 
 RCODE KrefCntrlCheck(
 	FDB *					pDb);
 
 void KrefCntrlFree(
-	FDB_p					pDb);
+	FDB *					pDb);
 
 RCODE flmProcessRecFlds(
 	FDB *		  			pDb,
-	IXD_p					pIxd,
+	IXD *					pIxd,
 	FLMUINT				uiContainerNum,
 	FLMUINT  			uiDrn,
 	FlmRecord *			pRecord,
@@ -596,14 +590,14 @@ RCODE flmEncryptField(
 	FlmRecord *			pRecord,
 	void *				pvField,
 	FLMUINT				uiEncId,
-	POOL *				pPool);
+	F_Pool *				pPool);
 
 RCODE flmDecryptField(
 	FDICT *				pDict,
 	FlmRecord *			pRecord,
 	void *				pvField,
 	FLMUINT				uiEncId,
-	POOL *				pPool);
+	F_Pool *				pPool);
 
 FLMBOOL flmCheckIfdPath(
 	IFD *					pIfd,
@@ -615,9 +609,9 @@ FLMBOOL flmCheckIfdPath(
 
 RCODE KYAddToKrefTbl(
 	FDB *					pDb,
-	IXD_p					pIxd,
+	IXD *					pIxd,
 	FLMUINT				uiContainer,
-	IFD_p					pIfd,
+	IFD *					pIfd,
 	FLMUINT				uiAction,
 	FLMUINT				uiDrn,
 	FLMBOOL *			pbHadUniqueKeys,
@@ -640,15 +634,15 @@ RCODE KYKeysCommit(
 
 void KYGetIxAndCdlEntries(
 	FDB *					pDb,
-	IXD_p					pIxd,
-	IFD_p					pIfd,
+	IXD *					pIxd,
+	IFD *					pIfd,
 	FLMUINT * 			puiIxEntryRV,
 	FLMUINT * 			puiCdlEntryRV);
 
 RCODE KYCmpKeyAdd2Lst(
 	FDB *					pDb,
-	IXD_p					pIxd,
-	IFD_p					pIfd,
+	IXD *					pIxd,
+	IFD *					pIfd,
 	void *				pFld,
 	void *				pRootContext);
 
@@ -683,7 +677,7 @@ RCODE KYVerifyMatchingPaths(
 
 RCODE KYTreeToKey(
 	FDB *					pDb,
-	IXD_p 				pIxd,
+	IXD * 				pIxd,
 	FlmRecord *			pRecord,
 	FLMUINT				uiContainerNum,
 	FLMBYTE *			pKeyBuf,
@@ -739,7 +733,7 @@ FLMBOOL KYEachWordParse(
 #define CJK_CHR		0x0010			// CJK word chr
 
 RCODE flmBuildFromAndUntilKeys(
-	IXD_p       		pIxd,
+	IXD *       		pIxd,
 	QPREDICATE ** 		ppQPredicate,
 	FLMBYTE *			pFromKey,	
 	FLMUINT *			puiFromKeyLen,
@@ -792,7 +786,7 @@ void flmUnlockDbMutex(
 	f_mutexUnlock( (pDb)->hShareMutex);
 
 FLMUINT flmGetDbTransType(
-	FDB_p					pDb);
+	FDB *					pDb);
 
 #define flmGetDbTransType( pDb) \
 	((pDb)->uiTransType)
@@ -819,7 +813,7 @@ void fdbInitCS(
 	FDB *					pDb);
 
 RCODE	fdbInit(
-	FDB_p					pDb,
+	FDB *					pDb,
 	FLMUINT				uiTransType,
 	FLMUINT				uiFlags,
 	FLMUINT				uiAutoTrans,
@@ -835,7 +829,7 @@ RCODE	fdbInit(
 void fdbExit(
 	FDB *					pDb);
 
-#if defined( FLM_DEBUG) && (defined( FLM_WIN) || defined( FLM_NLM))
+#if defined( FLM_DEBUG)
 	void fdbUseCheck(
 		FDB *				pDb);
 
@@ -874,9 +868,9 @@ void flmLogError(
 	FLMINT				iLineNumber = 0);
 
 void flmLogMessage(
-	FlmLogMessageSeverity 	eMsgSeverity,
-	FlmColorType  				eForground,
-	FlmColorType  				eBackground,
+	eLogMessageSeverity 		eMsgSeverity,
+	eColorType  				eForground,
+	eColorType  				eBackground,
 	const char *				pszFormat,
 	...);
 
@@ -903,13 +897,13 @@ RCODE fdictGetIndex(
 	FLMBOOL				bInLimitedMode,
 	FLMUINT				uiIxdId,
 	LFILE **				ppLFileRV,
-	IXD_p * 				ppIxdRV,
+	IXD ** 				ppIxdRV,
 	FLMBOOL				bOfflineOk = FALSE);
 
 RCODE fdictGetNextIXD(
 	FDICT *				pDict,
 	FLMUINT				uiIxdId,
-	IXD_p  *				ppIxdRV);
+	IXD **				ppIxdRV);
 
 RCODE  fdictReadLFiles( 
 	FDB *					pDb,
@@ -936,7 +930,7 @@ RCODE flmSendCSOp(
 	CS_CONTEXT *		pCSContext,
 	FLMUINT				uiClass,
 	FLMUINT				uiOp,
-	FDB_p					pDb);
+	FDB *					pDb);
 
 RCODE flmUnicodeToAscii(
 	FLMUNICODE *		puzString);
@@ -946,14 +940,14 @@ LFILE_STATS * fdbGetLFileStatPtr(
 	LFILE *				pLFile);
 
 RCODE flmIxKeyOutput(
-	IXD_p					pIxd,
+	IXD *					pIxd,
 	FLMBYTE *			pucFromKey,
 	FLMUINT				uiKeyLen,
 	FlmRecord **		ppKeyRV,
 	FLMBOOL				bFullFldPaths);
 
 RCODE flmBuildKeyPaths(
-	IFD_p					pIfd,
+	IFD *					pIfd,
 	FLMUINT				uiFldNum,
 	FLMUINT				uiDataType,
 	FLMBOOL				bFullFldPaths,
@@ -994,40 +988,20 @@ RCODE BlkCheckSum(
 	FLMUINT				uiBlkAddress,
 	FLMUINT				uiBlkSize);
 
-#if defined( FLM_NLM) || defined( FLM_WIN)
-	void FastBlockCheckSum(
-		void *			pBlk,
-		FLMUINT *		puiChecksum,	
-		FLMUINT *		puiXORData,
-		FLMUINT			uiNumberOfBytes);
-	
-	void InitFastBlockCheckSum( void);
-#endif
-
-#ifdef FLM_WIN
-	RCODE MapWinErrorToFlaim(
-		DWORD				udErrCode,
-		RCODE				defaultRc);
-#endif
-
 #define	CHECKSUM_SET				0
 #define	CHECKSUM_CHECK				1
 
 #define IsInCSMode(pDb) \
-	(FLMBOOL)((((FDB_p)pDb)->pCSContext != NULL) \
+	(FLMBOOL)((((FDB *)pDb)->pCSContext != NULL) \
 											  ? (FLMBOOL)TRUE \
 											  : (FLMBOOL)FALSE)
 
 RCODE flmGetCSConnection(
 	const char *		pszUrlName,
-	CS_CONTEXT_p *		ppCSContextRV);
+	CS_CONTEXT **		ppCSContextRV);
 
 void flmCloseCSConnection(
-	CS_CONTEXT_p *		ppCSContext);
-
-RCODE flmAllocHashTbl(
-	FLMUINT        	uiHashTblSize,
-	FBUCKET_p  *		ppHashTblRV);
+	CS_CONTEXT **		ppCSContext);
 
 RCODE flmGetTmpDir(
 	char *				pszOutputTmpDir);
@@ -1038,43 +1012,32 @@ F_BKGND_IX * flmBackgroundIndexGet(
 	FLMBOOL				bMutexLocked,
 	FLMUINT *			puiThreadId = NULL);
 
-FLMUINT flmBinHashBucket(
-	void *				pBuf,
-	FLMUINT				uiBufLen,
-	FBUCKET_p			pHashTbl,
-	FLMUINT				uiNumBuckets);
-
-RCODE flmWaitNotifyReq(
-	F_MUTEX				hMutex,
-	FNOTIFY_p  *		ppNotifyListRV,
-	void *				UserData);
-
 RCODE flmLinkFileToBucket(
-	FFILE_p				pFile);
+	FFILE *				pFile);
 	
 void flmLinkFileToNUList(
-	FFILE_p				pFile,
+	FFILE *				pFile,
 	FLMBOOL				bQuickTimeout = FALSE);
 	
 void flmUnlinkFileFromNUList(
-	FFILE_p				pFile);
+	FFILE *				pFile);
 
 void flmCheckNUStructs(
 	FLMUINT				uiCurrTime);
 
 void flmUnlinkDict(
-	FDICT_p				pDict);
+	FDICT *				pDict);
 
 void flmReleaseDict(
 	FDB *					pDb,
 	FDICT *				pDict);
 
 RCODE flmLinkFdbToFile(
-	FDB_p					pDb,
-	FFILE_p				pFile);
+	FDB *					pDb,
+	FFILE *				pFile);
 	
 void flmUnlinkFdbFromFile(
-	FDB_p					pDb);
+	FDB *					pDb);
 	
 void flmDoEventCallback(
 	FEventCategory		eCategory,
@@ -1101,9 +1064,10 @@ RCODE flmRcaConfig(
 void flmRcaExit( void);
 
 void flmRcaFindRec(
+	FFILE *				pFile,
+	F_SEM					hWaitSem,
 	FLMUINT				uiContainer,
 	FLMUINT				uiDrn,
-	FFILE_p				pFile,
 	FLMUINT				uiVersionNeeded,
 	FLMBOOL				bDontPoisonCache,
 	FLMUINT *			puiNumLooks,
@@ -1117,7 +1081,7 @@ RCODE flmRcaRetrieveRec(
 	FLMUINT				uiContainer,
 	FLMUINT				uiDrn,
 	FLMBOOL				bOkToGetFromDisk,
-	BTSK_p				pStack,
+	BTSK *				pStack,
 	LFILE *				pLFile,
 	FlmRecord **		ppRecord);
 
@@ -1130,7 +1094,7 @@ void flmRcaReduceCache(
 
 RCODE flmRcaInsertRec(
 	FDB *					pDb,
-	FLMUINT				uiContainer,
+	LFILE *				pLFile,
 	FLMUINT				uiDrn,
 	FlmRecord *			pRecord);
 
@@ -1140,7 +1104,7 @@ RCODE flmRcaRemoveRec(
 	FLMUINT				uiDrn);
 
 void flmRcaFreeFileRecs(
-	FFILE_p				pFile);
+	FFILE *				pFile);
 
 void flmRcaAbortTrans(
 	FDB *					pDb);
@@ -1180,7 +1144,7 @@ RCODE flmDecrField(
 	FLMUINT				uiTagNum);
 
 RCODE gedAddField(
-	POOL *				pPool,
+	F_Pool *				pPool,
 	NODE *				pRecord,
 	FLMUINT				uiTagNum,
 	const void *		pvData,
@@ -1200,12 +1164,12 @@ RCODE flmOpenFile(
 	FLMUINT				uiOpenFlags,
 	FLMBOOL				bInternalOpen,
 	F_Restore *			pRestoreObj,
-	F_FileHdlImp *		pLockFileHdl,
+	IF_FileHdl *		pLockFileHdl,
 	const char *		pszPassword,
-	FDB_p *				ppDb);
+	FDB **				ppDb);
 
 RCODE flmCompleteOpenOrCreate(
-	FDB_p *				ppDb,
+	FDB **				ppDb,
 	RCODE					rc,
 	FLMBOOL				bNewFile,
 	FLMBOOL				bAllocatedFdb);
@@ -1220,25 +1184,25 @@ RCODE flmOpenOrCreateDbClientServer(
 	CREATE_OPTS *		pCreateOpts,
 	FLMBOOL				bOpening,
 	CS_CONTEXT *		pCSContext,
-	FDB_p *				ppDb);
+	FDB **				ppDb);
 
 RCODE flmAllocFdb(
-	FDB_p *				ppDb);
+	FDB **				ppDb);
 
 RCODE flmNewFileFinish(
 	FFILE *				pFile,
 	RCODE					OpenRc);
 
 RCODE flmUnregisterFile(
-	FFILE_p				pFile	);
+	FFILE *				pFile	);
 
 RCODE flmVerifyFileUse(
 	F_MUTEX				hMutex,
-	FFILE_p *			ppFileRV);
+	FFILE **				ppFileRV);
 
 RCODE flmCreateLckFile(
 	const char *		pszFilePath,
-	F_FileHdlImp **	ppLockFileHdlRV);
+	IF_FileHdl **		ppLockFileHdlRV);
 
 RCODE flmGetExclAccess(
 	const char *		pszFilePath,
@@ -1247,17 +1211,20 @@ RCODE flmGetExclAccess(
 RCODE flmFindFile(
 	const char *		pDbPath,
 	const char *		pszDataDir,
-	FFILE_p  *			ppFileRV);
+	FFILE **				ppFileRV);
 
 RCODE flmAllocFile(
 	const char *		pDbPath,
 	const char *		pszDataDir,
 	const char *		pszDbPassword,
-	FFILE_p *			ppFile);
+	FFILE **				ppFile);
 
 RCODE flmStartCPThread(
 	FFILE *				pFile);
 
+RCODE flmStartDbMonitorThread(
+	FFILE *				pFile);
+
 RCODE flmStartMaintThread(
 	FFILE *				pFile);
 
@@ -1273,9 +1240,9 @@ RCODE flmMaintFreeBlockChain(
 	FLMUINT64 *			pui64BlocksFreed);
 
 RCODE flmGetHdrInfo(
-	F_SuperFileHdl_p 	pSFileHdl,
-	FILE_HDR_p			pFileHdrRV,
-	LOG_HDR_p			pLogHdrRV,
+	IF_FileHdl * 		pFileHdl,
+	FILE_HDR *			pFileHdrRV,
+	LOG_HDR *			pLogHdrRV,
 	FLMBYTE *			pLogHdr);
 
 void flmGetCreateOpts(
@@ -1293,24 +1260,24 @@ FLMUINT flmAdjustBlkSize(
 
 void flmInitFileHdrInfo(
 	CREATE_OPTS *		pCreateOpts,
-	FILE_HDR_p			pFileHdr,
+	FILE_HDR *			pFileHdr,
 	FLMBYTE *			pFileHdrBuf);
 
 RCODE flmWriteVersionNum(
-	F_SuperFileHdl_p 	pSFileHdl,
+	F_SuperFileHdl * 	pSFileHdl,
 	FLMUINT				uiVersionNum);
 
 RCODE flmGetFileHdrInfo(
 	FLMBYTE *			pPrefixBuf,
 	FLMBYTE *			pFileHdrBuf,
-	FILE_HDR_p			pFileHdrRV);
+	FILE_HDR *			pFileHdrRV);
 
 RCODE flmReadAndVerifyHdrInfo(
 	DB_STATS *			pDbStats,
-	F_FileHdl *			pFileHdl,
+	IF_FileHdl *		pFileHdl,
 	FLMBYTE *			pReadBuf,
-	FILE_HDR_p			pFileHdrRV,
-	LOG_HDR_p			pLogHdrRV,
+	FILE_HDR *			pFileHdrRV,
+	LOG_HDR *			pLogHdrRV,
 	FLMBYTE *			pLogHdr);
 
 RCODE flmStartIndexBuild(
@@ -1334,7 +1301,7 @@ void flmIndexingAfterAbort(
 RCODE flmLFileIndexBuild(
 	FDB *					pDb,
 	LFILE *				pIxLFile,
-	IXD_p					pIxd,
+	IXD *					pIxd,
 	FLMBOOL				bDoInBackground,
 	FLMBOOL				bCreateSuspended,
 	FLMBOOL *			pbLogCompleteIndexSet);
@@ -1383,7 +1350,7 @@ RCODE flmIndexSetOfRecords(
 	void *				IxCallbackData,
 	FINDEX_STATUS *	pIndexStatus,
 	FLMBOOL *			pbHitEnd,
-	F_Thread *			pThread = NULL,
+	IF_Thread *			pThread = NULL,
 	FlmRecord *			pReusableRec = NULL);
 
 RCODE flmRemoveContainerKeys(
@@ -1430,35 +1397,35 @@ RCODE tokenGetUnicode(
 	FLMUINT *			puiValBufSize);
 
 RCODE expImpInit(
-	F_FileHdl *			pFileHdl,
+	IF_FileHdl *		pFileHdl,
 	FLMUINT				uiFlag,
-	EXP_IMP_INFO_p		pExpImpInfoRV);
+	EXP_IMP_INFO *		pExpImpInfoRV);
 
 	#define	EXPIMP_IMPORT_DICTIONARY		1
 	#define	EXPIMP_EXPORT_DICTIONARY		2
 	#define	EXPIMP_IMPORT_EXPORT_GEDCOM	3
 
 void expImpFree(
-	EXP_IMP_INFO_p		pExpImpInfo);
+	EXP_IMP_INFO *		pExpImpInfo);
 
 RCODE expFlush(
-	EXP_IMP_INFO_p		pExpImpInfo);
+	EXP_IMP_INFO *		pExpImpInfo);
 
 RCODE expImpSeek(
-	EXP_IMP_INFO_p		pExpImpInfo,
+	EXP_IMP_INFO *		pExpImpInfo,
 	FLMUINT				uiSeekPos);
 
 RCODE expWriteRec(
-	EXP_IMP_INFO_p		pExpImpInfo,
+	EXP_IMP_INFO *		pExpImpInfo,
 	FlmRecord *			pRecord,
 	FLMUINT				uiDrn);
 
 RCODE impReadRec(
-	EXP_IMP_INFO_p		pExpImpInfo,
+	EXP_IMP_INFO *		pExpImpInfo,
 	FlmRecord **		ppRecordRV);
 
 RCODE impFileIsExpImp(
-	F_FileHdl *			pFileHdl,
+	IF_FileHdl *		pFileHdl,
 	FLMBOOL *			pbFileIsExpImpRV);
 
 #ifdef FLM_DBG_LOG
@@ -1495,7 +1462,7 @@ RCODE impFileIsExpImp(
 	
 	void flmDbgLogExit( void);
 
-#endif	// #ifdef FLM_DBG_LOG
+#endif	// FLM_DBG_LOG
 
 void flmDeleteCCSRefs(
 	FDICT *		pDict);
@@ -1505,7 +1472,7 @@ Desc:	Extracts the information from a log header.
 ****************************************************************************/
 FINLINE void flmGetLogHdrInfo(
 	FLMBYTE *			pucLogHdr,
-	LOG_HDR_p			pLogHdr)
+	LOG_HDR *			pLogHdr)
 {
 	pLogHdr->uiCurrTransID =
 		(FLMUINT)FB2UD( &pucLogHdr [LOG_CURR_TRANS_ID]);
@@ -1536,8 +1503,8 @@ FINLINE FLMUINT getIxContainerPartLen(
 	{
 		IFD *	pLastIfd = &pIxd->pFirstIfd [pIxd->uiNumFlds];
 
-		return( (pIxd->uiLanguage < FIRST_DBCS_LANG ||
-					pIxd->uiLanguage > LAST_DBCS_LANG ||
+		return( (pIxd->uiLanguage < FLM_FIRST_DBCS_LANG ||
+					pIxd->uiLanguage > FLM_LAST_DBCS_LANG ||
 					IFD_GET_FIELD_TYPE( pLastIfd) != FLM_TEXT_TYPE ||
 					(pLastIfd->uiFlags & IFD_CONTEXT))
 					? 3
@@ -1732,7 +1699,7 @@ Desc:	Flush all keys in KREF table, if any.  This is called by routines
 		flushed to the index.
 ****************************************************************************/
 FINLINE RCODE KYFlushKeys(
-	FDB_p					pDb)
+	FDB *					pDb)
 {
 	RCODE	rc = FERR_OK;
 
@@ -1740,7 +1707,7 @@ FINLINE RCODE KYFlushKeys(
 	{
 		if (RC_OK( rc = KYKeysCommit( pDb, FALSE)))
 		{
-			pDb->KrefCntrl.pReset = GedPoolMark( pDb->KrefCntrl.pPool);
+			pDb->KrefCntrl.pReset = pDb->KrefCntrl.pPool->poolMark();
 		}
 	}
 	return( rc);
@@ -1845,19 +1812,21 @@ FINLINE RCODE flmCheckVersionNum(
 
 	switch( uiVersionNum)
 	{
-		case FLM_VER_3_0:
-		case FLM_VER_3_02:
-		case FLM_VER_3_10:
-		case FLM_VER_4_0:
-		case FLM_VER_4_3:
-		case FLM_VER_4_31:
-		case FLM_VER_4_50:
-		case FLM_VER_4_51:
-		case FLM_VER_4_52:
-		case FLM_VER_4_60:
+		case FLM_FILE_FORMAT_VER_3_0:
+		case FLM_FILE_FORMAT_VER_3_02:
+		case FLM_FILE_FORMAT_VER_3_10:
+		case FLM_FILE_FORMAT_VER_4_0:
+		case FLM_FILE_FORMAT_VER_4_3:
+		case FLM_FILE_FORMAT_VER_4_31:
+		case FLM_FILE_FORMAT_VER_4_50:
+		case FLM_FILE_FORMAT_VER_4_51:
+		case FLM_FILE_FORMAT_VER_4_52:
+		case FLM_FILE_FORMAT_VER_4_60:
+		case FLM_FILE_FORMAT_VER_4_61:
+		case FLM_FILE_FORMAT_VER_4_62:
 			break;
 		default:
-			if( uiVersionNum > FLM_CURRENT_VERSION_NUM)
+			if( uiVersionNum > FLM_CUR_FILE_FORMAT_VER_NUM)
 			{
 				rc = RC_SET( FERR_NEWER_FLAIM);
 			}
@@ -1971,7 +1940,7 @@ Exit:
 /****************************************************************************
 Desc:
 ****************************************************************************/
-typedef struct RSIxKeyTag
+typedef struct RS_IX_KEY
 {
 	FLMUINT			uiRSIxNum;
 		#define RS_KEY_OVERHEAD				6
@@ -1986,7 +1955,7 @@ typedef struct RSIxKeyTag
 /****************************************************************************
 Desc:
 ****************************************************************************/
-typedef struct
+typedef struct LF_HDR
 {
 	LFILE *			pLFile;
 	IXD *				pIxd;
@@ -1997,7 +1966,7 @@ typedef struct
 /****************************************************************************
 Desc:
 ****************************************************************************/
-typedef struct Db_Info
+typedef struct DB_INFO
 {
 	FILE_HDR						FileHdr;
 	LF_HDR *						pLogicalFiles;
@@ -2009,19 +1978,18 @@ typedef struct Db_Info
 	FLMBOOL						bDbInitialized;
 	F_SuperFileHdl *			pSFileHdl;
 	FLMUINT						uiFlags;
-	FLMUINT						uiMaxLockWait;
 	FLMBOOL						bStartedUpdateTrans;
 } DB_INFO;
 
 /****************************************************************************
 Desc:
 ****************************************************************************/
-typedef struct
+typedef struct IX_CHK_INFO
 {
-	POOL					pool;
+	F_Pool				pool;
 	FLMUINT				uiIxCount;
 	FLMUINT *			puiIxArray;
-	void *				pRSet;
+	IF_ResultSet *		pRSet;
 	FLMBOOL				bGetNextRSKey;
 	RS_IX_KEY			IxKey1;
 	RS_IX_KEY			IxKey2;
@@ -2032,10 +2000,12 @@ typedef struct
 	FLMUINT				uiRSIxRefCount;
 	FLMUINT				uiFlags;
 	DB_INFO *			pDbInfo;
-
 } IX_CHK_INFO;
 
-typedef struct State_Info
+/****************************************************************************
+Desc:
+****************************************************************************/
+typedef struct STATE_INFO
 {
 	FLMUINT				uiVersionNum;
 	FDB *					pDb;
@@ -2076,6 +2046,7 @@ typedef struct State_Info
 #define FLM_FOP_NEXT_DRN		7
 #define FLM_FOP_REC_INFO		8
 #define FLM_FOP_ENCRYPTED		9
+#define FLM_FOP_LARGE			10
 #define FLM_FOP_BAD				0xFF
 	FLMUINT				uiFieldLen;
 	FLMUINT				uiFieldProcessedLen;
@@ -2096,13 +2067,19 @@ typedef struct State_Info
 	FLMUINT				uiEncFieldLen;
 } STATE_INFO;
 
-typedef struct
+/****************************************************************************
+Desc:
+****************************************************************************/
+typedef struct HDR_INFO
 {
 	FILE_HDR				FileHdr;
 	LOG_HDR				LogHdr;
 } HDR_INFO;
 
-typedef struct Rebuild_State
+/****************************************************************************
+Desc:
+****************************************************************************/
+typedef struct REBUILD_STATE
 {
 	STATUS_HOOK			fnStatusFunc;
 	void *				AppArg;
@@ -2127,7 +2104,7 @@ RCODE flmCreateNewFile(
 	const char *		pszDictBuf,
 	CREATE_OPTS *		pCreateOpts,
 	FLMUINT				uiStartCheckpoint,
-	FDB_p *				ppDb,
+	FDB **				ppDb,
 	REBUILD_STATE *	pvRebuildState = NULL);
 
 RCODE flmDbRebuildFile(
@@ -2143,10 +2120,12 @@ eCorruptionType flmVerifyTextField(
 	FLMUINT				uiTextLen);
 
 eCorruptionType flmVerifyNumberField(
+	STATE_INFO *		pStateInfo,													
 	FLMBYTE *			pNumber,
 	FLMUINT				uiNumberLen);
 
 eCorruptionType flmVerifyField(
+	STATE_INFO *		pStateInfo,
 	FLMBYTE *			pField,
 	FLMUINT				uiFieldLen,
 	FLMUINT				uiFieldType);
@@ -2180,12 +2159,6 @@ eCorruptionType flmVerifyElement(
 eCorruptionType flmVerifyElmFOP(
 	STATE_INFO *		pStateInfo);
 
-RCODE flmVerifyIXRefs(
-	STATE_INFO *		pStateInfo,
-	IX_CHK_INFO *		pIxChkInfo,
-	FLMUINT				uiResetDrn,
-	eCorruptionType *	piElmCorruptionCode);
-
 void flmInitReadState(
 	STATE_INFO *		pStateInfo,
 	FLMBOOL *			pbStateInitialized,
@@ -2196,28 +2169,18 @@ void flmInitReadState(
 	FLMUINT				uiBlkType,
 	FLMBYTE *			pKeyBuffer);
 
-RCODE flmGetRecKeys(
-	FDB *					pDb,
-	IXD *					pIxd,		
-	FlmRecord *			pRecord,
-	FLMUINT				uiContainerNum,
-	FLMBOOL				bRemoveDups,
-	POOL *				pPool,
-	REC_KEY **			ppKeysRV);
+RCODE flmVerifyIXRefs(
+	STATE_INFO *		pStateInfo,
+	IX_CHK_INFO *		pIxChkInfo,
+	FLMUINT				uiResetDrn,
+	eCorruptionType *	piElmCorruptionCode);
 
 RCODE chkVerifyIXRSet(
 	STATE_INFO *		pStateInfo,
 	IX_CHK_INFO *		pIxChkInfo,
 	FLMUINT				uiIxRefDrn);
 
-RCODE chkGetNextRSKey(
-	IX_CHK_INFO *		pIxChkInfo);
-
-RCODE	chkResolveIXMissingKey(
-	STATE_INFO *		pStateInfo,
-	IX_CHK_INFO *		pIxChkInfo);
-
-RCODE	chkResolveNonUniqueKey(
+RCODE chkResolveNonUniqueKey(
 	STATE_INFO *		pStateInfo,
 	IX_CHK_INFO *		pIxChkInfo,
 	FLMUINT				uiIndex,
@@ -2225,51 +2188,14 @@ RCODE	chkResolveNonUniqueKey(
 	FLMUINT				uiKeyLen,
 	FLMUINT				uiDrn);
 
-RCODE chkRSInit(
-	const char *		pszIoPath,
-	void **				pRSetRV);
-
-RCODE chkRSFinalize(
-	IX_CHK_INFO *		pIxChkInfo,
-	FLMUINT64 *			pui64TotalEntries);
-
-FLMINT chkCompareKeySet(
-	FLMUINT				uiIxNum1,
-	FLMBYTE *			pData1,
-	FLMUINT				uiLength1,
-	FLMUINT				uiDrn1,
-	FLMUINT				uiIxNum2,
-	FLMBYTE *			pData2,
-	FLMUINT				uiLength2,
-	FLMUINT				uiDrn2);
-
-RCODE chkBlkRead(
-	DB_INFO *			pDbInfo,
-	FLMUINT				uiBlkAddress,
-	LFILE *				pLFile,
-	FLMBYTE **			ppBlk,
-	SCACHE **			ppSCache,
-	eCorruptionType *	peCorruption);
-
-RCODE chkVerifyBTrees(
-	DB_INFO *			pDbInfo,
-	POOL *				pPool,
-	FLMBOOL *			pbStartOverRV);
-
-RCODE chkReportError(
-	DB_INFO *			pDbInfo,
-	eCorruptionType	eCorruption,
-	eCorruptionLocale	eErrLocale,
-	FLMUINT				uiErrLfNumber,
-	FLMUINT				uiErrLfType,
-	FLMUINT				uiErrBTreeLevel,
-	FLMUINT				uiErrBlkAddress,
-	FLMUINT				uiErrParentBlkAddress,
-	FLMUINT				uiErrElmOffset,
-	FLMUINT				uiErrDrn,
-	FLMUINT				uiErrElmRecOffset,
-	FLMUINT				uiErrFieldNum,
-	FLMBYTE *			pBlk);
+RCODE flmGetRecKeys(
+	FDB *					pDb,
+	IXD *					pIxd,		
+	FlmRecord *			pRecord,
+	FLMUINT				uiContainerNum,
+	FLMBOOL				bRemoveDups,
+	F_Pool *				pPool,
+	REC_KEY **			ppKeysRV);
 
 #ifdef FLM_UNIX
 	RCODE MapErrnoToFlaimErr(
@@ -2281,22 +2207,12 @@ void flmGetCPInfo(
 	void *				pFile,
 	CHECKPOINT_INFO *	pCheckpointInfo);
 
-/****************************************************************************
-Desc:
-****************************************************************************/
-FINLINE RCODE chkCallProgFunc(
-	DB_INFO *			pDbInfo)
-{
-	if( (pDbInfo->fnStatusFunc) && (RC_OK( pDbInfo->LastStatusRc)))
-	{
-		pDbInfo->LastStatusRc = (*pDbInfo->fnStatusFunc)( FLM_CHECK_STATUS,
-												(void *)pDbInfo->pProgress,
-												(void *)0,
-												pDbInfo->pProgress->AppArg);
-	}
-	return( pDbInfo->LastStatusRc);
-}
-
+RCODE flmSetRflSizeThreshold(
+	HFDB					hDb,
+	FLMUINT				uiSizeThreshold,
+	FLMUINT				uiTimeInterval,
+	FLMUINT				uiSizeInterval);
+	
 /****************************************************************************
 Desc: 	The FlmBlobImp class provides support for database Binary Large 
 	`		Objects (BLOB). This class replaces the old 'C' FlmBlobXxx functions.
@@ -2398,7 +2314,7 @@ private:
 	FLMBYTE *				m_pHeaderBuf;
 	FLMUINT					m_uiHeaderLen;
 	HFDB						m_hDb;
-	F_FileHdlImp *			m_pFileHdl;
+	IF_FileHdl *			m_pFileHdl;
 	FLMUINT					m_uiStorageType;
 #define BLOB_REFERENCE_TYPE		0x04
 #define BLOB_OWNED_TYPE				0x10
@@ -2443,6 +2359,197 @@ FINLINE FLMUINT flmGetSigBits(
 	return( uiSigBits);
 }
 
+enum GRD_DifferenceType
+{
+	GRD_Inserted,
+	GRD_Deleted,
+	GRD_Modified,
+	GRD_DeletedSubtree
+};
+
+/****************************************************************************
+Desc:
+****************************************************************************/
+typedef struct 
+{
+	GRD_DifferenceType	type;
+	// The 'type' indicates the nature 
+	// of the difference, and can have one of the following values:
+	//		GRD_Inserted: a field was inserted.  In this case, the field only exists
+	//						in the 'after record.'  'pAfterField' points to the 
+	//						inserted field.  'pBeforeField' == NULL.
+	//		GRD_Deleted: a field was deleted.  In this case, the field only exists in
+	//						the 'before record'.  'pBeforeField' points to the 
+	//						deleted field.  'pAfterField' == NULL.
+	//		GRD_Modified: a field was modified.  In this case, 'pBeforeField' points 
+	//						to the field before it was modified, and 'pAfterField'
+	//						points to the field after it was modified.
+	//		GRD_DeletedSubtree: a sub-tree was deleted.  In this case, the sub-tree only exists in
+	//						the 'before record'.  'pBeforeField' points to the 
+	//						deleted sub-tree.  'pAfterField' == NULL
+
+	FLMUINT					uiAbsolutePosition; 
+	// 'uiAbsolutePosition' is the 1-based position where the difference occured.
+	// When using the list of differences generated by flmRecordDifference to
+	// undo changes, uiAbsolutePosition can be thought of as the 1-based position
+	// relative to the 'after record.'  In order for 'undo' to work correctly,
+	// the differences must be undone in reverse order.
+	//
+	// When using the list of differences to redo changes, uiAbsolutePosition
+	// can be thought of as the 1-based position relative to the 'before
+	// record.'  In order for 'redo' to work correctly, the differences must be
+	// redone in order.  Note that when a node is inserted or deleted, all
+	// subsequent nodes are, in essence, renumbered.
+
+	FlmRecord *				pBeforeRecord;
+	
+	FlmRecord *				pAfterRecord;
+	
+	void *					pvBeforeField;
+	// 'pvBeforeField' is a pointer to the field before the change.  
+	// There are situations where 'pBeforeField' will be NULL.  
+	// See a description of the 'type' for more details.
+															
+	void *					pvAfterField;		
+	// 'pvAfterField' is a pointer to the field after the change.  There are
+	// situations where 'pBeforeField' will be NULL.  See a description 
+	// of the 'type' for more details.
+}	GRD_DifferenceData;
+
+
+typedef void (* GRD_CallBackFunction)(			// Called for each difference found
+	GRD_DifferenceData & 	difference,			// Description of difference
+	void *						pCallBackData); 	// User-defined data
+
+void flmRecordDifference(
+	FlmRecord *					pBeforeRecord,
+	FlmRecord *					pAfterRecord,
+	GRD_CallBackFunction		pCallBackFunction,
+	void *						pvCallBackData);
+
+/****************************************************************************
+Desc:	The F_FSRestore class is used to read backup and RFL files from 
+		a disk file system.
+****************************************************************************/
+class F_FSRestore : public F_Restore
+{
+public:
+
+	F_FSRestore();
+	
+	virtual ~F_FSRestore();
+
+	RCODE setup(
+		const char *		pucDbPath,
+		const char *		pucBackupSetPath,
+		const char *		pucRflDir);
+
+	RCODE openBackupSet( void);
+
+	RCODE openIncFile(
+		FLMUINT				uiFileNum);
+
+	RCODE openRflFile(
+		FLMUINT			uiFileNum);
+
+	RCODE read(
+		FLMUINT			uiLength,
+		void *			pvBuffer,
+		FLMUINT *		puiBytesRead);
+
+	RCODE close( void);
+
+	FINLINE RCODE abortFile( void)
+	{
+		return( close());
+	}
+
+	FINLINE RCODE processUnknown(
+		F_UnknownStream *		pUnkStrm)
+	{
+		// Skip any unknown data in the RFL
+
+		return( pUnkStrm->close());
+	}
+
+	FINLINE RCODE status(
+		eRestoreStatusType	eStatusType,
+		FLMUINT					uiTransId,
+		void *					pvValue1,
+		void *					pvValue2,
+		void *					pvValue3,
+		eRestoreActionType *	peRestoreAction)
+	{
+		F_UNREFERENCED_PARM( eStatusType);
+		F_UNREFERENCED_PARM( uiTransId);
+		F_UNREFERENCED_PARM( pvValue1);
+		F_UNREFERENCED_PARM( pvValue2);
+		F_UNREFERENCED_PARM( pvValue3);
+
+		*peRestoreAction = RESTORE_ACTION_CONTINUE;
+		return( FERR_OK);
+	}
+
+private:
+
+	IF_FileHdl *			m_pFileHdl;
+	IF_MultiFileHdl *		m_pMultiFileHdl;
+	FLMUINT64				m_ui64Offset;
+	FLMUINT					m_uiDbVersion;
+	char						m_szDbPath[ F_PATH_MAX_SIZE];
+	char						m_szBackupSetPath[ F_PATH_MAX_SIZE];
+	char						m_szRflDir[ F_PATH_MAX_SIZE];
+	FLMBOOL					m_bSetupCalled;
+	FLMBOOL					m_bOpen;
+};
+
+/****************************************************************************
+Desc:
+*****************************************************************************/
+class FLMEXP F_SuperFileClient : public IF_SuperFileClient
+{
+public:
+
+	F_SuperFileClient();
+	
+	virtual ~F_SuperFileClient();
+	
+	RCODE setup(
+		const char *			pszCFileName,
+		const char *			pszDataDir,
+		FLMUINT					uiVersionNum);
+	
+	FLMUINT FLMAPI getFileNumber(
+		FLMUINT					uiBlockAddr);
+		
+	FLMUINT FLMAPI getFileOffset(
+		FLMUINT					uiBlockAddr);
+		
+	FLMUINT FLMAPI getBlockAddress(
+		FLMUINT					uiFileNumber,
+		FLMUINT					uiFileOffset);
+		
+	RCODE FLMAPI getFilePath(
+		FLMUINT					uiFileNumber,
+		char *					pszPath);
+		
+	FLMUINT64 FLMAPI getMaxFileSize( void);
+		
+	static void bldSuperFileExtension(
+		FLMUINT					uiVersionNum,
+		FLMUINT					uiFileNum,
+		char *					pszFileExtension);
+		
+private:
+
+	char *						m_pszCFileName;
+	char *						m_pszDataFileBaseName;
+	FLMUINT						m_uiVersionNum;
+	FLMUINT						m_uiExtOffset;
+	FLMUINT						m_uiDataExtOffset;
+	FLMUINT						m_uiDbVersion;
+};
+
 #include "fpackoff.h"
 
 #endif
