@@ -24,10 +24,10 @@
 
 #include "flaimsys.h"
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc:	Upgrades a database to the latest FLAIM version.
-*END************************************************************************/
-RCODE FlmDbUpgrade(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmDbUpgrade(
 	HFDB				hDb,		
 	FLMUINT			uiNewVersion,
 	STATUS_HOOK		fnStatusCallback,
@@ -67,7 +67,7 @@ RCODE FlmDbUpgrade(
 
 	if( (pDb->uiFlags & FDB_HAS_FILE_LOCK) == 0)
 	{
-		if( RC_BAD( rc = FlmDbLock( hDb, FLM_LOCK_EXCLUSIVE, 0, 15)))
+		if( RC_BAD( rc = FlmDbLock( hDb, FLM_LOCK_EXCLUSIVE, 0, FLM_NO_TIMEOUT)))
 		{
 			goto Exit;
 		}
@@ -90,13 +90,14 @@ RCODE FlmDbUpgrade(
 
 	switch (uiOldVersion)
 	{
-		case FLM_VER_3_0:
-		case FLM_VER_3_02:
-		case FLM_VER_4_0:
-		case FLM_VER_4_3:
-		case FLM_VER_4_31:
-		case FLM_VER_4_50:
-		case FLM_VER_4_51:
+		case FLM_FILE_FORMAT_VER_3_0:
+		case FLM_FILE_FORMAT_VER_3_02:
+		case FLM_FILE_FORMAT_VER_4_0:
+		case FLM_FILE_FORMAT_VER_4_3:
+		case FLM_FILE_FORMAT_VER_4_31:
+		case FLM_FILE_FORMAT_VER_4_50:
+		case FLM_FILE_FORMAT_VER_4_51:
+		case FLM_FILE_FORMAT_VER_4_60:
 
 			// Upgrades from these versions are supported.
 
@@ -108,12 +109,13 @@ RCODE FlmDbUpgrade(
 
 	switch (uiNewVersion)
 	{
-		case FLM_VER_4_3:
-		case FLM_VER_4_31:
-		case FLM_VER_4_50:
-		case FLM_VER_4_51:
-		case FLM_CURRENT_VERSION_NUM:
-
+		case FLM_FILE_FORMAT_VER_4_3:
+		case FLM_FILE_FORMAT_VER_4_31:
+		case FLM_FILE_FORMAT_VER_4_50:
+		case FLM_FILE_FORMAT_VER_4_51:
+		case FLM_FILE_FORMAT_VER_4_60:
+		case FLM_CUR_FILE_FORMAT_VER_NUM:
+		{
 			// Verify that we can do the upgrade
 
 			if (uiNewVersion < uiOldVersion)
@@ -123,15 +125,19 @@ RCODE FlmDbUpgrade(
 			}
 			else if (uiNewVersion == uiOldVersion)
 			{
-
 				// No need to do upgrade - already there.
 
 				goto Exit;
 			}
+			
 			break;
+		}
+		
 		default:
+		{
 			rc = RC_SET( FERR_UNALLOWED_UPGRADE);
 			goto Exit;
+		}
 	}
 
 	// Save the state of RFL logging flag.
@@ -209,13 +215,14 @@ RCODE FlmDbUpgrade(
 	// If version is prior to 4.0, upgrade the non-leaf blocks in
 	// container B-Trees.
 
-	if (uiOldVersion < FLM_VER_4_0 && uiNewVersion >= FLM_VER_4_0)
+	if (uiOldVersion < FLM_FILE_FORMAT_VER_4_0 && 
+		 uiNewVersion >= FLM_FILE_FORMAT_VER_4_0)
 	{
 
 		// Upgrade non-leaf blocks in container B-Trees.
 
-		if (RC_BAD( rc = FSVersionConversion40( pDb, FLM_CURRENT_VERSION_NUM,
-				fnStatusCallback, UserData)))
+		if (RC_BAD( rc = FSVersionConversion40( pDb, 
+				FLM_CUR_FILE_FORMAT_VER_NUM, fnStatusCallback, UserData)))
 		{
 			goto Exit;
 		}
@@ -223,7 +230,8 @@ RCODE FlmDbUpgrade(
 
 	// If versions is pre-4.3, upgrade log header and RFL stuff.
 
-	if (uiOldVersion < FLM_VER_4_3 && uiNewVersion >= FLM_VER_4_3)
+	if (uiOldVersion < FLM_FILE_FORMAT_VER_4_3 && 
+		 uiNewVersion >= FLM_FILE_FORMAT_VER_4_3)
 	{
 
 		// Initialize backup options
@@ -332,7 +340,8 @@ RCODE FlmDbUpgrade(
 		bExpandingFileCount = TRUE;
 	}
 
-	if (uiOldVersion < FLM_VER_4_31 && uiNewVersion >= FLM_VER_4_31)
+	if (uiOldVersion < FLM_FILE_FORMAT_VER_4_31 && 
+		 uiNewVersion >= FLM_FILE_FORMAT_VER_4_31)
 	{
 
 		// NOTE: We could really set the LOG_LAST_RFL_COMMIT_ID to anything,
@@ -346,7 +355,8 @@ RCODE FlmDbUpgrade(
 
 #ifdef FLM_USE_NICI
 
-	if (uiOldVersion < FLM_VER_4_60 && uiNewVersion >= FLM_VER_4_60)
+	if (uiOldVersion < FLM_FILE_FORMAT_VER_4_60 && 
+		 uiNewVersion >= FLM_FILE_FORMAT_VER_4_60)
 	{
 
 		if( RC_BAD( rc = flmCommitDbTrans( pDb, 0, TRUE)))
@@ -415,7 +425,8 @@ RCODE FlmDbUpgrade(
 	// Makes no sense before that because prior to 4.30 there was no
 	// possibility of keeping RFL files and doing a restore from them.
 
-	if (!(pDb->uiFlags & FDB_REPLAYING_RFL) && uiOldVersion >= FLM_VER_4_3)
+	if (!(pDb->uiFlags & FDB_REPLAYING_RFL) && 
+		 uiOldVersion >= FLM_FILE_FORMAT_VER_4_3)
 	{
 		// We would have turned logging OFF above, so we need to
 		// turn it back on here.
@@ -469,7 +480,8 @@ RCODE FlmDbUpgrade(
 	// Set up to use a new RFL directory.  Must do this only after
 	// setting FileHdr.uiVersionNum above.
 
-	if (uiOldVersion < FLM_VER_4_3 && uiNewVersion >= FLM_VER_4_3)
+	if (uiOldVersion < FLM_FILE_FORMAT_VER_4_3 &&
+		 uiNewVersion >= FLM_FILE_FORMAT_VER_4_3)
 	{
 		char	szTmpName [F_PATH_MAX_SIZE];
 
@@ -489,7 +501,7 @@ RCODE FlmDbUpgrade(
 		if (RC_OK( rc = rflGetFileName( uiOldVersion, pFile->pszDbPath,
 									NULL, uiRflFileNum, szTmpName)))
 		{
-			gv_FlmSysData.pFileSystem->Delete( szTmpName);
+			gv_FlmSysData.pFileSystem->deleteFile( szTmpName);
 		}
 	}
 
@@ -514,7 +526,7 @@ Exit:
 			// a couple of lines down.
 
 			(void) fdbInit( (FDB *)hDb, FLM_UPDATE_TRANS,
-				0, FLM_AUTO_TRANS, &bStartedTrans);
+				0, FLM_NO_TIMEOUT | FLM_AUTO_TRANS, &bStartedTrans);
 			(void) flmWriteVersionNum( pDb->pSFileHdl, uiOldVersion);
 			(void) fdbExit( pDb);
 		}
@@ -547,10 +559,10 @@ Exit:
 	return( rc );
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Adds an encryption key to the database.
-*END************************************************************************/
-RCODE FlmEnableEncryption(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmEnableEncryption(
 	HFDB				hDb,
 	FLMBYTE **		ppucWrappingKeyRV,
 	FLMUINT32 *		pui32KeyLen)
@@ -565,7 +577,7 @@ RCODE FlmEnableEncryption(
 	FLMUINT		uiFlags = FLM_GET_TRANS_FLAGS( FLM_UPDATE_TRANS);
 	FLMBOOL		bTransBegun = FALSE;
 
-	// We must will start our own transaction.  Then we will force a checkpoint
+	// We must start our own transaction.  Then we will force a checkpoint
 	// when we commit the transaction
 
 	if ( pDb->uiTransType != FLM_NO_TRANS)
@@ -675,11 +687,11 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc:	Changes the way the database key is stored in the database.  Either
 		it is encrypted using a password or it is wrapped in the server key.
-*END************************************************************************/
-RCODE FlmDbWrapKey(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmDbWrapKey(
 	HFDB					hDb,
 	const char *		pszPassword)
 {
@@ -701,7 +713,7 @@ RCODE FlmDbWrapKey(
 
 	if( (pDb->uiFlags & FDB_HAS_FILE_LOCK) == 0)
 	{
-		if( RC_BAD( rc = FlmDbLock( hDb, FLM_LOCK_EXCLUSIVE, 0, 15)))
+		if( RC_BAD( rc = FlmDbLock( hDb, FLM_LOCK_EXCLUSIVE, 0, FLM_NO_TIMEOUT)))
 		{
 			goto Exit;
 		}
