@@ -37,13 +37,12 @@ FSTATIC RCODE flmInitFileHdrs(
 	CREATE_OPTS *		pCreateOpts,
 	FLMUINT				uiBlkSize,
 	FLMUINT				uiTransID,
-	FLMBYTE *			pInitBuf,
-	FLMUINT				uiBufSize);
+	FLMBYTE *			pInitBuf);
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Creates a new FLAIM database.
-*END************************************************************************/
-RCODE FlmDbCreate(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmDbCreate(
 	const char *		pszDbFileName,
 	const char *		pszDataDir,
 	const char *		pszRflDir,
@@ -55,7 +54,10 @@ RCODE FlmDbCreate(
 	RCODE					rc = FERR_OK;
 	CS_CONTEXT *		pCSContext;
 
-	*phDbRV = HFDB_NULL;
+	if( phDbRV)
+	{
+		*phDbRV = HFDB_NULL;
+	}
 
 	if( !pszDbFileName || !pszDbFileName[ 0])
 	{
@@ -74,7 +76,7 @@ RCODE FlmDbCreate(
 
 		if( RC_BAD( rc = flmOpenOrCreateDbClientServer( pszDbFileName,
 			pszDataDir, pszRflDir, 0, pszDictFileName,
-			pszDictBuf, pCreateOpts, FALSE, pCSContext, (FDB_p *)phDbRV)))
+			pszDictBuf, pCreateOpts, FALSE, pCSContext, (FDB * *)phDbRV)))
 		{
 			(void)flmCloseCSConnection( &pCSContext);
 		}
@@ -83,7 +85,7 @@ RCODE FlmDbCreate(
 
 	if( RC_BAD( rc = flmCreateNewFile( pszDbFileName, pszDataDir, pszRflDir,
 		pszDictFileName, pszDictBuf, pCreateOpts,
-		0, (FDB_p *)phDbRV)))
+		0, (FDB * *)phDbRV)))
 	{
 		goto Exit;
 	}
@@ -97,25 +99,29 @@ Exit:
 Desc:	This routine creates a FLAIM file.
 ****************************************************************************/
 RCODE flmCreateNewFile(
-	const char *		pszFilePath,
-	const char *		pszDataDir,
-	const char *		pszRflDir,
-	const char *		pszDictFileName,
-	const char *		pszDictBuf,
-	CREATE_OPTS *		pCreateOpts,
-	FLMUINT				uiTransID,
-	FDB_p *				ppDb,
-	REBUILD_STATE *	pRebuildState)
+	const char *			pszFilePath,
+	const char *			pszDataDir,
+	const char *			pszRflDir,
+	const char *			pszDictFileName,
+	const char *			pszDictBuf,
+	CREATE_OPTS *			pCreateOpts,
+	FLMUINT					uiTransID,
+	FDB * *					ppDb,
+	REBUILD_STATE *		pRebuildState)
 {
-	RCODE				rc = FERR_OK;
-	FDB *				pDb;
-	FFILE *			pFile;
-	FLMBOOL			bFileCreated = FALSE;
-	FLMBOOL			bNewFile = FALSE;
-	FLMBOOL			bAllocatedFdb = FALSE;
-	FLMBOOL			bMutexLocked = FALSE;
+	RCODE						rc = FERR_OK;
+	FDB *						pDb = NULL;
+	FFILE *					pFile;
+	FLMUINT					uiMaxFileSize;
+	FLMBOOL					bFileCreated = FALSE;
+	FLMBOOL					bNewFile = FALSE;
+	FLMBOOL					bMutexLocked = FALSE;
+	F_SuperFileClient *	pSFileClient = NULL;
 
-	*ppDb = NULL;
+	if( ppDb)
+	{
+		*ppDb = NULL;
+	}
 
 #ifndef FLM_USE_NICI
 	F_UNREFERENCED_PARM( pRebuildState);
@@ -123,12 +129,10 @@ RCODE flmCreateNewFile(
 
 	// Allocate and initialize an FDB structure.
 
-	if (RC_BAD( rc = flmAllocFdb( ppDb)))
+	if (RC_BAD( rc = flmAllocFdb( &pDb)))
 	{
 		goto Exit;
 	}
-	pDb = *ppDb;
-	bAllocatedFdb = TRUE;
 
 	f_mutexLock( gv_FlmSysData.hShareMutex);
 	bMutexLocked = TRUE;
@@ -180,38 +184,34 @@ RCODE flmCreateNewFile(
 	}
 	bNewFile = TRUE;
 
+	if (pCreateOpts != NULL)
+	{
+		pFile->FileHdr.uiBlockSize = flmAdjustBlkSize( pCreateOpts->uiBlockSize);
+		pFile->FileHdr.uiVersionNum = pCreateOpts->uiVersionNum;
+	}
+	else
+	{
+		pFile->FileHdr.uiBlockSize = DEFAULT_BLKSIZ;
+		pFile->FileHdr.uiVersionNum = FLM_CUR_FILE_FORMAT_VER_NUM;
+	}
+
 	// Link the FDB to the file.
 
 	rc = flmLinkFdbToFile( pDb, pFile);
 	f_mutexUnlock( gv_FlmSysData.hShareMutex);
 	bMutexLocked = FALSE;
+
 	if (RC_BAD( rc))
 	{
 		goto Exit;
 	}
 
-	// If the file has not already been created, do so now.
-
-	// Determine what to set file block size to.
-
-	if (pCreateOpts != NULL)
-	{
-		pDb->pSFileHdl->SetBlockSize(
-			flmAdjustBlkSize( pCreateOpts->uiBlockSize));
-		pDb->pSFileHdl->SetDbVersion( pCreateOpts->uiVersionNum);
-	}
-	else
-	{
-		pDb->pSFileHdl->SetBlockSize( DEFAULT_BLKSIZ);
-		pDb->pSFileHdl->SetDbVersion( FLM_CURRENT_VERSION_NUM);
-	}
-
 #ifdef FLM_USE_NICI
 
 	// Create a new F_CCS object for the database wrapping key if the new
 	// database version is at least ver 4.60
 	
-	if (!pCreateOpts || pCreateOpts->uiVersionNum >= FLM_VER_4_60)
+	if (!pCreateOpts || pCreateOpts->uiVersionNum >= FLM_FILE_FORMAT_VER_4_60)
 	{
 		if ((pFile->pDbWrappingKey = f_new F_CCS) == NULL)
 		{
@@ -228,8 +228,8 @@ RCODE flmCreateNewFile(
 		// Only generate a key when this is not part of a rebuild operation or
 		// the original database version was less than 4.60
 		
-		if (!pRebuildState ||
-			 pRebuildState->pHdrInfo->FileHdr.uiVersionNum < FLM_VER_4_60)
+		if (!pRebuildState || pRebuildState->pHdrInfo->FileHdr.uiVersionNum <
+										FLM_FILE_FORMAT_VER_4_60)
 		{
 			if (RC_BAD( rc = pFile->pDbWrappingKey->generateWrappingKey()))
 			{
@@ -239,8 +239,8 @@ RCODE flmCreateNewFile(
 		else
 		{
 			if( RC_BAD( rc = pFile->pDbWrappingKey->setKeyFromStore(
-				&pRebuildState->pLogHdr[LOG_DATABASE_KEY],
-				FB2UW(&pRebuildState->pLogHdr[LOG_DATABASE_KEY_LEN]),
+				&pRebuildState->pLogHdr[ LOG_DATABASE_KEY],
+				FB2UW(&pRebuildState->pLogHdr[ LOG_DATABASE_KEY_LEN]),
 				NULL, NULL, FALSE)))
 			{
 				goto Exit;
@@ -250,15 +250,54 @@ RCODE flmCreateNewFile(
 	}
 #endif
 
-	if (RC_OK( gv_FlmSysData.pFileSystem->Exists( pszFilePath)))
+	if (RC_OK( gv_FlmSysData.pFileSystem->doesFileExist( pszFilePath)))
 	{
 		rc = RC_SET( FERR_FILE_EXISTS);
 		goto Exit;
 	}
 
+	// Allocate the super file object
+
+	flmAssert( !pDb->pSFileHdl);
+	flmAssert( pFile->FileHdr.uiVersionNum);
+
+	if( pFile->FileHdr.uiVersionNum >= FLM_FILE_FORMAT_VER_4_3)
+	{
+		uiMaxFileSize = gv_FlmSysData.uiMaxFileSize;
+	}
+	else
+	{
+		uiMaxFileSize = MAX_FILE_SIZE_VER40;
+	}
+	
+	if( (pDb->pSFileHdl = f_new F_SuperFileHdl) == NULL)
+	{
+		rc = RC_SET( FERR_MEM);
+		goto Exit;
+	}
+	
+	if( (pSFileClient = f_new F_SuperFileClient) == NULL)
+	{
+		rc = RC_SET( FERR_MEM);
+		goto Exit;
+	}
+	
+	if( RC_BAD( rc = pSFileClient->setup( 
+		pFile->pszDbPath, pFile->pszDataDir, pFile->FileHdr.uiVersionNum)))
+	{
+		goto Exit;
+	}
+	
+	if( RC_BAD( rc = pDb->pSFileHdl->setup( pSFileClient, 
+		gv_FlmSysData.pFileHdlCache, gv_FlmSysData.uiFileOpenFlags,
+		gv_FlmSysData.uiFileCreateFlags)))
+	{
+		goto Exit;
+	}
+
 	// Create the .db file.
 
-	if( RC_BAD( rc = pDb->pSFileHdl->CreateFile( 0)))
+	if( RC_BAD( rc = pDb->pSFileHdl->createFile( 0)))
 	{
 		goto Exit;
 	}
@@ -293,6 +332,13 @@ RCODE flmCreateNewFile(
 		goto Exit;
 	}
 
+	// Start the database monitor thread
+	
+	if( RC_BAD( rc = flmStartDbMonitorThread( pFile)))
+	{
+		goto Exit;
+	}
+
 Exit:
 
 	if( bMutexLocked)
@@ -300,16 +346,23 @@ Exit:
 		f_mutexUnlock( gv_FlmSysData.hShareMutex);
 	}
 
-	rc = flmCompleteOpenOrCreate( ppDb, rc, bNewFile, bAllocatedFdb);
+	rc = flmCompleteOpenOrCreate( &pDb, rc, bNewFile, pDb ? TRUE : FALSE);
 
 	if( RC_BAD( rc))
 	{
 		if( bFileCreated)
 		{
-			(void)gv_FlmSysData.pFileSystem->Delete( pszFilePath);
+			(void)gv_FlmSysData.pFileSystem->deleteFile( pszFilePath);
 		}
-
-		*ppDb = NULL;
+	}
+	else if( ppDb)
+	{
+		*ppDb = pDb;
+	}
+	
+	if( pSFileClient)
+	{
+		pSFileClient->Release();
 	}
 
 	return( rc);
@@ -346,26 +399,22 @@ FSTATIC RCODE flmInitNewFile(
 
 	// Initialize the database file header.
 
-	// Allocate a buffer to use - must be AT LEAST 2K.
-
 	uiBufSize = (FLMUINT)((uiBlkSize < 2048)
 								 ? (FLMUINT)2048
 								 : (FLMUINT)uiBlkSize);
-	if (RC_BAD( rc = f_calloc( uiBufSize, &pBuf)))
+
+	if( RC_BAD( rc = f_allocAlignedBuffer( uiBufSize, 
+		(void **)&pBuf)))
 	{
 		goto Exit;
 	}
 
 	if (RC_BAD( rc = flmInitFileHdrs( pDb, pCreateOpts, uiBlkSize, 
-		uiTransID, pBuf, uiBufSize)))
+		uiTransID, pBuf)))
 	{
 		goto Exit;
 	}
 
-	// Free the buffer before returning.
-
-	f_free( &pBuf);
-
 	// Allocate the pRfl object.  Could not do this until this point
 	// because we need to have the version number, block size, etc.
 	// setup in the pFile->FileHdr.
@@ -382,38 +431,10 @@ FSTATIC RCODE flmInitNewFile(
 		goto Exit;
 	}
 
-	// Setup the FFILE's ECache object
-
-	flmAssert( pFile->pECacheMgr == NULL);
-	if( gv_FlmSysData.bOkToUseESM)
-	{
-		if( (pFile->pECacheMgr = f_new FlmECache) == NULL)
-		{
-			rc = RC_SET( FERR_MEM);
-			goto Exit;
-		}
-
-		if( !pFile->pECacheMgr->setupECache(
-			pFile->FileHdr.uiBlockSize, pFile->uiMaxFileSize))
-		{
-			pFile->pECacheMgr->Release();
-			pFile->pECacheMgr = NULL;
-		}
-		else
-		{
-			// Normally the ECacheMgr is set in flmLinkFdbToFile but
-			// we have to handle this special case here.  When this
-			// FDB was linked there was no ECacheMgr.
-
-			flmAssert( pDb->pSFileHdl != NULL);
-			pDb->pSFileHdl->setECacheMgr( pFile->pECacheMgr);
-		}
-	}
-
 	// The following code starts an update transaction on the new DB so
 	// we can get it built.
 
-	if (RC_BAD( rc = flmBeginDbTrans( pDb, FLM_UPDATE_TRANS, 0)))
+	if (RC_BAD( rc = flmBeginDbTrans( pDb, FLM_UPDATE_TRANS, FLM_NO_TIMEOUT)))
 	{
 		goto Exit;
 	}
@@ -440,7 +461,7 @@ Exit:
 
 	if (pBuf)
 	{
-		f_free( &pBuf);
+		f_freeAlignedBuffer( (void **)&pBuf);
 	}
 
 	if (bTransStarted)
@@ -463,35 +484,33 @@ FSTATIC RCODE flmInitFileHdrs(
 	CREATE_OPTS *	pCreateOpts,
 	FLMUINT			uiBlkSize,
 	FLMUINT			uiTransID,
-	FLMBYTE *		pInitBuf,
-	FLMUINT			uiBufSize)
+	FLMBYTE *		pucInitBuf)
 {
 	RCODE				rc = FERR_OK;
-	FFILE_p			pFile = pDb->pFile;
+	FFILE *			pFile = pDb->pFile;
 	FLMBYTE *		pucLastCommittedLogHdr;
 	FLMUINT			uiLogicalEOF;
-	FLMUINT			uiWriteBytes;
 	FLMUINT			uiMinRflFileSize;
 	FLMUINT			uiMaxRflFileSize;
 	FLMBYTE *		pucBuf = NULL;
 
 	// Initialize the FFILE structure and first 2048 bytes/blk of the file.
 
-	f_memset( pInitBuf, 0, uiBlkSize);
+	f_memset( pucInitBuf, 0, uiBlkSize);
 	flmInitFileHdrInfo( pCreateOpts, &pFile->FileHdr,
-						 &pInitBuf [FLAIM_HEADER_START]);
+						 &pucInitBuf [FLAIM_HEADER_START]);
 	if (pCreateOpts)
 	{
-		flmSetFilePrefix( pInitBuf, pCreateOpts->uiAppMajorVer,
+		flmSetFilePrefix( pucInitBuf, pCreateOpts->uiAppMajorVer,
 								pCreateOpts->uiAppMinorVer);
 	}
 	else
 	{
-		flmSetFilePrefix( pInitBuf, 0, 0);
+		flmSetFilePrefix( pucInitBuf, 0, 0);
 	}
 
-	if (RC_BAD( rc = pDb->pSFileHdl->WriteHeader( 0L, uiBlkSize,
-				pInitBuf, &uiWriteBytes)))
+	if (RC_BAD( rc = pDb->pSFileHdl->writeBlock( 0L, uiBlkSize, 
+		pucInitBuf, NULL)))
 	{
 		goto Exit;
 	}
@@ -501,7 +520,7 @@ FSTATIC RCODE flmInitFileHdrs(
 	// Reserve only room for LFH in 4.3 and above.
 
 	uiLogicalEOF = (FLMUINT)((pFile->FileHdr.uiVersionNum >=
-									  FLM_VER_4_3)
+									  FLM_FILE_FORMAT_VER_4_3)
 									 ? (FLMUINT)pFile->FileHdr.uiFirstLFHBlkAddr +
 												uiBlkSize
 									 : (FLMUINT)pFile->FileHdr.uiFirstLFHBlkAddr +
@@ -546,7 +565,7 @@ FSTATIC RCODE flmInitFileHdrs(
 										  ? pCreateOpts->uiMinRflFileSize
 										  : (FLMUINT)DEFAULT_MIN_RFL_FILE_SIZE);
 
-	if( pDb->pFile->FileHdr.uiVersionNum >= FLM_VER_4_3)
+	if( pDb->pFile->FileHdr.uiVersionNum >= FLM_FILE_FORMAT_VER_4_3)
 	{
 		FLMUINT16	ui16Tmp;
 
@@ -624,7 +643,7 @@ FSTATIC RCODE flmInitFileHdrs(
 
 	// Create the first block file.
 
-	if (RC_BAD( rc = pDb->pSFileHdl->CreateFile( 1)))
+	if (RC_BAD( rc = pDb->pSFileHdl->createFile( 1)))
 	{
 		goto Exit;
 	}
@@ -653,14 +672,19 @@ FSTATIC RCODE flmInitFileHdrs(
 		{
 			goto Exit;
 		}
-		// IMPORTANT NOTE: pucBuf must be freed before going to Exit!!!
+		
+		// Verify that the field in the log header is long enough to
+		// hold the key.
+		
+		if( ui32KeyLen > FLM_MAX_DB_ENC_KEY_LEN)
+		{
+			f_free( &pucBuf);
+			rc = RC_SET_AND_ASSERT( FERR_BAD_ENC_KEY);
+			goto Exit;
+		}
 
-		// Assert that the field in the log header is long enough to
-		// hold the key.  Note: This test is only valid if the key
-		// field is the last one in the log header!!
-		flmAssert( ui32KeyLen <= (LOG_HEADER_SIZE - LOG_DATABASE_KEY));
-
-		UW2FBA(ui32KeyLen, &pucLastCommittedLogHdr[LOG_DATABASE_KEY_LEN]);
+		UW2FBA(ui32KeyLen, &pucLastCommittedLogHdr[ LOG_DATABASE_KEY_LEN]);
+		
 		f_memcpy( &pucLastCommittedLogHdr[LOG_DATABASE_KEY], pucBuf,
 					 ui32KeyLen);
 		f_free( &pucBuf);
@@ -682,48 +706,45 @@ FSTATIC RCODE flmInitFileHdrs(
 
 	// Initialize and output the first LFH block
 
-	f_memset( pInitBuf, 0, uiBlkSize); 
-	SET_BH_ADDR( pInitBuf, pFile->FileHdr.uiFirstLFHBlkAddr);
-	pInitBuf [BH_TYPE] = BHT_LFH_BLK;
-	UD2FBA( (FLMUINT32)BT_END,  &pInitBuf [BH_PREV_BLK]);
-	UD2FBA( (FLMUINT32)BT_END,  &pInitBuf [BH_NEXT_BLK]);
-	UW2FBA( (FLMUINT16)BH_OVHD, &pInitBuf [BH_ELM_END]);
-	UD2FBA( (FLMUINT32)uiTransID, &pInitBuf [BH_TRANS_ID]);
+	f_memset( pucInitBuf, 0, uiBlkSize); 
+	SET_BH_ADDR( pucInitBuf, (FLMUINT32)pFile->FileHdr.uiFirstLFHBlkAddr);
+	pucInitBuf [BH_TYPE] = BHT_LFH_BLK;
+	UD2FBA( (FLMUINT32)BT_END,  &pucInitBuf [BH_PREV_BLK]);
+	UD2FBA( (FLMUINT32)BT_END,  &pucInitBuf [BH_NEXT_BLK]);
+	UW2FBA( (FLMUINT16)BH_OVHD, &pucInitBuf [BH_ELM_END]);
+	UD2FBA( (FLMUINT32)uiTransID, &pucInitBuf [BH_TRANS_ID]);
 
-	BlkCheckSum( pInitBuf, CHECKSUM_SET,
+	BlkCheckSum( pucInitBuf, CHECKSUM_SET,
 						pFile->FileHdr.uiFirstLFHBlkAddr,
 							uiBlkSize);
 	pDb->pSFileHdl->setMaxAutoExtendSize( pFile->uiMaxFileSize);
 	pDb->pSFileHdl->setExtendSize( pFile->uiFileExtendSize);
-	if (RC_BAD( rc = pDb->pSFileHdl->WriteBlock(
-								pFile->FileHdr.uiFirstLFHBlkAddr,
-								uiBlkSize, pInitBuf, uiBufSize, NULL,
-								&uiWriteBytes)))
+	if( RC_BAD( rc = pDb->pSFileHdl->writeBlock(
+				pFile->FileHdr.uiFirstLFHBlkAddr, uiBlkSize, pucInitBuf, NULL)))
 	{
 		goto Exit;
 	}
 
 	// Initialize and output the first pcode block.
 
-	if (pFile->FileHdr.uiVersionNum < FLM_VER_4_3)
+	if (pFile->FileHdr.uiVersionNum < FLM_FILE_FORMAT_VER_4_3)
 	{
 		FLMUINT	uiPcodeAddr;
 
-		f_memset( pInitBuf, 0, uiBlkSize);
+		f_memset( pucInitBuf, 0, uiBlkSize);
 		uiPcodeAddr = pFile->FileHdr.uiFirstLFHBlkAddr + uiBlkSize;
-		SET_BH_ADDR( pInitBuf, uiPcodeAddr);
-		pInitBuf [BH_TYPE] = BHT_PCODE_BLK;
-		UD2FBA( (FLMUINT32)BT_END,  &pInitBuf [BH_PREV_BLK]);
-		UD2FBA( (FLMUINT32)BT_END,  &pInitBuf [BH_NEXT_BLK]);
-		UW2FBA( (FLMUINT16)BH_OVHD, &pInitBuf [BH_ELM_END]);
-		UD2FBA( (FLMUINT32)uiTransID, &pInitBuf [BH_TRANS_ID]);
+		SET_BH_ADDR( pucInitBuf, (FLMUINT32)uiPcodeAddr);
+		pucInitBuf [BH_TYPE] = BHT_PCODE_BLK;
+		UD2FBA( (FLMUINT32)BT_END,  &pucInitBuf [BH_PREV_BLK]);
+		UD2FBA( (FLMUINT32)BT_END,  &pucInitBuf [BH_NEXT_BLK]);
+		UW2FBA( (FLMUINT16)BH_OVHD, &pucInitBuf [BH_ELM_END]);
+		UD2FBA( (FLMUINT32)uiTransID, &pucInitBuf [BH_TRANS_ID]);
 
-		BlkCheckSum( pInitBuf, CHECKSUM_SET, uiPcodeAddr, uiBlkSize);
+		BlkCheckSum( pucInitBuf, CHECKSUM_SET, uiPcodeAddr, uiBlkSize);
 		pDb->pSFileHdl->setMaxAutoExtendSize( pFile->uiMaxFileSize);
 		pDb->pSFileHdl->setExtendSize( pFile->uiFileExtendSize);
-		if (RC_BAD( rc = pDb->pSFileHdl->WriteBlock( uiPcodeAddr,
-									uiBlkSize, pInitBuf, uiBufSize, NULL,
-									&uiWriteBytes)))
+		if (RC_BAD( rc = pDb->pSFileHdl->writeBlock( 
+			uiPcodeAddr, uiBlkSize, pucInitBuf, NULL)))
 		{
 			goto Exit;
 		}
@@ -731,7 +752,7 @@ FSTATIC RCODE flmInitFileHdrs(
 
 	// Force things to disk.
 
-	if (RC_BAD( rc = pDb->pSFileHdl->Flush()))
+	if (RC_BAD( rc = pDb->pSFileHdl->flush()))
 	{
 		goto Exit;
 	}
