@@ -24,35 +24,35 @@
 
 #include "flaimsys.h"
 
-FSTATIC RCODE flmBackgroundIndexBuildThrd(
-	F_Thread *		pThread);
+FSTATIC RCODE FLMAPI flmBackgroundIndexBuildThrd(
+	IF_Thread *			pThread);
 
 FSTATIC void stopBackgroundIndexThread(
-	FDB *				pDb,
-	FLMUINT			uiIndexNum,
-	FLMBOOL			bWait,
-	FLMBOOL *		pbStopped);
+	FDB *					pDb,
+	FLMUINT				uiIndexNum,
+	FLMBOOL				bWait,
+	FLMBOOL *			pbStopped);
 
 FSTATIC RCODE flmIndexStatusCS(
 	FDB *					pDb,
 	FLMUINT				uiIndexNum,
 	FINDEX_STATUS *	pIndexStatus);
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Return the status of the index.
-*END************************************************************************/
-RCODE FlmIndexStatus(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmIndexStatus(
 	HFDB					hDb,
 	FLMUINT				uiIndexNum,
 	FINDEX_STATUS *	pIndexStatus)
 {
-	RCODE				rc = FERR_OK;
-	FLMBOOL			bStartedAutoTrans = FALSE;
-	FLMUINT 			uiLastDrnIndexed;
-	FDB *				pDb = (FDB *)hDb;
-	F_BKGND_IX *	pBackgroundIx;
-	FLMBOOL			bSuspended;
-	FLMBOOL			bMutexLocked = FALSE;
+	RCODE					rc = FERR_OK;
+	FLMBOOL				bStartedAutoTrans = FALSE;
+	FLMUINT 				uiLastDrnIndexed;
+	FDB *					pDb = (FDB *)hDb;
+	F_BKGND_IX *		pBackgroundIx;
+	FLMBOOL				bSuspended;
+	FLMBOOL				bMutexLocked = FALSE;
 
 	flmAssert( pIndexStatus != NULL);
 
@@ -115,7 +115,7 @@ RCODE FlmIndexStatus(
 		// Sanity check
 
 #ifdef FLM_DEBUG
-		if( pDb->pFile->FileHdr.uiVersionNum >= FLM_VER_4_51 &&
+		if( pDb->pFile->FileHdr.uiVersionNum >= FLM_FILE_FORMAT_VER_4_51 &&
 			bSuspended != bTrackerIxSuspended)
 		{
 			flmAssert( 0);
@@ -145,11 +145,11 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Return the number of the next index.  Pass in zero to get the
 		 first index.
-*END************************************************************************/
-RCODE FlmIndexGetNext(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmIndexGetNext(
 	HFDB			hDb,
 	FLMUINT *	puiIndexNum)
 {
@@ -164,7 +164,7 @@ RCODE FlmIndexGetNext(
 	{
 		fdbInitCS( pDb);
 
-		CS_CONTEXT_p		pCSContext = pDb->pCSContext;
+		CS_CONTEXT *		pCSContext = pDb->pCSContext;
 		FCL_WIRE				Wire( pCSContext, pDb);
 
 		if( !pCSContext->bConnectionGood)
@@ -235,7 +235,7 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Suspend the selected index from doing any key updates on records
 		 that are equal or higher than the next record ID value
 		 in the container that the index references.  If the index is offline
@@ -244,15 +244,10 @@ Desc : Suspend the selected index from doing any key updates on records
 		 suspended FERR_OK will be returned.  A suspended index is not
 		 persistant if the database goes down.  
 Notes: An update transaction will be started if necessary.
-*END************************************************************************/
-RCODE 
-	// FERR_BAD_IX - There is not an index with the input index number.
-	// FERR_IO_FILE_LOCK_ERR
-	FlmIndexSuspend(
-		HFDB			hDb,
-			// [IN] Database handle.
-		FLMUINT		uiIndexNum)
-			// [IN] The number of the index to suspend.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmIndexSuspend(
+	HFDB			hDb,
+	FLMUINT		uiIndexNum)
 {
 	RCODE			rc = FERR_OK;
 	FDB *			pDb = (FDB *)hDb;
@@ -267,7 +262,7 @@ RCODE
 	{
 		fdbInitCS( pDb);
 
-		CS_CONTEXT_p		pCSContext = pDb->pCSContext;
+		CS_CONTEXT *		pCSContext = pDb->pCSContext;
 		FCL_WIRE				Wire( pCSContext, pDb);
 
 		if( !pCSContext->bConnectionGood)
@@ -312,7 +307,7 @@ Transmission_Error:
 	}
 
 	if (RC_BAD( rc = fdbInit( pDb, FLM_UPDATE_TRANS,
-		FDB_TRANS_GOING_OK, FLM_AUTO_TRANS | 15, &bStartedTrans)))
+		FDB_TRANS_GOING_OK, FLM_AUTO_TRANS | FLM_NO_TIMEOUT, &bStartedTrans)))
 	{
 		goto Exit;
 	}
@@ -453,20 +448,15 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : If the index was suspended, restart the background process that
 		 will get the index up to date so that it will eventually be online.
 		 Returns FERR_OK with no change if the index is already online.
 Notes: An update transaction will be started if necessary.
-*END************************************************************************/
-RCODE 
-	// FERR_BAD_IX - There is not an index with the input index number.
-	// FERR_IO_FILE_LOCK_ERR
-	FlmIndexResume(
-		HFDB			hDb,
-			// [IN] Database handle.
-		FLMUINT		uiIndexNum)
-			// [IN] Index to resume
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmIndexResume(
+	HFDB			hDb,
+	FLMUINT		uiIndexNum)
 {
 	RCODE				rc = FERR_OK;
 	FDB *				pDb = (FDB *)hDb;
@@ -480,7 +470,7 @@ RCODE
 	{
 		fdbInitCS( pDb);
 
-		CS_CONTEXT_p		pCSContext = pDb->pCSContext;
+		CS_CONTEXT *		pCSContext = pDb->pCSContext;
 		FCL_WIRE				Wire( pCSContext, pDb);
 
 		if( !pCSContext->bConnectionGood)
@@ -541,7 +531,7 @@ Transmission_Error:
 	}
 
 	if (RC_BAD( rc = fdbInit( pDb, FLM_UPDATE_TRANS,
-		FDB_TRANS_GOING_OK, FLM_AUTO_TRANS | 15, &bStartedTrans)))
+		FDB_TRANS_GOING_OK, FLM_AUTO_TRANS | FLM_NO_TIMEOUT, &bStartedTrans)))
 	{
 		goto Exit;
 	}
@@ -885,9 +875,9 @@ FSTATIC void stopBackgroundIndexThread(
 	FLMBOOL			bWait,
 	FLMBOOL *		pbStopped)
 {
-	F_BKGND_IX *		pBackgroundIx;
-	FLMUINT				uiThreadId;
-	FLMBOOL				bMutexLocked = FALSE;
+	F_BKGND_IX *	pBackgroundIx;
+	FLMUINT			uiThreadId;
+	FLMBOOL			bMutexLocked = FALSE;
 
 	if( pbStopped)
 	{
@@ -927,8 +917,9 @@ FSTATIC void stopBackgroundIndexThread(
 
 		// The thread may be waiting to start a transaction. 
 
-		gv_FlmSysData.pServerLockMgr->SignalLockWaiter( uiThreadId);
-
+		pDb->pFile->pFileLockObj->timeoutLockWaiter( uiThreadId);
+		pDb->pFile->pWriteLockObj->timeoutLockWaiter( uiThreadId);
+		
 		if( !bWait)
 		{
 			break;
@@ -1011,15 +1002,15 @@ Desc:		Thread that will build an index in the background.
 			freed at the conclusion of the routine.
 ****************************************************************************/
 RCODE flmStartIndexBuild(
-	FDB *			pDb,
-	FLMUINT		uiIndexNum)
+	FDB *				pDb,
+	FLMUINT			uiIndexNum)
 {
-	RCODE					rc = FERR_OK;
-	FLMUINT				uiGMT;
-	IXD *					pIxd;
-	F_BKGND_IX *		pBackgroundIx = NULL;
-	char					szThreadName[ F_PATH_MAX_SIZE];
-	char					szBaseName[ F_FILENAME_SIZE];
+	RCODE				rc = FERR_OK;
+	FLMUINT			uiGMT;
+	IXD *				pIxd;
+	F_BKGND_IX *	pBackgroundIx = NULL;
+	char				szThreadName[ F_PATH_MAX_SIZE];
+	char				szBaseName[ F_FILENAME_SIZE];
 
 	f_timeGetSeconds( &uiGMT );
 	
@@ -1063,8 +1054,8 @@ RCODE flmStartIndexBuild(
 
 	// Generate the thread name
 
-	if (RC_BAD( rc = f_pathReduce( pDb->pFile->pszDbPath,
-							szThreadName, szBaseName)))
+	if (RC_BAD( rc = gv_FlmSysData.pFileSystem->pathReduce( 
+		pDb->pFile->pszDbPath, szThreadName, szBaseName)))
 	{
 		goto Exit;
 	}
@@ -1077,7 +1068,7 @@ RCODE flmStartIndexBuild(
 
 	if( RC_BAD( rc = f_threadCreate( NULL,
 						flmBackgroundIndexBuildThrd, szThreadName,
-						FLM_BACKGROUND_INDEXING_THREAD_GROUP, uiIndexNum,
+						gv_uiBackIxThrdGroup, uiIndexNum,
 						(void *)pBackgroundIx, NULL, 24000)))
 	{
 		goto Exit;
@@ -1098,8 +1089,8 @@ Desc:		Thread that will build an index in the background.
 			Caller will create a pDb to use.  This pDb must be
 			freed at the conclusion of the routine.
 ****************************************************************************/
-FSTATIC RCODE flmBackgroundIndexBuildThrd(
-	F_Thread *		pThread)
+FSTATIC RCODE FLMAPI flmBackgroundIndexBuildThrd(
+	IF_Thread *			pThread)
 {
 	RCODE					rc = FERR_OK;
 	IXD *					pIxd;
@@ -1165,6 +1156,8 @@ Loop_Again:
 		goto Exit;
 	}
 
+	flmAssert( pDb->pSFileHdl);
+
 	bDbInitialized = TRUE;
 	if (RC_BAD( rc = fdbInit( pDb, FLM_NO_TRANS, 0, 0, &bStartedTrans)))
 	{
@@ -1191,9 +1184,9 @@ Loop_Again:
 		// Obtain the file lock
 
 		flmAssert( !(pDb->uiFlags & FDB_HAS_FILE_LOCK));
-		if( RC_BAD( rc = pDb->pFile->pFileLockObj->Lock( TRUE, pDb, FALSE, 
+		if( RC_BAD( rc = pDb->pFile->pFileLockObj->lock( pDb->hWaitSem,  
 			TRUE, FLM_NO_TIMEOUT, FLM_BACKGROUND_LOCK_PRIORITY,
-			pDb->pDbStats)))
+			pDb->pDbStats ? &pDb->pDbStats->LockStats : NULL)))
 		{
 			if( rc == FERR_IO_FILE_LOCK_ERR)
 			{
@@ -1224,7 +1217,7 @@ Loop_Again:
 			pDb->pFile->pFileLockObj->haveHigherPriorityWaiter( 
 				FLM_BACKGROUND_LOCK_PRIORITY))
 		{
-			if (RC_BAD( rc = pDb->pFile->pFileLockObj->Unlock( TRUE, pDb)))
+			if (RC_BAD( rc = pDb->pFile->pFileLockObj->unlock()))
 			{
 				iErrorLine = (FLMINT)__LINE__;
 				goto Exit;
@@ -1256,9 +1249,7 @@ Loop_Again:
 		}
 		bStartedTrans = TRUE;
 
-		if( RC_BAD( rc = fdictGetIndex(
-			pDb->pDict,
-			pDb->pFile->bInLimitedMode,
+		if( RC_BAD( rc = fdictGetIndex( pDb->pDict, pDb->pFile->bInLimitedMode,
 			uiIndexNum, NULL, &pIxd, TRUE)))
 		{
 			// Index may have been deleted by another transaction, or
@@ -1310,8 +1301,7 @@ Loop_Again:
 		}
 		else
 		{
-			if( uiFirstDrn == DRN_LAST_MARKER &&
-				 uiContainerNum == 0xFFFFFFFF)
+			if( uiFirstDrn == DRN_LAST_MARKER && uiContainerNum == 0xFFFFFFFF)
 			{
 				goto Exit;
 			}
@@ -1377,7 +1367,6 @@ Loop_Again:
 			goto Exit;
 		}
 
-		pThread->setThreadStatus( FLM_THREAD_STATUS_COMMITTING_TRANS);
 		if( pBackgroundIx->indexStatus.uiRecordsProcessed - 
 			savedIxStatus.uiRecordsProcessed)
 		{
@@ -1405,7 +1394,7 @@ Loop_Again:
 		{
 			// flmIndexSetOfRecords brought the index on-line
 
-			if( gv_FlmSysData.EventHdrs[ F_EVENT_UPDATES].pEventCBList)
+			if( gv_FlmSysData.UpdateEvents.pEventCBList)
 			{
 				flmDoEventCallback( F_EVENT_UPDATES, 
 						F_EVENT_INDEXING_COMPLETE, (void *)uiIndexNum, 
@@ -1431,7 +1420,7 @@ Exit:
 
 	if( pDb && pDb->uiFlags & FDB_HAS_FILE_LOCK)
 	{
-		(void)pDb->pFile->pFileLockObj->Unlock( TRUE, pDb);
+		(void)pDb->pFile->pFileLockObj->unlock();
 		pDb->uiFlags &= ~(FDB_HAS_FILE_LOCK | FDB_FILE_LOCK_IMPLICIT);
 	}
 
@@ -1460,7 +1449,7 @@ Exit:
 
 			// Sleep a half second and try again.
 
-			f_sleep( 500);
+			pThread->sleep( 500);
 			goto Loop_Again;
 		}
 		else
@@ -1489,7 +1478,7 @@ Exit:
 				break;
 			}
 
-			f_sleep( 1000);
+			pThread->sleep( 1000);
 		}
 	}
 
@@ -1522,10 +1511,10 @@ F_BKGND_IX * flmBackgroundIndexGet(
 	FLMBOOL			bMutexLocked,
 	FLMUINT *		puiThreadId)
 {
-	RCODE					rc = FERR_OK;
-	F_Thread *			pThread;
-	FLMUINT				uiThreadId;
-	F_BKGND_IX *		pBackgroundIx = NULL;
+	RCODE				rc = FERR_OK;
+	IF_Thread *		pThread;
+	FLMUINT			uiThreadId;
+	F_BKGND_IX *	pBackgroundIx = NULL;
 
 	if( !bMutexLocked)
 	{
@@ -1536,7 +1525,7 @@ F_BKGND_IX * flmBackgroundIndexGet(
 	for( ;;)
 	{
 		if( RC_BAD( rc = gv_FlmSysData.pThreadMgr->getNextGroupThread( 
-			&pThread, FLM_BACKGROUND_INDEXING_THREAD_GROUP, &uiThreadId)))
+			&pThread, gv_uiBackIxThrdGroup, &uiThreadId)))
 		{
 			if( rc == FERR_NOT_FOUND)
 			{
@@ -1580,16 +1569,16 @@ F_BKGND_IX * flmBackgroundIndexGet(
 
 /****************************************************************************
 Desc : Return the status of the index (via C/S protocol)
-*END************************************************************************/
+****************************************************************************/
 FSTATIC RCODE flmIndexStatusCS(
 	FDB *					pDb,
 	FLMUINT				uiIndexNum,
 	FINDEX_STATUS *	pIndexStatus)
 {
-	RCODE				rc = FERR_OK;
-	CS_CONTEXT *	pCSContext = pDb->pCSContext;
-	FCL_WIRE			Wire( pCSContext, pDb);
-	void *			pvMark = GedPoolMark( &pCSContext->pool);
+	RCODE					rc = FERR_OK;
+	CS_CONTEXT *		pCSContext = pDb->pCSContext;
+	FCL_WIRE				Wire( pCSContext, pDb);
+	void *				pvMark = pCSContext->pool.poolMark();
 
 	// Set the temporary pool
 
@@ -1632,7 +1621,7 @@ FSTATIC RCODE flmIndexStatusCS(
 
 Exit:
 
-	GedPoolReset( &pCSContext->pool, pvMark);
+	pCSContext->pool.poolReset( pvMark);
 	return( rc);
 
 Transmission_Error:
