@@ -696,7 +696,7 @@ Exit:
 /****************************************************************************
 Desc:	This routine frees the memory associated with a FLM_STAT structure.
 ****************************************************************************/
-void FlmFreeStats(
+FLMEXP void FLMAPI FlmFreeStats(
 	FLM_STATS *	pStats
 	)
 {
@@ -803,37 +803,55 @@ FSTATIC RCODE flmUpdateDbStats(
 
 	flmUpdateRTransStats( &pDestDb->ReadTransStats,
 								 &pSrcDb->ReadTransStats);
+								 
 	flmUpdateUTransStats( &pDestDb->UpdateTransStats,
 								 &pSrcDb->UpdateTransStats);
+								 
 	pDestDb->bHaveStats = TRUE;
 	pDestDb->ui64NumCursors += pSrcDb->ui64NumCursors;
 	pDestDb->ui64NumCursorReads += pSrcDb->ui64NumCursorReads;
+	
 	flmUpdateCountTimeStats( &pDestDb->RecordAdds,
-		&pSrcDb->RecordAdds);
+									 &pSrcDb->RecordAdds);
+									 
 	flmUpdateCountTimeStats( &pDestDb->RecordDeletes,
-		&pSrcDb->RecordDeletes);
+									 &pSrcDb->RecordDeletes);
+									 
 	flmUpdateCountTimeStats( &pDestDb->RecordModifies,
-		&pSrcDb->RecordModifies);
+									 &pSrcDb->RecordModifies);
+									 
 	pDestDb->ui64NumRecordReads += pSrcDb->ui64NumRecordReads;
+	
 	flmUpdateBlockIOStats( &pDestDb->LFHBlockStats,
-								&pSrcDb->LFHBlockStats);
+								  &pSrcDb->LFHBlockStats);
+								  
 	flmUpdateBlockIOStats( &pDestDb->AvailBlockStats,
-								&pSrcDb->AvailBlockStats);
+								  &pSrcDb->AvailBlockStats);
+								  
 	flmUpdateDiskIOStats( &pDestDb->LogHdrWrites,
-									 &pSrcDb->LogHdrWrites);
+								 &pSrcDb->LogHdrWrites);
+								 
 	flmUpdateDiskIOStats( &pDestDb->LogBlockWrites,
-									 &pSrcDb->LogBlockWrites);
+								 &pSrcDb->LogBlockWrites);
+								 
 	flmUpdateDiskIOStats( &pDestDb->LogBlockRestores,
-									 &pSrcDb->LogBlockRestores);
+								 &pSrcDb->LogBlockRestores);
+								 
 	flmUpdateDiskIOStats( &pDestDb->LogBlockReads,
-									 &pSrcDb->LogBlockReads);
+								 &pSrcDb->LogBlockReads);
+								 
 	pDestDb->uiLogBlockChkErrs += pSrcDb->uiLogBlockChkErrs;
 	pDestDb->uiReadErrors += pSrcDb->uiReadErrors;
 	pDestDb->uiWriteErrors += pSrcDb->uiWriteErrors;
-	flmUpdateCountTimeStats( &pDestDb->NoLocks, &pSrcDb->NoLocks);
-	flmUpdateCountTimeStats( &pDestDb->WaitingForLock,
-		&pSrcDb->WaitingForLock);
-	flmUpdateCountTimeStats( &pDestDb->HeldLock, &pSrcDb->HeldLock);
+	
+	flmUpdateCountTimeStats( &pDestDb->LockStats.NoLocks, 
+									 &pSrcDb->LockStats.NoLocks);
+									 
+	flmUpdateCountTimeStats( &pDestDb->LockStats.WaitingForLock,
+									 &pSrcDb->LockStats.WaitingForLock);
+									 
+	flmUpdateCountTimeStats( &pDestDb->LockStats.HeldLock,
+									 &pSrcDb->LockStats.HeldLock);
 
 	// Go through the LFILE statistics.
 
@@ -1249,12 +1267,12 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Returns statistics that have been collected for a share.
 Notes: The statistics returned will be the statistics for ALL
 		 databases associated with the share structure.
-*END************************************************************************/
-RCODE FlmGetStats(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmGetStats(
 	FLM_STATS *	pFlmStats)
 {
 	RCODE			rc = FERR_OK;
@@ -1299,9 +1317,6 @@ BLOCKIO_STATS * flmGetBlockIOStatPtr(
 		pLFileStats->bHaveStats =
 		pDbStats->bHaveStats = TRUE;
 		
-		// VISIT: Consider a one level tree.  
-		// Is it more important to count root stats over leaf stats?
-		
 		// Consider invalid type.
 
 		if ((BH_GET_TYPE( pBlk) != BHT_LEAF) &&
