@@ -25,80 +25,89 @@
 #include "flaimsys.h"
 
 FSTATIC RCODE FLRReadBlkHdr(
-	FDB_p			pDb,
+	FDB *			pDb,
 	FLMUINT		uiBlkAddress,
 	FLMBYTE *	pucBlockHeader,
 	FLMINT * 	iTypeRV);
 	
 FSTATIC RCODE FLRMoveBtreeBlk(
-	FDB_p			pDb,
+	FDB *			pDb,
 	FLMUINT		uiBlkAddr,
-	FLMUINT		uiLfNumber);
+	FLMUINT		uiLfNumber,
+	FLMBOOL *	pbDone);
 
 FSTATIC RCODE FLRMovePcodeLFHBlk(
-	FDB_p			pDb,
+	FDB *			pDb,
 	FLMUINT		uiBlkAddr,
 	FLMUINT		uiBlkType);
 
 FSTATIC RCODE FLRFreeAvailBlk(
-	FDB_p			pDb,
+	FDB *			pDb,
+	FLMBYTE *	pucBlkHeader,
 	FLMUINT		uiBlkAddr);
 
 FSTATIC RCODE FLRFindPrevAvailBlk(
-	FDB_p			pDb,
+	FDB *			pDb,
+	FLMBYTE *	pucBlkHeader,
 	FLMUINT *	puiBlkAddrRV,
 	FLMBOOL *	pbFirstChainFlagRV);
 
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Reduces the size of a FLAIM database file.
 Notes: The size of the database file is reduced by freeing a specified
 		 number of blocks from the available (unused) block list.  The blocks
 		 are moved to the end of the file and the file is truncated.  If the
 		 available block list is empty, FLAIM will attemp to add blocks to
 		 the list by freeing log extent blocks.
-*END************************************************************************/
-RCODE FlmDbReduceSize(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmDbReduceSize(
 	HFDB				hDb,
 	FLMUINT			uiCount,
-	FLMUINT *		puiCountRV
-	)
+	FLMUINT *		puiCountRV)
 {
-	RCODE			rc;
-	FDB_p			pDb = (FDB_p) hDb;
-	F_Rfl *		pRfl = NULL;
-	FLMUINT		uiLogicalEOF;	 			/* Local variable- change dbd->logEof last*/
-	FLMUINT		uiBlkAddr;
-	FLMUINT		uiNumBlksMoved = 0;			/* Initialize before again: goto loop */
-	FLMUINT		uiBlkSize;
-	FLMBYTE		BlkHeader [BH_OVHD + BH_OVHD ];	/* Enough for future log extent */
-	FLMINT		iType;
-	FLMBOOL		bIgnore;
-	FLMBOOL		bLoggingWasOff = FALSE;
-	FLMBOOL		bRestoreLoggingOffFlag = FALSE;
-	FLMBOOL		bLockedDatabase = FALSE;
+	RCODE				rc = FERR_OK;
+	FDB *				pDb = (FDB *) hDb;
+	F_Rfl *			pRfl = NULL;
+	FLMUINT			uiLogicalEOF;
+	FLMUINT			uiBlkAddr;
+	FLMUINT			uiNumBlksMoved = 0;
+	FLMUINT			uiBlkSize;
+	FLMUINT			uiLogicalFileNum;
+	FLMBYTE *		pucBlkHeader = NULL;
+	FLMINT			iType;
+	FLMBOOL			bIgnore;
+	FLMBOOL			bLoggingWasOff = FALSE;
+	FLMBOOL			bRestoreLoggingOffFlag = FALSE;
+	FLMBOOL			bLockedDatabase = FALSE;
+	FLMBOOL			bDone = FALSE;
+
+	if( RC_BAD( rc = f_allocAlignedBuffer( MAX_BLOCK_SIZE, &pucBlkHeader)))
+	{
+		goto Exit;
+	}
 
 	// Lock the database if not already locked.
 	// Cannot lose exclusive access between the checkpoint and
-	// the update transaction that does the conversion.
+	// the update transaction that does the truncation.
 
 	if( (pDb->uiFlags & FDB_HAS_FILE_LOCK) == 0)
 	{
-		if( RC_BAD( rc = FlmDbLock( hDb, FLM_LOCK_EXCLUSIVE, 0, 15)))
+		if( RC_BAD( rc = FlmDbLock( hDb, FLM_LOCK_EXCLUSIVE, 0, FLM_NO_TIMEOUT)))
 		{
 			goto Exit;
 		}
 		bLockedDatabase = TRUE;
 	}
 
-	if (IsInCSMode( pDb))
+	if( IsInCSMode( pDb))
 	{
 		fdbInitCS( pDb);
 
-		CS_CONTEXT_p	pCSSession = pDb->pCSContext;
+		CS_CONTEXT *	pCSSession = pDb->pCSContext;
 		FCL_WIRE			Wire( pCSSession, pDb);
 
-		/* Send a request to reduce the file. */
+		// Send a request to reduce the file
 
 		if (RC_BAD( rc = Wire.sendOp(
 			FCS_OPCLASS_DATABASE, FCS_OP_DB_REDUCE_SIZE)))
@@ -119,7 +128,7 @@ RCODE FlmDbReduceSize(
 			goto Transmission_Error;
 		}
 
-		/* Read the response. */
+		// Read the response
 	
 		if (RC_BAD( rc = Wire.read()))
 		{
@@ -131,6 +140,7 @@ RCODE FlmDbReduceSize(
 		goto Exit;
 
 Transmission_Error:
+
 		pCSSession->bConnectionGood = FALSE;
 		goto Exit;
 	}
@@ -141,7 +151,7 @@ Transmission_Error:
 		goto Exit;
 	}
 
-	/* Make sure we are NOT in a database transaction. */
+	// Make sure we are NOT in a database transaction
 
 	if (pDb->uiTransType != FLM_NO_TRANS)
 	{
@@ -160,20 +170,10 @@ Transmission_Error:
 	pRfl->setLoggingOffState( TRUE);
 	bRestoreLoggingOffFlag = TRUE;
 
-	/**-------------------------------------------------------------------
-	***  Keep looping to here until the count is satisfied or there
-	***  are not any more log extent blocks to turn into avail blks.
-	***  The loop does a begin transaction - move blocks - set logical
-	***  EOF and commits the transaction.  During the commit if there are
-	***  not any avail blocks left then a log extent (if any) will be turned
-	***  into more avail blocks and we can do this again with more avail
-	***  blocks.
-	***------------------------------------------------------------------*/
-
-	/* Start a database transaction */
+	// Start a database transaction
 
 	if (RC_BAD(rc = flmBeginDbTrans( pDb, FLM_UPDATE_TRANS, 
-		15, FLM_DONT_POISON_CACHE)))
+		FLM_NO_TIMEOUT, FLM_DONT_POISON_CACHE)))
 	{
 		goto Exit;
 	}
@@ -181,82 +181,90 @@ Transmission_Error:
 	// Make sure that commit does something.
 
 	pDb->bHadUpdOper = TRUE;
-
 	uiBlkSize = pDb->pFile->FileHdr.uiBlockSize;
 
-	/**-----------------------------------------------------------------
-	***  Get the logical end of file and use internally.
-	***  Loop until there are not any more free blocks left or the
-	***  input count is matched.  Switch on each block type found
-	***  while backing up through the file.
-	***----------------------------------------------------------------*/
+	// Get the logical end of file and use internally.
+	// Loop until there are not any more free blocks left or the
+	// input count is matched.  Switch on each block type found
 
 	uiLogicalEOF = pDb->LogHdr.uiLogicalEOF;
 
-	while( (pDb->LogHdr.uiFirstAvailBlkAddr != BT_END )
-		 && ((!uiCount) || (uiNumBlksMoved < uiCount)))
+	while( (pDb->LogHdr.uiFirstAvailBlkAddr != BT_END) &&
+			 ((!uiCount) || (uiNumBlksMoved < uiCount)))
 	{
 
-		/* Read the last block and determine block type. */
-
-		/* Special case for 3x files.  */
+		// Read the last block and determine block type
 
 		if( FSGetFileOffset( uiLogicalEOF) == 0)
 		{
-			F_FileHdlImp *		pFileHdl;
 			FLMUINT				uiFileNumber = FSGetFileNumber( uiLogicalEOF) - 1;
-			FLMUINT				uiFileSize;
+			FLMUINT64			ui64FileSize;
 			FLMUINT				uiTemp;
-
-			if( RC_BAD( rc = pDb->pSFileHdl->GetFileHdl( 
-				uiFileNumber, TRUE, &pFileHdl)))
+			
+			if( RC_BAD( rc = pDb->pSFileHdl->getFileSize( uiFileNumber, 
+				&ui64FileSize))) 
 			{
 				goto Reduce_Size_Error;
 			}
 			
-			if( RC_BAD( rc = pFileHdl->Size( &uiFileSize)))
+			// Adjust to a block bounds
+			
+			uiTemp = (FLMUINT)((ui64FileSize / uiBlkSize) * uiBlkSize);
+			if( uiTemp < ui64FileSize)
 			{
-				goto Reduce_Size_Error;
+				ui64FileSize = uiTemp + uiBlkSize;
 			}
-
-			// Adjust to a block bounds.
-			uiTemp = (uiFileSize / uiBlkSize) * uiBlkSize;
-			if( uiTemp < uiFileSize)
-			{
-				uiFileSize = uiTemp + uiBlkSize;
-			}
-			uiLogicalEOF = FSBlkAddress( uiFileNumber, uiFileSize);
+			uiLogicalEOF = FSBlkAddress( uiFileNumber, (FLMUINT)ui64FileSize);
 		}
 			
 		uiBlkAddr = uiLogicalEOF - uiBlkSize;
 
-		if (RC_BAD( rc = FLRReadBlkHdr( pDb, uiBlkAddr, BlkHeader, &iType)))
+		if( RC_BAD( rc = FLRReadBlkHdr( pDb, uiBlkAddr, pucBlkHeader, &iType)))
 		{
 			goto Reduce_Size_Error;
 		}
 
+		uiLogicalFileNum = FB2UW( &pucBlkHeader[ BH_LOG_FILE_NUM]);
+
 		switch( iType )
 		{
 			case	BHT_FREE:
-				rc = FLRFreeAvailBlk( pDb, uiBlkAddr );
+			{
+				rc = FLRFreeAvailBlk( pDb, pucBlkHeader, uiBlkAddr);
 				break;
+			}
 
 			case	BHT_LEAF:
 			case	BHT_NON_LEAF:
 			case	BHT_NON_LEAF_DATA:
-				rc = FLRMoveBtreeBlk( pDb, uiBlkAddr,
-							 FB2UW( &BlkHeader [BH_LOG_FILE_NUM ]));
+			{
+				rc = FLRMoveBtreeBlk( pDb, uiBlkAddr, uiLogicalFileNum, &bDone);
 				break;
+			}
 
 			case	BHT_LFH_BLK:
 			case	BHT_PCODE_BLK:
+			{
 				rc = FLRMovePcodeLFHBlk( pDb, uiBlkAddr, iType);
 				break;
+			}
+			
 			default:
+			{
 				rc = RC_SET( FERR_BTREE_ERROR);
+				break;
+			}
 		}
+		
 		if (RC_BAD(rc))
+		{
 			goto Reduce_Size_Error;
+		}
+		
+		if (bDone)
+		{
+			break;
+		}
 
 		uiNumBlksMoved++;
 
@@ -266,30 +274,29 @@ Transmission_Error:
 		if( FSGetFileOffset( uiLogicalEOF) == 0)
 		{
 			FLMUINT				uiFileNumber = FSGetFileNumber( uiLogicalEOF);
-			FLMUINT				uiFileOffset;
-			F_FileHdlImp *		pFileHdl;
+			FLMUINT64			ui64FileOffset;
 
 			if( uiFileNumber <= 1)
+			{
 				break;
+			}
 
 			// Leave the current file at zero bytes and move to the 
 			// previous store file.
+			
 			uiFileNumber--;
 			
 			// Compute the end of the previous block file.
-			if( RC_BAD( rc = pDb->pSFileHdl->GetFileHdl( 
-				uiFileNumber, TRUE, &pFileHdl)))
-			{
-				goto Exit;
-			}
-
-			if( RC_BAD( rc = pFileHdl->Size( &uiFileOffset)))
+			
+			if( RC_BAD( rc = pDb->pSFileHdl->getFileSize( uiFileNumber, 
+				&ui64FileOffset)))
 			{
 				goto Exit;
 			}
 			
-			uiLogicalEOF = FSBlkAddress( uiFileNumber, uiFileOffset);
+			uiLogicalEOF = FSBlkAddress( uiFileNumber, (FLMUINT)ui64FileOffset);
 		}
+		
 		uiLogicalEOF -= uiBlkSize;
 	}
 
@@ -298,7 +305,7 @@ Transmission_Error:
 	// and then turn it back off after logging the packet.
 
 	if (!(pDb->uiFlags & FDB_REPLAYING_RFL) &&
-		  pDb->pFile->FileHdr.uiVersionNum >= FLM_VER_4_3)
+		  pDb->pFile->FileHdr.uiVersionNum >= FLM_FILE_FORMAT_VER_4_3)
 	{
 
 		// We would have turned logging OFF above, so we need to
@@ -319,50 +326,75 @@ Transmission_Error:
 		}
 	}
 
-	/* Commit the transaction. */
+	// Commit the transaction
 
 	{
-		FLMBOOL	bFlagSet;
+		FLMBOOL		bFlagSet;
+		FLMUINT		uiSaveRflFootprintSize = pDb->pFile->uiRflFootprintSize;
+		FLMUINT		uiSaveRblFootprintSize = pDb->pFile->uiRblFootprintSize;
 		
 		if (pDb->uiFlags & FDB_DO_TRUNCATE)
+		{
 			bFlagSet = TRUE;
+		}
 		else
 		{
 			bFlagSet = FALSE;
 			pDb->uiFlags |= FDB_DO_TRUNCATE;
 		}
+		
+		// Set the roll-forward and roll-back log thresholds to
+		// their minimum sizes
+		
+		pDb->pFile->uiRflFootprintSize = 512;
+		pDb->pFile->uiRblFootprintSize = pDb->pFile->FileHdr.uiBlockSize;
 
 		rc = flmCommitDbTrans( pDb, uiLogicalEOF, TRUE);
+		
+		// Restore the RFL and RBL footprint sizes
+		
+		pDb->pFile->uiRflFootprintSize = uiSaveRflFootprintSize;
+		pDb->pFile->uiRblFootprintSize = uiSaveRblFootprintSize;
+		
 		if (!bFlagSet)
+		{
 			pDb->uiFlags &= (~(FDB_DO_TRUNCATE));
+		}
+		
 		if (RC_BAD( rc))
+		{
 			goto Exit;
+		}
 	}
 
 Exit:
 
 	if( puiCountRV)
 	{
-		*puiCountRV = uiNumBlksMoved;	/* May be more than requested count */
+		*puiCountRV = uiNumBlksMoved;
 	}
 
-	if (bRestoreLoggingOffFlag)
+	if( bRestoreLoggingOffFlag)
 	{
 		pRfl->setLoggingOffState( bLoggingWasOff);
 	}
 
-	if (bLockedDatabase)
+	if( bLockedDatabase)
 	{
-		(void) FlmDbUnlock( hDb);
+		FlmDbUnlock( hDb);
 	}
 
+	if( pucBlkHeader)
+	{
+		f_freeAlignedBuffer( &pucBlkHeader);
+	}
+	
 	flmExit( FLM_DB_REDUCE_SIZE, pDb, rc);
-
 	return( rc);
 
 Reduce_Size_Error:
 
-	(void)flmAbortDbTrans( pDb);
+	(void)flmAbortDbTrans( pDb, FALSE);
 	uiNumBlksMoved = 0;
 	goto Exit;
 }
@@ -371,58 +403,51 @@ Reduce_Size_Error:
 Desc:	Read the block header and return the type of block it is
 ****************************************************************************/
 FSTATIC RCODE FLRReadBlkHdr(
-	FDB_p			pDb,
-	FLMUINT		uiBlkAddress,
-	FLMBYTE *	pucBlockHeader,
-	FLMINT *		piTypeRV	)
+	FDB *				pDb,
+	FLMUINT			uiBlkAddress,
+	FLMBYTE *		pucBlockHeader,
+	FLMINT *			piTypeRV)
 {
 	RCODE				rc = FERR_OK;
 	FLMUINT			uiBytesRead;
 	FLMUINT			uiNumLooks;
-	F_FileHdlImp *	pTmpFileHdl = NULL;
 	SCACHE *			pBlkSCache;
 	DB_STATS *		pDbStats = pDb->pDbStats;
 	LFILE_STATS *	pLFileStats;
 	F_TMSTAMP		StartTime;
 	FLMUINT64		ui64ElapTime;
 
-	/**-----------------------------------------------
-	***  See if first the block is in cache.
-	***  Previous writes may not have been forced out
-	***  to cache.
-	***----------------------------------------------*/
+	// See if first the block is in cache.  Previous writes may not have been
+	// forced out to cache.
 
-	if (RC_BAD( rc = ScaGetBlock( pDb, NULL, BHT_LEAF,
-											uiBlkAddress, &uiNumLooks,
-										 	&pBlkSCache)))
+	if( RC_BAD( rc = ScaGetBlock( pDb, NULL, BHT_LEAF,
+		uiBlkAddress, &uiNumLooks, &pBlkSCache)))
 	{
 		goto Exit;
 	}
 
-	if (pBlkSCache)		// If found in cache ...
+	if( pBlkSCache)
 	{
 		f_memcpy( pucBlockHeader, pBlkSCache->pucBlk, BH_OVHD);
 		ScaReleaseCache( pBlkSCache, FALSE);
 	}
 	else
 	{
-		if (pDbStats)
+		if( pDbStats)
 		{
 			ui64ElapTime = 0;
 			f_timeGetTimeStamp( &StartTime);
 		}
+		
+		rc = pDb->pSFileHdl->readBlock( uiBlkAddress, 
+			pDb->pFile->FileHdr.uiBlockSize, 
+			pucBlockHeader, &uiBytesRead);
 
-		if( RC_OK( rc = pDb->pSFileHdl->GetFileHdl(
-			FSGetFileNumber( uiBlkAddress), TRUE, &pTmpFileHdl)))
-		{
-			rc = pTmpFileHdl->Read( FSGetFileOffset( uiBlkAddress), 
-					BH_OVHD, pucBlockHeader, &uiBytesRead);
-		}
-
-		if (pDbStats)
+		if( pDbStats)
 		{
 			flmAddElapTime( &StartTime, &ui64ElapTime);
-			if (RC_BAD( rc))
+
+			if( RC_BAD( rc))
 			{
 				pDbStats->bHaveStats = TRUE;
 				pDbStats->uiReadErrors++;
@@ -434,7 +459,7 @@ FSTATIC RCODE FLRReadBlkHdr(
 				FLMUINT				uiBlkType;
 
 				uiLFileNum = FB2UW( &pucBlockHeader [BH_LOG_FILE_NUM]);
-				if (!uiLFileNum)
+				if( !uiLFileNum)
 				{
 					pLFileStats = NULL;
 					uiBlkType = (FLMUINT)BH_GET_TYPE( pucBlockHeader);
@@ -483,23 +508,16 @@ FSTATIC RCODE FLRReadBlkHdr(
 			}
 		}
 
-		if (RC_BAD( rc))
+		if( RC_BAD( rc))
 		{
-			if (rc != FERR_IO_END_OF_FILE && rc != FERR_MEM)
-			{
-				pDb->pSFileHdl->ReleaseFile( FSGetFileNumber( uiBlkAddress),
-														TRUE);
-			}
 			goto Exit;
 		}
+		
 		pucBlockHeader [BH_CHECKSUM_LOW] = (FLMBYTE) uiBlkAddress;
 	}
 
-	/**---------------------------------------------------
-	***  If the block address does not agree with what 
-	***  is expected then the block is a log extent.
-	***  Otherwise the block contains the type it is.
-	***--------------------------------------------------*/
+	// If the block address does not agree with what is expected then the
+	// block is a log extent.  Otherwise the block contains the type it is.
 
 	if (piTypeRV)
 	{
@@ -507,7 +525,8 @@ FSTATIC RCODE FLRReadBlkHdr(
 	}
 				
 Exit:
-	return( rc );
+
+	return( rc);
 }
 
 /****************************************************************************
@@ -517,12 +536,13 @@ Notes:	Some of this code could be called in movePcodeLFHBlk but we have
 			to worry about if the block is a root or right most leaf block.
 ****************************************************************************/
 FSTATIC RCODE FLRMoveBtreeBlk(
-	FDB_p			pDb,
-	FLMUINT		uiBlkAddr,		// Block Address
-	FLMUINT		uiLfNumber)
+	FDB *			pDb,
+	FLMUINT		uiBlkAddr,
+	FLMUINT		uiLfNumber,
+	FLMBOOL *	pbDone)
 {
 	RCODE			rc;
-	FFILE_p		pFile = pDb->pFile;
+	FFILE *		pFile = pDb->pFile;
 	LFILE *		pLFile;
 	SCACHE *		pSCache;
 	FLMBOOL		bReleaseCache = FALSE;
@@ -533,14 +553,14 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 	FLMUINT		uiRightBlkAddr;
 	SCACHE *		pFreeSCache;
 	FLMBOOL		bReleaseCache2 = FALSE;
-	BTSK			StackArea;			 		/* Single stack allocation */
-	BTSK_p		pStack = &StackArea;		/* Points to stack - easier to use */
-	FLMUINT		uiElmOvhd;				 	/* Number of bytes in block overhead */
-	FLMUINT		uiSearchKeyLen;		 		/* Length of block's 1st key */
+	BTSK			StackArea;
+	BTSK *		pStack = &StackArea;
+	FLMUINT		uiElmOvhd;
+	FLMUINT		uiSearchKeyLen;
 	FLMBYTE		ucKeyBuf [MAX_KEY_SIZ];
-	FLMBYTE		ucSearchKey [MAX_KEY_SIZ];/* Holds block's 1st key */
+	FLMBYTE		ucSearchKey [MAX_KEY_SIZ];
 	FLMUINT		uiTargetLevel;
-	FLMUINT		uiLevel;						/* Level numbers in the btree */
+	FLMUINT		uiLevel;
 	FLMUINT		uiRootBlkFlag;
 	FLMUINT		uiSavePrevTransID;
 	FLMUINT		uiSavePrevBlkAddr;
@@ -554,6 +574,15 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		 (RC_BAD( rc = fdictGetIndex( pDb->pDict, pDb->pFile->bInLimitedMode,
 		 		uiLfNumber, &pLFile, NULL, TRUE))))
 	{
+		// It may be that the index or container is being deleted by a background
+		// thread.  In that case, we need to bail out, as there is nothing
+		// more we can do until the background thread finishes its delete.
+
+		if (rc == FERR_BAD_IX)
+		{
+			*pbDone = TRUE;
+			rc = FERR_OK;
+		}
 		goto Exit;
 	}
 
@@ -570,24 +599,14 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 	}
 	pucBlk = pSCache->pucBlk;
 
-	/**--------------------------------------------------
-	***  Added 05/04/93
-	***  Need to make sure that LFILE is up to date.
-	***  Force reading it in.  This does a block read
-	***  so the cache will get hit without a great
-	***  performance loss.  This is the safest place
-	***  to do this because only pSCache is pinned.
-	***------------------------------------------------*/
+	// Need to make sure that LFILE is up to date.
 
 	if (RC_BAD( rc = flmLFileRead( pDb, pLFile)))
 	{
 		goto Exit;
 	}
 
-	/**----------------------------------------
-	***  Get all of the information from the
-	***  block like linkages and a search key.
-	***---------------------------------------*/
+	// Get all of the information from the block like linkages and a search key.
 
 	uiLeftBlkAddr  = FB2UD( &pucBlk [BH_PREV_BLK ]);
 	uiRightBlkAddr = FB2UD( &pucBlk [BH_NEXT_BLK ]);
@@ -603,7 +622,7 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		uiElmOvhd = BNE_KEY_START;
 		break;
 	case BHT_NON_LEAF_DATA:
-		uiElmOvhd = 0; // First key starts at BH_OVHD
+		uiElmOvhd = 0;
 		break;
 	case BHT_NON_LEAF_COUNTS:
 		uiElmOvhd = BNE_KEY_COUNTS_START;
@@ -614,15 +633,12 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 	}
 
 	uiSearchKeyLen = (uiBlockType == BHT_NON_LEAF_DATA 
-					? 4 
-					: BBE_GET_KL( &pucBlk [BH_OVHD ]));
+								? 4 
+								: BBE_GET_KL( &pucBlk [BH_OVHD ]));
 
 	f_memcpy( ucSearchKey, &pucBlk [BH_OVHD + uiElmOvhd ], uiSearchKeyLen );
 	
-	/**-------------------------------
-	***  Get the next free block.
-	***  Copy block to free block.
-	***------------------------------*/
+	// Get the next free block.  Copy block to free block.
 
 	if (RC_BAD( rc = FSBlockUseNextAvail( pDb, pLFile, &pFreeSCache)))
 	{
@@ -632,13 +648,11 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 	pucFreeBlk = pFreeSCache->pucBlk;	
 	uiFreeBlkAddr = GET_BH_ADDR( pucFreeBlk);
 
-	/*
-	The free block has been logged and set to dirty
-	in FSBlockUseNextAvail().
-	BUT, need to preserve previous transaction ID and previous
-	block address - those should NOT be copied over from the block
-	we are switching with.
-	*/
+	// The free block has been logged and set to dirty
+	// in FSBlockUseNextAvail().
+	// BUT, need to preserve previous transaction ID and previous
+	// block address - those should NOT be copied over from the block
+	// we are switching with.
 
 	uiSavePrevTransID = (FLMUINT)FB2UD(
 									&pFreeSCache->pucBlk [BH_PREV_TRANS_ID]);
@@ -646,7 +660,7 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 									&pFreeSCache->pucBlk [BH_PREV_BLK_ADDR]);
 
 	f_memcpy( pFreeSCache->pucBlk, pucBlk, pFile->FileHdr.uiBlockSize);
-	SET_BH_ADDR( pucFreeBlk, uiFreeBlkAddr );
+	SET_BH_ADDR( pucFreeBlk, (FLMUINT32)uiFreeBlkAddr );
 
 	// Restore the saved previous transaction ID and block address.
 
@@ -659,16 +673,13 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 	bReleaseCache2 = FALSE;
 	uiRootBlkFlag = (FLMUINT)(BH_IS_ROOT_BLK( pucBlk ));
 
-	/* Done with block. */
+	// Done with block.
 
 	ScaReleaseCache( pSCache, FALSE);
 	bReleaseCache = FALSE;
 
-	/**----------------------------------------------
-	***  If this is a root block this is easy!
-	***  Otherwise you must find the blocks parent
-	***  and next/prev blocks and change linkages.
-	***---------------------------------------------*/
+	// If this is a root block this is easy!  Otherwise you must find the 
+	// blocks parent and next/prev blocks and change linkages.
 
 	if( uiRootBlkFlag)
 	{
@@ -696,12 +707,9 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		goto Exit;
 	}
 
-	/**--------------------------------------------------
-	***  Read left and right blocks and adjust their 
-	***  pointers to point to the new block.
-	***  This doesn't matter what level of the b-tree
-	***  you are on.
-	***--------------------------------------------------*/
+	// Read left and right blocks and adjust their pointers to point to
+	// the new block.  This doesn't matter what level of the b-tree
+	// you are on.
 
 	if( uiLeftBlkAddr != BT_END)
 	{
@@ -710,13 +718,16 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		{
 			goto Exit;
 		}
+		
 		bReleaseCache = TRUE;
+		
 		if (RC_BAD( rc = ScaLogPhysBlk( pDb, &pSCache)))
 		{
 			goto Exit;
 		}
+		
 		pucBlk = pSCache->pucBlk;
-		UD2FBA( uiFreeBlkAddr, &pucBlk [BH_NEXT_BLK ]);
+		UD2FBA( (FLMUINT32)uiFreeBlkAddr, &pucBlk [BH_NEXT_BLK ]);
 		ScaReleaseCache( pSCache, FALSE);
 		bReleaseCache = FALSE;
 	}
@@ -728,24 +739,24 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		{
 			goto Exit;
 		}
+		
 		bReleaseCache = TRUE;
+		
 		if (RC_BAD( rc = ScaLogPhysBlk( pDb, &pSCache)))
 		{
 			goto Exit;
 		}
 
 		pucBlk = pSCache->pucBlk;
-		UD2FBA( uiFreeBlkAddr, &pucBlk [BH_PREV_BLK ]);
+		UD2FBA( (FLMUINT32)uiFreeBlkAddr, &pucBlk [BH_PREV_BLK ]);
 		ScaReleaseCache( pSCache, FALSE);
 		bReleaseCache = FALSE;
 	}
 
-	/**--------------------------------------------------
-	***  Now for the hard part!  Build a search key.
-	***  Scan down the tree one level above blk.
-	***  Scan right until find element that has child blk
-	***  that matches uiBlkAddr and adjust child blk addr.
-	***--------------------------------------------------*/
+	// Now for the hard part!  Build a search key.
+	// Scan down the tree one level above blk.
+	// Scan right until find element that has child blk
+	// that matches uiBlkAddr and adjust child blk addr.
 
 	if (RC_BAD(rc = FSGetBlock( pDb, pLFile,
 										  pLFile->uiRootBlk, pStack)))
@@ -759,7 +770,7 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		uiLevel = (FLMUINT)CABLK_ELM( pStack, BH_LEVEL );
 		pStack->uiLevel = uiLevel;
 
-		/* Scan the block for the matching key */
+		// Scan the block for the matching key
 
 		if( pStack->uiBlkType != BHT_NON_LEAF_DATA)
 		{
@@ -767,7 +778,7 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		}
 		else
 		{
-			rc = FSBtScanNonLeafData( pStack, byteToLong( ucSearchKey));
+			rc = FSBtScanNonLeafData( pStack, f_bigEndianToUINT32( ucSearchKey));
 		}
 		if( RC_BAD( rc))
 		{
@@ -784,12 +795,10 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		}
 	}
 
-	/**----------------------------------------------------------
-	***  The block MUST be a non-leaf block so our job is easier.
-	***  Scan the elements going right to find the element that
-	***  has the matching block address.
-	***  Set NO_STACK flag so get next element doesn't pop stack!
-	***-----------------------------------------------------------*/
+	// The block MUST be a non-leaf block so our job is easier.
+	// Scan the elements going right to find the element that
+	// has the matching block address.
+	// Set NO_STACK flag so get next element doesn't pop stack!
 
 	pStack->uiFlags = NO_STACK;
 	
@@ -798,7 +807,7 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 		if (FSChildBlkAddr( pStack) == uiBlkAddr )
 		{
 
-			/* FOUND THE BLOCK ! ! ! */
+			// Found the block
 			
 			if (RC_BAD( rc = FSLogPhysBlk( pDb, pStack)))
 			{
@@ -818,14 +827,17 @@ FSTATIC RCODE FLRMoveBtreeBlk(
 			}
 			goto Exit;
 		}
-	}		
-	/* WOW - WE ARE DONE ! ! ! */
+	}
+	
 Exit:
+
 	FSReleaseBlock( &StackArea, FALSE);
+	
 	if (bReleaseCache)
 	{
 		ScaReleaseCache( pSCache, FALSE);
 	}
+	
 	if (bReleaseCache2)
 	{
 		ScaReleaseCache( pFreeSCache, FALSE);
@@ -839,7 +851,7 @@ Desc:	Find where a pcode list the input block is located.  Move to
 		a free block and change all pointers to the block.
 ****************************************************************************/
 FSTATIC RCODE FLRMovePcodeLFHBlk(
-	FDB_p			pDb,
+	FDB *			pDb,
 	FLMUINT		uiBlkAddr,
 	FLMUINT		uiBlkType)
 {
@@ -853,7 +865,7 @@ FSTATIC RCODE FLRMovePcodeLFHBlk(
 	FLMUINT		uiLeftBlkAddr;
 	FLMUINT		uiRightBlkAddr;
 	FLMUINT		uiFreeBlkAddr;
-	FFILE_p		pFile = pDb->pFile;
+	FFILE *		pFile = pDb->pFile;
 	FLMUINT		uiSavePrevTransID;
 	FLMUINT		uiSavePrevBlkAddr;
 
@@ -897,7 +909,7 @@ FSTATIC RCODE FLRMovePcodeLFHBlk(
 									&pFreeSCache->pucBlk [BH_PREV_BLK_ADDR]);
 
 	f_memcpy( pFreeSCache->pucBlk, pucBlk, pFile->FileHdr.uiBlockSize);
-	SET_BH_ADDR( pucFreeBlk, uiFreeBlkAddr );
+	SET_BH_ADDR( pucFreeBlk, (FLMUINT32)uiFreeBlkAddr);
 
 	// Restore the saved previous transaction ID and block address.
 
@@ -979,7 +991,7 @@ FSTATIC RCODE FLRMovePcodeLFHBlk(
 		}
 
 		pucBlk = pSCache->pucBlk;
-		UD2FBA( uiFreeBlkAddr, &pucBlk [BH_NEXT_BLK ]);
+		UD2FBA( (FLMUINT32)uiFreeBlkAddr, &pucBlk [BH_NEXT_BLK ]);
 		ScaReleaseCache( pSCache, FALSE);
 		bReleaseCache = FALSE;
 	}
@@ -998,7 +1010,7 @@ FSTATIC RCODE FLRMovePcodeLFHBlk(
 		}
 
 		pucBlk = pSCache->pucBlk;
-		UD2FBA( uiFreeBlkAddr, &pucBlk [BH_PREV_BLK ]);
+		UD2FBA( (FLMUINT32)uiFreeBlkAddr, &pucBlk [BH_PREV_BLK ]);
 		ScaReleaseCache( pSCache, FALSE);
 		bReleaseCache = FALSE;
 	}
@@ -1022,12 +1034,12 @@ Exit:
 Desc:	Free the input avail block.  Link the block out of the free list
 ****************************************************************************/
 FSTATIC RCODE FLRFreeAvailBlk(
-	FDB_p			pDb,
+	FDB *			pDb,
+	FLMBYTE *	pucBlkHeader,
 	FLMUINT		uiBlkAddr)
 {
 	RCODE			rc = FERR_OK;
-	FFILE_p		pFile = pDb->pFile;
-	FLMBYTE		ucBlkHeader [BH_OVHD];
+	FFILE *		pFile = pDb->pFile;
 	FLMBYTE *	pucBlk;
 	FLMUINT		uiPrevBlkAddr;
 	FLMUINT		uiNextBlkAddr;
@@ -1038,7 +1050,7 @@ FSTATIC RCODE FLRFreeAvailBlk(
 	FLMBOOL		bFirstChainFlag;
 	FLMBYTE *	pucLogHdr = &pFile->ucUncommittedLogHdr [0];
 
-	/* Check for first avail block condition. */
+	// Check for first avail block condition.
 
 	if (uiBlkAddr == pDb->LogHdr.uiFirstAvailBlkAddr)
 	{
@@ -1049,39 +1061,37 @@ FSTATIC RCODE FLRFreeAvailBlk(
 		goto Exit;
 	}
 
-	/* Not first block -- resolve pointers */
-
-	/* Read the block header and get pointers */
+	// Read the block header and get pointers
 
 	if (RC_BAD( rc = FLRReadBlkHdr( pDb, uiBlkAddr,
-									ucBlkHeader, (FLMINT *)0 )))
+									pucBlkHeader, (FLMINT *)0 )))
 	{
 		goto Exit;
 	}
-	uiPrevBlkAddr = uiBlkAddr;			/* Call uses uiPrevBlkAddr */
-	if (RC_BAD( rc = FLRFindPrevAvailBlk( pDb, &uiPrevBlkAddr,
-													  &bFirstChainFlag)))
+	
+	uiPrevBlkAddr = uiBlkAddr;
+	uiNextBlkAddr = FB2UD( &pucBlkHeader[ BH_NEXT_BLK]);
+	
+	if( pFile->FileHdr.uiVersionNum >= 111)
 	{
-		goto Exit;
-	}
-
-	uiNextBlkAddr = FB2UD( &ucBlkHeader [BH_NEXT_BLK]);
-	if (pFile->FileHdr.uiVersionNum >= 111)
-	{
-		/* Only valid for versions 1.11 and higher */
-
-		uiPbcAddr = ALGetPBC( ucBlkHeader);
-		uiNbcAddr = ALGetNBC( ucBlkHeader);
-		flmDecrUint( &pucLogHdr [LOG_PF_NUM_AVAIL_BLKS], 1);
+		uiPbcAddr = ALGetPBC( pucBlkHeader);
+		uiNbcAddr = ALGetNBC( pucBlkHeader);
+		flmDecrUint( &pucLogHdr[ LOG_PF_NUM_AVAIL_BLKS], 1);
 	}
 	else
 	{
 		uiPbcAddr = uiNbcAddr = 0;
 	}
 
-	/* Check for unexpected error conditions. */
+	if( RC_BAD( rc = FLRFindPrevAvailBlk( pDb, pucBlkHeader,
+		&uiPrevBlkAddr, &bFirstChainFlag)))
+	{
+		goto Exit;
+	}
 
-	if (( uiPrevBlkAddr == uiBlkAddr)  ||
+	// Check for unexpected error conditions
+
+	if( (uiPrevBlkAddr == uiBlkAddr)  ||
 			((!uiNbcAddr) && ( uiPbcAddr)) || 
 			(( uiNbcAddr) && (!uiPbcAddr)))
 	{
@@ -1089,12 +1099,10 @@ FSTATIC RCODE FLRFreeAvailBlk(
 		goto Exit;
 	}
 
-	/**--------------------------------
-	***  NON-CHAIN BLOCK
-	***  This is also minor verion 0
-	***-------------------------------*/
+	// NON-CHAIN BLOCK
+	// This is also minor verion 0
 
-	if (!uiNbcAddr)				 /* either both are zero or both non-zero*/
+	if (!uiNbcAddr)
 	{
 		if (RC_BAD( rc = ScaGetBlock( pDb, NULL, BHT_FREE,
 										uiPrevBlkAddr, NULL, &pSCache)))
@@ -1114,22 +1122,12 @@ FSTATIC RCODE FLRFreeAvailBlk(
 			pucLogHdr [LOG_PF_FIRST_BC_CNT]--;
 		}
 
-		UD2FBA( uiNextBlkAddr, &pucBlk [BH_NEXT_BLK]);
+		UD2FBA( (FLMUINT32)uiNextBlkAddr, &pucBlk [BH_NEXT_BLK]);
 		ScaReleaseCache( pSCache, FALSE);
 		bReleaseCache = FALSE;
 		goto Exit;
 	}
 
-	/**--------------------------------
-	***  CHAIN BLOCK
-	***  Only in minor verion > 0 
-	***-------------------------------*/
-
-	/**--------------------------------
-	***  CHAIN BLOCK - previous block
-	***  is nbc (next backchain)
-	***-------------------------------*/
-
 	if (uiPrevBlkAddr == uiNbcAddr)
 	{
 		if ( RC_BAD( rc = ScaGetBlock( pDb, NULL, BHT_FREE,
@@ -1146,7 +1144,7 @@ FSTATIC RCODE FLRFreeAvailBlk(
 
 		pucBlk = pSCache->pucBlk;
 		ALPutPBC( pucBlk, uiPbcAddr);
-		UD2FBA( uiNextBlkAddr, &pucBlk [BH_NEXT_BLK]);
+		UD2FBA( (FLMUINT32)uiNextBlkAddr, &pucBlk [BH_NEXT_BLK]);
 		ScaReleaseCache( pSCache, FALSE);
 		bReleaseCache = FALSE;
 
@@ -1165,23 +1163,11 @@ FSTATIC RCODE FLRFreeAvailBlk(
 			}
 
 			pucBlk = pSCache->pucBlk;
-			ALPutNBC( pucBlk, uiNbcAddr);
+			ALPutNBC( pucBlk, (FLMUINT32)uiNbcAddr);
 			ScaReleaseCache( pSCache, FALSE);
 			bReleaseCache = FALSE;
 		}
 	}
-
-	/**--------------------------------
-	***  CHAIN BLOCK - next block
-	***  is pbc (previous backchain)
-	***
-	***									|----------->>-PBC->>---------|
-	***									|                             |
-	***		header ----> FREE -->>-nextBlk->>--------> FREE
-	***									|                             |
-	***									|---------<<-NBC-<<-----------|
-	***-------------------------------*/
-
 	else if ((uiNextBlkAddr == uiPbcAddr) && (uiNextBlkAddr != BT_END))
 	{
 		if (RC_BAD( rc = ScaGetBlock( pDb, NULL, BHT_FREE,
@@ -1197,7 +1183,7 @@ FSTATIC RCODE FLRFreeAvailBlk(
 		}
 
 		pucBlk = pSCache->pucBlk;
-		UD2FBA( uiNextBlkAddr, &pucBlk [BH_NEXT_BLK]);
+		UD2FBA( (FLMUINT32)uiNextBlkAddr, &pucBlk [BH_NEXT_BLK]);
 		ScaReleaseCache( pSCache, FALSE);
 		bReleaseCache = FALSE;
 
@@ -1216,7 +1202,7 @@ FSTATIC RCODE FLRFreeAvailBlk(
 			}
 
 			pucBlk = pSCache->pucBlk;
-			ALPutNBC( pucBlk, uiNbcAddr);
+			ALPutNBC( pucBlk, (FLMUINT32)uiNbcAddr);
 			ScaReleaseCache( pSCache, FALSE);
 			bReleaseCache = FALSE;
 		}
@@ -1245,13 +1231,6 @@ FSTATIC RCODE FLRFreeAvailBlk(
 			bReleaseCache = FALSE;
 		}
 	}
-
-	/**-----------------------------------
-	***  CHAIN BLOCK - normal chain block
-	***  No adjacent chain blocks
-	***  May be the last block in the chain
-	***----------------------------------*/
-
 	else
 	{
 		if (RC_BAD( rc = ScaGetBlock( pDb, NULL, BHT_FREE,
@@ -1267,9 +1246,9 @@ FSTATIC RCODE FLRFreeAvailBlk(
 		}
 
 		pucBlk = pSCache->pucBlk;
-		ALPutNBC( pucBlk, uiNbcAddr);
-		ALPutPBC( pucBlk, uiPbcAddr);
-		UD2FBA( uiNextBlkAddr, &pucBlk [BH_NEXT_BLK]);
+		ALPutNBC( pucBlk, (FLMUINT32)uiNbcAddr);
+		ALPutPBC( pucBlk, (FLMUINT32)uiPbcAddr);
+		UD2FBA( (FLMUINT32)uiNextBlkAddr, &pucBlk [BH_NEXT_BLK]);
 		ScaReleaseCache( pSCache, FALSE);
 		bReleaseCache = FALSE;
 
@@ -1288,7 +1267,7 @@ FSTATIC RCODE FLRFreeAvailBlk(
 			}
 
 			pucBlk = pSCache->pucBlk;
-			ALPutNBC( pucBlk, uiPrevBlkAddr);
+			ALPutNBC( pucBlk, (FLMUINT32)uiPrevBlkAddr);
 			ScaReleaseCache( pSCache, FALSE);
 			bReleaseCache = FALSE;
 		}
@@ -1324,6 +1303,7 @@ FSTATIC RCODE FLRFreeAvailBlk(
 	}
 
 Exit:
+
 	if (bReleaseCache)
 	{
 		ScaReleaseCache( pSCache, FALSE);
@@ -1337,12 +1317,12 @@ Desc:	Move an avail block out of the avail block list.
 		Worry about version 1.11+ back chaining
 ****************************************************************************/
 FSTATIC RCODE  FLRFindPrevAvailBlk(
-	FDB_p			pDb,
+	FDB *			pDb,
+	FLMBYTE *	pucBlkHeader,
 	FLMUINT *	puiBlkAddrRV,
 	FLMBOOL *	pbFirstChainFlagRV)
 {
 	RCODE			rc = FERR_OK;
-	FLMBYTE		ucBlkHeader [BH_OVHD ];
 	FLMUINT		uiTargetBlkAddr = *puiBlkAddrRV;
 	FLMUINT		uiNextBlkAddr;
 	FLMUINT		uiNbcAddr;
@@ -1351,62 +1331,71 @@ FSTATIC RCODE  FLRFindPrevAvailBlk(
 	*pbFirstChainFlagRV = FALSE;
 
 	if( RC_BAD( rc = FLRReadBlkHdr( pDb, uiTargetBlkAddr,
-											  ucBlkHeader, (FLMINT *)0 )))
-		goto Exit;
-
-	uiNextBlkAddr = FB2UD( &ucBlkHeader [BH_NEXT_BLK]);
-	if ( uiNextBlkAddr == pDb->LogHdr.uiFirstAvailBlkAddr)
+		pucBlkHeader, (FLMINT *)0)))
 	{
-		/* Done */
 		goto Exit;
 	}
 
-	/* Find next chain block */
+	uiNextBlkAddr = FB2UD( &pucBlkHeader[ BH_NEXT_BLK]);
+	if( uiNextBlkAddr == pDb->LogHdr.uiFirstAvailBlkAddr)
+	{
+		goto Exit;
+	}
 
-	uiNbcAddr = ALGetNBC( ucBlkHeader);
+	// Find next chain block
+
+	uiNbcAddr = ALGetNBC( pucBlkHeader);
 	
-	while( ( !uiNbcAddr) && ( uiNextBlkAddr != BT_END))
+	while( !uiNbcAddr && (uiNextBlkAddr != BT_END))
 	{
 		if( RC_BAD( rc = FLRReadBlkHdr( pDb, uiNextBlkAddr,
-												  ucBlkHeader, (FLMINT *)0)))
+												  pucBlkHeader, (FLMINT *)0)))
+		{
 			goto Exit;
+		}
 
-		if( ( uiTempBlkAddr = GET_BH_ADDR( ucBlkHeader)) != uiNextBlkAddr)
+		if( (uiTempBlkAddr = GET_BH_ADDR( pucBlkHeader)) != uiNextBlkAddr)
 		{
 			rc = RC_SET( FERR_DATA_ERROR);
 			goto Exit;
 		}
-		uiNbcAddr = ALGetNBC( ucBlkHeader);
-		uiNextBlkAddr = FB2UD( &ucBlkHeader [BH_NEXT_BLK]);
+		
+		uiNbcAddr = ALGetNBC( pucBlkHeader);
+		uiNextBlkAddr = FB2UD( &pucBlkHeader [BH_NEXT_BLK]);
 	}
 
-	/* Now find the previous avail block */
+	// Now find the previous avail block
 
 	if( uiNbcAddr == BT_END)
 	{
 		uiNextBlkAddr = pDb->LogHdr.uiFirstAvailBlkAddr;
-		*pbFirstChainFlagRV = TRUE;		/* Within first chain */
+		*pbFirstChainFlagRV = TRUE;
 	}
 	else
+	{
 		uiNextBlkAddr = uiNbcAddr;
+	}
 
-	while( ( uiNextBlkAddr != uiTargetBlkAddr) && ( uiNextBlkAddr != BT_END))
+	while( (uiNextBlkAddr != uiTargetBlkAddr) && (uiNextBlkAddr != BT_END))
 	{
 		if (RC_BAD( rc = FLRReadBlkHdr( pDb, uiNextBlkAddr,
-												  ucBlkHeader, (FLMINT *)0 )))
+												  pucBlkHeader, (FLMINT *)0 )))
+		{
 			goto Exit;
+		}
 
-		if( ( uiTempBlkAddr = GET_BH_ADDR( ucBlkHeader)) != uiNextBlkAddr)
+		if( (uiTempBlkAddr = GET_BH_ADDR( pucBlkHeader)) != uiNextBlkAddr)
 		{
 			rc = RC_SET( FERR_DATA_ERROR);
 			goto Exit;
 		}
-		uiNextBlkAddr = FB2UD( &ucBlkHeader [BH_NEXT_BLK]);
+		
+		uiNextBlkAddr = FB2UD( &pucBlkHeader [BH_NEXT_BLK]);
 	}
 
 	*puiBlkAddrRV = uiTempBlkAddr;
 
 Exit:
-	return( rc );
-}
 
+	return( rc);
+}
