@@ -34,43 +34,43 @@ POOL_STATS	g_QueryPoolStats = {0,0};
 // Local Function Prototypes
 
 FSTATIC RCODE flmCurCopyQTInfo(
-	QTINFO_p		pSrc,
-	QTINFO_p		pDest,
-	POOL *		pPool);
+	QTINFO *		pSrc,
+	QTINFO *		pDest,
+	F_Pool *		pPool);
 
 FSTATIC void flmCurClearSelect(
-	CURSOR_p		pCursor);
+	CURSOR *		pCursor);
 
 FSTATIC RCODE flmCurPosToEOF(
-	CURSOR_p		pCursor);
+	CURSOR *		pCursor);
 
 FSTATIC RCODE flmCurPosToBOF(
-	CURSOR_p		pCursor);
+	CURSOR *		pCursor);
 
 FSTATIC RCODE flmCurSetPos(
-	CURSOR_p		pDestCursor,
-	CURSOR_p		pSrcCursor	);
+	CURSOR *		pDestCursor,
+	CURSOR *		pSrcCursor	);
 
 FSTATIC RCODE flmCurSetAbsolutePos(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMUINT		uiPosition,
 	FLMBOOL		bFallForward,
 	FLMUINT *	puiPosition);
 
 FSTATIC RCODE flmCurPositionable(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL *	pbPositionable);
 
 FSTATIC RCODE flmCurAbsPositionable(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL *	pbAbsPositionable);
 
 FSTATIC RCODE flmCurGetAbsolutePos(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMUINT *	puiPosition);
 
 FSTATIC RCODE flmCurGetAbsoluteCount(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMUINT *	puiCount);
 
 FSTATIC FLMBOOL flmCurMatchIndexPath( 
@@ -82,7 +82,7 @@ FSTATIC FLMBOOL flmCurMatchIndexPath(
 Desc: Finishes a source's invisible transaction, if any.
 ****************************************************************************/
 void flmCurFinishTrans(
-	CURSOR_p		pCursor)
+	CURSOR *		pCursor)
 {
 	FLMBOOL		bIgnore;
 
@@ -112,7 +112,7 @@ void flmCurFinishTrans(
 Desc: Initializes an FDB for a source.
 ****************************************************************************/
 RCODE flmCurDbInit(
-	CURSOR_p		pCursor)
+	CURSOR *		pCursor)
 {
 	RCODE			rc;
 	FLMBOOL		bStartedTrans;
@@ -131,27 +131,18 @@ RCODE flmCurDbInit(
 	return( rc);
 }
 
-/*API~***********************************************************************
-Name : FlmCursorInit
-Area : CURSOR
-Desc : Initializes a cursor for subsequent definition and navigation of
-		 a record set.  A cursor must be initialized before it can
-		 be used.
-*END************************************************************************/
-RCODE FlmCursorInit(
-	HFDB				hDb,
-		// [IN] Initial source database.
-	FLMUINT			uiContainer,
-		// [IN] Initial source container.
-	HFCURSOR  *		phCursor
-		// [OUT] Cursor handle to be initialized.  If initialization fails,
-		// the returned cursor handle will have a value of HFCURSOR_NULL.
-		// Otherwise, the cursor handle will be ready for use in subsequent
-		// calls to cursor routines.
-	)
+/****************************************************************************
+Desc:	Initializes a cursor for subsequent definition and navigation of
+		a record set.  A cursor must be initialized before it can
+		be used.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorInit(
+	HFDB			hDb,
+	FLMUINT		uiContainer,
+	HFCURSOR *	phCursor)
 {
 	RCODE       rc = FERR_OK;
-	CURSOR_p    pCursor = NULL;
+	CURSOR *    pCursor = NULL;
 	FDB *			pDb = (FDB *)hDb;
 
 	flmAssert( hDb != HFDB_NULL);
@@ -173,8 +164,8 @@ RCODE FlmCursorInit(
 
 	// Initialize cursor members
 
-	GedSmartPoolInit( &pCursor->QueryPool, &g_QueryPoolStats);
-	GedSmartPoolInit( &pCursor->SQPool, &g_SQPoolStats);
+	pCursor->QueryPool.smartPoolInit( &g_QueryPoolStats);
+	pCursor->SQPool.smartPoolInit( &g_SQPoolStats);
 
 	pCursor->pDb = pDb;
 	pCursor->uiContainer = uiContainer;
@@ -186,16 +177,15 @@ RCODE FlmCursorInit(
 	pCursor->uiCursorId = FCS_INVALID_ID;
 
 	pCursor->QTInfo.uiExpecting = FLM_Q_OPERAND;
-	pCursor->QTInfo.uiFlags = FLM_NOCASE | FLM_WILD;
+	pCursor->QTInfo.uiFlags = FLM_COMP_CASE_INSENSITIVE | FLM_COMP_WILD;
 
 Exit:
 	if (RC_BAD( rc))
 	{
 		if (pCursor)
 		{
-			GedPoolFree( &pCursor->QueryPool);
-
-			GedPoolFree( &pCursor->SQPool);
+			pCursor->QueryPool.poolFree();
+			pCursor->SQPool.poolFree();
 			f_free( &pCursor);
 		}
 	}
@@ -208,14 +198,14 @@ Desc:	Copies a passed-in query tree into a new tree, using the passed-in
 		memory pool.
 ****************************************************************************/
 FSTATIC RCODE flmCurCopyQTInfo(
-	QTINFO_p		pSrc,
-	QTINFO_p		pDest,
-	POOL *		pPool)
+	QTINFO *		pSrc,
+	QTINFO *		pDest,
+	F_Pool *		pPool)
 {
 	RCODE			rc = FERR_OK;
-	FQNODE_p		pDestParentNode;
-	FQNODE_p		pSrcCurrNode;
-	FQNODE_p		pDestCurrNode;
+	FQNODE *		pDestParentNode;
+	FQNODE *		pSrcCurrNode;
+	FQNODE *		pDestCurrNode;
 	FLMBOOL		bGoingUp = FALSE;
 	FLMBOOL		bTreeComplete;
 
@@ -366,26 +356,19 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
-Area : CURSOR
-Desc : Initializes a new cursor and sets its selection criteria and record
-		 sources to be the same as those of the passed-in cursor.
-*END************************************************************************/
-RCODE FlmCursorClone(
+/****************************************************************************
+Desc:	Initializes a new cursor and sets its selection criteria and record
+		sources to be the same as those of the passed-in cursor.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorClone(
 	HFCURSOR      hSource,
-		// [IN] Source cursor.
-	HFCURSOR  *   phCursor
-		// [OUT] Cursor handle to be initialized.  If initialization fails,
-		// the returned cursor handle will have a value of HFCURSOR_NULL.
-		// Otherwise, the cursor handle will be ready for use in subsequent
-		// calls to cursor routines.
-	)
+	HFCURSOR  *   phCursor)
 {
-	RCODE			rc = FERR_OK;
-	CURSOR_p    pSrcCursor;
-	CURSOR_p    pDestCursor = NULL;
+	RCODE				rc = FERR_OK;
+	CURSOR *    	pSrcCursor;
+	CURSOR *    	pDestCursor = NULL;
 
-	if ((pSrcCursor = (CURSOR_p)hSource) == NULL)
+	if ((pSrcCursor = (CURSOR *)hSource) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
@@ -413,8 +396,8 @@ RCODE FlmCursorClone(
 
 	// Initialize cursor members
 
-	GedSmartPoolInit( &pDestCursor->QueryPool, &g_QueryPoolStats);
-	GedSmartPoolInit( &pDestCursor->SQPool, &g_SQPoolStats);
+	pDestCursor->QueryPool.smartPoolInit( &g_QueryPoolStats);
+	pDestCursor->SQPool.smartPoolInit( &g_SQPoolStats);
 
 	// Set up a tree info structure for query declaration.
 
@@ -459,7 +442,7 @@ Exit:
 Desc: Frees up memory associated with a subquery structure.
 ****************************************************************************/
 void flmSQFree(
-	SUBQUERY_p     pSubQuery,
+	SUBQUERY *     pSubQuery,
 	FLMBOOL			bFreeEverything)
 {
 	if (!bFreeEverything)
@@ -475,7 +458,7 @@ void flmSQFree(
 	}
 	else
 	{
-		FQNODE_p	pCurrNode = pSubQuery->pTree;
+		FQNODE *	pCurrNode = pSubQuery->pTree;
 		QTYPES	eType;
 
 		// Free the memory associated with callbacks in the query tree.
@@ -516,7 +499,7 @@ void flmSQFree(
 			}
 		}
 
-		GedPoolFree( &pSubQuery->OptPool);
+		pSubQuery->OptPool.poolFree();
 
 		// Free up the file system cursors, if any.
 
@@ -542,11 +525,11 @@ void flmSQFree(
 Desc: Frees up memory associated with a cursor.
 ****************************************************************************/
 void flmCurFree(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFinishTrans)
 {
 	FLMUINT			uiCnt;
-	CS_CONTEXT_p	pCSContext;
+	CS_CONTEXT *	pCSContext;
 
 	if (bFinishTrans)
 	{
@@ -560,11 +543,11 @@ void flmCurFree(
 	// Free the memory associated with any subqueries.
 
 	flmCurFreeSQList( pCursor, TRUE);
-	GedPoolFree( &pCursor->SQPool);
+	pCursor->SQPool.poolFree();
 
 	// Free the memory associated with the pool structures
 
-	GedPoolFree( &pCursor->QueryPool);
+	pCursor->QueryPool.poolFree();
 	if (pCursor->pDRNSet)
 	{
 		pCursor->pDRNSet->Release();
@@ -630,56 +613,49 @@ CS_Exit:
 	return;
 }
 
-/*API~***********************************************************************
-Name : FlmCursorReleaseResources
-Area : CURSOR
+/****************************************************************************
 Desc:	Frees resources of the cursor without actually freeing the cursor.
 		Keeps around the stuff that is needed to display the cursor
 		information for debugging purposes after the fact.  At this point
 		the cursor is no longer usable.
-*END************************************************************************/
-void FlmCursorReleaseResources(
-	HFCURSOR	hCursor
-	)
+****************************************************************************/
+FLMEXP void FLMAPI FlmCursorReleaseResources(
+	HFCURSOR			hCursor)
 {
-	FLMUINT	uiCnt;
-	CURSOR_p	pCursor = (CURSOR_p)hCursor;
+	FLMUINT			uiCnt;
+	CURSOR *			pCursor = (CURSOR *)hCursor;
 
 	flmCurFinishTransactions( pCursor, TRUE);
 	flmCurFreeSQList( pCursor, FALSE);
+	
 	for (uiCnt = 0; uiCnt < pCursor->QTInfo.uiNumPredicates; uiCnt++)
 	{
 		pCursor->QTInfo.ppPredicates [uiCnt]->releaseResources();
 	}
 }
 
-/*API~***********************************************************************
-Name : FlmCursorFree
-Area : CURSOR
-Desc : Frees memory allocated to an initialized cursor.  The cursor handle
-		 cannot be used for additional cursor operations unless it is
-		 re-initialized.
-*END************************************************************************/
-RCODE FlmCursorFree(
-	HFCURSOR  *   phCursor
-		// [IN/OUT] Cursor handle to be de-allocated.
-		// The cursor handle must have been previously initialized.
-		// The value of the handle is guaranteed to be HFCURSOR_NULL
-		// if the operation is successful.
-	)
+/****************************************************************************
+Desc:	Frees memory allocated to an initialized cursor.  The cursor handle
+		cannot be used for additional cursor operations unless it is
+		re-initialized.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorFree(
+	HFCURSOR  *   	phCursor)
 {
-	CURSOR_p			pCursor = (CURSOR *)*phCursor;
-	F_LogMessage *	pLogMsg = NULL;
+	CURSOR *						pCursor = (CURSOR *)*phCursor;
+	IF_LogMessageClient *	pLogMsg = NULL;
 
-	flmAssert( pCursor != NULL);
-
-	// Log the query before getting rid of it
-
-	if ((pLogMsg = flmBeginLogMessage( FLM_QUERY_MESSAGE,
-							FLM_DEBUG_MESSAGE)) != NULL)
+	flmAssert( pCursor);
+	
+	if( gv_FlmSysData.pLogger)
 	{
-		flmLogQuery( pLogMsg, 0, pCursor);
-		flmEndLogMessage( &pLogMsg);
+		if ((pLogMsg = gv_FlmSysData.pLogger->beginMessage( FLM_QUERY_MESSAGE,
+								F_DEBUG_MESSAGE)) != NULL)
+		{
+			flmLogQuery( pLogMsg, 0, pCursor);
+			pLogMsg->endMessage();
+			pLogMsg->Release();
+		}
 	}
 
 	if (!pCursor->pCSContext && gv_FlmSysData.uiMaxQueries)
@@ -694,30 +670,18 @@ RCODE FlmCursorFree(
 		*phCursor = HFCURSOR_NULL;
 	}
 
-	return FERR_OK;
+	return( FERR_OK);
 }
 
-/*API~***********************************************************************
-Name : FlmCursorSetMode
-Area : CURSOR
-Desc : Sets flags in the query that determine text comparision modes and the
-		 granularity for QuickFinder indexes.
-*END************************************************************************/
-RCODE FlmCursorSetMode(
+/****************************************************************************
+Desc:	Sets flags in the query that determine text comparision modes
+		and the granularity for QuickFinder indexes.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorSetMode(
 	HFCURSOR    hCursor,
-			// [IN] Handle to a cursor.
 	FLMUINT		uiFlags)
-			// [IN] Possible values of uiFlags:
-			//
-			// FLM_NOCASE:  Indicates that case-insensitive comparisions should be
-			// made when comparing field content to a string value. (Text
-			// comparison mode)
-			//
-			// FLM_WILD:  Indicates that '*' and '?' characters will be treated
-			// as wild cards in a string value when comparing to field content.
-			// (Text comparison mode)
 {
-	CURSOR_p    pCursor = (CURSOR *)hCursor;
+	CURSOR *    pCursor = (CURSOR *)hCursor;
 
 	flmAssert( pCursor != NULL);
 
@@ -734,7 +698,7 @@ RCODE FlmCursorSetMode(
 Desc: Clears the selection criteria in a query.
 ****************************************************************************/
 FSTATIC void flmCurClearSelect(
-	CURSOR_p     pCursor)
+	CURSOR *     pCursor)
 {
 	flmCurFreeSQList( pCursor, TRUE);
 	pCursor->pTree = NULL;
@@ -748,9 +712,9 @@ FSTATIC void flmCurClearSelect(
 	pCursor->QTInfo.pCurAtomNode = NULL;
 	pCursor->QTInfo.uiNestLvl = 0;
 	pCursor->QTInfo.uiExpecting = FLM_Q_OPERAND;
-	pCursor->QTInfo.uiFlags = FLM_NOCASE | FLM_WILD;
+	pCursor->QTInfo.uiFlags = FLM_COMP_CASE_INSENSITIVE | FLM_COMP_WILD;
 
-	GedPoolReset( &pCursor->QueryPool, NULL);
+	pCursor->QueryPool.poolReset();
 
 	pCursor->uiLastRecID = 0;
 	pCursor->ReadRc = FERR_OK;
@@ -761,8 +725,7 @@ FSTATIC void flmCurClearSelect(
 Desc: Positions a cursor to EOF.
 ****************************************************************************/
 FSTATIC RCODE flmCurPosToEOF(
-	CURSOR_p	pCursor
-	)
+	CURSOR *		pCursor)
 {
 	RCODE			rc = FERR_OK;
 	FlmRecord *	pRecord = NULL;
@@ -800,7 +763,7 @@ FSTATIC RCODE flmCurPosToEOF(
 Desc: Positions a cursor to BOF.
 ****************************************************************************/
 FSTATIC RCODE flmCurPosToBOF(
-	CURSOR_p	pCursor
+	CURSOR *	pCursor
 	)
 {
 	RCODE			rc = FERR_OK;
@@ -840,16 +803,16 @@ Desc: Sets the positioning information in a query to be the same as that of
 		another query.
 ****************************************************************************/
 FSTATIC RCODE flmCurSetPos(
-	CURSOR_p		pDestCursor,
-	CURSOR_p		pSrcCursor)
+	CURSOR *		pDestCursor,
+	CURSOR *		pSrcCursor)
 {
 	RCODE			rc = FERR_OK;
-	FDB_p			pDb = NULL;
+	FDB *			pDb = NULL;
 	FlmRecord *	pRecord = NULL;
 	FLMUINT		uiRecordDrn;
 	FLMUINT		uiContainerNum;
-	SUBQUERY_p	pSrcSubQuery;
-	SUBQUERY_p	pDestSubQuery;
+	SUBQUERY *	pSrcSubQuery;
+	SUBQUERY *	pDestSubQuery;
 	FLMUINT		uiRecMatch;
 	FLMBYTE *	pucKeyBuffer = NULL;
 	FLMUINT		uiKeyLen;
@@ -919,7 +882,8 @@ FSTATIC RCODE flmCurSetPos(
 	// Initialize an FDB structure for various and sundry operations.
 
 	pDb = pDestCursor->pDb;
-	pvMark = GedPoolMark( &pDb->TempPool);
+	pvMark = pDb->TempPool.poolMark();
+	
 	if( RC_BAD( rc = flmCurDbInit( pDestCursor)))
 	{
 		goto Exit;
@@ -1129,15 +1093,18 @@ FSTATIC RCODE flmCurSetPos(
 	pDestCursor->pCurrSubQuery = pDestSubQuery;
 
 Exit:
+
 	if (pRecord)
 	{
 		pRecord->Release();
 	}
+	
 	if (pDb)
 	{
-		GedPoolReset( &pDb->TempPool, pvMark);
-		(void)fdbExit( pDb);
+		pDb->TempPool.poolReset( pvMark);
+		fdbExit( pDb);
 	}
+	
 	return( rc);
 }
 
@@ -1145,11 +1112,11 @@ Exit:
 Desc:	Saves the current cursor position.
 ****************************************************************************/
 RCODE flmCurSavePosition(
-	CURSOR_p	pCursor
+	CURSOR *	pCursor
 	)
 {
 	RCODE			rc = FERR_OK;
-	SUBQUERY_p	pSaveSubQuery;
+	SUBQUERY *	pSaveSubQuery;
 
 	pCursor->pSaveSubQuery = pSaveSubQuery = pCursor->pCurrSubQuery;
 	if (pSaveSubQuery)
@@ -1190,11 +1157,11 @@ Exit:
 Desc:	Restores the last cursor position that was saved.
 ****************************************************************************/
 RCODE flmCurRestorePosition(
-	CURSOR_p	pCursor
+	CURSOR *	pCursor
 	)
 {
 	RCODE			rc = FERR_OK;
-	SUBQUERY_p	pSaveSubQuery = pCursor->pSaveSubQuery;
+	SUBQUERY *	pSaveSubQuery = pCursor->pSaveSubQuery;
 
 	if ((pCursor->pCurrSubQuery =
 			pSaveSubQuery =
@@ -1238,7 +1205,7 @@ Exit:
 Desc:	Sets a cursor to an absolute position.
 ****************************************************************************/
 FSTATIC RCODE flmCurSetAbsolutePos(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMUINT		uiPosition,
 	FLMBOOL		bFallForward,
 	FLMUINT *	puiPosition
@@ -1420,7 +1387,7 @@ FSTATIC RCODE flmCurSetAbsolutePos(
 
 			if (pCursor->uiTimeLimit)
 			{
-				FLM_TIMER_UNITS_TO_SECS( pCursor->uiTimeLimit, uiSeconds);
+				uiSeconds = FLM_TIMER_UNITS_TO_SECS( pCursor->uiTimeLimit);
 				if (!uiSeconds)
 				{
 					uiSeconds = 1;
@@ -1579,116 +1546,19 @@ Exit:
 	return( pCursor->rc = rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Allows configuration of cursor attributes, including assignment of
 		 QuickFinder strings, indexes and search records.
-*END************************************************************************/
-RCODE FlmCursorConfig(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorConfig(
 	HFCURSOR				hCursor,
-		// [IN] Handle to a cursor.
 	eCursorConfigType	eConfigType,
-		// [IN] Cursor element to configure.  Possible values of uiType:
-		//
-		//      PARAM     TYPE       MEANING / USE
-		//
-		// FCURSOR_ALLOW_DUPS:  Allow duplicate keys to be returned.
-		//      Value1    N/A        N/A
-		//      Value2    N/A        N/A
-		//
-		// FCURSOR_ELIMINATE_DUPS:  Eliminate duplicate keys.
-		//      Value1    N/A        N/A
-		//      Value2    N/A        N/A
-		//
-		// FCURSOR_CLEAR_QUERY:  Clears the query criteria.
-		//      Value1    N/A        N/A
-		//      Value2    N/A        N/A
-		//
-		//	FCURSOR_DISCONNECT:  Calls into QuickFinder to free memory
-		// associated with files used by QF.
-		//      Value1    N/A        N/A
-		//      Value2    N/A        N/A
-		//
-		//	FCURSOR_GEN_POS_KEYS:  Generates an array of positioning keys for
-		// a cursor.
-		//      Value1    N/A        N/A
-		//      Value2    N/A        N/A
-		//
-		// FCURSOR_SET_HDB:  Resets the database handle associated with this
-		// cursor.
-		//      Value1    HFDB     Database handle to be used for cursor.
-		//      Value2    N/A      N/A
-		//
-		// FCURSOR_SET_FLM_IX:  Sets the index to be used by the cursor.
-		//      Value1    FLMUINT     Index number.
-		//      Value2    N/A         N/A
-		//
-		// FCURSOR_SET_OP_TIME_LIMIT:	Sets a time limit for the next read
-		// operation.
-		//      Value1    FLMUINT    Time limit in seconds.
-		//      Value2    N/A        N/A
-		//
-		// FCURSOR_SET_PERCENT_POS:  Sets the percentage position in the
-		// cursor's result set.
-		//      Value1    FLMUINT     Percentage value (1 - 100) to which the
-		//                           cursor position is to be set.
-		//      Value2    N/A        N/A
-		//
-		// FCURSOR_SET_ABS_POS:  Sets the absolute position in the
-		// cursor's result set.
-		//      Value1    FLMUINT *	Absolute position to which the cursor
-		//										is to be set.  Also returns the
-		//										position actually set to (if we fall
-		//										forward or backward).
-		//      Value2    FLMBOOL		If the position specified doesn't
-		//										pass the criteria, this flag specifies
-		//										whether to fall forward or backward.
-		//										TRUE=fall forward, FALSE=fall backward.
-		//
-		// FCURSOR_SET_POS:  Sets the cursor position from that of another
-		// cursor.
-		//      Value1    HFCURSOR   Handle to cursor from which position is
-		//                           to be set.
-		//      Value2    N/A        N/A
-		//
-		// FCURSOR_SET_POS_FROM_DRN:  Sets the cursor position from a DRN.
-		//      Value1    FLMUINT    DRN from which position is to be set.
-		//      Value2    N/A        N/A
-		//
-		// FCURSOR_SET_REC_TYPE:  Sets the record type associated with a
-		// cursor.  Only records of the specified type will be returned by
-		// by the cursor.
-		//      Value1    FLMUINT     Record type ID.
-		//      Value2    N/A         N/A
-		//
-		// FCURSOR_RETURN_KEYS_OK:  Sets the cursor to return keys, if possible.
-		//      Value1    FLMBOOL    TRUE = return keys, FALSE = return records
-		//      Value2    N/A        N/A
-		//
-		// FCURSOR_SET_REC_VALIDATOR: Set record validator for cursor.
-		//      Value1    REC_VALIDATOR_HOOK		  N/A
-		//      Value2    Data to be passed to callback.
-		//
-		// FCURSOR_SET_STATUS_HOOK: Set status callback for cursor.
-		//      Value1    STATUS_HOOK		  N/A
-		//      Value2    Data to be passed to callback.
-		//
-		// FCURSOR_SAVE_POSITION: Save current position of cursor.
-		//      Value1    N/A		  N/A
-		//      Value2    N/A		  N/A
-		//
-		// FCURSOR_RESTORE_POSITION: Restore cursor to last saved
-		// position.
-		//      Value1    N/A		  N/A
-		//      Value2    N/A		  N/A
-		//
-	void *      Value1,
-		// [IN] The type and domain of Value1 are determined by eConfigType.
-	void *      Value2
-		// [IN] The type and domain of Value2 are determined by eConfigType.
+	void *				Value1,
+	void *				Value2
 	)
 {
 	RCODE			rc = FERR_OK;
-	CURSOR_p		pCursor = (CURSOR *)hCursor;
+	CURSOR *		pCursor = (CURSOR *)hCursor;
 
 	if (!pCursor)
 	{
@@ -1767,7 +1637,7 @@ RCODE FlmCursorConfig(
 			break;
 
 		case FCURSOR_RETURN_KEYS_OK:
-			pCursor->bOkToReturnKeys = (FLMBOOL)((FLMBOOL)Value1 ? TRUE : FALSE);
+			pCursor->bOkToReturnKeys = (FLMBOOL)((FLMBOOL)(FLMUINT)Value1 ? TRUE : FALSE);
 			break;
 
 		case FCURSOR_SET_FLM_IX:
@@ -1800,8 +1670,7 @@ RCODE FlmCursorConfig(
 			uiTimeLimit = pCursor->uiTimeLimit = (FLMUINT)Value1;
 			if (uiTimeLimit)
 			{
-				FLM_SECS_TO_TIMER_UNITS( uiTimeLimit,
-							pCursor->uiTimeLimit);
+				pCursor->uiTimeLimit = FLM_SECS_TO_TIMER_UNITS( uiTimeLimit);
 			}
 			break;
 		}
@@ -1826,15 +1695,15 @@ RCODE FlmCursorConfig(
 			}
 			rc = flmCurSetAbsolutePos( pCursor,
 									*((FLMUINT *)Value1),
-									(FLMBOOL)Value2,
+									(FLMBOOL)(FLMUINT)Value2,
 									(FLMUINT *)Value1);
 			break;
 
 		case FCURSOR_SET_POS:
 		{
-			CURSOR_p      pPosCursor;
+			CURSOR *      pPosCursor;
 
-			if ((pPosCursor = (CURSOR_p)Value1) == NULL)
+			if ((pPosCursor = (CURSOR *)Value1) == NULL)
 			{
 				flmAssert( 0);
 				rc = RC_SET( FERR_INVALID_PARM);
@@ -1904,15 +1773,14 @@ Exit:
 }
 
 /************************************************************************
-Name : flmCurPositionable
 Desc : Returns whether or not a query is positionable.
 *************************************************************************/
 FSTATIC RCODE flmCurPositionable(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL *	pbPositionable)
 {
 	RCODE			rc = FERR_OK;
-	SUBQUERY_p	pSubQuery;
+	SUBQUERY *	pSubQuery;
 
 	*pbPositionable = FALSE;
 
@@ -1948,15 +1816,14 @@ Exit:
 }
 
 /************************************************************************
-Name : flmCurAbsPositionable
 Desc : Returns whether or not a query is absolute positionable.
 *************************************************************************/
 FSTATIC RCODE flmCurAbsPositionable(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL *	pbAbsPositionable)
 {
 	RCODE			rc = FERR_OK;
-	SUBQUERY_p	pSubQuery;
+	SUBQUERY *	pSubQuery;
 	FLMBOOL		bSavedInvisTrans;
 
 	*pbAbsPositionable = FALSE;
@@ -2000,11 +1867,10 @@ Exit:
 }
 
 /************************************************************************
-Name : flmCurGetAbsolutePos
 Desc : Returns absolute position of cursor.
 *************************************************************************/
 FSTATIC RCODE flmCurGetAbsolutePos(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMUINT *	puiPosition
 	)
 {
@@ -2080,13 +1946,12 @@ Exit:
 }
 
 /************************************************************************
-Name : flmCurGetAbsoluteCount
 Desc : Returns absolute count for the cursor's index.  NOTE: This is
 		 not necessarily the same thing as the number of records that
 		 will pass the filter criteria.
 *************************************************************************/
 FSTATIC RCODE flmCurGetAbsoluteCount(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMUINT *	puiCount
 	)
 {
@@ -2145,107 +2010,17 @@ Exit:
 	return( pCursor->rc = rc);
 }
 
-/*API~***********************************************************************
-Name : FlmCursorGetConfig
-Area : CURSOR
-Desc : Returns FLAIM cursor configuration values.
-*END************************************************************************/
-RCODE FlmCursorGetConfig(
+/****************************************************************************
+Desc:	Returns FLAIM cursor configuration values.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorGetConfig(
 	HFCURSOR						hCursor,
-		// [IN] Handle to a cursor.
 	eCursorGetConfigType		eGetConfigType,
-		// [IN] Cursor element to retrieve.  Possible values of uiType:
-		//
-		//      PARAM     TYPE             MEANING / USE
-		//
-		// FCURSOR_GET_PERCENT_POS:  Returns the percentage position of the
-		// cursor's current position.
-		//      Value1    FLMUINT *      Pointer to where percentage
-		//                               position is to be returned.
-		//
-		// FCURSOR_GET_ABS_POS:  Finds the absolute position of the
-		// cursor's current position.
-		//      Value1    FLMUINT *      Pointer to where absolute
-		//                               position is to be returned.
-		//
-		// FCURSOR_GET_ABS_COUNT:  Returns the absolute count of the
-		// cursor's index range.  NOTE: This is not necessarily the count of
-		// records that will pass the query criteria.
-		//      Value1    FLMUINT *      Pointer to where count
-		//                               is to be returned.
-		//
-		// FCURSOR_GET_OPT_INFO_LIST:  Populates a preallocated array of
-		// OPT_INFO structures with information from the subqueries in
-		// the current cursor.  NOTE:  the size of the array should be
-		// determined by calling this API with a NULL OPT_INFO *.
-		//      Value1    OPT_INFO *		Preallocated array of OPT_INFO
-		//                               structures to be populated.
-		//      Value2    FLMUINT *      Size of the array. A null Value1 will
-		//                               return the total number of sub queries.
-		//
-		// FCURSOR_GET_OPT_INFO:  Retrieves information about how a particular
-		// subquery is being optimized.
-		//      Value1    N/A            N/A
-		//		  Value2		OPT_INFO *		Preallocated OPT_INFO structure.
-		//
-		// FCURSOR_GET_FLM_IX:  Retrieves the number of the index being used
-		// to optimize query.  0 is returned if there is no index associated
-		// with the current cursor or if multiple indexes are being used.  In
-		// the case of multiple indexes, Value2 can be used to differentiate
-		// the use of multiple indexes from the no index case.
-		//      Value1    FLMUINT *		Storage location for returning the
-		//                               index number.
-		//      Value2    FLMUINT *		Index information
-		//												HAVE_NO_INDEX
-		//												HAVE_ONE_INDEX
-		//												HAVE_ONE_INDEX_MULT_PARTS
-		//												HAVE_MULTIPLE_INDEXES
-		//
-		// FCURSOR_GET_REC_TYPE:  Retrieves the record type associated with
-		// a cursor.
-		//      Value1    FLMUINT *      Storage location for returning the
-		//											record type.
-		//      Value2    N/A            N/A
-		//
-		// FCURSOR_GET_FLAGS:  Retrieves flags set by FlmCursorSetMode.
-		//      Value1    FLMUINT *      Storage location for returning the
-		//                               cursor flags.
-		//      Value2    N/A            N/A
-		//
-		// FCURSOR_GET_STATE:  Retrieves flags describing the state of the query.
-		//      Value1    FLMUINT *      Storage location for returning the
-		//                               state flags.
-		//      Value2    N/A            N/A
-		//
-		// FCURSOR_GET_POSITIONABLE:  Determines if a cursor is positionable.
-		//      Value1    FLMBOOL *      Storage location for returning whether
-		//                               or not the cursor is positionable.
-		//      Value2    N/A            N/A
-		//
-		// FCURSOR_GET_ABS_POSITIONABLE:  Determines if a cursor is
-		//	absolute positionable.
-		//      Value1    FLMBOOL *      Storage location for returning whether
-		//                               or not the cursor is absolute positionable.
-		//      Value2    N/A            N/A
-		//
-		// FCURSOR_AT_BOF:  Determines if a cursor is at BOF.
-		//      Value1    FLMBOOL *      Storage location for returning whether
-		//                               or not the cursor is at BOF.
-		//      Value2    N/A            N/A
-		//
-		// FCURSOR_AT_EOF:  Determines if a cursor is at EOF.
-		//      Value1    FLMBOOL *      Storage location for returning whether
-		//                               or not the cursor is at EOF.
-		//      Value2    N/A            N/A
-		//
-	void *					Value1,
-		// [IN/OUT] The type and domain of Value1 is determined by uiType.
-	void *					Value2
-		// [OUT] The type and domain of Value2 is determined by uiType.
-	)
+	void *						Value1,
+	void *						Value2)
 {
 	RCODE			rc = FERR_OK;
-	CURSOR_p		pCursor = (CURSOR *)hCursor;
+	CURSOR *		pCursor = (CURSOR *)hCursor;
 
 	if (!pCursor)
 	{
@@ -2262,6 +2037,7 @@ RCODE FlmCursorGetConfig(
 	switch( eGetConfigType)
 	{
 		case FCURSOR_GET_PERCENT_POS:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2270,8 +2046,12 @@ RCODE FlmCursorGetConfig(
 			{
 				rc = flmCurGetPercentPos( pCursor, (FLMUINT *)Value1);
 			}
+			
 			break;
+		}
+			
 		case FCURSOR_GET_ABS_POS:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2280,8 +2060,12 @@ RCODE FlmCursorGetConfig(
 			{
 				rc = flmCurGetAbsolutePos( pCursor, (FLMUINT *)Value1);
 			}
+			
 			break;
+		}
+			
 		case FCURSOR_GET_ABS_COUNT:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2290,8 +2074,12 @@ RCODE FlmCursorGetConfig(
 			{
 				rc = flmCurGetAbsoluteCount( pCursor, (FLMUINT *)Value1);
 			}
+			
 			break;
+		}
+		
 		case FCURSOR_GET_OPT_INFO_LIST:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2310,6 +2098,7 @@ RCODE FlmCursorGetConfig(
 						goto Exit;
 					}
 				}
+				
 				for (pSubQuery = pCursor->pSubQueryList;
 					  pSubQuery;
 					  pSubQuery = pSubQuery->pNext)
@@ -2319,12 +2108,18 @@ RCODE FlmCursorGetConfig(
 						f_memcpy( &pOptInfoArray[ uiSubQueryCnt],
 										&pSubQuery->OptInfo, sizeof( OPT_INFO));   
 					}
+					
 					uiSubQueryCnt++;
 				}
+				
 				*puiSubQueryCnt = uiSubQueryCnt;
 			}
+			
 			break;
+		}
+		
 		case FCURSOR_GET_OPT_INFO:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2338,14 +2133,19 @@ RCODE FlmCursorGetConfig(
 						goto Exit;
 					}
 				}
+				
 				if (pCursor->pSubQueryList)
 				{
 					f_memcpy( (OPT_INFO *)Value2,
 						&pCursor->pSubQueryList->OptInfo, sizeof( OPT_INFO));
 				}
 			}
+			
 			break;
+		}
+		
 		case FCURSOR_GET_FLM_IX:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2366,7 +2166,7 @@ RCODE FlmCursorGetConfig(
 
 				if( pCursor->pSubQueryList)
 				{
-					SUBQUERY_p		pTmpSubQuery = pCursor->pSubQueryList;
+					SUBQUERY *		pTmpSubQuery = pCursor->pSubQueryList;
 					FLMUINT			uiSQIndex = 0;
 
 					while( pTmpSubQuery)
@@ -2382,7 +2182,9 @@ RCODE FlmCursorGetConfig(
 						{
 							FLMUINT	uiTmpIndexInfo;
 
-							uiSQIndex = pTmpSubQuery->pPredicate->getIndex( &uiTmpIndexInfo);
+							uiSQIndex = pTmpSubQuery->pPredicate->getIndex( 
+												&uiTmpIndexInfo);
+												
 							if (uiTmpIndexInfo == HAVE_MULTIPLE_INDEXES)
 							{
 								if (!uiIxNum)
@@ -2455,14 +2257,24 @@ RCODE FlmCursorGetConfig(
 					*((FLMUINT *)Value2) = uiIndexInfo;
 				}
 			}
+			
 			break;
+		}
+		
 		case FCURSOR_GET_REC_TYPE:
+		{
 			*((FLMUINT *)Value1) = pCursor->uiRecType;
 			break;
+		}
+		
 		case FCURSOR_GET_FLAGS:
+		{
 			*((FLMUINT *)Value1) = pCursor->QTInfo.uiFlags;
 			break;
+		}
+		
 		case FCURSOR_GET_STATE:
+		{
 			*((FLMUINT *)Value1) = 0;
 
 			if (pCursor->QTInfo.pTopNode ||
@@ -2471,23 +2283,30 @@ RCODE FlmCursorGetConfig(
 			{
 				*((FLMUINT *)Value1) |= FCURSOR_HAVE_CRITERIA;
 			}
+			
 			if (pCursor->QTInfo.uiExpecting & FLM_Q_OPERATOR)
 			{
 				*((FLMUINT *)Value1) |= FCURSOR_EXPECTING_OPERATOR;
 			}
+			
 			if ((pCursor->QTInfo.uiNestLvl == 0) ||
 				 ((pCursor->QTInfo.uiExpecting & FLM_Q_OPERATOR) &&
 					pCursor->QTInfo.pTopNode))
 			{
 				*((FLMUINT *)Value1) |= FCURSOR_QUERY_COMPLETE;
 			}
+			
 			if (pCursor->bOptimized)
 			{
 				*((FLMUINT *)Value1) |=
 					(FCURSOR_QUERY_OPTIMIZED | FCURSOR_READ_PERFORMED);
 			}
+			
 			break;
+		}
+		
 		case FCURSOR_GET_POSITIONABLE:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2496,8 +2315,12 @@ RCODE FlmCursorGetConfig(
 			{
 				rc = flmCurPositionable( pCursor, (FLMBOOL *)Value1);
 			}
+			
 			break;
+		}
+		
 		case FCURSOR_GET_ABS_POSITIONABLE:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2506,8 +2329,12 @@ RCODE FlmCursorGetConfig(
 			{
 				rc = flmCurAbsPositionable( pCursor, (FLMBOOL *)Value1);
 			}
+			
 			break;
+		}
+		
 		case FCURSOR_AT_BOF:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2521,13 +2348,18 @@ RCODE FlmCursorGetConfig(
 						goto Exit;
 					}
 				}
+				
 				*((FLMBOOL *)Value1) = (FLMBOOL)((!pCursor->uiLastRecID &&
 															 pCursor->ReadRc == FERR_BOF_HIT)
 															? (FLMBOOL)TRUE
 															: (FLMBOOL)FALSE);
 			}
+			
 			break;
+		}
+		
 		case FCURSOR_AT_EOF:
+		{
 			if (pCursor->pCSContext)
 			{
 				rc = RC_SET( FERR_NOT_IMPLEMENTED);
@@ -2541,24 +2373,31 @@ RCODE FlmCursorGetConfig(
 						goto Exit;
 					}
 				}
+				
 				*((FLMBOOL *)Value1) = (FLMBOOL)((!pCursor->uiLastRecID &&
 															 pCursor->ReadRc == FERR_EOF_HIT)
 															? (FLMBOOL)TRUE
 															: (FLMBOOL)FALSE);
 			}
+			
 			break;
+		}
+		
 		default:
+		{
 			rc = RC_SET( FERR_NOT_IMPLEMENTED);
 			break;
+		}
 	}
 
 Exit:
+
 	return( rc);
 }
 
 /****************************************************************************
-Desc: 	Given a IFD this function will verify that the input path matches and
-			that it is in the same position (for compound keys)
+Desc: Given a IFD this function will verify that the input path matches and
+		that it is in the same position (for compound keys)
 ****************************************************************************/
 FSTATIC FLMBOOL flmCurMatchIndexPath( 
 	IFD *			pIfd, 
@@ -2594,7 +2433,7 @@ Exit:
 	return( bIsMatch);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc:		Uses the specified field path[s] to find a matching ordering index.
 Note:		FlmCursorConfig( type == FCURSOR_SET_FLM_IX) and FlmCursorSetOrderIndex
 			cannot both be called for the same cursor (they will override each 
@@ -2602,8 +2441,8 @@ Note:		FlmCursorConfig( type == FCURSOR_SET_FLM_IX) and FlmCursorSetOrderIndex
 Warning:	The index selected from this call will be used for query optimization
 			in addition to ordering the results. This could result in slower
 			query performance.
-*END************************************************************************/
-RCODE FlmCursorSetOrderIndex(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorSetOrderIndex(
 	HFCURSOR		hCursor,
 	FLMUINT *	puiFieldPaths,		/* List of field paths to match on. Each path
 												is terminated with a single 0, and the 
@@ -2613,11 +2452,11 @@ RCODE FlmCursorSetOrderIndex(
 												was found. */
 {
 	RCODE			rc = FERR_OK;
-	CURSOR_p    pCursor = (CURSOR *)hCursor;
-	FDB_p			pDb = NULL;
-	IFD_p			pIfd;
-	IFD_p			pIfd2;
-	IXD_p			pIxd;
+	CURSOR *    pCursor = (CURSOR *)hCursor;
+	FDB *			pDb = NULL;
+	IFD *			pIfd;
+	IFD *			pIfd2;
+	IXD *			pIxd;
 	FLMUINT *	puiField = puiFieldPaths;
 	FLMUINT		uiPos;
 	FLMUINT		uiScore;
@@ -2781,10 +2620,10 @@ Exit:
 Desc:
 ****************************************************************************/
 void flmCurFreeSQList(
-	CURSOR_p	pCursor,
+	CURSOR *	pCursor,
 	FLMBOOL	bFreeEverything)
 {
-	SUBQUERY_p	pSubQuery;
+	SUBQUERY *	pSubQuery;
 
 	for( pSubQuery = pCursor->pSubQueryList;
 		  pSubQuery;
@@ -2795,7 +2634,7 @@ void flmCurFreeSQList(
 
 	if (bFreeEverything)
 	{
-		GedPoolReset( &pCursor->SQPool, NULL);
+		pCursor->SQPool.poolReset();
 		pCursor->pSubQueryList = NULL;
 	}
 }
