@@ -25,7 +25,7 @@
 #include "flaimsys.h"
 
 FSTATIC RCODE flmCurCSTestRec(
-	CURSOR_p			pCursor,
+	CURSOR *			pCursor,
 	FLMUINT			uiDrn,
 	FlmRecord *		pTestRec,
 	FLMBOOL *		pbIsMatchRV);
@@ -35,8 +35,8 @@ Desc: Makes a SET_DEL from a record.
 ****************************************************************************/
 RCODE flmCurMakeKeyFromRec(
 	FDB *				pDb,
-	IXD_p				pIxd,
-	POOL *			pPool,
+	IXD *				pIxd,
+	F_Pool *			pPool,
 	FlmRecord *		pRec,
 	FLMBYTE **		ppucKeyBuffer,
 	FLMUINT *		puiKeyLen)
@@ -78,10 +78,8 @@ RCODE flmCurMakeKeyFromRec(
 
 	if (!(*ppucKeyBuffer))
 	{
-		if ((*ppucKeyBuffer = (FLMBYTE *)GedPoolCalloc( 
-			pPool, MAX_KEY_SIZ)) == NULL)
+		if( RC_BAD( rc = pPool->poolCalloc( MAX_KEY_SIZ, (void **)ppucKeyBuffer)))
 		{
-			rc = RC_SET( FERR_MEM);
 			goto Exit;
 		}
 	}
@@ -111,17 +109,17 @@ Exit:
 Desc:	Sets a query's position from a passed-in DRN.
 ****************************************************************************/
 RCODE flmCurSetPosFromDRN(
-	CURSOR_p			pCursor,
+	CURSOR *			pCursor,
 	FLMUINT			uiDRN
 	)
 {
 	RCODE				rc = FERR_OK;
 	FlmRecord *		pRec = NULL;
-	POOL *			pTempPool;
-	FDB_p				pDb = NULL;
-	IXD_p				pIxd;
+	F_Pool *			pTempPool;
+	FDB *				pDb = NULL;
+	IXD *				pIxd;
 	LFILE *			pLFile;
-	SUBQUERY_p		pSubQuery;
+	SUBQUERY *		pSubQuery;
 	FLMBOOL			bPositioned;
 	FLMBYTE *		pucKeyBuffer = NULL;
 	FLMUINT			uiKeyLen;
@@ -303,10 +301,10 @@ Exit:
 	return( pCursor->rc = rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc:	Given a cursor and two DRNs, this API does the following:
-*END************************************************************************/
-RCODE FlmCursorCompareDRNs(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorCompareDRNs(
 	HFCURSOR		hCursor,
 	FLMUINT		uiDRN1,
 	FLMUINT		uiDRN2,
@@ -316,16 +314,16 @@ RCODE FlmCursorCompareDRNs(
 	FLMUINT *	puiCount)
 {
 	RCODE					rc = FERR_OK;
-	CURSOR_p				pCursor = (CURSOR *)hCursor;
-	FDB_p					pDb = NULL;
-	POOL *				pTempPool;
+	CURSOR *				pCursor = (CURSOR *)hCursor;
+	FDB *					pDb = NULL;
+	F_Pool *				pTempPool;
 	FLMBYTE *			pucKey1;
 	FLMUINT				uiKey1Len;
 	FLMBYTE *			pucKey2;
 	FLMUINT				uiKey2Len;
 	FlmRecord *			pRec1 = NULL;
 	FlmRecord *			pRec2 = NULL;
-	IXD_p					pIxd;
+	IXD *					pIxd;
 	FSIndexCursor *	pTmpFSIndexCursor = NULL;
 	FSIndexCursor *	pSaveFSIndexCursor = NULL;
 	FLMUINT				uiSaveTimeLimit = 0;
@@ -638,7 +636,7 @@ RCODE FlmCursorCompareDRNs(
 	}
 	else
 	{
-		FLM_SECS_TO_TIMER_UNITS( uiTimeLimit, pCursor->uiTimeLimit);
+		pCursor->uiTimeLimit = FLM_SECS_TO_TIMER_UNITS( uiTimeLimit);
 	}
 
 	// Perform the count operation.
@@ -693,14 +691,14 @@ Desc:	Does FlmCursorTestRec and FlmCursorTestDRN over the client/server
 		line.
 ****************************************************************************/
 FSTATIC RCODE flmCurCSTestRec(
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMUINT		uiDrn,
 	FlmRecord *	pTestRec,
 	FLMBOOL *	pbIsMatchRV
 	)
 {
 	RCODE				rc = FERR_OK;
-	CS_CONTEXT_p	pCSContext = pCursor->pCSContext;
+	CS_CONTEXT *	pCSContext = pCursor->pCSContext;
 	FCL_WIRE			Wire( pCSContext);
 
 	// If there is no VALID id for the cursor, get one.
@@ -768,29 +766,22 @@ Transmission_Error:
 }
 
 
-/*API~***********************************************************************
-Name : FlmCursorTestRec
-Area : CURSOR
-Desc : Checks a record that has been retrieved from the database to see if
-		 satisfies the cursor selection criteria.
-		 IMPORTANT NOTE: pRec's containerID better be set to the container it
-		 came from, because flmCurEvalCriteria verifies that the record's
-		 container number matches the cursor's container number.
-*END************************************************************************/
-RCODE FlmCursorTestRec(
+/****************************************************************************
+Desc:	Checks a record that has been retrieved from the database to see if
+		satisfies the cursor selection criteria.
+		IMPORTANT NOTE: pRec's containerID better be set to the container it
+		came from, because flmCurEvalCriteria verifies that the record's
+		container number matches the cursor's container number.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorTestRec(
 	HFCURSOR			hCursor,
-		// [IN] Handle to a cursor.
 	FlmRecord * 	pRec,
-		// [IN] Pointer to the record to be checked.
-	FLMBOOL * 		pbIsMatch
-		// [OUT] If *pbIsMatch == TRUE, then the record is a match.
-		// Otherwise, the record did not meet the criteria and is not a match.
-	)
+	FLMBOOL * 		pbIsMatch)
 {
-	RCODE			rc = FERR_OK;
-	FDB_p			pDb = NULL;
-	CURSOR_p		pCursor = (CURSOR *)hCursor;
-	SUBQUERY_p	pSubQuery;
+	RCODE				rc = FERR_OK;
+	FDB *				pDb = NULL;
+	CURSOR *			pCursor = (CURSOR *)hCursor;
+	SUBQUERY *		pSubQuery;
 
 	flmAssert( pCursor != NULL);
 	*pbIsMatch = FALSE;
@@ -868,32 +859,22 @@ Exit2:
 	return( rc);
 }
 
-/*API~***********************************************************************
-Name : FlmCursorTestDRN
-Area : CURSOR
-Desc : Retrieves the record identified by the passed-in DRN and checks it to
-		 see if it satisfies the cursor selection criteria.
-Notes: This function is designed for use with cursors having only one
-		 associated source.  Multiple sources are not supported.
-*END************************************************************************/
-RCODE 
-		// FERR_NOT_IMPLEMENTED - The source list associated with the cursor
-		// is either empty or contains more than one source.
-	FlmCursorTestDRN(
-		HFCURSOR			hCursor,
-			// [IN] Handle to a cursor.
-		FLMUINT 			uiDrn,
-			// [IN] DRN of the record to be checked.
-		FLMBOOL * 		pbIsMatch
-			// [OUT] If *pbIsMatch == TRUE, then the record is a match.
-			// Otherwise, the record did not meet the criteria and is not a match.
-	)
+/****************************************************************************
+Desc:		Retrieves the record identified by the passed-in DRN and checks it
+			to see if it satisfies the cursor selection criteria.
+Notes: 	This function is designed for use with cursors having only one
+		 	associated source.  Multiple sources are not supported.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorTestDRN(
+	HFCURSOR			hCursor,
+	FLMUINT 			uiDrn,
+	FLMBOOL * 		pbIsMatch)
 {
-	RCODE			rc = FERR_OK;
-	FDB_p			pDb = NULL;
-	CURSOR_p		pCursor = (CURSOR *)hCursor;
-	SUBQUERY_p	pSubQuery;
-	FlmRecord *	pRec = NULL;
+	RCODE				rc = FERR_OK;
+	FDB *				pDb = NULL;
+	CURSOR *			pCursor = (CURSOR *)hCursor;
+	SUBQUERY *		pSubQuery;
+	FlmRecord *		pRec = NULL;
 
 	flmAssert( pCursor != NULL);
 	*pbIsMatch = FALSE;
