@@ -25,41 +25,41 @@
 #include "flaimsys.h"
 
 FSTATIC void flmLogIndent(
-	F_LogMessage *	pLogMsg,
-	FLMUINT			uiIndent);
+	IF_LogMessageClient *	pLogMsg,
+	FLMUINT						uiIndent);
 
 FSTATIC void flmLogOperator(
-	F_LogMessage *	pLogMsg,
-	QTYPES			eOperator,
-	FLMBOOL			bEndLine);
+	IF_LogMessageClient *	pLogMsg,
+	QTYPES						eOperator,
+	FLMBOOL						bEndLine);
 
 FSTATIC void flmLogBinary(
-	F_LogMessage *	pLogMsg,
-	FLMBYTE *		pucBuf,
-	FLMUINT			uiBufLen);
+	IF_LogMessageClient *	pLogMsg,
+	FLMBYTE *					pucBuf,
+	FLMUINT						uiBufLen);
 
 FSTATIC void flmLogText(
-	F_LogMessage *	pLogMsg,
-	const char *	pucBuf,
-	FLMUINT			uiBufLen);
+	IF_LogMessageClient *	pLogMsg,
+	const char *				pucBuf,
+	FLMUINT						uiBufLen);
 
 FSTATIC void flmLogPredicate(
-	F_LogMessage *	pLogMsg,
-	FLMUINT			uiIndent,
-	FQNODE *			pQNode);
+	IF_LogMessageClient *	pLogMsg,
+	FLMUINT						uiIndent,
+	FQNODE *						pQNode);
 
 FSTATIC void flmLogSubQuery(
-	F_LogMessage *	pLogMsg,
-	FLMUINT			uiIndent,
-	QTYPES			eParentOp,
-	SUBQUERY *		pSubQuery);
+	IF_LogMessageClient *	pLogMsg,
+	FLMUINT						uiIndent,
+	QTYPES						eParentOp,
+	SUBQUERY *					pSubQuery);
 
 /****************************************************************************
 Desc:	This routine indents in the log.
 ****************************************************************************/
 FSTATIC void flmLogIndent(
-	F_LogMessage *	pLogMsg,
-	FLMUINT			uiIndent)
+	IF_LogMessageClient *	pLogMsg,
+	FLMUINT						uiIndent)
 {
 	char		szIndent [100];
 
@@ -67,7 +67,7 @@ FSTATIC void flmLogIndent(
 	{
 		f_memset( szIndent, ' ', uiIndent);
 		szIndent [uiIndent] = 0;
-		pLogMsg->setColor( FLM_LIGHTGRAY, FLM_BLACK);
+		pLogMsg->changeColor( FLM_LIGHTGRAY, FLM_BLACK);
 		pLogMsg->appendString( szIndent);
 	}
 }
@@ -76,10 +76,9 @@ FSTATIC void flmLogIndent(
 Desc:	This routine logs an operator
 ****************************************************************************/
 FSTATIC void flmLogOperator(
-	F_LogMessage *	pLogMsg,
-	QTYPES			eOperator,
-	FLMBOOL			bEndLine
-	)
+	IF_LogMessageClient *	pLogMsg,
+	QTYPES						eOperator,
+	FLMBOOL						bEndLine)
 {
 	const char *	pszOperator;
 
@@ -163,11 +162,11 @@ FSTATIC void flmLogOperator(
 	pLogMsg->pushBackgroundColor();
 	if (eOperator == FLM_LPAREN_OP || eOperator == FLM_RPAREN_OP)
 	{
-		pLogMsg->setColor( FLM_CYAN, FLM_BLACK);
+		pLogMsg->changeColor( FLM_CYAN, FLM_BLACK);
 	}
 	else
 	{
-		pLogMsg->setColor( FLM_BLUE, FLM_LIGHTGRAY);
+		pLogMsg->changeColor( FLM_BLUE, FLM_LIGHTGRAY);
 	}
 	
 	pLogMsg->appendString( pszOperator);
@@ -202,9 +201,9 @@ FINLINE void flmFormatByteToHex(
 Desc:	This routine logs a buffer of binary bytes as ASCII hex.
 ****************************************************************************/
 FSTATIC void flmLogBinary(
-	F_LogMessage *	pLogMsg,
-	FLMBYTE *		pucBuf,
-	FLMUINT			uiBufLen)
+	IF_LogMessageClient *	pLogMsg,
+	FLMBYTE *					pucBuf,
+	FLMUINT						uiBufLen)
 {
 	FLMUINT		uiLoop;
 	FLMUINT		uiOffset;
@@ -303,9 +302,9 @@ FSTATIC void flmLogBinary(
 Desc:	This routine logs text data.
 ****************************************************************************/
 FSTATIC void flmLogText(
-	F_LogMessage *		pLogMsg,
-	const char *		pucBuf,
-	FLMUINT				uiBufLen)
+	IF_LogMessageClient *	pLogMsg,
+	const char *				pucBuf,
+	FLMUINT						uiBufLen)
 {
 	FLMUINT			uiLoop;
 	FLMUINT			uiOffset;
@@ -331,7 +330,7 @@ FSTATIC void flmLogText(
 		}
 
 		ucChar = *pucBuf;
-		uiObjType = GedTextObjType( ucChar);
+		uiObjType = flmTextObjType( ucChar);
 		switch (uiObjType)
 		{
 			case ASCII_CHAR_CODE:  			// 0nnnnnnn
@@ -412,10 +411,9 @@ FSTATIC void flmLogText(
 Desc:	This routine logs the query criteria for a cursor.
 ****************************************************************************/
 FSTATIC void flmLogPredicate(
-	F_LogMessage *	pLogMsg,
-	FLMUINT			uiIndent,
-	FQNODE *			pQNode
-	)
+	IF_LogMessageClient *	pLogMsg,
+	FLMUINT						uiIndent,
+	FQNODE *						pQNode)
 {
 	FLMUINT	uiNestLevel = 0;
 	QTYPES	eCurrentOp;
@@ -441,21 +439,29 @@ FSTATIC void flmLogPredicate(
 
 		if (IS_VAL( eCurrentOp))
 		{
-			pLogMsg->setColor( FLM_WHITE, FLM_BLACK);
+			pLogMsg->changeColor( FLM_WHITE, FLM_BLACK);
 			switch (eCurrentOp)
 			{
 				case FLM_BOOL_VAL:
-					flmLogPrintf( pLogMsg, "%u",
+					f_logPrintf( pLogMsg, "%u",
 						(unsigned)pQNode->pQAtom->val.uiBool);
 					break;
 				case FLM_REC_PTR_VAL:
 				case FLM_UINT32_VAL:
-					flmLogPrintf( pLogMsg, "%u",
-						(unsigned)pQNode->pQAtom->val.uiVal);
+					f_logPrintf( pLogMsg, "%u",
+						(unsigned)pQNode->pQAtom->val.ui32Val);
+					break;
+				case FLM_UINT64_VAL:
+					f_logPrintf( pLogMsg, "%I64u",
+						pQNode->pQAtom->val.ui64Val);
 					break;
 				case FLM_INT32_VAL:
-					flmLogPrintf( pLogMsg, "%d",
-						(int)pQNode->pQAtom->val.iVal);
+					f_logPrintf( pLogMsg, "%d",
+						(int)pQNode->pQAtom->val.i32Val);
+					break;
+				case FLM_INT64_VAL:
+					f_logPrintf( pLogMsg, "%I64d",
+						pQNode->pQAtom->val.i64Val);
 					break;
 				case FLM_BINARY_VAL:
 					pLogMsg->appendString( "BINARY(");
@@ -480,7 +486,7 @@ FSTATIC void flmLogPredicate(
 			FLMUINT		uiCnt;
 
 			flmAssert( IS_FIELD( eCurrentOp));
-			pLogMsg->setColor( FLM_YELLOW, FLM_BLACK);
+			pLogMsg->changeColor( FLM_YELLOW, FLM_BLACK);
 			pLogMsg->appendString( "FLD:");
 
 			// Fields are from child to parent order - must count fields
@@ -496,11 +502,11 @@ FSTATIC void flmLogPredicate(
 				uiCnt--;
 				if (uiCnt)
 				{
-					flmLogPrintf( pLogMsg, "%u.", (unsigned)puiFldPath [uiCnt]);
+					f_logPrintf( pLogMsg, "%u.", (unsigned)puiFldPath [uiCnt]);
 				}
 				else
 				{
-					flmLogPrintf( pLogMsg, "%u", (unsigned)puiFldPath [uiCnt]);
+					f_logPrintf( pLogMsg, "%u", (unsigned)puiFldPath [uiCnt]);
 				}
 			}
 		}
@@ -540,13 +546,12 @@ Exit:
 Desc:	This routine logs the query criteria for a cursor.
 ****************************************************************************/
 FSTATIC void flmLogSubQuery(
-	F_LogMessage *	pLogMsg,
-	FLMUINT			uiIndent,
-	QTYPES			eParentOp,
-	SUBQUERY *		pSubQuery
-	)
+	IF_LogMessageClient *	pLogMsg,
+	FLMUINT						uiIndent,
+	QTYPES						eParentOp,
+	SUBQUERY *					pSubQuery)
 {
-	FQNODE_p		pQNode;
+	FQNODE *		pQNode;
 	QTYPES		eCurrentOp;
 	QTYPES		eTmpParentOp;
 	FLMBYTE *	pucFromKey;
@@ -560,7 +565,7 @@ FSTATIC void flmLogSubQuery(
 	{
 		flmLogIndent( pLogMsg, uiIndent);
 		flmLogOperator( pLogMsg, FLM_LPAREN_OP, FALSE);
-		pLogMsg->setColor( FLM_WHITE, FLM_BLACK);
+		pLogMsg->changeColor( FLM_WHITE, FLM_BLACK);
 		pLogMsg->appendString( "<empty>");
 		flmLogOperator( pLogMsg, FLM_RPAREN_OP, TRUE);
 		goto Output_Opt_Info;
@@ -603,13 +608,13 @@ FSTATIC void flmLogSubQuery(
 			flmLogOperator( pLogMsg, FLM_LPAREN_OP, FALSE);
 			if (hCursor == HFCURSOR_NULL)
 			{
-				pLogMsg->setColor( FLM_WHITE, FLM_BLACK);
+				pLogMsg->changeColor( FLM_WHITE, FLM_BLACK);
 				pLogMsg->appendString( " [EmbeddedPredicate] ");
 				flmLogOperator( pLogMsg, FLM_RPAREN_OP, TRUE);
 			}
 			else
 			{
-				pLogMsg->setColor( FLM_LIGHTGRAY, FLM_BLACK);
+				pLogMsg->changeColor( FLM_LIGHTGRAY, FLM_BLACK);
 				pLogMsg->appendString( " [BeginEmbedded");
 				if (pSubQuery->OptInfo.eOptType == QOPT_USING_PREDICATE &&
 					 pSubQuery->pPredicate == pQNode->pQAtom->val.pPredicate)
@@ -623,11 +628,11 @@ FSTATIC void flmLogSubQuery(
 				bIndentOptInfo = FALSE;
 				pLogMsg->newline();
 				uiIndent += 2;
-				flmLogQuery( pLogMsg, uiIndent, (CURSOR_p)hCursor);
+				flmLogQuery( pLogMsg, uiIndent, (CURSOR *)hCursor);
 				uiIndent -= 2;
 				flmLogIndent( pLogMsg, uiIndent);
 				flmLogOperator( pLogMsg, FLM_RPAREN_OP, FALSE);
-				pLogMsg->setColor( FLM_LIGHTGRAY, FLM_BLACK);
+				pLogMsg->changeColor( FLM_LIGHTGRAY, FLM_BLACK);
 				pLogMsg->appendString( " [EndEmbedded]");
 				pLogMsg->newline();
 			}
@@ -684,26 +689,26 @@ Output_Opt_Info:
 	switch (pSubQuery->OptInfo.eOptType)
 	{
 		case QOPT_USING_INDEX:
-			flmLogPrintf( pLogMsg, F_WHITE "UsingIX=" F_YELLOW "%u",
+			f_logPrintf( pLogMsg, F_FOREWHITE "UsingIX=" F_FOREYELLOW "%u",
 				pSubQuery->OptInfo.uiIxNum);
-			flmLogPrintf( pLogMsg, F_LIGHTGRAY ", KeyMatch=");
+			f_logPrintf( pLogMsg, F_FORELIGHTGRAY ", KeyMatch=");
 			if (pSubQuery->OptInfo.bDoKeyMatch)
 			{
-				flmLogPrintf( pLogMsg, F_GREEN "YES");
+				f_logPrintf( pLogMsg, F_FOREGREEN "YES");
 			}
 			else
 			{
-				flmLogPrintf( pLogMsg, F_RED "NO");
+				f_logPrintf( pLogMsg, F_FORERED "NO");
 			}
 
-			flmLogPrintf( pLogMsg, F_LIGHTGRAY ", RecMatch=");
+			f_logPrintf( pLogMsg, F_FORELIGHTGRAY ", RecMatch=");
 			if (pSubQuery->OptInfo.bDoRecMatch)
 			{
-				flmLogPrintf( pLogMsg, F_GREEN "YES");
+				f_logPrintf( pLogMsg, F_FOREGREEN "YES");
 			}
 			else
 			{
-				flmLogPrintf( pLogMsg, F_RED "NO");
+				f_logPrintf( pLogMsg, F_FORERED "NO");
 			}
 
 			pucFromKey = NULL;
@@ -716,95 +721,95 @@ Output_Opt_Info:
 
 				// Show the from key
 
-				flmLogPrintf( pLogMsg,
-					F_LIGHTGRAY ", FromKeyLen=" F_YELLOW "%u"
-					F_LIGHTGRAY ", FromKey=(",
+				f_logPrintf( pLogMsg,
+					F_FORELIGHTGRAY ", FromKeyLen=" F_FOREYELLOW "%u"
+					F_FORELIGHTGRAY ", FromKey=(",
 					uiFromKeyLen);
 				if (uiFromKeyLen)
 				{
-					pLogMsg->setColor( FLM_YELLOW, FLM_BLACK);
+					pLogMsg->changeColor( FLM_YELLOW, FLM_BLACK);
 					flmLogBinary( pLogMsg, pucFromKey, uiFromKeyLen);
 				}
 				else
 				{
-					flmLogPrintf( pLogMsg, F_YELLOW "<empty>");
+					f_logPrintf( pLogMsg, F_FOREYELLOW "<empty>");
 				}
-				flmLogPrintf( pLogMsg, F_LIGHTGRAY ")");
+				f_logPrintf( pLogMsg, F_FORELIGHTGRAY ")");
 
 				// Show the until key.
 
-				flmLogPrintf( pLogMsg,
-					F_LIGHTGRAY ", UntilKeyLen=" F_YELLOW "%u"
-					F_LIGHTGRAY ", UntilExcl=" F_YELLOW "%s"
-					F_LIGHTGRAY ", UntilKey=(",
+				f_logPrintf( pLogMsg,
+					F_FORELIGHTGRAY ", UntilKeyLen=" F_FOREYELLOW "%u"
+					F_FORELIGHTGRAY ", UntilExcl=" F_FOREYELLOW "%s"
+					F_FORELIGHTGRAY ", UntilKey=(",
 					uiUntilKeyLen,
 					(bUntilKeyExclusive
 								 ? "Yes"
 								 : "No"));
 				if (uiUntilKeyLen)
 				{
-					pLogMsg->setColor( FLM_YELLOW, FLM_BLACK);
+					pLogMsg->changeColor( FLM_YELLOW, FLM_BLACK);
 					flmLogBinary( pLogMsg, pucUntilKey, uiUntilKeyLen);
 				}
 				else
 				{
-					flmLogPrintf( pLogMsg, F_YELLOW "<empty>");
+					f_logPrintf( pLogMsg, F_FOREYELLOW "<empty>");
 				}
-				flmLogPrintf( pLogMsg, F_LIGHTGRAY ")");
+				f_logPrintf( pLogMsg, F_FORELIGHTGRAY ")");
 				f_free( &pucFromKey);
 				f_free( &pucUntilKey);
 			}
 			break;
 
 		case QOPT_USING_PREDICATE:
-			flmLogPrintf( pLogMsg, F_WHITE "Using Embedded Predicate");
+			f_logPrintf( pLogMsg, F_FOREWHITE "Using Embedded Predicate");
 			break;
 
 		case QOPT_SINGLE_RECORD_READ:
-			flmLogPrintf( pLogMsg, F_WHITE "Single Record Read, DRN: "
-				F_YELLOW "%u", pSubQuery->OptInfo.uiDrn);
+			f_logPrintf( pLogMsg, F_FOREWHITE "Single Record Read, DRN: "
+				F_FOREYELLOW "%u", pSubQuery->OptInfo.uiDrn);
 			break;
 
 		case QOPT_PARTIAL_CONTAINER_SCAN:
-			flmLogPrintf( pLogMsg, F_WHITE "Partial Container Scan");
+			f_logPrintf( pLogMsg, F_FOREWHITE "Partial Container Scan");
 //VISIT: Output from and until DRNs - need a method from
 //pSubQuery->pFSDataCursor to return them.
 			break;
 
 		case QOPT_FULL_CONTAINER_SCAN:
-			flmLogPrintf( pLogMsg, F_WHITE "Full Container Scan");
+			f_logPrintf( pLogMsg, F_FOREWHITE "Full Container Scan");
 			break;
 
 		default:
-			flmLogPrintf( pLogMsg, F_WHITE "Unknown optimization");
+			f_logPrintf( pLogMsg, F_FOREWHITE "Unknown optimization");
 			break;
 	}
-	flmLogPrintf( pLogMsg, F_LIGHTGRAY "}\n");
+	f_logPrintf( pLogMsg, F_FORELIGHTGRAY "}\n");
 
 	flmLogIndent( pLogMsg, uiIndent);
 	pLogMsg->appendString( "{Stats: ");
-	flmLogPrintf( pLogMsg, F_LIGHTGRAY "Container=" F_WHITE "%u",
+	f_logPrintf( pLogMsg, F_FORELIGHTGRAY "Container=" F_FOREWHITE "%u",
 		(unsigned)pSubQuery->SQStatus.uiContainerNum);
 
-	flmLogPrintf( pLogMsg, F_LIGHTGRAY ", Matched=" F_WHITE "%u",
+	f_logPrintf( pLogMsg, F_FORELIGHTGRAY ", Matched=" F_FOREWHITE "%u",
 		(unsigned)pSubQuery->SQStatus.uiMatchedCnt);
 
 	if (pSubQuery->SQStatus.uiNumRejectedByCallback)
 	{
-		flmLogPrintf( pLogMsg, F_LIGHTGRAY ", CallbackRejected=" F_WHITE "%u",
+		f_logPrintf( pLogMsg, F_FORELIGHTGRAY ", CallbackRejected=" F_FOREWHITE "%u",
 			(unsigned)pSubQuery->SQStatus.uiNumRejectedByCallback);
 	}
 
 	if (pSubQuery->SQStatus.uiDupsEliminated)
 	{
-		flmLogPrintf( pLogMsg, F_LIGHTGRAY ", DupsElim=" F_WHITE "%u",
+		f_logPrintf( pLogMsg, F_FORELIGHTGRAY ", DupsElim=" F_FOREWHITE "%u",
 			(unsigned)pSubQuery->SQStatus.uiDupsEliminated);
 	}
 
 	if (pSubQuery->SQStatus.uiKeysTraversed ||
 		 pSubQuery->SQStatus.uiKeysRejected)
 	{
-		flmLogPrintf( pLogMsg, F_LIGHTGRAY ", KeysFailed=" F_WHITE "%u of %u",
+		f_logPrintf( pLogMsg, F_FORELIGHTGRAY ", KeysFailed=" F_FOREWHITE "%u of %u",
 			(unsigned)pSubQuery->SQStatus.uiKeysRejected,
 			(unsigned)pSubQuery->SQStatus.uiKeysTraversed);
 	}
@@ -812,7 +817,7 @@ Output_Opt_Info:
 	if (pSubQuery->SQStatus.uiRefsTraversed ||
 		 pSubQuery->SQStatus.uiRefsRejected)
 	{
-		flmLogPrintf( pLogMsg, F_LIGHTGRAY ", RefsFailed=" F_WHITE "%u of %u",
+		f_logPrintf( pLogMsg, F_FORELIGHTGRAY ", RefsFailed=" F_FOREWHITE "%u of %u",
 			(unsigned)pSubQuery->SQStatus.uiRefsRejected,
 			(unsigned)pSubQuery->SQStatus.uiRefsTraversed);
 	}
@@ -821,15 +826,15 @@ Output_Opt_Info:
 		 pSubQuery->SQStatus.uiRecsRejected ||
 		 pSubQuery->SQStatus.uiRecsNotFound)
 	{
-		flmLogPrintf( pLogMsg, F_LIGHTGRAY ", RecsFetched=" F_WHITE "%u"
-									  F_LIGHTGRAY ", RecsRejected=" F_WHITE "%u"
-									  F_LIGHTGRAY ", RecsNotFound=" F_WHITE "%u",
+		f_logPrintf( pLogMsg, F_FORELIGHTGRAY ", RecsFetched=" F_FOREWHITE "%u"
+									  F_FORELIGHTGRAY ", RecsRejected=" F_FOREWHITE "%u"
+									  F_FORELIGHTGRAY ", RecsNotFound=" F_FOREWHITE "%u",
 			(unsigned)pSubQuery->SQStatus.uiRecsFetchedForEval,
 			(unsigned)pSubQuery->SQStatus.uiRecsRejected,
 			(unsigned)pSubQuery->SQStatus.uiRecsNotFound);
 	}
 
-	flmLogPrintf( pLogMsg, F_LIGHTGRAY "}\n");
+	f_logPrintf( pLogMsg, F_FORELIGHTGRAY "}\n");
 
 	if (bIndentOptInfo)
 	{
@@ -842,10 +847,9 @@ Output_Opt_Info:
 Desc:	This routine logs the query criteria for a cursor.
 ****************************************************************************/
 void flmLogQuery(
-	F_LogMessage *	pLogMsg,
-	FLMUINT			uiIndent,
-	CURSOR_p			pCursor
-	)
+	IF_LogMessageClient *	pLogMsg,
+	FLMUINT						uiIndent,
+	CURSOR *						pCursor)
 {
 	SUBQUERY *	pSubQuery;
 	QTYPES		eParentOp = (pCursor->pSubQueryList &&
@@ -855,7 +859,7 @@ void flmLogQuery(
 
 	if (!uiIndent)
 	{
-		pLogMsg->setColor( FLM_LIGHTGRAY, FLM_BLACK);
+		pLogMsg->changeColor( FLM_LIGHTGRAY, FLM_BLACK);
 		pLogMsg->appendString( "QUERY CRITERIA:");
 		if (!pCursor->pSubQueryList)
 		{
