@@ -34,9 +34,9 @@ FLMBOOL gv_DoValAndDictTypesMatch[ LAST_VALUE][ FLM_CONTEXT_TYPE + 1] =
 /*INT32*/	{FALSE,	TRUE,		FALSE,	TRUE},
 /*REAL*/		{FALSE,	FALSE,	FALSE,	FALSE},
 /*REC_PTR*/	{FALSE,	TRUE,		FALSE,	TRUE},
-/*TIME*/		{FALSE,	FALSE,	FALSE,	FALSE},
-/*DATE*/		{FALSE,	FALSE,	FALSE,	FALSE},
-/*TMSTAMP*/	{FALSE,	FALSE,	FALSE,	FALSE},
+/*UINT64*/	{FALSE,	TRUE,		FALSE,	TRUE},
+/*INT64*/	{FALSE,	TRUE,		FALSE,	TRUE},
+/*NOTUSED*/	{FALSE,	FALSE,	FALSE,	FALSE},
 /*BINARY*/	{FALSE,	FALSE,	TRUE,		FALSE},
 /*STRING*/	{FALSE,	FALSE,	FALSE,	FALSE},
 /*UNICODE*/	{FALSE,	FALSE,	FALSE,	FALSE},
@@ -96,8 +96,8 @@ FINLINE FLMBOOL DoValAndDictTypesMatch(
 Desc: Clips a SUBQUERY from a list, and frees memory associated with it.
 */
 FINLINE void flmClipSubQuery(
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery
+	CURSOR *		pCursor,
+	SUBQUERY *	pSubQuery
 	)
 {
 	if( pSubQuery == pCursor->pSubQueryList)
@@ -116,21 +116,21 @@ FINLINE void flmClipSubQuery(
 }
 
 FSTATIC RCODE flmAllocIndexInfo(
-	POOL *			pPool,
+	F_Pool *			pPool,
 	QINDEX **		ppIndex,
 	QINDEX **		ppIndexList,
 	IXD *				pIxd);
 
 FSTATIC RCODE flmSQGetDrnRanges(
-	SUBQUERY_p		pSubQuery,
+	SUBQUERY *		pSubQuery,
 	QTYPES			eOperator,
 	FLMUINT			uiVal);
 
 FSTATIC RCODE flmSQGenPredicateList(
 	FDB *				pDb,
-	SUBQUERY_p		pSubQuery,
-	POOL *			pPool,
-	QPREDICATE_p *	ppPredicateList,
+	SUBQUERY *		pSubQuery,
+	F_Pool *			pPool,
+	QPREDICATE * *	ppPredicateList,
 	FLMUINT *		puiTotalPredicates,
 	FLMBOOL *		pbHaveUserPredicates);
 
@@ -151,14 +151,14 @@ FSTATIC FLMBOOL flmIxFldPathSuitable(
 FSTATIC RCODE flmSQGetSuitableIndexes(
 	FDB *					pDb,
 	FLMUINT				uiForceIndex,
-	CURSOR_p				pCursor,
-	SUBQUERY_p			pSubQuery,
+	CURSOR *				pCursor,
+	SUBQUERY *			pSubQuery,
 	FLMUINT				uiContainer,
-	POOL *				pPool,
+	F_Pool *				pPool,
 	QPREDICATE *		pPredicateList,
 	FLMUINT				uiTotalPredicates,
 	FLMBOOL				bHaveUserPredicates,
-	QINDEX_p *			ppIndexList,
+	QINDEX * *			ppIndexList,
 	FLMUINT *			puiMaxIfds);
 
 FSTATIC RCODE flmSQEvaluateCurrIndexKey(
@@ -171,27 +171,27 @@ FSTATIC RCODE flmSQEvaluateCurrIndexKey(
 
 FSTATIC RCODE flmCheckUserPredicateCosts(
 	FDB *			pDb,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMBOOL		bOkToOptimizeWithPredicate);
 
 FSTATIC RCODE flmMergeSubQueries(
-	CURSOR_p			pCursor,
-	SUBQUERY_p *	ppFromSubQuery,
-	SUBQUERY_p		pIntoSubQuery,
+	CURSOR *			pCursor,
+	SUBQUERY * *	ppFromSubQuery,
+	SUBQUERY *		pIntoSubQuery,
 	FLMBOOL			bFromSubQuerySubsumed);
 
 FSTATIC RCODE flmSQSetupFullContainerScan(
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery);
+	CURSOR *		pCursor,
+	SUBQUERY *	pSubQuery);
 
 FSTATIC RCODE flmSQChooseBestIndex(
-	CURSOR_p			pCursor,
+	CURSOR *			pCursor,
 	FDB *				pDb,
 	FLMUINT			uiForceIndex,
 	FLMUINT			bForceFirstToLastKey,
-	SUBQUERY_p		pSubQuery,
-	POOL *			pTempPool,
-	QPREDICATE_p	pPredicateList,
+	SUBQUERY *		pSubQuery,
+	F_Pool *			pTempPool,
+	QPREDICATE *	pPredicateList,
 	FLMUINT			uiTotalPredicates,
 	FLMBOOL			bHaveUserPredicates);
 
@@ -199,7 +199,7 @@ FSTATIC RCODE flmSQChooseBestIndex(
 Desc:	Keep track of DRN ranges for a subquery.
 ****************************************************************************/
 FSTATIC RCODE flmSQGetDrnRanges(
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	QTYPES		eOperator,
 	FLMUINT		uiVal
 	)
@@ -316,9 +316,9 @@ Desc:	Generate the predicate list for a sub-query.
 ****************************************************************************/
 FSTATIC RCODE flmSQGenPredicateList(
 	FDB *				pDb,
-	SUBQUERY_p		pSubQuery,
-	POOL *			pPool,
-	QPREDICATE_p *	ppPredicateList,
+	SUBQUERY *		pSubQuery,
+	F_Pool *			pPool,
+	QPREDICATE * *	ppPredicateList,
 	FLMUINT *		puiTotalPredicates,
 	FLMBOOL *		pbHaveUserPredicates)
 {
@@ -358,12 +358,12 @@ FSTATIC RCODE flmSQGenPredicateList(
 			// Better be a parent node that is the operator for
 			// this field.
 
-			if ((pPredicate = (QPREDICATE_p)GedPoolCalloc( pPool,
-										sizeof( QPREDICATE))) == NULL)
+			if( RC_BAD( rc = pPool->poolCalloc( sizeof( QPREDICATE), 
+				(void **)&pPredicate)))
 			{
-				rc = RC_SET( FERR_MEM);
 				goto Exit;
 			}
+			
 			(*puiTotalPredicates)++;
 			pPredicate->puiFldPath = pQNode->pQAtom->val.QueryFld.puiFldPath;
 			if (pQNode->pQAtom->uiFlags & FLM_SINGLE_VALUED)
@@ -446,7 +446,7 @@ FSTATIC RCODE flmSQGenPredicateList(
 							flmAssert( eSibOp == FLM_UINT32_VAL);
 							if (RC_BAD( rc = flmSQGetDrnRanges( pSubQuery,
 													pPredicate->eOperator,
-													pPredicate->pVal->val.uiVal)))
+													(FLMUINT)pPredicate->pVal->val.ui32Val)))
 							{
 								goto Exit;
 							}
@@ -566,7 +566,7 @@ Exit:
 Desc:	Allocate a QINDEX structure for an index.
 ****************************************************************************/
 FSTATIC RCODE flmAllocIndexInfo(
-	POOL *			pPool,
+	F_Pool *			pPool,
 	QINDEX **		ppIndex,
 	QINDEX **		ppIndexList,
 	IXD *				pIxd)
@@ -574,11 +574,11 @@ FSTATIC RCODE flmAllocIndexInfo(
 	RCODE			rc = FERR_OK;
 	QINDEX *		pIndex;
 
-	if ((pIndex = (QINDEX *)GedPoolCalloc( pPool, sizeof( QINDEX))) == NULL)
+	if( RC_BAD( rc = pPool->poolCalloc( sizeof( QINDEX), (void **)&pIndex)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
+	
 	*ppIndex = pIndex;
 
 	// The following items are initialized because of the calloc:
@@ -592,13 +592,11 @@ FSTATIC RCODE flmAllocIndexInfo(
 
 	// Allocate space for a list of predicate pointers
 	// for each IFD.
-
-	if ((pIndex->ppFieldPredicateList =
-						(QFIELD_PREDICATE **)GedPoolCalloc( pPool,
-						sizeof( QFIELD_PREDICATE *) *
-							pIndex->uiNumFields)) == NULL)
+	
+	if( RC_BAD( rc = pPool->poolCalloc( 
+		sizeof( QFIELD_PREDICATE *) * pIndex->uiNumFields,
+		(void **)&pIndex->ppFieldPredicateList)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
 
@@ -609,8 +607,11 @@ FSTATIC RCODE flmAllocIndexInfo(
 	{
 		(*ppIndexList)->pPrev = pIndex;
 	}
+	
 	*ppIndexList = pIndex;
+	
 Exit:
+
 	return( rc);
 }
 
@@ -829,14 +830,14 @@ Desc:	Generate the list of suitable indexes for a sub-query.  Rank each
 FSTATIC RCODE flmSQGetSuitableIndexes(
 	FDB *					pDb,
 	FLMUINT				uiForceIndex,
-	CURSOR_p				pCursor,
+	CURSOR *				pCursor,
 	SUBQUERY *			pSubQuery,
 	FLMUINT				uiContainer,
-	POOL *				pPool,
+	F_Pool *				pPool,
 	QPREDICATE *		pPredicateList,
 	FLMUINT				uiTotalPredicates,
 	FLMBOOL				bHaveUserPredicates,
-	QINDEX_p *			ppIndexList,
+	QINDEX * *			ppIndexList,
 	FLMUINT *			puiMaxIfds)
 {
 	RCODE						rc = FERR_OK;
@@ -1030,12 +1031,12 @@ FSTATIC RCODE flmSQGetSuitableIndexes(
 
 				// Add this predicate to the list of predicates for this IFD.
 
-				if ((pFieldPredicate = (QFIELD_PREDICATE *)GedPoolAlloc( pPool,
-													sizeof( QFIELD_PREDICATE))) == NULL)
+				if( RC_BAD( rc = pPool->poolAlloc( sizeof( QFIELD_PREDICATE),
+					(void **)&pFieldPredicate)))
 				{
-					rc = RC_SET( FERR_MEM);
 					goto Exit;
 				}
+				
 				pFieldPredicate->pIfd = pIfd;
 				pFieldPredicate->pPredicate = pPredicate;
 				pFieldPredicate->uiRank = flmCurCalcPredicateRank( pPredicate,
@@ -1198,11 +1199,10 @@ Process_IFD:
 						}
 
 						// Add this predicate to the list of predicates for this IFD.
-
-						if ((pFieldPredicate = (QFIELD_PREDICATE *)GedPoolAlloc( 
-							pPool, sizeof( QFIELD_PREDICATE))) == NULL)
+						
+						if( RC_BAD( rc = pPool->poolAlloc( sizeof( QFIELD_PREDICATE),
+							(void **)&pFieldPredicate)))
 						{
-							rc = RC_SET( FERR_MEM);
 							goto Exit;
 						}
 						
@@ -1416,7 +1416,7 @@ FSTATIC RCODE flmSQEvaluateCurrIndexKey(
 	if ((pTmpFSIndexCursor = *ppTmpFSIndexCursor) == NULL)
 	{
 		if ((pTmpFSIndexCursor = *ppTmpFSIndexCursor =
-					new FSIndexCursor) == NULL)
+					f_new FSIndexCursor) == NULL)
 		{
 			rc = RC_SET( FERR_MEM);
 			goto Exit;
@@ -1523,8 +1523,8 @@ Exit:
 Desc:	Set up a sub-query to do a full container scan.
 ****************************************************************************/
 FSTATIC RCODE flmSQSetupFullContainerScan(
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery
+	CURSOR *		pCursor,
+	SUBQUERY *	pSubQuery
 	)
 {
 	RCODE		rc = FERR_OK;
@@ -1587,19 +1587,19 @@ Exit:
 Desc:	Chooses a best index to use for a sub-query.
 ****************************************************************************/
 FSTATIC RCODE flmSQChooseBestIndex(
-	CURSOR_p			pCursor,
+	CURSOR *			pCursor,
 	FDB *				pDb,
 	FLMUINT			uiForceIndex,
 	FLMUINT			bForceFirstToLastKey,
-	SUBQUERY_p		pSubQuery,
-	POOL *			pTempPool,
-	QPREDICATE_p	pPredicateList,
+	SUBQUERY *		pSubQuery,
+	F_Pool *			pTempPool,
+	QPREDICATE *	pPredicateList,
 	FLMUINT			uiTotalPredicates,
 	FLMBOOL			bHaveUserPredicates)
 {
 	RCODE						rc = FERR_OK;
-	QINDEX_p					pIndexList;
-	QINDEX_p					pIndex;
+	QINDEX *					pIndexList;
+	QINDEX *					pIndex;
 	FLMUINT					uiCurrIfd;
 	FLMUINT					uiMaxIfds;
 	QFIELD_PREDICATE **	ppFieldCurrPredicate = NULL;
@@ -1657,23 +1657,21 @@ FSTATIC RCODE flmSQChooseBestIndex(
 		// Allocate space for a second list of predicate pointers
 		// for each IFD.  This one is used to keep track of which
 		// predicate we are on when we are generating keys.
-
-		if ((ppFieldCurrPredicate =
-							(QFIELD_PREDICATE **)GedPoolCalloc( pTempPool,
-							sizeof( QFIELD_PREDICATE *) * uiMaxIfds)) == NULL)
+		
+		if( RC_BAD( rc = pTempPool->poolCalloc(
+			sizeof( QFIELD_PREDICATE *) * uiMaxIfds,
+			(void **)&ppFieldCurrPredicate)))
 		{
-			rc = RC_SET( FERR_MEM);
 			goto Exit;
 		}
 
 		// Allocate space for the array that will be passed into the
 		// key generation routine.
-
-		if ((ppPredicateList =
-							(QPREDICATE **)GedPoolCalloc( pTempPool,
-								sizeof( QPREDICATE *) * uiMaxIfds)) == NULL)
+		
+		if( RC_BAD( rc = pTempPool->poolCalloc( 
+			sizeof( QPREDICATE *) * uiMaxIfds,
+			(void **)&ppPredicateList)))
 		{
-			rc = RC_SET( FERR_MEM);
 			goto Exit;
 		}
 	}
@@ -1923,12 +1921,12 @@ Desc:	Gets scores for any embedded user predicate.
 ****************************************************************************/
 FSTATIC RCODE flmCheckUserPredicateCosts(
 	FDB *			pDb,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMBOOL		bOkToOptimizeWithPredicate
 	)
 {
 	RCODE						rc = FERR_OK;
-	FQNODE_p					pQNode = pSubQuery->pTree;
+	FQNODE *					pQNode = pSubQuery->pTree;
 	FLMUINT					uiCost;
 	FLMUINT					uiDrnCost;
 	FlmUserPredicate *	pPredicate;
@@ -2099,9 +2097,9 @@ Exit:
 Desc: Merges two SUBQUERY structures.
 ****************************************************************************/
 FSTATIC RCODE flmMergeSubQueries(
-	CURSOR_p			pCursor,
-	SUBQUERY_p *	ppFromSubQuery,
-	SUBQUERY_p		pIntoSubQuery,
+	CURSOR *			pCursor,
+	SUBQUERY * *	ppFromSubQuery,
+	SUBQUERY *		pIntoSubQuery,
 	FLMBOOL			bFromSubQuerySubsumed
 	)
 {
@@ -2333,19 +2331,19 @@ Exit:
 Desc: Optimizes the passed-in query.
 ****************************************************************************/
 RCODE flmCurOptimize(
-	CURSOR_p			pCursor,
+	CURSOR *			pCursor,
 	FLMBOOL			bStratified)
 {
 	RCODE				rc = FERR_OK;
-	FDB_p				pDb = NULL;
-	SUBQUERY_p		pSubQuery;
-	SUBQUERY_p		pTmpSubQuery;
-	SUBQUERY_p		pContainerScanSubQuery = NULL;
+	FDB *				pDb = NULL;
+	SUBQUERY *		pSubQuery;
+	SUBQUERY *		pTmpSubQuery;
+	SUBQUERY *		pContainerScanSubQuery = NULL;
 	FLMBOOL			bChoosingIndex;
 	DB_STATS *		pDbStats;
-	QPREDICATE_p	pPredicateList = NULL;
+	QPREDICATE *	pPredicateList = NULL;
 	FLMUINT			uiTotalPredicates = 0;
-	POOL *			pTempPool;
+	F_Pool *			pTempPool;
 	void *			pvMark;
 	qOptTypes		eOptType;
 	FLMBOOL			bFromSubQuerySubsumed = FALSE;
@@ -2378,7 +2376,7 @@ RCODE flmCurOptimize(
 
 	pSubQuery = pCursor->pSubQueryList;
 	pTempPool = &pDb->TempPool;
-	pvMark = GedPoolMark( pTempPool);
+	pvMark = pTempPool->poolMark();
 	bChoosingIndex = (FLMBOOL)((pCursor->uiIndexNum == FLM_SELECT_INDEX)
 										? (FLMBOOL)TRUE
 										: (FLMBOOL)FALSE);
@@ -2387,7 +2385,7 @@ RCODE flmCurOptimize(
 
 	for(;;)
 	{
-		GedPoolReset( pTempPool, pvMark);
+		pTempPool->poolReset( pvMark);
 
 		// First create the predicate list for the sub-query - so
 		// that it only has to be done once.  This call also verifies
