@@ -27,45 +27,45 @@
 POOL_STATS	g_SubQueryOptPoolStats = {0,0};
 
 FSTATIC void flmCurPruneNode(
-	FQNODE_p 	pQNode);
+	FQNODE * 	pQNode);
 
 FSTATIC RCODE flmCurAddSubQuery(
-	CURSOR_p		pCursor,
-	FQNODE_p		pQNode);
+	CURSOR *		pCursor,
+	FQNODE *		pQNode);
 
 FSTATIC RCODE flmCurDivideQTree(
-	CURSOR_p		pCursor);
+	CURSOR *		pCursor);
 
 FSTATIC RCODE flmCurCreateSQList(
-	CURSOR_p		pCursor);
+	CURSOR *		pCursor);
 
 FSTATIC void flmCurClipNode(
-	FQNODE_p 	pQNode);
+	FQNODE * 	pQNode);
 
 FSTATIC void flmCurReplaceNode(
-	FQNODE_p		pNodeToReplace,
-	FQNODE_p		pReplacementNode);
+	FQNODE *		pNodeToReplace,
+	FQNODE *		pReplacementNode);
 
 FSTATIC RCODE flmCurDoDeMorgan(
-	CURSOR_p		pCursor);
+	CURSOR *		pCursor);
 
 FSTATIC RCODE flmCurCopyQTree(
-	FQNODE_p		pSrcTree,
-	FQNODE_p  * ppDestTree,
-	POOL *		pPool);
+	FQNODE *		pSrcTree,
+	FQNODE *  * ppDestTree,
+	F_Pool *		pPool);
 
 FSTATIC RCODE flmCurStratify(
-	CURSOR_p		pCursor,
-	POOL *		pPool,
+	CURSOR *		pCursor,
+	F_Pool *		pPool,
 	FLMBOOL *	pbStratified,
-	FQNODE_p *	ppTree);
+	FQNODE * *	ppTree);
 
 /****************************************************************************
 Desc:	Prunes an FQNODE, along with its children, from a query tree.
 Ret:
 ****************************************************************************/
 FSTATIC void flmCurPruneNode(
-	FQNODE_p	pQNode
+	FQNODE *	pQNode
 	)
 {
 	// If necessary, unlink the node from any parent or siblings
@@ -98,20 +98,19 @@ Desc:	Allocates space for a subquery, initializes certain members, and adds
 Ret:
 ****************************************************************************/
 FSTATIC RCODE flmCurAddSubQuery(
-	CURSOR_p	pCursor,
-	FQNODE_p	pQNode )
+	CURSOR *	pCursor,
+	FQNODE *	pQNode )
 {
 	RCODE			rc = FERR_OK;
-	SUBQUERY_p	pSubQuery;
+	SUBQUERY *	pSubQuery;
 
-	if ((pSubQuery = (SUBQUERY_p)GedPoolCalloc( &pCursor->SQPool,
-											sizeof( SUBQUERY))) == NULL)
+	if( RC_BAD( rc = pCursor->SQPool.poolCalloc( sizeof( SUBQUERY),
+		(void **)&pSubQuery)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
-
-	GedSmartPoolInit( &pSubQuery->OptPool, &g_SubQueryOptPoolStats);
+	
+	pSubQuery->OptPool.smartPoolInit( &g_SubQueryOptPoolStats);
 
 	pSubQuery->pTree = pQNode;
 
@@ -121,7 +120,7 @@ FSTATIC RCODE flmCurAddSubQuery(
 	}
 	else
 	{
-		SUBQUERY_p		pTmpSubQuery;
+		SUBQUERY *		pTmpSubQuery;
 		
 		for( pTmpSubQuery = pCursor->pSubQueryList;
 				pTmpSubQuery->pNext;
@@ -140,12 +139,12 @@ Desc:	Scans a query tree and breaks it into a set of
 		conjunct subqueries.
 ****************************************************************************/
 FSTATIC RCODE flmCurDivideQTree(
-	CURSOR_p	pCursor
+	CURSOR *	pCursor
 	)
 {
 	RCODE		rc = FERR_OK;
-	FQNODE_p	pQNode;
-	FQNODE_p	pParent;
+	FQNODE *	pQNode;
+	FQNODE *	pParent;
 
 	// Caller has already verified that pCursor->pTree is non-NULL.
 
@@ -208,7 +207,7 @@ Desc:	Scans a query tree and breaks it into a set of
 Ret:
 ****************************************************************************/
 FSTATIC RCODE flmCurCreateSQList(
-	CURSOR_p	pCursor)
+	CURSOR *	pCursor)
 {
 	RCODE	rc = FERR_OK;
 
@@ -240,9 +239,9 @@ FSTATIC RCODE flmCurCreateSQList(
 Desc:	Clips an FQNODE from a query tree, grafting its children to its parent.
 ****************************************************************************/
 FSTATIC void flmCurClipNode(
-	FQNODE_p 	pQNode)
+	FQNODE * 	pQNode)
 {
-	FQNODE_p		pTmpQNode;
+	FQNODE *		pTmpQNode;
 
 	// If necessary, unlink pQNode from its parent, children and siblings
 
@@ -298,11 +297,11 @@ FSTATIC void flmCurClipNode(
 Desc:	Replace one node with another node in the tree.
 ****************************************************************************/
 FSTATIC void flmCurReplaceNode(
-	FQNODE_p		pNodeToReplace,
-	FQNODE_p		pReplacementNode
+	FQNODE *		pNodeToReplace,
+	FQNODE *		pReplacementNode
 	)
 {
-	FQNODE_p	pParentNode;
+	FQNODE *	pParentNode;
 	FLMBOOL	bLinkAsFirst = (pNodeToReplace->pNextSib) ? TRUE : FALSE;
 
 	pParentNode = pNodeToReplace->pParent;
@@ -326,11 +325,11 @@ Desc:	Applies DeMorgan's laws to get rid of NOT operators in a tree - this
 		is necessary to do before we optimize the query.
 ****************************************************************************/
 FSTATIC RCODE flmCurDoDeMorgan(
-	CURSOR_p		pCursor
+	CURSOR *		pCursor
 	)
 {
 	RCODE		rc = FERR_OK;
-	FQNODE_p	pQNode;
+	FQNODE *	pQNode;
 	FLMBOOL	bNotted;
 	QTYPES	eOp;
 
@@ -454,7 +453,7 @@ FSTATIC RCODE flmCurDoDeMorgan(
 
 				if (pQNode->eOpType == FLM_NOT_OP)
 				{
-					FQNODE_p	pKeepNode;
+					FQNODE *	pKeepNode;
 
 					bNotted = !bNotted;
 
@@ -480,9 +479,9 @@ FSTATIC RCODE flmCurDoDeMorgan(
 				{
 					FLMUINT	uiLeftBoolVal = 0;
 					FLMUINT	uiRightBoolVal = 0;
-					FQNODE_p	pLeftNode = pQNode->pChild;
-					FQNODE_p	pRightNode = pLeftNode->pNextSib;
-					FQNODE_p	pReplacementNode = NULL;
+					FQNODE *	pLeftNode = pQNode->pChild;
+					FQNODE *	pRightNode = pLeftNode->pNextSib;
+					FQNODE *	pReplacementNode = NULL;
 
 					if (pLeftNode->eOpType == FLM_BOOL_VAL)
 					{
@@ -598,10 +597,10 @@ Desc:	Copies a passed-in query node into a new node, using the passed-in
 		memory pool.
 ****************************************************************************/
 RCODE flmCurCopyQNode(
-	FQNODE_p			pSrcNode,
-	QTINFO_p			pDestQTInfo,
-	FQNODE_p * 		ppDestNode,
-	POOL *			pPool)
+	FQNODE *			pSrcNode,
+	QTINFO *			pDestQTInfo,
+	FQNODE * * 		ppDestNode,
+	F_Pool *			pPool)
 {
 	RCODE				rc = FERR_OK;
 	FLMUINT *		pTmpPath;
@@ -612,7 +611,7 @@ RCODE flmCurCopyQNode(
 	FLMUINT			uiLen;
 	FLMUINT			uiFlags;
 	FLMUINT			uiCnt;
-	FQNODE_p			pDestNd;
+	FQNODE *			pDestNd;
 
 	if( IS_OP( pSrcNode->eOpType))
 	{
@@ -637,14 +636,26 @@ RCODE flmCurCopyQNode(
 			
 			case FLM_INT32_VAL:
 			{
-				pVal = (void *)&pSrcNode->pQAtom->val.iVal;
+				pVal = (void *)&pSrcNode->pQAtom->val.i32Val;
+				break;
+			}
+			
+			case FLM_INT64_VAL:
+			{
+				pVal = (void *)&pSrcNode->pQAtom->val.i64Val;
 				break;
 			}
 			
 			case FLM_REC_PTR_VAL:
 			case FLM_UINT32_VAL:
 			{
-				pVal = (void *)&pSrcNode->pQAtom->val.uiVal;
+				pVal = (void *)&pSrcNode->pQAtom->val.ui32Val;
+				break;
+			}
+			
+			case FLM_UINT64_VAL:
+			{
+				pVal = (void *)&pSrcNode->pQAtom->val.ui64Val;
 				break;
 			}
 			
@@ -671,10 +682,9 @@ RCODE flmCurCopyQNode(
 				// needs to be reversed because it is reversed back in the call
 				// to flmCurMakeQNode below.
 				
-				if ((pTmpPath = (FLMUINT *)GedPoolCalloc( pPool,
-						((uiPathCnt + 1) *	sizeof( FLMUINT)))) == NULL)
+				if( RC_BAD( rc = pPool->poolCalloc(
+					(uiPathCnt + 1) *	sizeof( FLMUINT), (void **)&pTmpPath)))
 				{
-					rc = RC_SET( FERR_MEM);
 					break;
 				}
 				
@@ -769,11 +779,10 @@ RCODE flmCurCopyQNode(
 		if ((pSrcNode->pQAtom->val.QueryFld.pvUserData) &&
 			 (pSrcNode->pQAtom->val.QueryFld.uiUserDataLen))
 		{
-			if ((pDestNd->pQAtom->val.QueryFld.pvUserData =
-				GedPoolAlloc( pPool,
-					pSrcNode->pQAtom->val.QueryFld.uiUserDataLen)) == NULL)
+			if( RC_BAD( rc = pPool->poolAlloc(
+				pSrcNode->pQAtom->val.QueryFld.uiUserDataLen,
+				&pDestNd->pQAtom->val.QueryFld.pvUserData)))
 			{
-				rc = RC_SET( FERR_MEM);
 				goto Exit;
 			}
 			
@@ -800,14 +809,14 @@ Desc:	Copies a passed-in query tree into a new tree, using the passed-in
 		memory pool.
 ****************************************************************************/
 FSTATIC RCODE flmCurCopyQTree(
-	FQNODE_p			pSrcTree,
-	FQNODE_p  * 	ppDestTree,
-	POOL *			pPool)
+	FQNODE *			pSrcTree,
+	FQNODE *  * 	ppDestTree,
+	F_Pool *			pPool)
 {
 	RCODE				rc = FERR_OK;
-	FQNODE_p			pQNode;
-	FQNODE_p			pDestNode;
-	FQNODE_p			pParentNode;
+	FQNODE *			pQNode;
+	FQNODE *			pDestNode;
+	FQNODE *			pParentNode;
 
 	// Don't try to copy a NULL tree.
 	
@@ -881,28 +890,28 @@ Desc:	Applies associativity to logical operators in a query tree to render
 Ret:
 ****************************************************************************/
 FSTATIC RCODE flmCurStratify(
-	CURSOR_p		pCursor,
-	POOL *		pPool,
+	CURSOR *		pCursor,
+	F_Pool *		pPool,
 	FLMBOOL *	pbStratified,
-	FQNODE_p *	ppTree)
+	FQNODE * *	ppTree)
 {
 	RCODE			rc = FERR_OK;
 	QTYPES		eOp;
 	QTYPES		eLeftOp;
 	QTYPES		eRightOp;
-	FQNODE_p		pTree = *ppTree;
-	FQNODE_p		pOrOp;
-	FQNODE_p		pOtherAndOp;
-	FQNODE_p		pOtherAndOpCopy;
-	FQNODE_p		pOrLeftOp;
-	FQNODE_p		pOrRightOp;
-	FQNODE_p		pNewAndOp1;
-	FQNODE_p		pNewAndOp2;
-	FQNODE_p		pNewOrOp;
-	FQNODE_p		pAndParent;
-	FQNODE_p		pCurrNode;
+	FQNODE *		pTree = *ppTree;
+	FQNODE *		pOrOp;
+	FQNODE *		pOtherAndOp;
+	FQNODE *		pOtherAndOpCopy = NULL;
+	FQNODE *		pOrLeftOp;
+	FQNODE *		pOrRightOp;
+	FQNODE *		pNewAndOp1;
+	FQNODE *		pNewAndOp2;
+	FQNODE *		pNewOrOp;
+	FQNODE *		pAndParent;
+	FQNODE *		pCurrNode;
 	FLMBOOL		bStratified = TRUE;
-	void *		pvMark = GedPoolMark( pPool);
+	void *		pvMark = pPool->poolMark();
 	FLMUINT		uiCount = 0;
 	FLMUINT		uiStartTime = FLM_GET_TIMER();
 	FLMUINT		uiCheckTime = 0;
@@ -913,7 +922,7 @@ FSTATIC RCODE flmCurStratify(
 
 	if (gv_FlmSysData.uiMaxStratifyIterations && gv_FlmSysData.uiMaxStratifyTime)
 	{
-		FLM_SECS_TO_TIMER_UNITS( gv_FlmSysData.uiMaxStratifyTime, uiTimeOut);
+		uiTimeOut = FLM_SECS_TO_TIMER_UNITS( gv_FlmSysData.uiMaxStratifyTime);
 	}
 	else
 	{
@@ -944,7 +953,7 @@ FSTATIC RCODE flmCurStratify(
 					uiCheckTime = FLM_GET_TIMER();
 					if( uiTimeOut && FLM_ELAPSED_TIME( uiCheckTime, uiStartTime) > uiTimeOut)
 					{
-						GedPoolReset( pPool, pvMark);
+						pPool->poolReset( pvMark);
 						rc = flmCurCopyQTree( pCursor->QTInfo.pSaveQuery,
 									&pTree, pPool);
 
@@ -1081,7 +1090,7 @@ Desc: Prepares a query for subsequent use by partitioning it and optimizing
 		its subqueries.
 ****************************************************************************/
 RCODE flmCurPrep(
-	CURSOR_p	pCursor)
+	CURSOR *	pCursor)
 {
 	RCODE		rc = FERR_OK;
 	FLMBOOL	bStratified;
