@@ -29,56 +29,61 @@
 #define STATUS_CB_INTERVAL 1
 
 FSTATIC RCODE flmCurSetSubQuery(
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery);
+	CURSOR *		pCursor,
+	SUBQUERY *	pSubQuery);
+
+FSTATIC int DRNCompareFunc(
+	void *	pvData1,
+	void *	pvData2,
+	void *	pvUserValue);
 
 FSTATIC RCODE flmCurRecValidate(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery,
+	CURSOR *		pCursor,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiSkipCount,
 	FLMUINT *	puiCount,
 	FLMBOOL *	pbReturnRecOK);
 
 FSTATIC RCODE flmCurRetrieveRec(
-	FDB_p			pDb,
-	SUBQUERY_p	pSubQuery,
+	FDB *			pDb,
+	SUBQUERY *	pSubQuery,
 	FLMUINT		uiContainer);
 
 FSTATIC RCODE flmCurSearchIndex(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFirstRead,
 	FLMBOOL		bReadForward,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiCount,
 	FLMUINT *	puiSkipCount,
 	FLMBOOL		bGettingRecord);
 
 FSTATIC RCODE flmCurSearchPredicate(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFirstRead,
 	FLMBOOL		bReadForward,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiCount,
 	FLMUINT *	puiSkipCount);
 
 FSTATIC RCODE flmCurSearchContainer(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFirstRead,
 	FLMBOOL		bReadForward,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiCount,
 	FLMUINT *	puiSkipCount);
 
 FSTATIC RCODE flmCurEvalSingleRec(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFirstRead,
 	FLMBOOL		bReadForward,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiCount,
 	FLMUINT *	puiSkipCount);
 
@@ -87,8 +92,8 @@ Desc: This routine will do all the setup needed to establish a sub-query as
 		the current subquery for the query.
 ****************************************************************************/
 FSTATIC RCODE flmCurSetSubQuery(
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery
+	CURSOR *		pCursor,
+	SUBQUERY *	pSubQuery
 	)
 {
 	RCODE			rc = FERR_OK;
@@ -119,19 +124,38 @@ Exit:
 	return( rc);
 }
 
+/****************************************************************************
+Desc: DRN comparison callback function for dynamic result set.
+****************************************************************************/
+FSTATIC int DRNCompareFunc(
+	void *	pvData1,
+	void *	pvData2,
+	void *	// pvUserValue
+	)
+{
+	if( *((FLMUINT *)pvData1) < *((FLMUINT *)pvData2))
+	{
+		return -1;
+	}
+	else if( *((FLMUINT *)pvData1) > *((FLMUINT *)pvData2))
+	{
+		return 1;
+	}
+	return 0;
+}
+
 /****************************************************************************
 Desc: Validate a record that has passed the search criteria.  This routine
 		checks the record against the validation function and also checks it
 		against the result set, if there is one.
 ****************************************************************************/
 FSTATIC RCODE flmCurRecValidate(
-	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery,
-	FLMUINT *	puiSkipCount,
-	FLMUINT *	puiCount,
-	FLMBOOL *	pbReturnRecOK
-	)
+	eFlmFuncs		eFlmFuncId,
+	CURSOR *			pCursor,
+	SUBQUERY *		pSubQuery,
+	FLMUINT *		puiSkipCount,
+	FLMUINT *		puiCount,
+	FLMBOOL *		pbReturnRecOK)
 {
 	RCODE		rc = FERR_OK;
 	FLMBOOL	bSavedInvisTrans;
@@ -163,17 +187,15 @@ FSTATIC RCODE flmCurRecValidate(
 
 	if (pCursor->bEliminateDups)
 	{
-		/*
-		Setup the result set
-		*/
+		// Setup the result set
 
 		if( !pCursor->pDRNSet)
 		{
 			char		szTmpDir[ F_PATH_MAX_SIZE];
 
 			szTmpDir[ 0] = 0;
-
-			if ((pCursor->pDRNSet = f_new FDynSearchSet) == NULL)
+			
+			if ((pCursor->pDRNSet = f_new F_DynSearchSet) == NULL)
 			{
 				rc = RC_SET( FERR_MEM);
 				goto Exit;
@@ -189,24 +211,24 @@ FSTATIC RCODE flmCurRecValidate(
 
 			if( !szTmpDir[ 0])
 			{
-				if( RC_BAD( rc = f_pathReduce( 
+				if( RC_BAD( rc = gv_FlmSysData.pFileSystem->pathReduce( 
 					pCursor->pDb->pFile->pszDbPath, szTmpDir, NULL)))
 				{
 					goto Exit;
 				}
 			}
-
+			
 			if (RC_BAD( rc = pCursor->pDRNSet->setup( szTmpDir, sizeof( FLMUINT))))
 			{
 				goto Exit;
 			}
 
-			pCursor->pDRNSet->setCompareFunc( DRNCompareFunc, (void *) 4);
+			pCursor->pDRNSet->setCompareFunc( DRNCompareFunc, NULL);
 		}
 
 		if (RC_BAD( rc = pCursor->pDRNSet->addEntry( &pSubQuery->uiDrn)))
 		{
-			if (rc == FERR_EXISTS)
+			if (rc == NE_FLM_EXISTS)
 			{
 				*pbReturnRecOK = FALSE;
 				rc = FERR_OK;
@@ -249,7 +271,9 @@ FSTATIC RCODE flmCurRecValidate(
 	// pass it back out to the caller.
 
 	*pbReturnRecOK = TRUE;
+	
 Exit:
+
 	return( rc);
 }
 
@@ -257,8 +281,8 @@ Exit:
 Desc: Does the actual reading of a record from cache or disk.
 ****************************************************************************/
 FSTATIC RCODE flmCurRetrieveRec(
-	FDB_p			pDb,
-	SUBQUERY_p	pSubQuery,
+	FDB *			pDb,
+	SUBQUERY *	pSubQuery,
 	FLMUINT		uiContainer
 	)
 {
@@ -289,17 +313,17 @@ Desc: Searches an index for matching record.
 ****************************************************************************/
 FSTATIC RCODE flmCurSearchIndex(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFirstRead,
 	FLMBOOL		bReadForward,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiCount,
 	FLMUINT *	puiSkipCount,
 	FLMBOOL		bGettingRecord
 	)
 {
 	RCODE					rc = FERR_OK;
-	FDB_p					pDb = pCursor->pDb;
+	FDB *					pDb = pCursor->pDb;
 	FSIndexCursor *	pFSIndexCursor = pSubQuery->pFSIndexCursor;
 	FLMUINT				uiCBTimer = 0;
 	FLMUINT				uiCurrCBTime;
@@ -317,7 +341,7 @@ FSTATIC RCODE flmCurSearchIndex(
 
 	if (pCursor->fnStatus)
 	{
-		FLM_SECS_TO_TIMER_UNITS( STATUS_CB_INTERVAL, uiCBTimer);
+		uiCBTimer = FLM_SECS_TO_TIMER_UNITS( STATUS_CB_INTERVAL);
 	}
 
 	// Set up initial search parameters.  
@@ -683,16 +707,16 @@ Desc: Searches a user predicate for matching record.
 ****************************************************************************/
 FSTATIC RCODE flmCurSearchPredicate(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFirstRead,
 	FLMBOOL		bReadForward,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiCount,
 	FLMUINT *	puiSkipCount
 	)
 {
 	RCODE						rc = FERR_OK;
-	FDB_p						pDb = pCursor->pDb;
+	FDB *						pDb = pCursor->pDb;
 	FlmUserPredicate *	pPredicate = pSubQuery->pPredicate;
 	FLMBOOL					bSavedInvisTrans;
 	FLMUINT					uiCBTimer = 0;
@@ -706,7 +730,7 @@ FSTATIC RCODE flmCurSearchPredicate(
 
 	if (pCursor->fnStatus)
 	{
-		FLM_SECS_TO_TIMER_UNITS( STATUS_CB_INTERVAL, uiCBTimer);
+		uiCBTimer = FLM_SECS_TO_TIMER_UNITS( STATUS_CB_INTERVAL);
 	}
 
 	// Set up initial search parameters.  
@@ -848,16 +872,16 @@ Desc: Searches a container for matching record.
 ****************************************************************************/
 FSTATIC RCODE flmCurSearchContainer(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFirstRead,
 	FLMBOOL		bReadForward,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiCount,
 	FLMUINT *	puiSkipCount
 	)
 {
 	RCODE					rc = FERR_OK;
-	FDB_p					pDb = pCursor->pDb;
+	FDB *					pDb = pCursor->pDb;
 	FSDataCursor *		pFSDataCursor = pSubQuery->pFSDataCursor;
 	FLMUINT				uiCBTimer = 0;
 	FLMUINT				uiCurrCBTime;
@@ -871,7 +895,7 @@ FSTATIC RCODE flmCurSearchContainer(
 
 	if (pCursor->fnStatus)
 	{
-		FLM_SECS_TO_TIMER_UNITS( STATUS_CB_INTERVAL, uiCBTimer);
+		uiCBTimer = FLM_SECS_TO_TIMER_UNITS( STATUS_CB_INTERVAL);
 	}
 
 	// Set up initial search parameters.  
@@ -1001,16 +1025,16 @@ Desc: Retrieves a single record and evaluates it.
 ****************************************************************************/
 FSTATIC RCODE flmCurEvalSingleRec(
 	eFlmFuncs	eFlmFuncId,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bFirstRead,
 	FLMBOOL		bReadForward,
-	SUBQUERY_p	pSubQuery,
+	SUBQUERY *	pSubQuery,
 	FLMUINT *	puiCount,
 	FLMUINT *	puiSkipCount
 	)
 {
 	RCODE			rc = FERR_OK;
-	FDB_p			pDb = pCursor->pDb;
+	FDB *			pDb = pCursor->pDb;
 	FLMBOOL		bReturnRecOK;
 	FLMUINT		uiRecMatch;
 
@@ -1080,7 +1104,7 @@ Desc: Performs the search operation.
 ****************************************************************************/
 RCODE flmCurSearch(
 	eFlmFuncs		eFlmFuncId,
-	CURSOR_p			pCursor,
+	CURSOR *			pCursor,
 	FLMBOOL			bFirstRead,
 	FLMBOOL			bReadForward,
 	FLMUINT *		puiCount,
@@ -1093,7 +1117,7 @@ RCODE flmCurSearch(
 	FDB *			pDb;
 	DB_STATS *	pDbStats;
 	RCODE			TmpRc;
-	SUBQUERY_p	pSubQuery = pCursor->pCurrSubQuery;
+	SUBQUERY *	pSubQuery = pCursor->pCurrSubQuery;
 	FLMBOOL		bSavedInvisTrans;
 
 	pDb = pCursor->pDb;
@@ -1236,7 +1260,7 @@ RCODE flmCurSearch(
 
 		// Reached BOF/EOF in the current subquery. Move on to the next one.
 
-		pSubQuery = (SUBQUERY_p)((bReadForward)
+		pSubQuery = (SUBQUERY *)((bReadForward)
 										 ? pSubQuery->pNext
 										 : pSubQuery->pPrev);
 		if (!pSubQuery)
