@@ -58,20 +58,20 @@ static FLMUINT PrecedenceTable [FLM_USER_PREDICATE - FLM_AND_OP + 1] =
 								? PrecedenceTable [(e) - FLM_AND_OP] \
 								: (FLMUINT)0)
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Adds an operator to the selection criteria of a given cursor.
-*END************************************************************************/
-RCODE FlmCursorAddOp(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorAddOp(
 	HFCURSOR		hCursor,
 	QTYPES		eOperator,
 	FLMBOOL		bResolveUnknown
 	)
 {
 	RCODE			rc = FERR_OK;
-	CURSOR_p		pCursor = (CURSOR *)hCursor;
-	FQNODE_p		pTmpQNode;
-	FQNODE_p		pTmpGraftNode;
-	FQNODE_p		pTmpChildNode;
+	CURSOR *		pCursor = (CURSOR *)hCursor;
+	FQNODE *		pTmpQNode;
+	FQNODE *		pTmpGraftNode;
+	FQNODE *		pTmpChildNode;
 	FLMBOOL		bDecrementNestLvl = FALSE;
 	FLMUINT		uiFlags = bResolveUnknown ? FLM_RESOLVE_UNK : 0;
 
@@ -253,7 +253,7 @@ Exit:
 Desc: Add a reference to an embedded user predicate.
 ****************************************************************************/
 RCODE flmCurAddRefPredicate(
-	QTINFO_p					pQTInfo,
+	QTINFO *					pQTInfo,
 	FlmUserPredicate *	pPredicate
 	)
 {
@@ -304,17 +304,17 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc: Adds an embedded user predicate.
-*END************************************************************************/
-RCODE  FlmCursorAddUserPredicate(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorAddUserPredicate(
 	HFCURSOR					hCursor,
 	FlmUserPredicate *	pPredicate
 	)
 {
 	RCODE			rc = FERR_OK;
-	CURSOR_p		pCursor = (CURSOR_p)hCursor;
-	FQNODE_p		pQNode;
+	CURSOR *		pCursor = (CURSOR *)hCursor;
+	FQNODE *		pQNode;
 	QTYPES		eOperator;
 
 	if (!pCursor || !pPredicate)
@@ -394,11 +394,11 @@ Exit:
 Desc:	Links one FQNODE as the first child of another.
 ****************************************************************************/
 void flmCurLinkFirstChild(
-	FQNODE_p pParent,
-	FQNODE_p pChild
+	FQNODE * pParent,
+	FQNODE * pChild
 	)
 {
-	FQNODE_p	pTmpQNode;
+	FQNODE *	pTmpQNode;
 
 	// If necessary, unlink the child from a sibling list and link it back in
 	// as the first child.
@@ -443,11 +443,11 @@ void flmCurLinkFirstChild(
 Desc:	Links one FQNODE as the last child of another.
 ****************************************************************************/
 void flmCurLinkLastChild(
-	FQNODE_p	pParent,
-	FQNODE_p	pChild
+	FQNODE *	pParent,
+	FQNODE *	pChild
 	)
 {
-	FQNODE_p	pTmpQNode;
+	FQNODE *	pTmpQNode;
 
 	// If necessary, unlink the child from any parent or siblings
 
@@ -495,7 +495,9 @@ void flmCurLinkLastChild(
 }
 
 /****************************************************************************
-Desc:	Put a value in an FQATOM node - so we can call it from SMI.
+Desc:	Put a value in an FQATOM node - so we can call it from SMI.  Can
+		only be used for values, not field paths.  Cannot be used for
+		unknown values.
 ****************************************************************************/
 RCODE flmPutValInAtom(
 	void *	pAtom,
@@ -506,7 +508,7 @@ RCODE flmPutValInAtom(
 	)
 {
 	RCODE		rc = FERR_OK;
-	FQATOM_p	pQAtom = (FQATOM_p)pAtom;
+	FQATOM *	pQAtom = (FQATOM *)pAtom;
 
 	pQAtom->uiFlags = uiFlags;
 	pQAtom->eType = eValType;
@@ -517,19 +519,22 @@ RCODE flmPutValInAtom(
 			break;
 		case FLM_UINT32_VAL:
 		case FLM_REC_PTR_VAL:
-			pQAtom->val.uiVal = *((FLMUINT *)pvVal);
+			pQAtom->val.ui32Val = *((FLMUINT32 *)pvVal);
+			break;
+		case FLM_UINT64_VAL:
+			pQAtom->val.ui64Val = *((FLMUINT64 *)pvVal);
 			break;
 		case FLM_INT32_VAL:
-			pQAtom->val.iVal = *((FLMINT *)pvVal);
+			pQAtom->val.i32Val = *((FLMINT32 *)pvVal);
+			break;
+		case FLM_INT64_VAL:
+			pQAtom->val.i64Val = *((FLMINT64 *)pvVal);
 			break;
 		case FLM_BINARY_VAL:
 		case FLM_TEXT_VAL:
 			pQAtom->val.pucBuf = (FLMBYTE *)pvVal;
 			pQAtom->uiBufLen = uiValLen;
 			break;
-		case FLM_FLD_PATH:
-			pQAtom->val.QueryFld.puiFldPath = (FLMUINT *)pvVal;
-			break;
 		case FLM_UNKNOWN:
 			break;
 		default:
@@ -545,14 +550,15 @@ Exit:
 Desc:	Makes an FQNODE of a given type, and puts a value in it if necessary.
 ****************************************************************************/
 RCODE flmCurMakeQNode(
-	POOL *		pPool,
+	F_Pool *		pPool,
 	QTYPES		eType,
 	void *		pVal,
 	FLMUINT		uiValLen,
 	FLMUINT		uiFlags,
-	FQNODE_p *	ppQNode)
+	FQNODE * *	ppQNode)
 {
 	FLMUINT *	puiTmpPath;
+	FLMUINT *	puiPToCPath;
 	FLMUINT *	puiFldPath;
 	FLMUINT		uiTmpLen = uiValLen;
 	FLMBYTE *	pTmpBuf;
@@ -562,12 +568,12 @@ RCODE flmCurMakeQNode(
 	FQNODE *		pQNode;
 	FQATOM *		pQAtom;
 
-	if ((*ppQNode = pQNode = (FQNODE_p)GedPoolCalloc( pPool,
-											sizeof( FQNODE))) == NULL)
+	if( RC_BAD( rc = pPool->poolCalloc( sizeof( FQNODE), (void **)&pQNode)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
+	
+	*ppQNode = pQNode;
 
 	// Always set eOpType to the eType
 
@@ -577,39 +583,64 @@ RCODE flmCurMakeQNode(
 		pQNode->uiStatus = uiFlags;
 		goto Exit;
 	}
-	if ((pQNode->pQAtom = pQAtom = (FQATOM_p)GedPoolCalloc( pPool,
-												sizeof( FQATOM))) == NULL)
+	
+	if( RC_BAD( rc = pPool->poolCalloc( sizeof( FQATOM), (void **)&pQAtom)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
+	
+	pQNode->pQAtom = pQAtom;
 	pQAtom->uiFlags = uiFlags;
 
 	switch (eType)
 	{
 		case FLM_TEXT_VAL:
-			if ((pTmpBuf = (FLMBYTE *)GedPoolCalloc( pPool,
-									(FLMUINT)(uiTmpLen + 1))) == NULL)
+		{
+			if( RC_BAD( rc = pPool->poolAlloc( uiTmpLen + 1, (void **)&pTmpBuf)))
 			{
-				rc = RC_SET( FERR_MEM);
 				goto Exit;
 			}
+			
 			f_memcpy( pTmpBuf, pVal, uiTmpLen);
-			pTmpBuf[ uiTmpLen ] = '\0';	// MUST BE NULL TERIMINATED!
+			pTmpBuf[ uiTmpLen ] = '\0';
 			pQAtom->val.pucBuf = pTmpBuf;
-			pQAtom->uiBufLen = uiTmpLen;	// Must be actual length.
+			pQAtom->uiBufLen = uiTmpLen;
 			break;
+		}
+		
 		case FLM_BOOL_VAL:
+		{
 			pQAtom->val.uiBool = *(FLMUINT *)pVal;
 			break;
+		}
+		
 		case FLM_INT32_VAL:
-			pQAtom->val.iVal = *(FLMINT *)pVal;
+		{
+			pQAtom->val.i32Val = *(FLMINT32 *)pVal;
 			break;
+		}
+		
+		case FLM_INT64_VAL:
+		{
+			pQAtom->val.i64Val = *(FLMINT64 *)pVal;
+			break;
+		}
+		
 		case FLM_REC_PTR_VAL:
 		case FLM_UINT32_VAL:
-			pQAtom->val.uiVal = *(FLMUINT *)pVal;
+		{
+			pQAtom->val.ui32Val = *(FLMUINT32 *)pVal;
 			break;
+		}
+		
+		case FLM_UINT64_VAL:
+		{
+			pQAtom->val.ui64Val = *(FLMUINT64 *)pVal;
+			break;
+		}
+		
 		case FLM_FLD_PATH:
+		{
 			for (uiPathCnt = 0;
 					((FLMUINT *)pVal)[ uiPathCnt];
 					uiPathCnt++)
@@ -620,41 +651,56 @@ RCODE flmCurMakeQNode(
 					goto Exit;
 				}
 			}
-
-			if ((puiTmpPath = (FLMUINT *)GedPoolCalloc( pPool,
-				(FLMUINT)((FLMUINT)(uiPathCnt + 1) * 
-					(FLMUINT)sizeof( FLMUINT)))) == NULL)
+			
+			if( RC_BAD( rc = pPool->poolCalloc(
+				((FLMUINT)(uiPathCnt + 1) * 2 * sizeof( FLMUINT)),
+				(void **)&puiTmpPath)))
 			{
-				rc = RC_SET( FERR_MEM);
 				goto Exit;
 			}
+				
+			puiPToCPath = &puiTmpPath [uiPathCnt + 1];
 
 			puiFldPath = (FLMUINT *)pVal;
 			for (uiCnt = 0; uiCnt < uiPathCnt; uiCnt++)
 			{
 				puiTmpPath[ uiPathCnt - uiCnt - 1] = puiFldPath[ uiCnt];
+				puiPToCPath [uiCnt] = puiFldPath [uiCnt];
 			}
 			pQAtom->val.QueryFld.puiFldPath = puiTmpPath;
+			pQAtom->val.QueryFld.puiPToCPath = puiPToCPath;
 			break;
+		}
+		
 		case FLM_BINARY_VAL:
-			if ((pTmpBuf = (FLMBYTE *)GedPoolCalloc( pPool, uiTmpLen)) == NULL)
+		{
+			if( RC_BAD( rc = pPool->poolAlloc( uiTmpLen, (void **)&pTmpBuf)))
 			{
-				rc = RC_SET( FERR_MEM);
 				goto Exit;
 			}
+			
 			f_memcpy( pTmpBuf, pVal, uiTmpLen);
 			pQAtom->val.pucBuf = pTmpBuf;
 			pQAtom->uiBufLen = uiTmpLen;
 			break;
+		}
+		
 		case FLM_USER_PREDICATE:
+		{
 			break;
+		}
+		
 		default:
+		{
 			rc = RC_SET( FERR_CURSOR_SYNTAX);
 			goto Exit;
+		}
 	}
+	
 	pQAtom->eType = eType;
 
 Exit:
+
 	return( rc);
 }
 
@@ -664,12 +710,12 @@ Desc:	Grafts FQNODE onto a passed-in query tree as the right branch of a new
 Ret:
 ****************************************************************************/
 RCODE flmCurGraftNode(
-	POOL *		pPool,
-	FQNODE_p 	pQNode,
+	F_Pool *		pPool,
+	FQNODE * 	pQNode,
 	QTYPES		eGraftOp,
-	FQNODE_p  * ppQTree)
+	FQNODE *  * ppQTree)
 {
-	FQNODE_p		pTmpQNode;
+	FQNODE *		pTmpQNode;
 	RCODE			rc = FERR_OK;
 
 	if (*ppQTree == NULL)
@@ -692,10 +738,10 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
+/****************************************************************************
 Desc : Adds a value to the selection criteria of a given cursor.
-*END************************************************************************/
-RCODE FlmCursorAddValue(
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorAddValue(
 	HFCURSOR		hCursor,
 	QTYPES		eValType,
 	void *		pVal,
@@ -703,12 +749,11 @@ RCODE FlmCursorAddValue(
 	)
 {
 	RCODE			rc = FERR_OK;
-	FLMINT		iVal;
 	FLMUINT		uiVal;
 	void *		pTmpVal = pVal;
-	CURSOR_p		pCursor = (CURSOR *)hCursor;
+	CURSOR *		pCursor = (CURSOR *)hCursor;
+	F_Pool		pool;
 	FLMBOOL		bPoolInitialized = FALSE;
-	POOL			pool;
 
 	if (!pCursor)
 	{
@@ -716,6 +761,7 @@ RCODE FlmCursorAddValue(
 		rc = RC_SET( FERR_INVALID_PARM);
 		goto Exit;
 	}
+	
 	if (RC_BAD( rc = pCursor->rc))
 	{
 		goto Exit;
@@ -749,7 +795,7 @@ RCODE FlmCursorAddValue(
 
 			f_memset( &node, 0, sizeof(NODE));
 
-			GedPoolInit( &pool, 512);
+			pool.poolInit( 512);
 			bPoolInitialized = TRUE;
 
 			rc = (eValType == FLM_UNICODE_VAL) 
@@ -781,42 +827,16 @@ RCODE FlmCursorAddValue(
 			break;
 
 		case FLM_INT32_VAL:
-
-			// Need to make switch to FLMINT, because that is what
-			// flmCurMakeQNode is expecting.  No need to change
-			// eValType.
-
-			iVal = (FLMINT)(*(FLMINT32 *)pVal);
-			pTmpVal = &iVal;
-			break;
-
 		case FLM_UINT32_VAL:
-
-			// Need to make switch to FLMUINT, because that is what
-			// flmCurMakeQNode is expecting.  No need to change
-			// eValType.
-
-			uiVal = (FLMUINT)(*(FLMUINT32 *)pVal);
-			pTmpVal = &uiVal;
-			break;
-
 		case FLM_REC_PTR_VAL:
-
-			// Need to make switch to FLMUINT, because that is what
-			// flmCurMakeQNode is expecting.  No need to change
-			// eValType.
-
-			uiVal = (FLMUINT)(*(FLMUINT32 *)pVal);
-			pTmpVal = &uiVal;
-			break;
-
+		case FLM_UINT64_VAL:
+		case FLM_INT64_VAL:
 		case FLM_TEXT_VAL:
-			pTmpVal = pVal;
-			eValType = FLM_TEXT_VAL;
-			break;
-
 		case FLM_BINARY_VAL:
-			eValType = FLM_BINARY_VAL;
+		
+			// pTmpVal is already pointing to pVal, and
+			// eValType does not need to be changed.
+			
 			break;
 
 		default:
@@ -839,6 +859,7 @@ RCODE FlmCursorAddValue(
 	}
 
 Exit:
+
 	if (pCursor)
 	{
 		pCursor->rc = rc;
@@ -846,32 +867,23 @@ Exit:
 
 	if (bPoolInitialized)
 	{
-		GedPoolFree( &pool);
+		pool.poolFree();
 	}
+	
 	return( rc);
 }
 
-/*API~***********************************************************************
-Name : FlmCursorAddField
-Area : CURSOR
-Desc : Adds a field ID to the selection criteria of a given cursor.
-*END************************************************************************/
-RCODE FlmCursorAddField(
+/****************************************************************************
+Desc:	Adds a field ID to the selection criteria of a given cursor.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorAddField(
 	HFCURSOR		hCursor,
-		// [IN] Handle to a cursor.
 	FLMUINT		uiFldId,
-		// [IN] Field number.
-	FLMUINT		uiFlags
-		// [IN] Flags. Valid values for uiFlags are as follows:
-		//      FLM_USE_DEFAULT_VALUE -- If a field is missing from a record,
-		//		  use a default value.
-		//		  FLM_SINGLE_VALUED -- Field will only have a single occurrance
-		//		  in any record it appears in.
-	)
+	FLMUINT		uiFlags)
 {
 	RCODE			rc = FERR_OK;
-	CURSOR_p		pCursor = (CURSOR_p)hCursor;
-	FQNODE_p		pTmpQNode;
+	CURSOR *		pCursor = (CURSOR *)hCursor;
+	FQNODE *		pTmpQNode;
 	FLMUINT		uiPath [2];
 
 	if (!pCursor)
@@ -932,53 +944,18 @@ Exit:
 	return( rc);
 }
 
-
-/*API~***********************************************************************
-Name : FlmCursorAddFieldPath
-Area : CURSOR
-Desc : Adds a field path to the selection criteria of a given cursor.  A
-		 field path is the fully qualified context of a field within a record.
-*END************************************************************************/
-RCODE FlmCursorAddFieldPath(
+/****************************************************************************
+Desc:	Adds a field path to the selection criteria of a given cursor.  A
+		field path is the fully qualified context of a field within a record.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorAddFieldPath(
 	HFCURSOR		hCursor,
-		// [IN] Handle to a cursor.
 	FLMUINT *	puiFldPath,
-		// [IN] Null-terminated array of field numbers.  The first member
-		// is the root field and the last member is the leaf field.
-		//
-		// Example:
-		//
-		// Assume that a sample database has a data dictionary with the fields
-		// PERSON (context field, id 567), BUILDING (context field, id 568),
-		// and NAME (string, id 569) defined.  Also, the following records
-		// have been added to the default data container:
-		//
-		// 0 PERSON                                0 BUILDING
-		//   1 NAME "john doe"                       1 NAME "empire state"
-		//
-		// If it is desired to select all records from the database
-		// in which the NAME field is found within the context of the PERSON
-		// field (occurences of NAME field which are directly subordinate
-		// to the PERSON field), a field path can be used:
-		//
-		//           FLMUINT     puiFldPath[] = { 567, 569, 0};
-		//
-		// The field path can be view simply as a "qualified" field,
-		// and as such, adding a field path to the selection criteria is no
-		// different syntactically than adding a field to the criteria.
-		// All operations, operators, and constructs which are valid when
-		// applied to a field are also valid when applied to a field path.
-	FLMUINT		uiFlags
-		// [IN] Flags. Valid values for uiFlags are as follows:
-		//      FLM_USE_DEFAULT_VALUE -- If a field is missing from a record,
-		//		  use a default value.
-		//		  FLM_SINGLE_VALUED -- Field will only have a single occurrance
-		//		  in any record it appears in.
-	)
+	FLMUINT		uiFlags)
 {
 	RCODE			rc = FERR_OK;
-	FQNODE_p		pTmpQNode;
-	CURSOR_p		pCursor = (CURSOR_p)hCursor;
+	FQNODE *		pTmpQNode;
+	CURSOR *		pCursor = (CURSOR *)hCursor;
 
 	if (!pCursor)
 	{
@@ -1029,60 +1006,22 @@ Exit:
 	return( rc);
 }
 
-/*API~***********************************************************************
-Name : FlmCursorAddFieldCB
-Area : CURSOR
-Desc : Adds a field path to the selection criteria of a given cursor - with
-		 a callback to retrieve the field.
-*END************************************************************************/
-RCODE FlmCursorAddFieldCB(
-	HFCURSOR		hCursor,
-		// [IN] Handle to a cursor.
-	FLMUINT *	puiFldPath,
-		// [IN] Null-terminated array of field numbers.  The first member
-		// is the root field and the last member is the leaf field.
-		//
-		// Example:
-		//
-		// Assume that a sample database has a data dictionary with the fields
-		// PERSON (context field, id 567), BUILDING (context field, id 568),
-		// and NAME (string, id 569) defined.  Also, the following records
-		// have been added to the default data container:
-		//
-		// 0 PERSON                                0 BUILDING
-		//   1 NAME "john doe"                       1 NAME "empire state"
-		//
-		// If it is desired to select all records from the database
-		// in which the NAME field is found within the context of the PERSON
-		// field (occurences of NAME field which are directly subordinate
-		// to the PERSON field), a field path can be used:
-		//
-		//           FLMUINT     puiFldPath[] = { 567, 569, 0 };
-		//
-		// The field path can be view simply as a "qualified" field,
-		// and as such, adding a field path to the selection criteria is no
-		// different syntactically than adding a field to the criteria.
-		// All operations, operators, and constructs which are valid when
-		// applied to a field are also valid when applied to a field path.
-	FLMUINT		uiFlags,
-		// [IN] Flags. Valid values for uiFlags are as follows:
-		//      FLM_USE_DEFAULT_VALUE -- If a field is missing from a record,
-		//		  use a default value.
-		//		  FLM_SINGLE_VALUED -- Field will only have a single occurrance
-		//		  in any record it appears in.
-	FLMBOOL		bValidateOnly,
-		// [IN] Validate fields only.  If TRUE, this indicates that fields are
-		// to be validated via the callback, not fetched.
+/****************************************************************************
+Desc:	Adds a field path to the selection criteria of a given cursor - with
+		a callback to retrieve the field.
+****************************************************************************/
+FLMEXP RCODE FLMAPI FlmCursorAddFieldCB(
+	HFCURSOR					hCursor,
+	FLMUINT *				puiFldPath,
+	FLMUINT					uiFlags,
+	FLMBOOL					bValidateOnly,
 	CURSOR_GET_FIELD_CB	fnGetField,
-		// [IN] Callback function to retrieve the field.
 	void *					pvUserData,
-		// [IN] User data for callback function
-	FLMUINT		uiUserDataLen
-	)
+	FLMUINT					uiUserDataLen)
 {
 	RCODE			rc = FERR_OK;
-	FQNODE_p		pTmpQNode;
-	CURSOR_p		pCursor = (CURSOR_p)hCursor;
+	FQNODE *		pTmpQNode;
+	CURSOR *		pCursor = (CURSOR *)hCursor;
 
 	if (!pCursor)
 	{
@@ -1114,18 +1053,19 @@ RCODE FlmCursorAddFieldCB(
 									puiFldPath, 0, pCursor->QTInfo.uiFlags,
 									&pTmpQNode)))
 	{
-		FQATOM_p	pQAtom = pTmpQNode->pQAtom;
+		FQATOM *	pQAtom = pTmpQNode->pQAtom;
 
 		pQAtom->val.QueryFld.fnGetField = fnGetField;
 		pQAtom->val.QueryFld.bValidateOnly = bValidateOnly;
+		
 		if (pvUserData && uiUserDataLen)
 		{
-			if ((pQAtom->val.QueryFld.pvUserData =
-				GedPoolAlloc( &pCursor->QueryPool, uiUserDataLen)) == NULL)
+			if( RC_BAD( rc = pCursor->QueryPool.poolAlloc( uiUserDataLen,
+				(void **)&pQAtom->val.QueryFld.pvUserData)))
 			{
-				rc = RC_SET( FERR_MEM);
 				goto Exit;
 			}
+			
 			f_memcpy( pQAtom->val.QueryFld.pvUserData, pvUserData,
 							uiUserDataLen);
 			pQAtom->val.QueryFld.uiUserDataLen = uiUserDataLen;
