@@ -25,7 +25,7 @@
 #include "flaimsys.h"
 
 /****************************************************************************
-Public: Constructor
+Desc:
 ****************************************************************************/
 FSDataCursor::FSDataCursor() 
 {
@@ -37,7 +37,7 @@ FSDataCursor::FSDataCursor()
 }
 
 /****************************************************************************
-Public: Destructor
+Desc:
 ****************************************************************************/
 FSDataCursor::~FSDataCursor() 
 {
@@ -46,8 +46,7 @@ FSDataCursor::~FSDataCursor()
 }
 
 /****************************************************************************
-Public: 	reset
-Desc: 	Resets any allocations, keys, state, etc.
+Desc:	Resets any allocations, keys, state, etc.
 ****************************************************************************/
 void FSDataCursor::reset( void)
 {
@@ -69,10 +68,9 @@ void FSDataCursor::reset( void)
 
 
 /****************************************************************************
-Public: 	resetTransaction
-Desc: 	Resets to a new transaction that may change the read consistency of
-			the query.  This is usually an old view error internal or external of
-			this class.
+Desc: Resets to a new transaction that may change the read consistency of
+		the query.  This is usually an old view error internal or external of
+		this class.
 ****************************************************************************/
 RCODE FSDataCursor::resetTransaction( 
 	FDB *			pDb)
@@ -89,9 +87,7 @@ RCODE FSDataCursor::resetTransaction(
 	m_uiBlkChangeCnt = pDb->uiBlkChangeCnt;
 	m_bIsUpdateTrans = (pDb->uiTransType == FLM_UPDATE_TRANS) ? TRUE : FALSE;
 
-	/*
-	Need to release all stacks that are currently in use.
-	*/
+	// Need to release all stacks that are currently in use.
 
 	for( pTmpSet = m_pFirstSet; pTmpSet; pTmpSet = pTmpSet->pNext)
 	{
@@ -142,10 +138,8 @@ void FSDataCursor::freeSets( void)
 
 
 /****************************************************************************
-Public: 	releaseBlocks
-Desc: 	Releases the cache blocks back to cache.
+Desc:	Releases the cache blocks back to cache.
 ****************************************************************************/
-
 void FSDataCursor::releaseBlocks( void)
 {
 	RECSET *		pCurSet;
@@ -163,10 +157,9 @@ void FSDataCursor::releaseBlocks( void)
 }
 
 /****************************************************************************
-Public: 	setupRange
-Desc: 	Setup the from and until keys in the cursor.  Return counts
-			after positioning to the from and until key in the index.
-			This code does not work with multiple key sets of FROM/UNTIL keys.
+Desc:	Setup the from and until keys in the cursor.  Return counts
+		after positioning to the from and until key in the index.
+		This code does not work with multiple key sets of FROM/UNTIL keys.
 ****************************************************************************/
 RCODE FSDataCursor::setupRange(
 	FDB *			pDb,
@@ -272,8 +265,7 @@ Exit:
 }
 
 /****************************************************************************
-Public: 	unionRange
-Desc: 	Merge the input cursors fromUntil sets as a result of a UNION.
+Desc:	Merge the input cursors fromUntil sets as a result of a UNION.
 ****************************************************************************/
 RCODE FSDataCursor::unionRange( 
 	FSDataCursor * pFSCursor)
@@ -291,7 +283,7 @@ RCODE FSDataCursor::unionRange(
 	while( pSrcSet || pInputSet)
 	{
 		FLMBOOL		bFromKeyLessThan;
-		FLMBOOL		bUntilKeyGreaterThan;
+		FLMBOOL		bUntilKeyGreaterThan = FALSE;
 
 		pPrevDestSet = pCurDestSet;
 		if( RC_BAD( rc = f_calloc( sizeof( RECSET), &pCurDestSet)))
@@ -420,8 +412,7 @@ Exit:
 }
 
 /****************************************************************************
-Public: 	intersectRange
-Desc: 	Intersect the from/until key sets of pFSCursor into 'this'.
+Desc:	Intersect the from/until key sets of pFSCursor into 'this'.
 ****************************************************************************/
 RCODE FSDataCursor::intersectRange( 
 	FSDataCursor * pFSCursor)
@@ -548,11 +539,9 @@ FLMBOOL FSDataCursor::FSCompareRecPos(			// TRUE if keys overlap
 }
 
 /****************************************************************************
-Public: 	currentRec
 Desc: 	Return the current record and record id.
 VISIT:	We may want to return BOF/EOF when positioned on an endpoint.
 ****************************************************************************/
-
 RCODE FSDataCursor::currentRec(		// FERR_OK, FERR_EOF_HIT or error
 	FDB *				pDb,
 	FlmRecord **	ppRecord,			// Will replace what is there
@@ -595,15 +584,14 @@ Exit:
 }
 
 /****************************************************************************
-Public: 	firstRec
-Desc: 	Position to and return the first record.
-			This is hard because positioning using the first key may actually
-			position past or into another FROM/UNTIL set in the list.
+Desc: Position to and return the first record.
+		This is hard because positioning using the first key may actually
+		position past or into another FROM/UNTIL set in the list.
 ****************************************************************************/
-RCODE FSDataCursor::firstRec(			// FERR_OK, FERR_EOF_HIT or error
+RCODE FSDataCursor::firstRec(
 	FDB *				pDb,
 	FlmRecord **	ppRecord,		// Will replace what is there
-	FLMUINT *		puiRecordId)		// Set the record ID
+	FLMUINT *		puiRecordId)	// Set the record ID
 {
 	RCODE				rc;
 
@@ -680,7 +668,7 @@ FINLINE void setItemsFromBlock(
 	RECPOS *	pRecPos
 	)
 {
-	pRecPos->uiRecordId = byteToLong( pRecPos->pKey);
+	pRecPos->uiRecordId = f_bigEndianToUINT32( pRecPos->pKey);
 	pRecPos->uiBlockAddr = pRecPos->pStack->uiBlkAddr;
 	pRecPos->uiBlockTransId = (pRecPos->uiBlockAddr != BT_END) 
 									  ? FB2UD( &pRecPos->pStack->pBlk[ BH_TRANS_ID])
@@ -714,7 +702,7 @@ RCODE FSDataCursor::setRecPosition(
 	pOutRecPos->pStack = pOutRecPos->Stack;
 	pOutRecPos->Stack[0].pKeyBuf = pOutRecPos->pKey;
 	uiRecordId = pInRecPos->uiRecordId;
-	longToByte( uiRecordId, buf);
+	f_UINT32ToBigEndian( (FLMUINT32)uiRecordId, buf);
 
 	// All of the variables should be setup for the search.
 	if( RC_BAD( rc = FSBtSearch( pDb, m_pLFile, &pOutRecPos->pStack,
@@ -731,8 +719,8 @@ RCODE FSDataCursor::setRecPosition(
 	}
 	if( bGoingForward)
 	{
-		if( pOutRecPos->pStack->uiCmpStatus == BT_END_OF_DATA
-		 || byteToLong( pOutRecPos->pKey) == DRN_LAST_MARKER)
+		if( pOutRecPos->pStack->uiCmpStatus == BT_END_OF_DATA ||
+			f_bigEndianToUINT32( pOutRecPos->pKey) == DRN_LAST_MARKER)
 		{
 			rc = RC_SET( FERR_EOF_HIT);
 			goto Exit;
@@ -740,8 +728,8 @@ RCODE FSDataCursor::setRecPosition(
 	}
 	else
 	{
-		if( (pOutRecPos->pStack->uiCmpStatus == BT_END_OF_DATA)
-		 || (byteToLong( pOutRecPos->pKey) > uiRecordId))
+		if( (pOutRecPos->pStack->uiCmpStatus == BT_END_OF_DATA) ||
+			 (f_bigEndianToUINT32( pOutRecPos->pKey) > uiRecordId))
 		{
 			// Went a little too far - go back to the previous record.
 			// Need to position back one element.
@@ -777,14 +765,13 @@ Exit:
 }
 
 /****************************************************************************
-Public: 	lastRec
-Desc: 	Position to and return the last record.
-			This is hard because positioning using the first key may actually
-			position past or into another FROM/UNTIL set in the list.
+Desc: Position to and return the last record.
+		This is hard because positioning using the first key may actually
+		position past or into another FROM/UNTIL set in the list.
 ****************************************************************************/
-RCODE FSDataCursor::lastRec(				// FERR_OK, FERR_BOF_HIT or error
+RCODE FSDataCursor::lastRec(
 	FDB *				pDb,
-	FlmRecord **	ppRecord,		// Will replace what is there
+	FlmRecord **	ppRecord,			// Will replace what is there
 	FLMUINT *		puiRecordId)		// Set the record ID
 {
 	RCODE				rc;
@@ -912,10 +899,9 @@ Exit:
 }
 
 /****************************************************************************
-Public: 	nextRec
-Desc: 	Position to the next key and the first reference of that key.
+Desc: Position to the next key and the first reference of that key.
 ****************************************************************************/
-RCODE FSDataCursor::nextRec(			// FERR_OK, FERR_EOF_HIT or error
+RCODE FSDataCursor::nextRec(
 	FDB *				pDb,
 	FlmRecord **	ppRecord,
 	FLMUINT *		puiRecordId)
@@ -988,7 +974,7 @@ RCODE FSDataCursor::nextRec(			// FERR_OK, FERR_EOF_HIT or error
 					goto Exit;
 				}
 				bRecordGone = TRUE;
-				if( byteToLong( m_curRecPos.pKey) <=
+				if( f_bigEndianToUINT32( m_curRecPos.pKey) <=
 						m_pCurSet->untilKey.uiRecordId)
 				{
 					setItemsFromBlock( &m_curRecPos);
@@ -1045,10 +1031,9 @@ Exit:
 }
 
 /****************************************************************************
-Public: 	prevRec
-Desc: 	Position to the PREVIOUS record.
+Desc:	Position to the PREVIOUS record.
 ****************************************************************************/
-RCODE FSDataCursor::prevRec(			// FERR_OK, FERR_EOF_HIT or error
+RCODE FSDataCursor::prevRec(
 	FDB *				pDb,
 	FlmRecord **	ppRecord,
 	FLMUINT *		puiRecordId)
@@ -1135,7 +1120,8 @@ RCODE FSDataCursor::prevRec(			// FERR_OK, FERR_EOF_HIT or error
 					pCurElm = CURRENT_ELM( pStack);
 				}
 				bRecordGone = TRUE;
-				if( byteToLong( m_curRecPos.pKey) >= m_pCurSet->fromKey.uiRecordId)
+				if( f_bigEndianToUINT32( m_curRecPos.pKey) >= 
+						m_pCurSet->fromKey.uiRecordId)
 				{
 					setItemsFromBlock( &m_curRecPos);
 					break;
@@ -1294,10 +1280,9 @@ Exit:
 }
 
 /****************************************************************************
-Public: 	positionTo
-Desc: 	Position to the input key + recordId.
+Desc:	Position to the input key + recordId.
 ****************************************************************************/
-RCODE FSDataCursor::positionTo(	// FERR_NOT_FOUND if outside set or not found
+RCODE FSDataCursor::positionTo(
 	FDB *				pDb,
 	FLMUINT			uiRecordId)
 {
@@ -1330,10 +1315,9 @@ Exit:
 };
 
 /****************************************************************************
-Public: 	positionToOrAfter
-Desc: 	Position to the input key + recordId.
+Desc:	Position to the input key + recordId.
 ****************************************************************************/
-RCODE FSDataCursor::positionToOrAfter(	// FERR_EOF_HIT or error.
+RCODE FSDataCursor::positionToOrAfter(
 	FDB *				pDb,
 	FLMUINT *		puiRecordId)
 {
@@ -1381,8 +1365,7 @@ Exit:
 };
 
 /****************************************************************************
-Public: 	savePosition
-Desc: 	Save the current position.
+Desc:	Save the current position.
 ****************************************************************************/
 RCODE FSDataCursor::savePosition( void)
 {
@@ -1403,8 +1386,7 @@ Exit:
 }
 
 /****************************************************************************
-Public: 	restorePosition
-Desc: 	Save the current position.
+Desc:	Save the current position.
 ****************************************************************************/
 RCODE FSDataCursor::restorePosition( void)
 {
@@ -1416,5 +1398,3 @@ RCODE FSDataCursor::restorePosition( void)
 
 	return FERR_OK;
 }
-
-
