@@ -46,7 +46,7 @@ FSTATIC RCODE flmFreeContainerBlocks(
 	LFILE *			pLFile);
 
 FSTATIC RCODE flmFreeIndexBlocks(
-	FDB_p			pDb,
+	FDB *			pDb,
 	LFILE *			pLFile,
 	FLMBOOL			bInvalidateLFile);
 
@@ -65,8 +65,8 @@ FSTATIC RCODE flmModifyTrackerRec(
 	FLMUINT			uiDrn,
 	FlmRecord *		pRecord);
 
-FSTATIC RCODE flmMaintThread(
-	F_Thread *		pThread);
+FSTATIC RCODE FLMAPI flmMaintThread(
+	IF_Thread *		pThread);
 
 FSTATIC RCODE fdictRemoveIndexes(
 	FDB *				pDb,
@@ -94,7 +94,7 @@ Desc:		Verify that the action being attempted in a dictionary update
 ****************************************************************************/
 RCODE flmLFileDictUpdate(
 	FDB *			pDb,
-	LFILE *		pDictLFile,
+	LFILE **		ppDictLFile,
 	FLMUINT *	puiDrnRV,
 	FlmRecord *	pNewRecord,
 	FlmRecord *	pOldRecord,
@@ -284,7 +284,7 @@ RCODE flmLFileDictUpdate(
 	// It also makes sure we are not trying to change the key on EncDef records.
 	// It will make sure new keys are generated for new EncDef records.
 
-	if( RC_BAD( rc = fdictRecUpdate( pDb, pDictLFile, pDictIxLFile,
+	if( RC_BAD( rc = fdictRecUpdate( pDb, *ppDictLFile, pDictIxLFile,
 									puiDrnRV, pNewRecord, pOldRecord, bRebuildOp)))
 	{
 		goto Exit;
@@ -443,6 +443,15 @@ RCODE flmLFileDictUpdate(
 		{
 			goto Exit;
 		}
+		
+		// Re-get the dictionary LFILE
+		
+		if( RC_BAD( rc = fdictGetContainer( pDb->pDict, 
+			FLM_DICT_CONTAINER, ppDictLFile)))
+		{
+			goto Exit;
+		}
+		
 
 		if( pNewRecord && uiOldRecordType == FLM_INDEX_TAG)
 		{
@@ -596,8 +605,8 @@ RCODE flmLFileIndexBuild(
 		// Don't index now.  The RFL function INDEX_SET will 
 		// generate index keys.
 
-		if( pDb->pFile->FileHdr.uiVersionNum >= FLM_VER_3_02 &&
-			pDb->pFile->FileHdr.uiVersionNum <= FLM_VER_4_51)
+		if( pDb->pFile->FileHdr.uiVersionNum >= FLM_FILE_FORMAT_VER_3_02 &&
+			pDb->pFile->FileHdr.uiVersionNum <= FLM_FILE_FORMAT_VER_4_51)
 		{
 			if( RC_BAD( rc = flmSetIxTrackerInfo( pDb, 
 						pIxd->uiIndexNum, 1, 0, TRANS_ID_OFFLINE, FALSE)))
@@ -729,7 +738,7 @@ void flmLogIndexingProgress(
 	FLMUINT		uiLastDrn)
 {
 	flmLogMessage( 
-		FLM_DEBUG_MESSAGE,
+		F_DEBUG_MESSAGE,
 		FLM_YELLOW,
 		FLM_BLACK,
 		uiLastDrn
@@ -755,43 +764,42 @@ RCODE flmIndexSetOfRecords(
 	void *				IxCallbackData,
 	FINDEX_STATUS *	pIndexStatus,
 	FLMBOOL *			pbHitEnd,
-	F_Thread *			pThread,
+	IF_Thread *			pThread,
 	FlmRecord *			pReusableRec)
 {
-	RCODE				rc = FERR_OK;
-	FLMUINT			uiDrn;
-	FLMUINT			uiLastDrn = 0;
-	IXD *				pIxd = NULL;
-	LFILE *			pDataLFile;
-	FlmRecord *		pRecord = NULL;
-	FlmRecord *		pModRecord = NULL;
-	ServerLockObject *
-						pFileLockObj = pDb->pFile->pFileLockObj;
-	FLMBOOL			bHitEnd = FALSE;
-	FLMBOOL			bDataRecordRead;
-	FLMUINT			uiCurrTime;
-	FLMUINT			uiLastStatusTime = 0;
-	FLMUINT			uiStartTime;
-	FLMUINT			uiMinTU;
-	FLMUINT			uiStatusIntervalTU;
-	FLMUINT			uiRecsProcessed = 0;
-	FLMBOOL			bUpdateTracker = FALSE;
-	FLMBOOL			bHadUniqueKeys;
-	FLMBOOL			bRelinquish = FALSE;
-	BTSK  			stackBuf [BH_MAX_LEVELS];
-	BTSK *			pStack = &stackBuf [0];
-	FLMBYTE			ucKeyBuf [DIN_KEY_SIZ];
-	FLMBYTE			ucSearchKey [DIN_KEY_SIZ];
-	FLMBOOL			bDoAllContainers = FALSE;
-	ITT *				pItt;
-	POOL				ReadPool;
-	void *			pvTmpPoolMark = GedPoolMark( &pDb->TempPool);
+	RCODE					rc = FERR_OK;
+	FLMUINT				uiDrn;
+	FLMUINT				uiLastDrn = 0;
+	IXD *					pIxd = NULL;
+	LFILE *				pDataLFile;
+	FlmRecord *			pRecord = NULL;
+	FlmRecord *			pModRecord = NULL;
+	IF_LockObject *	pFileLockObj = pDb->pFile->pFileLockObj;
+	FLMBOOL				bHitEnd = FALSE;
+	FLMBOOL				bDataRecordRead;
+	FLMUINT				uiCurrTime;
+	FLMUINT				uiLastStatusTime = 0;
+	FLMUINT				uiStartTime;
+	FLMUINT				uiMinTU;
+	FLMUINT				uiStatusIntervalTU;
+	FLMUINT				uiRecsProcessed = 0;
+	FLMBOOL				bUpdateTracker = FALSE;
+	FLMBOOL				bHadUniqueKeys;
+	FLMBOOL				bRelinquish = FALSE;
+	BTSK  				stackBuf [BH_MAX_LEVELS];
+	BTSK *				pStack = &stackBuf [0];
+	FLMBYTE				ucKeyBuf [DIN_KEY_SIZ];
+	FLMBYTE				ucSearchKey [DIN_KEY_SIZ];
+	FLMBOOL				bDoAllContainers = FALSE;
+	ITT *					pItt;
+	F_Pool				ReadPool;
+	void *				pvTmpPoolMark = pDb->TempPool.poolMark();
 
-	GedPoolInit( &ReadPool, 8192);
+	ReadPool.poolInit( 8192);
 	FSInitStackCache( &stackBuf [0], BH_MAX_LEVELS);
 
-	FLM_MILLI_TO_TIMER_UNITS( 500, uiMinTU);
-	FLM_SECS_TO_TIMER_UNITS( 10, uiStatusIntervalTU);
+	uiMinTU = FLM_MILLI_TO_TIMER_UNITS( 500);
+	uiStatusIntervalTU = FLM_SECS_TO_TIMER_UNITS( 10);
 	uiStartTime = FLM_GET_TIMER();
 
 	if( !pReusableRec)
@@ -825,7 +833,7 @@ RCODE flmIndexSetOfRecords(
 
 	if (!pIxd->uiContainerNum && !uiContainerNum)
 	{
-		flmAssert( pDb->pFile->FileHdr.uiVersionNum >= FLM_VER_4_50);
+		flmAssert( pDb->pFile->FileHdr.uiVersionNum >= FLM_FILE_FORMAT_VER_4_50);
 		bDoAllContainers = TRUE;
 	}
 
@@ -843,7 +851,8 @@ RCODE flmIndexSetOfRecords(
 #ifdef FLM_DEBUG
 			if( !pIxd->uiContainerNum)
 			{
-				flmAssert( pDb->pFile->FileHdr.uiVersionNum >= FLM_VER_4_50);
+				flmAssert( pDb->pFile->FileHdr.uiVersionNum >= 
+							  FLM_FILE_FORMAT_VER_4_50);
 			}
 #endif
 
@@ -890,7 +899,7 @@ RCODE flmIndexSetOfRecords(
 
 		uiLastDrn = 0;
 		pStack->pKeyBuf = ucKeyBuf;
-		longToByte( uiStartDrn, ucSearchKey);
+		f_UINT32ToBigEndian( (FLMUINT32)uiStartDrn, ucSearchKey);
 
 		if (RC_BAD( rc = FSBtSearch( pDb, pDataLFile, &pStack,
 									ucSearchKey, 4, 0)))
@@ -909,7 +918,7 @@ RCODE flmIndexSetOfRecords(
 
 		for (;;)
 		{
-			if ((uiDrn = byteToLong( ucKeyBuf)) == DRN_LAST_MARKER)
+			if ((uiDrn = f_bigEndianToUINT32( ucKeyBuf)) == DRN_LAST_MARKER)
 			{
 				bHitEnd = TRUE;
 				break;
@@ -1006,7 +1015,7 @@ RCODE flmIndexSetOfRecords(
 			// entries.  Now that we are finished indexing the current record,
 			// we need to reset the pool to free the CDL allocations.
 
-			GedPoolReset( &pDb->TempPool, pvTmpPoolMark);
+			pDb->TempPool.poolReset( pvTmpPoolMark);
 
 			// See if there is an indexing callback
 
@@ -1044,7 +1053,7 @@ RCODE flmIndexSetOfRecords(
 					FSInitStackCache( &stackBuf [0], BH_MAX_LEVELS);
 					pStack = stackBuf;
 					pStack->pKeyBuf = ucKeyBuf;
-					longToByte( uiDrn, ucSearchKey);
+					f_UINT32ToBigEndian( (FLMUINT32)uiDrn, ucSearchKey);
 					if (RC_BAD( rc = FSBtSearch( pDb, pDataLFile, &pStack,
 												ucSearchKey, 4, 0)))
 					{
@@ -1088,7 +1097,7 @@ RCODE flmIndexSetOfRecords(
 					break;
 				}
 
-				if( pFileLockObj->ThreadWaitingLock())
+				if( pFileLockObj->getWaiterCount())
 				{
 					// See if our minimum run time has elapsed
 
@@ -1124,7 +1133,7 @@ RCODE flmIndexSetOfRecords(
 
 					if( FLM_ELAPSED_TIME( uiCurrTime, uiStartTime) > 
 						gv_FlmSysData.uiMaxCPInterval && 
-						pDb->pFile->pWriteLockObj->ThreadWaitingLock())
+						pDb->pFile->pWriteLockObj->getWaiterCount())
 					{
 						bRelinquish = TRUE;
 						break;
@@ -1149,7 +1158,7 @@ RCODE flmIndexSetOfRecords(
 
 				// Send indexing completed event notification
 
-				if( gv_FlmSysData.EventHdrs[ F_EVENT_UPDATES].pEventCBList)
+				if( gv_FlmSysData.UpdateEvents.pEventCBList)
 				{
 					flmDoEventCallback( F_EVENT_UPDATES, 
 							F_EVENT_INDEXING_COMPLETE, (void *)uiIxNum, 
@@ -1284,7 +1293,7 @@ Exit:
 
 	if( !pThread)
 	{
-		if( gv_FlmSysData.EventHdrs[ F_EVENT_UPDATES].pEventCBList)
+		if( gv_FlmSysData.UpdateEvents.pEventCBList)
 		{
 			flmDoEventCallback( F_EVENT_UPDATES, 
 					F_EVENT_INDEXING_COMPLETE, (void *)uiIxNum, 
@@ -1295,7 +1304,7 @@ Exit:
 	}
 	else if( uiLastDrn)
 	{
-		if( gv_FlmSysData.EventHdrs[ F_EVENT_UPDATES].pEventCBList)
+		if( gv_FlmSysData.UpdateEvents.pEventCBList)
 		{
 			flmDoEventCallback( F_EVENT_UPDATES, 
 					F_EVENT_INDEXING_COMPLETE, (void *)uiIxNum, 
@@ -1320,8 +1329,7 @@ Exit:
 
 	FSReleaseStackCache( stackBuf, BH_MAX_LEVELS, FALSE);
 	KrefCntrlFree( pDb);
-	GedPoolReset( &pDb->TempPool, pvTmpPoolMark);
-	GedPoolFree( &ReadPool);
+	pDb->TempPool.poolReset( pvTmpPoolMark);
 
 	if( pReusableRec)
 	{
@@ -1463,7 +1471,7 @@ RCODE flmSetIxTrackerInfo(
 		goto Exit;
 	}
 
-	if( pDb->pFile->FileHdr.uiVersionNum >= FLM_VER_4_51)
+	if( pDb->pFile->FileHdr.uiVersionNum >= FLM_FILE_FORMAT_VER_4_51)
 	{
 		FLMUINT32	ui32IndexSuspended = bSuspended ? 1 : 0;
 		if( RC_BAD( rc = flmModField( pRecord, FLM_STATE_TAG,
@@ -1483,8 +1491,7 @@ RCODE flmSetIxTrackerInfo(
 	pRecord->setID( uiIndexNum);
 	pRecord->setContainerID( FLM_TRACKER_CONTAINER);
 
-	if( RC_BAD( rc = flmRcaInsertRec( pDb, FLM_TRACKER_CONTAINER, 
-		uiIndexNum, pRecord)))
+	if( RC_BAD( rc = flmRcaInsertRec( pDb, pLFile, uiIndexNum, pRecord)))
 	{
 		goto Exit;
 	}
@@ -2261,7 +2268,7 @@ FSTATIC RCODE flmFreeIndexBlocks(
 		goto Exit;
 	}
 
-	if( pFile->FileHdr.uiVersionNum <= FLM_VER_4_51)
+	if( pFile->FileHdr.uiVersionNum <= FLM_FILE_FORMAT_VER_4_51)
 	{
 		// Background deletion is not supported.  Must delete
 		// the blocks of the LFILE now.
@@ -2367,8 +2374,7 @@ FSTATIC RCODE flmFreeIndexBlocks(
 				goto Exit;
 			}
 
-			if( RC_BAD( rc = flmRcaInsertRec( pDb, FLM_TRACKER_CONTAINER,
-				uiDrn, pRec)))
+			if( RC_BAD( rc = flmRcaInsertRec( pDb, pTrackerLFile, uiDrn, pRec)))
 			{
 				goto Exit;
 			}
@@ -2650,7 +2656,8 @@ RCODE flmStartMaintThread(
 
 	// Generate the thread name
 
-	if( RC_BAD( rc = f_pathReduce( pFile->pszDbPath, szThreadName, szBaseName)))
+	if( RC_BAD( rc = gv_FlmSysData.pFileSystem->pathReduce( 
+		pFile->pszDbPath, szThreadName, szBaseName)))
 	{
 		goto Exit;
 	}
@@ -2666,7 +2673,7 @@ RCODE flmStartMaintThread(
 
 	if( RC_BAD( rc = f_threadCreate( &pFile->pMaintThrd,
 		flmMaintThread, szThreadName, 
-		FLM_DEFAULT_THREAD_GROUP, 0, pFile, NULL, 32000)))
+		0, 0, pFile, NULL, 32000)))
 	{
 		goto Exit;
 	}
@@ -2700,17 +2707,17 @@ FSTATIC RCODE flmRetrieveTrackerRec(
 	FlmRecord **	ppRecord)
 {
 	RCODE				rc = FERR_OK;
-	POOL				readPool;
+	F_Pool			readPool;
 	LFILE *			pTrackerLFile;
 	BTSK  			stackBuf[ BH_MAX_LEVELS];
-	BTSK_p			pStack = &stackBuf[ 0];
+	BTSK *			pStack = &stackBuf[ 0];
 	FLMBYTE			ucKeyBuf[ DIN_KEY_SIZ];
 	FLMBYTE			ucSearchKey[ DIN_KEY_SIZ];
 	FlmRecord *		pTrackerRec = NULL;
 	FLMUINT			uiFoundDrn;
 
 	FSInitStackCache( &stackBuf[ 0], BH_MAX_LEVELS);
-	GedPoolInit( &readPool, 8192);
+	readPool.poolInit( 8192);
 
 	// Retrieve a tracker record for processing
 
@@ -2721,7 +2728,7 @@ FSTATIC RCODE flmRetrieveTrackerRec(
 	}
 
 	pStack->pKeyBuf = ucKeyBuf;
-	longToByte( uiDrn, ucSearchKey);
+	f_UINT32ToBigEndian( (FLMUINT32)uiDrn, ucSearchKey);
 
 	if( RC_BAD( rc = FSBtSearch( 
 		pDb, pTrackerLFile, &pStack, ucSearchKey, 4, 0)))
@@ -2739,7 +2746,7 @@ FSTATIC RCODE flmRetrieveTrackerRec(
 
 	// Stack points to leaf element
 
-	if( (uiFoundDrn = byteToLong( ucKeyBuf)) == DRN_LAST_MARKER)
+	if( (uiFoundDrn = f_bigEndianToUINT32( ucKeyBuf)) == DRN_LAST_MARKER)
 	{
 		rc = RC_SET( FERR_EOF_HIT);
 		goto Exit;
@@ -2791,7 +2798,6 @@ Exit:
 	}
 
 	FSReleaseStackCache( stackBuf, BH_MAX_LEVELS, FALSE);
-	GedPoolFree( &readPool);
 	return( rc);
 }
 
@@ -2856,8 +2862,7 @@ FSTATIC RCODE flmModifyTrackerRec(
 	pRecord->setID( uiDrn);
 	pRecord->setContainerID( FLM_TRACKER_CONTAINER);
 
-	if( RC_BAD( rc = flmRcaInsertRec( pDb, FLM_TRACKER_CONTAINER, 
-		uiDrn, pRecord)))
+	if( RC_BAD( rc = flmRcaInsertRec( pDb, pLFile, uiDrn, pRecord)))
 	{
 		goto Exit;
 	}
@@ -2870,8 +2875,8 @@ Exit:
 /***************************************************************************
 Desc: 
 *****************************************************************************/
-FSTATIC RCODE flmMaintThread(
-	F_Thread *		pThread)
+FSTATIC RCODE FLMAPI flmMaintThread(
+	IF_Thread *		pThread)
 {
 	RCODE					rc = FERR_OK;
 	FLMBOOL				bStartedTrans = FALSE;
@@ -2923,7 +2928,7 @@ FSTATIC RCODE flmMaintThread(
 
 		// Wait for work to become available
 
-		if( RC_BAD( rc = f_semWait( pFile->hMaintSem, F_SEM_WAITFOREVER)))
+		if( RC_BAD( rc = f_semWait( pFile->hMaintSem, F_WAITFOREVER)))
 		{
 			goto Exit;
 		}
@@ -2943,9 +2948,9 @@ FSTATIC RCODE flmMaintThread(
 			pStatus->eDoing = FLM_MAINT_WAITING_FOR_LOCK;
 
 			flmAssert( !(pDb->uiFlags & FDB_HAS_FILE_LOCK));
-			if( RC_BAD( rc = pDb->pFile->pFileLockObj->Lock( TRUE, pDb, FALSE, 
+			if( RC_BAD( rc = pDb->pFile->pFileLockObj->lock( pDb->hWaitSem, 
 				TRUE, FLM_NO_TIMEOUT, FLM_BACKGROUND_LOCK_PRIORITY,
-				pDb->pDbStats)))
+				pDb->pDbStats ? &pDb->pDbStats->LockStats : NULL)))
 			{
 				if( rc == FERR_IO_FILE_LOCK_ERR)
 				{
@@ -2971,7 +2976,7 @@ FSTATIC RCODE flmMaintThread(
 				pDb->pFile->pFileLockObj->haveHigherPriorityWaiter( 
 					FLM_BACKGROUND_LOCK_PRIORITY))
 			{
-				if( RC_BAD( rc = pDb->pFile->pFileLockObj->Unlock( TRUE, pDb)))
+				if( RC_BAD( rc = pDb->pFile->pFileLockObj->unlock()))
 				{
 					goto Exit;
 				}
@@ -3016,7 +3021,6 @@ FSTATIC RCODE flmMaintThread(
 				}
 
 				rc = FERR_OK;
-				pThread->setThreadStatus( FLM_THREAD_STATUS_ABORTING_TRANS);
 				(void)flmAbortDbTrans( pDb);
 				bStartedTrans = FALSE;
 				break;
@@ -3050,8 +3054,6 @@ FSTATIC RCODE flmMaintThread(
 					}
 				}
 				
-				pThread->setThreadStatus( FLM_THREAD_STATUS_COMMITTING_TRANS);
-
 				// Commit the transaction
 
 				pStatus->eDoing = FLM_MAINT_ENDING_TRANS;
@@ -3084,7 +3086,7 @@ Exit:
 
 	if( pDb && pDb->uiFlags & FDB_HAS_FILE_LOCK)
 	{
-		(void)pDb->pFile->pFileLockObj->Unlock( TRUE, pDb);
+		pDb->pFile->pFileLockObj->unlock();
 		pDb->uiFlags &= ~(FDB_HAS_FILE_LOCK | FDB_FILE_LOCK_IMPLICIT);
 	}
 
@@ -3105,7 +3107,7 @@ Exit:
 /***************************************************************************
 Desc:
 ****************************************************************************/
-RCODE FlmMaintenanceStatus(
+FLMEXP RCODE FLMAPI FlmMaintenanceStatus(
 	HFDB					hDb,
 	FMAINT_STATUS *	pMaintStatus)
 {
