@@ -146,7 +146,7 @@ void F_FlmSysDataPage::write_data(
 	
 	printHTMLLink(
 		"pMrnuFile",
-		"FFILE_p",
+		"FFILE *",
 		(void *)&gv_FlmSysData,
 		(void *)&gv_FlmSysData.pMrnuFile,
 		(void *)gv_FlmSysData.pMrnuFile,
@@ -168,7 +168,7 @@ void F_FlmSysDataPage::write_data(
 	
 	printHTMLLink(
 		"pLrnuFile",
-		"FFILE_p",
+		"FFILE *",
 		(void *)&gv_FlmSysData,
 		(void *)&gv_FlmSysData.pLrnuFile,
 		(void *)gv_FlmSysData.pLrnuFile,
@@ -183,7 +183,7 @@ void F_FlmSysDataPage::write_data(
 
 	printHTMLLink(
 		"pFileHashTbl",
-		"FFILE_p",
+		"FFILE *",
 		(void *)&gv_FlmSysData,
 		(void *)&gv_FlmSysData.pFileHashTbl,
 		(void *)gv_FlmSysData.pFileHashTbl,
@@ -204,46 +204,6 @@ void F_FlmSysDataPage::write_data(
 
 	
 	
-	
-	// hFileHdlMutex - File handle mutex
-	printAddress( (void *)&gv_FlmSysData.hFileHdlMutex, szAddress);
-	printHTMLString(
-		"hFileHdlMutex",
-		"F_MUTEX",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.hFileHdlMutex,
-		(char *)szAddress,
-		(bHighlight = !bHighlight));
-	
-	
-	
-	// hServerLockMgrMutex - Server lock manager mutex
-	printAddress( (void *)&gv_FlmSysData.hServerLockMgrMutex, szAddress);
-	printHTMLString(
-		"hServerLockMgrMutex",
-		"F_MUTEX",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.hServerLockMgrMutex,
-		(char *)szAddress,
-		(bHighlight = !bHighlight));
-
-
-
-	// pFileHdlMgr - File handle manager
-	f_sprintf( (char *)pszTemp, "%s/FileHdlMgr",
-		m_pszURLString);
-
-	printHTMLLink(
-		"pFileHdlMgr",
-		"FFILE_p",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.pFileHdlMgr,
-		(void *)gv_FlmSysData.pFileHdlMgr,
-		(char *)pszTemp,
-		(bHighlight = !bHighlight));
-
-
-
 	// pFileSystem - File system
 	printAddress( (void *)gv_FlmSysData.pFileSystem, szAddress);
 	printHTMLString(
@@ -269,28 +229,6 @@ void F_FlmSysDataPage::write_data(
 	
 	
 	
-	// bOkToDoAsyncWrites - Asynchronous writes
-	printHTMLString(
-		"bOkToDoAsyncWrites",
-		"FLMBOOL",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.bOkToDoAsyncWrites,
-		(char *)(gv_FlmSysData.bOkToDoAsyncWrites ? "Yes" : "No"),
-		(bHighlight = !bHighlight));
-	
-	
-	
-	// bOkToUseESM
-	printHTMLString(
-		"bOkToUseESM",
-		"FLMBOOL",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.bOkToUseESM,
-		(char *)(gv_FlmSysData.bOkToUseESM ? "Yes" : "No"),
-		(bHighlight = !bHighlight));
-
-
-
 	// bCheckCache - Check cache
 	printHTMLString(
 		"bCheckCache",
@@ -300,22 +238,7 @@ void F_FlmSysDataPage::write_data(
 		(char *)(gv_FlmSysData.bCheckCache ? "Yes" : "No"),
 		(bHighlight = !bHighlight));
 
-	// pServerLockMgr - Server lock Manager
-	f_sprintf( (char *)pszTemp,
-				"%s/ServerLockManager",
-				m_pszURLString);
 
-	printHTMLLink(
-		"pServerLockMgr",
-		"ServerLockManager_p",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.pServerLockMgr,
-		(void *)gv_FlmSysData.pServerLockMgr,
-		(char *)pszTemp,
-		(bHighlight = !bHighlight));	
-	
-	
-	
 	
 	// uiMaxCPInterval - Maximum checkpoint interval
 	printHTMLUint(
@@ -622,24 +545,6 @@ void F_FlmSysDataPage::write_data(
 	
 	
 	
-	// EventHdrs - Event Headers
-	f_sprintf( (char *)pszTemp, "<A HREF=\"javascript:openPopup('%s/EventHdr')\">EventHdrs</A>",
-				m_pszURLString);
-	printAddress( (void *)&gv_FlmSysData.EventHdrs, szAddress);
-	f_sprintf( (char *)pszTemp2, "<A HREF=\"javascript:openPopup('%s/EventHdr')\">%s</A>",
-				m_pszURLString, szAddress);
-
-	printHTMLString(
-		(char *)pszTemp,
-		"FEVENT_HDR",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.EventHdrs[0],
-		(char *)szAddress,
-		(bHighlight = !bHighlight));
-
-	
-	
-	
 	// KRefPool - Update Pool
 	printAddress( (void *)&gv_FlmSysData.KRefPool, szAddress);
 	printHTMLString(
@@ -679,229 +584,6 @@ void F_FlmSysDataPage::write_data(
 		gv_FlmSysData.uiMaxFileSize,
 		(bHighlight = !bHighlight));
 
-	// pLogger - Logger
-	f_sprintf( (char *)pszTemp, "%s/Logger",
-		m_pszURLString);
-
-	printHTMLLink(
-		"pLogger",
-		"F_Logger	*",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.pLogger,
-		(void *)gv_FlmSysData.pLogger,
-		(char *)pszTemp,
-		(bHighlight = !bHighlight));
-
-
-#ifdef FLM_DEBUG
-	// Variables for memory allocation tracking.
-
-	// bTrackLeaks
-	printHTMLString(
-		"bTrackLeaks",
-		"FLMBOOL",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.bTrackLeaks,
-		(char *)(gv_FlmSysData.bTrackLeaks ? "Yes" : "No"),
-		(bHighlight = !bHighlight));
-
-
-
-
-	// bLogLeaks
-	printHTMLString(
-		"bLogLeaks",
-		"FLMBOOL",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.bLogLeaks,
-		(char *)(gv_FlmSysData.bLogLeaks ? "Yes" : "No"),
-		(bHighlight = !bHighlight));
-
-
-
-
-	// bStackWalk
-	printHTMLString(
-		"bStackWalk",
-		"FLMBOOL",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.bStackWalk,
-		(char *)(gv_FlmSysData.bStackWalk ? "Yes" : "No"),
-		(bHighlight = !bHighlight));
-
-
-
-
-	// bMemTrackingInitialized
-	printHTMLString(
-		"bMemTrackingInitialized",
-		"FLMBOOL",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.bMemTrackingInitialized,
-		(char *)(gv_FlmSysData.bMemTrackingInitialized ? "Yes" : "No"),
-		(bHighlight = !bHighlight));
-
-
-
-
-	// uiInitThreadId
-	printHTMLUint(
-		"uiInitThreadId",
-		"FLMUINT",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.uiInitThreadId,
-		gv_FlmSysData.uiInitThreadId,
-		(bHighlight = !bHighlight));
-
-
-
-
-	// hMemTrackingmutex
-	printAddress( (void *)&gv_FlmSysData.hMemTrackingMutex, szAddress);
-	printHTMLString(
-		"hMemTrackingMutex",
-		"F_MUTEX",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.hMemTrackingMutex,
-		(char *)szAddress,
-		(bHighlight = !bHighlight));
-
-
-
-
-	// ppvMemTrackingPtrs
-	printAddress( (void *)gv_FlmSysData.ppvMemTrackingPtrs, szAddress);
-	printHTMLString(
-		"ppvMemTrackingPtrs",
-		"void **",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.ppvMemTrackingPtrs,
-		(char *)szAddress,
-		(bHighlight = !bHighlight));
-
-
-
-
-
-	// uiMemTrackingPtrArraySize
-	printHTMLUint(
-		"uiMemTrackingPtrArraySize",
-		"FLMUINT",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.uiMemTrackingPtrArraySize,
-		gv_FlmSysData.uiMemTrackingPtrArraySize,
-		(bHighlight = !bHighlight));
-
-
-
-
-	// uiMemNumPtrs
-	printHTMLUint(
-		"uiMemNumPtrs",
-		"FLMUINT",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.uiMemNumPtrs,
-		gv_FlmSysData.uiMemNumPtrs,
-		(bHighlight = !bHighlight));
-
-
-
-
-	// uiMemNextPtrSlotToUse
-	printHTMLUint(
-		"uiMemNextPtrSlotToUse",
-		"FLMUINT",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.uiMemNextPtrSlotToUse,
-		gv_FlmSysData.uiMemNextPtrSlotToUse,
-		(bHighlight = !bHighlight));
-
-
-
-
-	// uiAllocCnt
-	printHTMLUint(
-		"uiAllocCnt",
-		"FLMUINT",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.uiAllocCnt,
-		gv_FlmSysData.uiAllocCnt,
-		(bHighlight = !bHighlight));
-
-
-#if defined( FLM_WIN)
-
-
-	// hMemProcess
-	printHTMLUint(
-		"hMemProcess",
-		"HANDLE",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.hMemProcess,
-		(FLMUINT)gv_FlmSysData.hMemProcess,
-		(bHighlight = !bHighlight));
-
-
-#endif
-
-#ifdef DEBUG_SIM_OUT_OF_MEM
-
-	// uiOutOfMemSimEnabledFlag
-	printHTMLUint(
-		"uiOutOfMemSimEnabledFlag",
-		"FLMUINT",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.uiOutOfMemSimEnabledFlag,
-		gv_FlmSysData.uiOutOfMemSimEnabledFlag,
-		(bHighlight = !bHighlight));
-
-
-
-	// memSimRandomGen
-	printAddress( (void *)&gv_FlmSysData.memSimRandomGen, szAddress);
-	printHTMLString(
-		"memSimRandomGen",
-		"f_randomGenerator",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.memSimRandomGen,
-		(char *)szAddress,
-		(bHighlight = !bHighlight));
-
-
-
-	// uiSimOutOfMemFailTotal
-	printHTMLUint(
-		"uiSimOutOfMemFailTotal",
-		"FLMUINT",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.uiSimOutOfMemFailTotal,
-		gv_FlmSysData.uiSimOutOfMemFailTotal,
-		(bHighlight = !bHighlight));
-
-
-
-	// uiSimOutOfMemFailSequence
-	printHTMLUint(
-		"uiSimOutOfMemFailSequence",
-		"FLMUINT",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.uiSimOutOfMemFailSequence,
-		gv_FlmSysData.uiSimOutOfMemFailSequence,
-		(bHighlight = !bHighlight));
-
-#endif //#ifdef DEBUG_SIM_OUT_OF_MEM
-#endif
-
-	// pThreadMgr
-	printAddress( (void *)gv_FlmSysData.pThreadMgr, szAddress);
-	printHTMLString(
-		"pThreadMgr",
-		"F_ThreadMgr *",
-		(void *)&gv_FlmSysData,
-		(void *)&gv_FlmSysData.pThreadMgr,
-		(char *)szAddress,
-		(bHighlight = !bHighlight));
-
 	printTableEnd();
 
 Exit:
@@ -919,6 +601,9 @@ Exit:
 	return;
 }
 
+/****************************************************************************
+Desc:
+*****************************************************************************/
 RCODE F_HttpConfigParmsPage::display(
 	FLMUINT			uiNumParams,
 	const char ** 	ppszParams)
@@ -1129,136 +814,5 @@ RCODE F_HttpConfigParmsPage::display(
 	fnEmit();
 
 
-	return( rc);
-}
-
-/****************************************************************************
-Desc:	This implements the display method of the F_FEventHdr class
-*****************************************************************************/
-RCODE F_EventHdrPage::display(
-	FLMUINT			uiNumParams,
-	const char ** 	ppszParams)
-{
-	RCODE			rc = FERR_OK;
-	FLMUINT		uiLoop = 0;
-	FEVENT_p		pCurrentEvent = NULL;
-
-	char			szAddress[20];
-	char			szOffset[8];
-
-	F_UNREFERENCED_PARM( uiNumParams);
-	F_UNREFERENCED_PARM( ppszParams);
-
-
-	printDocStart(	"EventHdrs", FALSE);
-	
-	for (uiLoop = 0; uiLoop < F_MAX_EVENT_CATEGORIES; uiLoop++)
-	{
-				
-
-		f_sprintf( (char *)szAddress, "EventHdrs[%lu]\n", uiLoop);
-		printTableStart( (char *)szAddress, 4);
-
-		printColumnHeading( "Byte Offset (hex)");
-		printColumnHeading( "Field Name");
-		printColumnHeading( "Field Type");
-		printColumnHeading( "Value");
-
-		printAddress( (void *)gv_FlmSysData.EventHdrs[uiLoop].pEventCBList, szAddress);
-		printOffset( &gv_FlmSysData.EventHdrs[uiLoop],
-						 &gv_FlmSysData.EventHdrs[uiLoop].pEventCBList,
-						 szOffset);
-		printTableRowStart();
-		fnPrintf( m_pHRequest, TD_s "<TD>pEventCBList</TD> <TD>FEVENT_p</TD>" TD_s,
-					 szOffset, szAddress);
-		printTableRowEnd();
-
-		printAddress( (void *)gv_FlmSysData.EventHdrs[uiLoop].hMutex, szAddress);
-		printOffset( &gv_FlmSysData.EventHdrs[uiLoop],
-						 &gv_FlmSysData.EventHdrs[uiLoop].hMutex,
-						 szOffset);
-		printTableRowStart( TRUE);
-		fnPrintf( m_pHRequest, TD_s "<TD>hMutex</TD> <TD>F_MUTEX</TD>" TD_s,
-					 szOffset, szAddress);
-		printTableRowEnd();
-		
-		printTableEnd();
-
-		f_mutexLock( gv_FlmSysData.EventHdrs[uiLoop].hMutex);
-		pCurrentEvent = gv_FlmSysData.EventHdrs[uiLoop].pEventCBList;
-		while (pCurrentEvent)
-		{
-			displayEvent( pCurrentEvent);
-			pCurrentEvent = pCurrentEvent->pNext;
-		} // end of while loop
-		f_mutexUnlock( gv_FlmSysData.EventHdrs[uiLoop].hMutex);
-		fnPrintf( m_pHRequest, "<BR>\n");
-		
-	}  // end of for loop
-		
-		
-	fnPrintf( m_pHRequest, " </BODY> </HTML>\n");
-	fnEmit();
-	return( rc);
-}
-
-
-/****************************************************************************
-Desc:	Displays a single FEVENT struct.  Assumes that the event mutex has
-		already been locked!
-*****************************************************************************/
-RCODE F_EventHdrPage::displayEvent(
-	FEVENT_p			pCurrentEvent)
-{
-	RCODE			rc = FERR_OK;
-	char			szOffset[8];
-	char			szAddress[20];
-	char			szTitle[30];
-	
-	printAddress( (void *)pCurrentEvent, szAddress);
-	f_sprintf( (char *)szTitle, "FEVENT  %s", szAddress);
-	printTableStart( (char *)szTitle, 4);
-
-	printColumnHeading( "Byte Offset (hex)");
-	printColumnHeading( "Field Name");
-	printColumnHeading( "Field Type");
-	printColumnHeading( "Value");
-
-	printOffset( pCurrentEvent, &pCurrentEvent->eCategory, szOffset);
-	printTableRowStart();
-	fnPrintf( m_pHRequest, TD_s "<TD>eCategory</TD> <TD>FEventCategory</TD>" TD_lu,
-				 szOffset, pCurrentEvent->eCategory);
-	printTableRowEnd();
-
-	printAddress( *((void **)&pCurrentEvent->fnEventCB), szAddress);
-	printOffset( pCurrentEvent, &pCurrentEvent->fnEventCB, szOffset);
-	printTableRowStart( TRUE);
-	fnPrintf( m_pHRequest, TD_s "<TD>fnEventCB</TD> <TD>FEVENT_CB</TD>" TD_s,
-				 szOffset, szAddress);
-	printTableRowEnd();
-
-	printAddress( (void *)pCurrentEvent->pvAppData, szAddress);
-	printOffset( pCurrentEvent, &pCurrentEvent->pvAppData, szOffset);
-	printTableRowStart();
-	fnPrintf( m_pHRequest, TD_s "<TD>pvAppData</TD> <TD>void *</TD>" TD_s,
-				 szOffset, szAddress);
-	printTableRowEnd();
-
-	printAddress( (void *)pCurrentEvent->pNext, szAddress);
-	printOffset( pCurrentEvent, &pCurrentEvent->pNext, szOffset);
-	printTableRowStart( TRUE);
-	fnPrintf( m_pHRequest, TD_s "<TD>pNext</TD> <TD>FEVENT_p</TD>" TD_s,
-				 szOffset, szAddress);
-	printTableRowEnd();
-
-	printAddress( (void *)pCurrentEvent->pPrev, szAddress);
-	printOffset( pCurrentEvent, &pCurrentEvent->pPrev, szOffset);
-	printTableRowStart();
-	fnPrintf( m_pHRequest, TD_s "<TD>pPrev</TD> <TD>FEVENT_p</TD>" TD_s,
-				 szOffset, szAddress);
-	printTableRowEnd();
-
-	printTableEnd();
-
 	return( rc);
 }
