@@ -24,7 +24,7 @@
 
 #include "flaimsys.h"
 
-#define Q_FIELD_COLOR		FLM_PURPLE
+#define Q_FIELD_COLOR		FLM_MAGENTA
 #define Q_LABEL_COLOR		FLM_BLACK
 #define Q_VALUE_COLOR		FLM_GREEN
 #define Q_PARAM_COLOR		FLM_BLUE
@@ -34,8 +34,8 @@
 #define Q_DOT_COLOR			FLM_BLACK
 
 FSTATIC FLMBOOL findSubQuery(
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery);
+	CURSOR *		pCursor,
+	SUBQUERY *	pSubQuery);
 
 /****************************************************************************
 Desc: Class for formatting a query into HTML
@@ -49,14 +49,14 @@ public:
 	void formatQuery(
 		HRequest *	pHRequest,
 		F_WebPage *	pWebPage,
-		CURSOR_p		pCursor,
+		CURSOR *		pCursor,
 		FLMBOOL		bSingleLineOnly,
 		FLMUINT		uiMaxChars);
 
 	void outputSubqueryStats(
 		HRequest *	pHRequest,
 		F_WebPage *	pWebPage,
-		SUBQUERY_p	pSubQuery);
+		SUBQUERY *	pSubQuery);
 
 private:
 
@@ -64,12 +64,12 @@ private:
 		const char *	pszStr);
 
 	void changeColor(
-		FlmColorType	eColor,
+		eColorType		eColor,
 		FLMBOOL			bForceColor = FALSE);
 
 	void appendString(
 		const char *	pszStr,
-		FlmColorType	eColor = FLM_CURRENT_COLOR,
+		eColorType		eColor = FLM_CURRENT_COLOR,
 		FLMBOOL			bForceColor = FALSE);
 
 	void newline( void);
@@ -99,12 +99,12 @@ private:
 	void outputBinary(
 		FLMBYTE *		pucBuf,
 		FLMUINT			uiBufLen,
-		FlmColorType	eValueColor = Q_VALUE_COLOR);
+		eColorType		eValueColor = Q_VALUE_COLOR);
 
 	void outputText(
 		FLMBYTE *		pucBuf,
 		FLMUINT			uiBufLen,
-		FlmColorType	eColor = Q_VALUE_COLOR);
+		eColorType		eColor = Q_VALUE_COLOR);
 
 	void outputPredicate(
 		FLMUINT			uiIndent,
@@ -113,47 +113,47 @@ private:
 	void outputSubQuery(
 		FLMUINT			uiIndent,
 		QTYPES			eParentOp,
-		CURSOR_p			pReferenceCursor,
+		CURSOR *			pReferenceCursor,
 		SUBQUERY *		pSubQuery);
 
 	void outputQuery(
 		FLMUINT			uiIndent,
-		CURSOR_p			pReferenceCursor,
-		CURSOR_p			pCursor);
+		CURSOR *			pReferenceCursor,
+		CURSOR *			pCursor);
 
 	void outputLabel(
 		const char *	pszLabel,
-		FlmColorType	eLabelColor = Q_LABEL_COLOR);
+		eColorType		eLabelColor = Q_LABEL_COLOR);
 
 	void outputStringRow(
 		const char *	pszLabel,
 		const char *	pszValue,
-		FlmColorType	eLabelColor = Q_LABEL_COLOR,
-		FlmColorType	eValueColor = Q_VALUE_COLOR);
+		eColorType		eLabelColor = Q_LABEL_COLOR,
+		eColorType		eValueColor = Q_VALUE_COLOR);
 
 	void outputYesNoRow(
 		const char *	pszLabel,
 		FLMBOOL			bYesNo,
-		FlmColorType	eLabelColor = Q_LABEL_COLOR,
-		FlmColorType	eYesColor = Q_YES_COLOR,
-		FlmColorType	eNoColor = Q_NO_COLOR);
+		eColorType		eLabelColor = Q_LABEL_COLOR,
+		eColorType		eYesColor = Q_YES_COLOR,
+		eColorType		eNoColor = Q_NO_COLOR);
 
 	void outputUINTRow(
 		const char *	pszLabel,
 		FLMUINT			uiValue,
-		FlmColorType	eLabelColor = Q_LABEL_COLOR,
-		FlmColorType	eValueColor = Q_VALUE_COLOR);
+		eColorType		eLabelColor = Q_LABEL_COLOR,
+		eColorType		eValueColor = Q_VALUE_COLOR);
 
 	void outputBinaryRow(
 		const char *	pszLabel,
 		FLMBYTE *		pucValue,
 		FLMUINT			uiValueLen,
-		FlmColorType	eLabelColor,
-		FlmColorType	eValueColor);
+		eColorType		eLabelColor,
+		eColorType		eValueColor);
 
 	HRequest *		m_pHRequest;
 	F_WebPage *		m_pWebPage;
-	FlmColorType	m_eCurrColor;
+	eColorType		m_eCurrColor;
 	FLMBOOL			m_bSingleLineOnly;
 	FLMUINT			m_uiMaxChars;
 	FLMUINT			m_uiVisibleChars;
@@ -209,12 +209,12 @@ RCODE F_QueriesPage::display(
 	while (pQueryHdr)
 	{
 		char			szAddress [20];
-		CURSOR_p		pCursor;
-		SUBQUERY_p	pSubQuery;
+		CURSOR *		pCursor;
+		SUBQUERY *	pSubQuery;
 		FLMUINT		uiRecCount;
 
 		hCursor = pQueryHdr->hCursor;
-		pCursor = (CURSOR_p)hCursor;
+		pCursor = (CURSOR *)hCursor;
 
 		// Setup a hyperlink for the query.
 
@@ -337,7 +337,7 @@ void F_QueryFormatter::outputStr(
 Desc: Output a new color code, but only if the color has changed.
 ****************************************************************************/
 void F_QueryFormatter::changeColor(
-	FlmColorType	eColor,
+	eColorType		eColor,
 	FLMBOOL			bForceColor)
 {
 	const char *	pszColor;
@@ -384,7 +384,7 @@ void F_QueryFormatter::changeColor(
 			case FLM_RED:
 				pszColor = "<font color=\"Red\">";
 				break;
-			case FLM_PURPLE:
+			case FLM_MAGENTA:
 				pszColor = "<font color=\"Purple\">";
 				break;
 			case FLM_BROWN:
@@ -414,7 +414,7 @@ void F_QueryFormatter::changeColor(
 				//VISIT: Redo this one
 				pszColor = "<font color=\"Red\">";
 				break;
-			case FLM_LIGHTPURPLE:
+			case FLM_LIGHTMAGENTA:
 				//VISIT: Redo this one
 				pszColor = "<font color=\"Fuchsia\">";
 				break;
@@ -444,7 +444,7 @@ Desc: Append a string to the output buffer.
 ****************************************************************************/
 void F_QueryFormatter::appendString(
 	const char *	pszStr,
-	FlmColorType	eColor,
+	eColorType		eColor,
 	FLMBOOL			bForceColor)
 {
 	char		szTmpBuf [80];
@@ -678,7 +678,7 @@ Desc:	This routine outputs a buffer of binary bytes as ASCII hex.
 void F_QueryFormatter::outputBinary(
 	FLMBYTE *		pucBuf,
 	FLMUINT			uiBufLen,
-	FlmColorType	eValueColor)
+	eColorType		eValueColor)
 {
 	FLMUINT			uiLoop;
 	FLMUINT			uiOffset;
@@ -795,8 +795,7 @@ Desc:	This routine outputs text data.
 void F_QueryFormatter::outputText(
 	FLMBYTE *		pucBuf,
 	FLMUINT			uiBufLen,
-	FlmColorType	eColor
-	)
+	eColorType		eColor)
 {
 	FLMUINT			uiLoop;
 	FLMUINT			uiOffset;
@@ -822,7 +821,7 @@ void F_QueryFormatter::outputText(
 		}
 
 		ucChar = *pucBuf;
-		uiObjType = GedTextObjType( ucChar);
+		uiObjType = flmTextObjType( ucChar);
 		switch (uiObjType)
 		{
 			case ASCII_CHAR_CODE:  			// 0nnnnnnn
@@ -924,7 +923,7 @@ void F_QueryFormatter::outputPredicate(
 
 	for (;;)
 	{
-		FlmColorType	eSaveCurrColor;
+		eColorType	eSaveCurrColor;
 
 		eCurrentOp = GET_QNODE_TYPE( pQNode);
 		if (IS_OP( eCurrentOp))
@@ -950,11 +949,19 @@ void F_QueryFormatter::outputPredicate(
 					break;
 				case FLM_REC_PTR_VAL:
 				case FLM_UINT32_VAL:
-					f_sprintf( szBuf, "%u", (unsigned)pQNode->pQAtom->val.uiVal);
+					f_sprintf( szBuf, "%u", (unsigned)pQNode->pQAtom->val.ui32Val);
+					appendString( szBuf, Q_VALUE_COLOR);
+					break;
+				case FLM_UINT64_VAL:
+					f_sprintf( szBuf, "%I64u", pQNode->pQAtom->val.ui64Val);
 					appendString( szBuf, Q_VALUE_COLOR);
 					break;
 				case FLM_INT32_VAL:
-					f_sprintf( szBuf, "%d", (int)pQNode->pQAtom->val.iVal);
+					f_sprintf( szBuf, "%d", (int)pQNode->pQAtom->val.i32Val);
+					appendString( szBuf, Q_VALUE_COLOR);
+					break;
+				case FLM_INT64_VAL:
+					f_sprintf( szBuf, "%I64d", pQNode->pQAtom->val.i64Val);
 					appendString( szBuf, Q_VALUE_COLOR);
 					break;
 				case FLM_BINARY_VAL:
@@ -1046,12 +1053,12 @@ Desc:	This routine outputs a subquery.
 void F_QueryFormatter::outputSubQuery(
 	FLMUINT			uiIndent,
 	QTYPES			eParentOp,
-	CURSOR_p			pReferenceCursor,
+	CURSOR *			pReferenceCursor,
 	SUBQUERY *		pSubQuery
 	)
 {
 	char *		pszURL = NULL;
-	FQNODE_p		pQNode;
+	FQNODE *		pQNode;
 	QTYPES		eCurrentOp;
 	QTYPES		eTmpParentOp;
 	FLMBOOL		bIndentOptInfo = TRUE;
@@ -1140,7 +1147,7 @@ void F_QueryFormatter::outputSubQuery(
 					newline();
 				}
 				uiIndent += 2;
-				outputQuery( uiIndent, pReferenceCursor, (CURSOR_p)hCursor);
+				outputQuery( uiIndent, pReferenceCursor, (CURSOR *)hCursor);
 				uiIndent -= 2;
 				if (!m_bSingleLineOnly)
 				{
@@ -1255,7 +1262,7 @@ Desc:	This routine formats the query criteria for a cursor and optionally
 void F_QueryFormatter::formatQuery(
 	HRequest *	pHRequest,
 	F_WebPage *	pWebPage,
-	CURSOR_p		pCursor,
+	CURSOR *		pCursor,
 	FLMBOOL		bSingleLineOnly,
 	FLMUINT		uiMaxChars
 	)
@@ -1276,8 +1283,8 @@ Desc:	This routine formats the query criteria for a cursor and optionally
 ****************************************************************************/
 void F_QueryFormatter::outputQuery(
 	FLMUINT			uiIndent,
-	CURSOR_p			pReferenceCursor,
-	CURSOR_p			pCursor
+	CURSOR *			pReferenceCursor,
+	CURSOR *			pCursor
 	)
 {
 	SUBQUERY *		pSubQuery;
@@ -1387,7 +1394,7 @@ RCODE F_QueryPage::display(
 	{
 		// Output query
 
-		qf.formatQuery( m_pHRequest, this, (CURSOR_p)hCursor, FALSE, 0);
+		qf.formatQuery( m_pHRequest, this, (CURSOR *)hCursor, FALSE, 0);
 	}
 	else
 	{
@@ -1417,11 +1424,11 @@ Exit:
 Desc:	Find a sub-query within a cursor.
 ****************************************************************************/
 FSTATIC FLMBOOL findSubQuery(
-	CURSOR_p		pCursor,
-	SUBQUERY_p	pSubQuery
+	CURSOR *		pCursor,
+	SUBQUERY *	pSubQuery
 	)
 {
-	SUBQUERY_p	pTmpSubQuery;
+	SUBQUERY *	pTmpSubQuery;
 	FLMBOOL		bFound = FALSE;
 	HFCURSOR		hTmpCursor;
 	FLMUINT		uiLoop;
@@ -1446,7 +1453,7 @@ FSTATIC FLMBOOL findSubQuery(
 		if ((hTmpCursor = pCursor->QTInfo.ppPredicates [uiLoop]->getCursor()) !=
 						HFCURSOR_NULL)
 		{
-			if (findSubQuery( (CURSOR_p)hTmpCursor, pSubQuery))
+			if (findSubQuery( (CURSOR *)hTmpCursor, pSubQuery))
 			{
 				bFound = TRUE;
 				goto Exit;
@@ -1470,7 +1477,7 @@ RCODE F_QueryStatsPage::display(
 	RCODE					rc = FERR_OK;
 	QUERY_HDR *			pQueryHdr;
 	HFCURSOR				hCursor;
-	SUBQUERY_p			pSubQuery;
+	SUBQUERY *			pSubQuery;
 	char					szPtr [100];
 	F_QueryFormatter	qf;
 	FLMBOOL				bMutexLocked = FALSE;
@@ -1493,7 +1500,7 @@ RCODE F_QueryStatsPage::display(
 	{
 		goto Exit;
 	}
-	pSubQuery = (SUBQUERY_p)f_atoud( szPtr);
+	pSubQuery = (SUBQUERY *)f_atoud( szPtr);
 
 	// Lock the mutex on the queries
 
@@ -1513,7 +1520,7 @@ RCODE F_QueryStatsPage::display(
 
 		// Make sure we can find the sub-query.
 
-		if (!findSubQuery( (CURSOR_p)hCursor, pSubQuery))
+		if (!findSubQuery( (CURSOR *)hCursor, pSubQuery))
 		{
 			fnPrintf( m_pHRequest,
 				"<center>SubQuery is no longer in the query!</center>\n");
@@ -1555,7 +1562,7 @@ Desc:	This routine outputs a label in its own column.
 ****************************************************************************/
 void F_QueryFormatter::outputLabel(
 	const char *	pszLabel,
-	FlmColorType	eLabelColor)
+	eColorType		eLabelColor)
 {
 	// Label goes in a column by itself
 
@@ -1577,8 +1584,8 @@ Desc:	This routine outputs a row that has a label in column one and a
 void F_QueryFormatter::outputStringRow(
 	const char *	pszLabel,
 	const char *	pszValue,
-	FlmColorType	eLabelColor,
-	FlmColorType	eValueColor)
+	eColorType		eLabelColor,
+	eColorType		eValueColor)
 {
 	// Start a new row in the table
 
@@ -1615,9 +1622,9 @@ Desc:	This routine outputs a row that has a label in column one and a
 void F_QueryFormatter::outputYesNoRow(
 	const char *	pszLabel,
 	FLMBOOL			bYesNo,
-	FlmColorType	eLabelColor,
-	FlmColorType	eYesColor,
-	FlmColorType	eNoColor)
+	eColorType		eLabelColor,
+	eColorType		eYesColor,
+	eColorType		eNoColor)
 {
 	// Start a new row in the table
 
@@ -1654,8 +1661,8 @@ Desc:	This routine outputs a row that has a label in column one and a
 void F_QueryFormatter::outputUINTRow(
 	const char *	pszLabel,
 	FLMUINT			uiValue,
-	FlmColorType	eLabelColor,
-	FlmColorType	eValueColor)
+	eColorType		eLabelColor,
+	eColorType		eValueColor)
 {
 	char	szTmp [20];
 
@@ -1689,8 +1696,8 @@ void F_QueryFormatter::outputBinaryRow(
 	const char *			pszLabel,
 	FLMBYTE *		pucValue,
 	FLMUINT			uiValueLen,
-	FlmColorType	eLabelColor,
-	FlmColorType	eValueColor)
+	eColorType		eLabelColor,
+	eColorType		eValueColor)
 {
 	// Start a new row in the table
 
@@ -1723,7 +1730,7 @@ Desc:	This routine formats the sub-query statistics.
 void F_QueryFormatter::outputSubqueryStats(
 	HRequest *		pHRequest,
 	F_WebPage *		pWebPage,
-	SUBQUERY_p		pSubQuery
+	SUBQUERY *		pSubQuery
 	)
 {
 	FLMBYTE *	pucFromKey = NULL;
