@@ -459,7 +459,7 @@ RCODE F_RCachePage::display(
 	RCACHE *				pOlderRCache;
 	RCACHE *				pNewerRCache;
 	char					szFile[GENERIC_SIZE];
-	FFILE_p				pFile;
+	FFILE *				pFile;
 	char					szFrom[GENERIC_SIZE];
 	char					szBucket[GENERIC_SIZE];
 	FLMUINT				uiBucket;
@@ -563,7 +563,7 @@ RCODE F_RCachePage::display(
 		{
 			goto Exit;
 		}
-		pFile = (FFILE_p)f_atoud( szFile);
+		pFile = (FFILE *)f_atoud( szFile);
 
 		// Version tag
 		if (RC_BAD(rc = ExtractParameter( uiNumParams, 
@@ -640,15 +640,8 @@ RCODE F_RCachePage::display(
 	f_mutexLock( gv_FlmSysData.RCacheMgr.hMutex);
 	bRCLocked = TRUE;
 
-	flmRcaFindRec(uiContainer, 
-					  uiDrn, 
-					  pFile, 
-					  uiVersion, 
-					  TRUE, 
-					  0, 
-					  &pRCache, 
-					  &pNewerRCache, 
-					  &pOlderRCache);
+	flmRcaFindRec( pFile, F_SEM_NULL, uiContainer, uiDrn, uiVersion, TRUE, 
+					  0, &pRCache, &pNewerRCache, &pOlderRCache);
 
 	// We want to hold the RCache and pFile in memory while we render this page.
 	if (pRCache)
@@ -799,7 +792,7 @@ void F_RCachePage::write_data(
 		
 		printHTMLLink(
 			"pFile",
-			"FFILE_p",
+			"FFILE *",
 			(void *)pRCache,
 			(void *)&pRCache->pFile,
 			(void *)pRCache->pFile,
@@ -1064,7 +1057,7 @@ void F_RCachePage::write_data(
 		
 		printHTMLLink(
 			"pNotifyList",
-			"FNOTIFY_p",
+			"FNOTIFY *",
 			(void *)pRCache,
 			(void *)&pRCache->pNotifyList,
 			(void *)pRCache->pNotifyList,
@@ -1108,7 +1101,7 @@ RCODE F_RecordPage::display(
 	RCACHE *				pOlderRCache;
 	RCACHE *				pNewerRCache;
 	char					szFile[GENERIC_SIZE];
-	FFILE_p				pFile;
+	FFILE *				pFile;
 	FlmRecord *			pRecord = NULL;
 	FLMBOOL				bpFileInc = FALSE;
 	FLMBYTE *			pszTemp = NULL;
@@ -1150,7 +1143,7 @@ RCODE F_RecordPage::display(
 	{
 		goto Exit;
 	}
-	pFile = (FFILE_p)f_atoud( szFile);
+	pFile = (FFILE *)f_atoud( szFile);
 
 
 
@@ -1224,15 +1217,8 @@ RCODE F_RecordPage::display(
 	f_mutexLock( gv_FlmSysData.hShareMutex);
 	f_mutexLock( gv_FlmSysData.RCacheMgr.hMutex);
 
-	flmRcaFindRec( uiContainer, 
-					   uiDrn, 
-					   pFile, 
-					   uiVersion, 
-					   TRUE, 
-					   0, 
-					   &pRCache, 
-					   &pNewerRCache, 
-					   &pOlderRCache);
+	flmRcaFindRec( pFile, F_SEM_NULL, uiContainer, uiDrn, uiVersion, 
+					   TRUE, 0, &pRCache, &pNewerRCache, &pOlderRCache);
 
 	if (pRCache)
 	{
