@@ -24,131 +24,129 @@
 
 #include "flaimsys.h"
 
-typedef struct CMP_KEY_ELM * CMP_KEY_ELM_p;
-
 typedef struct CMP_KEY_ELM
 {
 	const FLMBYTE *	pValue;
 	FLMUINT				uiValueLen;
 	FLMUINT				uiType;
 	FLMUINT				uiTagNum;
-	CMP_KEY_ELM_p		pParent;
+	CMP_KEY_ELM *		pParent;
 	FLMBOOL				bFirstSubstring;
 	FLMBOOL				bSubstringComponent;
 } CMP_KEY_ELM;
 
 FSTATIC RCODE flmKeyAdd(
-	FDB_p				pDb,
-	IXD_p				pIxd,
-	FlmRecord *		pRecord,
-	FLMUINT			uiContainerNum,
-	POOL *			pPool,
-	FLMBOOL			bRemoveDups,
-	REC_KEY **		ppKeyList);
+	FDB *					pDb,
+	IXD *					pIxd,
+	FlmRecord *			pRecord,
+	FLMUINT				uiContainerNum,
+	F_Pool *				pPool,
+	FLMBOOL				bRemoveDups,
+	REC_KEY **	 		ppKeyList);
 
 FSTATIC RCODE flmGetFieldKeys(
-	FDB_p				pDb,
-	IXD_p				pIxd,		
-	FlmRecord *		pRecord,
-	FLMUINT			uiContainerNum,
-	void **			ppPathFlds,
-	FLMUINT			uiLeafFieldLevel,
-	void *			pvField,
-	FLMBOOL			bRemoveDups,
-	POOL *			pPool,
-	REC_KEY **		ppKeyList,
-	FLMBOOL  *		bHasCmpKeys);
+	FDB *					pDb,
+	IXD *					pIxd,
+	FlmRecord *			pRecord,
+	FLMUINT				uiContainerNum,
+	void **		 		ppPathFlds,
+	FLMUINT				uiLeafFieldLevel,
+	void *				pvField,
+	FLMBOOL				bRemoveDups,
+	F_Pool *				pPool,
+	REC_KEY **	 		ppKeyList,
+	FLMBOOL *			bHasCmpKeys);
 
 FSTATIC RCODE flmBuildCompoundKey(
-	FDB_p				pDb,
-	IXD_p				pIxd,		
-	CMP_KEY_ELM_p	pCmpKeyElm,
-	FLMBOOL			bRemoveDups,
-	POOL *			pPool,
-	FLMUINT			uiContainerNum,
-	REC_KEY **		ppKeyList);
+	FDB *					pDb,
+	IXD *					pIxd,
+	CMP_KEY_ELM *		pCmpKeyElm,
+	FLMBOOL				bRemoveDups,
+	F_Pool *				pPool,
+	FLMUINT				uiContainerNum,
+	REC_KEY **		 	ppKeyList);
 
 FSTATIC RCODE flmGetCmpKeyElement(
-	FDB_p				pDb,
-	IXD_p				pIxd,		
-	IFD_p				pIfd,
-	FLMUINT			uiCdlEntry,
-	FLMUINT			uiCompoundPos,
-	CMP_KEY_ELM_p	pParent,
-	FLMBOOL			bRemoveDups,
-	POOL *			pPool,
-	REC_KEY **		ppKeyList,
-	FlmRecord *		pRecord,
-	FLMUINT			uiContainerNum,
-	FLD_CONTEXT *	pFldContext);
+	FDB *					pDb,
+	IXD *					pIxd,
+	IFD *					pIfd,
+	FLMUINT				uiCdlEntry,
+	FLMUINT				uiCompoundPos,
+	CMP_KEY_ELM *		pParent,
+	FLMBOOL				bRemoveDups,
+	F_Pool *				pPool,
+	REC_KEY **		 	ppKeyList,
+	FlmRecord *			pRecord,
+	FLMUINT				uiContainerNum,
+	FLD_CONTEXT *		pFldContext);
 
 FSTATIC RCODE flmGetCompoundKeys(
-	FDB_p				pDb,
-	IXD_p				pIxd,		
-	FLMBOOL			bRemoveDups,
-	POOL *			pPool,
-	FlmRecord *		pRecord,
-	FLMUINT			uiContainerNum,
-	REC_KEY **		ppKeyList);
+	FDB *					pDb,
+	IXD *					pIxd,
+	FLMBOOL				bRemoveDups,
+	F_Pool *				pPool,
+	FlmRecord *			pRecord,
+	FLMUINT				uiContainerNum,
+	REC_KEY **	 		ppKeyList);
 
-
-/***************************************************************************
-Desc:	This routine adds a key to a key list.
-*****************************************************************************/
+/****************************************************************************
+Desc: This routine adds a key to a key list.
+****************************************************************************/
 FSTATIC RCODE flmKeyAdd(
-	FDB_p				pDb,
-	IXD_p				pIxd,
+	FDB *				pDb,
+	IXD *				pIxd,
 	FlmRecord *		pRecord,
 	FLMUINT			uiContainerNum,
-	POOL *			pPool,
+	F_Pool *			pPool,
 	FLMBOOL			bRemoveDups,
 	REC_KEY **		ppKeyList)
 {
 	RCODE				rc = FERR_OK;
 	REC_KEY *		pTempRecKey;
-	FLMBYTE			Key1Buf [MAX_KEY_SIZ];
+	FLMBYTE			Key1Buf[MAX_KEY_SIZ];
 	FLMUINT			uiKey1Len;
-	FLMBYTE			Key2Buf [MAX_KEY_SIZ];
+	FLMBYTE			Key2Buf[MAX_KEY_SIZ];
 	FLMUINT			uiKey2Len;
 
-	/* First see if the key is already in the list. */
+	// First see if the key is already in the list.
 
 	pTempRecKey = *ppKeyList;
-	if( pTempRecKey && bRemoveDups)
+	if (pTempRecKey && bRemoveDups)
 	{
-		if( RC_BAD( rc = KYTreeToKey( pDb, pIxd, pRecord, uiContainerNum,
-								Key1Buf, &uiKey1Len, 0)))
+		if (RC_BAD( rc = KYTreeToKey( pDb, pIxd, pRecord, uiContainerNum, 
+			Key1Buf, &uiKey1Len, 0)))
+		{
 			goto Exit;
+		}
 
 		while (pTempRecKey != NULL)
 		{
 
-			/* Build the collated keys for each key tree in *ppKeyList */
+			// Build the collated keys for each key tree in *ppKeyList
 
-			if( RC_BAD( rc = KYTreeToKey( pDb, pIxd, pTempRecKey->pKey,
-										uiContainerNum,
-			  							Key2Buf, &uiKey2Len, 0)))
+			if (RC_BAD( rc = KYTreeToKey( pDb, pIxd, pTempRecKey->pKey,
+						  uiContainerNum, Key2Buf, &uiKey2Len, 0)))
+			{
 				goto Exit;
+			}
 
-			/*
-			If the key was found, return success - don't add to list.
-			Also, free up the memory pool back to where the key
-			started.
-			*/
+			// If the key was found, return success - don't add to list.
+			// Also, free up the memory pool back to where the key started.
 
 			if (KYKeyCompare( Key1Buf, uiKey1Len, Key2Buf, uiKey2Len) == BT_EQ_KEY)
 			{
+
 				// Should return FERR_OK.
-				goto Exit; 
+
+				goto Exit;
 			}
+
 			pTempRecKey = pTempRecKey->pNextKey;
 		}
 	}
-
-	if ((pTempRecKey = (REC_KEY *)GedPoolAlloc( pPool,
-		sizeof(REC_KEY))) == NULL)
+	
+	if( RC_BAD( rc = pPool->poolAlloc( sizeof( REC_KEY), (void **)&pTempRecKey)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
 
@@ -156,29 +154,31 @@ FSTATIC RCODE flmKeyAdd(
 	pRecord->AddRef();
 	pTempRecKey->pNextKey = *ppKeyList;
 	*ppKeyList = pTempRecKey;
+	
 Exit:
-	return( rc);
+
+	return (rc);
 }
 
-/***************************************************************************
-Desc:	This routine gets all of the keys for a field and either saves them
+/****************************************************************************
+Desc: This routine gets all of the keys for a field and either saves them
 		as an element for a compound key, or saves them into the key list.
-*****************************************************************************/
+****************************************************************************/
 FSTATIC RCODE flmGetFieldKeys(
-	FDB_p					pDb,
-	IXD_p					pIxd,		
-	FlmRecord *			pRecord,
-	FLMUINT				uiContainerNum,
-	void **				ppPathFlds,
-	FLMUINT				uiLeafFieldLevel,
-	void *				pvField,
-	FLMBOOL				bRemoveDups,
-	POOL *				pPool,
-	REC_KEY **			ppKeyList,
-	FLMBOOL  *			pbHasCmpKeys)
+	FDB *				pDb,
+	IXD *				pIxd,
+	FlmRecord *		pRecord,
+	FLMUINT			uiContainerNum,
+	void **			ppPathFlds,
+	FLMUINT			uiLeafFieldLevel,
+	void *			pvField,
+	FLMBOOL			bRemoveDups,
+	F_Pool *			pPool,
+	REC_KEY **	 	ppKeyList,
+	FLMBOOL *		pbHasCmpKeys)
 {
 	RCODE					rc = FERR_OK;
-	IFD_p					pIfd;
+	IFD *					pIfd;
 	FlmRecord *			pFieldRecord = NULL;
 	void *				pvRootContext;
 	void *				pvValueField;
@@ -198,35 +198,33 @@ FSTATIC RCODE flmGetFieldKeys(
 	// See if the field is defined in this index.
 
 	pIfd = pIxd->pFirstIfd;
-	for (uiCounter = 0; uiCounter < pIxd->uiNumFlds; uiCounter++, pIfd++ )
+	for (uiCounter = 0; uiCounter < pIxd->uiNumFlds; uiCounter++, pIfd++)
 	{
 		if (pIfd->uiFldNum == uiTagNum)
 		{
 			if (flmCheckIfdPath( pIfd, pRecord, ppPathFlds, uiLeafFieldLevel,
-										pvField, &pvRootContext))
+									  pvField, &pvRootContext))
 			{
-				break;	// Found one that matches.
+				// Found one that matches.
+				
+				break;
 			}
 		}
 	}
 
-	/* If the field is not part of the index, return. */
+	// If the field is not part of the index, return.
 
-	if( uiCounter == pIxd->uiNumFlds)
-		goto Exit;		/* Should return FERR_OK. */
+	if (uiCounter == pIxd->uiNumFlds)
+	{
+		goto Exit;
+	}
 
-	/* At this point, we know the field is part of the index. */
+	// At this point, we know the field is part of the index.
 
-	pExportPtr  = pRecord->getDataPtr( pvField);
+	pExportPtr = pRecord->getDataPtr( pvField);
 	uiExportLen = pRecord->getDataLength( pvField);
 	uiFieldType = pRecord->getDataType( pvField);
 
-	/*
-	VISIT:
-	Scott thinks we should treat all keys like a compound key and get rid of the
-	flmKeyAdd() call above. 
-	*/
-	
 	if (pIfd->uiFlags & IFD_COMPOUND)
 	{
 		rc = KYCmpKeyAdd2Lst( pDb, pIxd, pIfd, pvField, pvRootContext);
@@ -234,7 +232,7 @@ FSTATIC RCODE flmGetFieldKeys(
 	}
 	else
 	{
-		if( (pFieldRecord = f_new FlmRecord) == NULL)
+		if ((pFieldRecord = f_new FlmRecord) == NULL)
 		{
 			rc = RC_SET( FERR_MEM);
 			goto Exit;
@@ -243,32 +241,35 @@ FSTATIC RCODE flmGetFieldKeys(
 		pFieldRecord->setContainerID( uiContainerNum);
 
 		// Build a record with just this field in it.
+
 		puiFieldPath = pIfd->pFieldPathPToC;
-		for( uiLevel = 0; *puiFieldPath; puiFieldPath++)
+		for (uiLevel = 0; *puiFieldPath; puiFieldPath++)
 		{
-			if( RC_BAD( rc = pFieldRecord->insertLast( uiLevel++, 
-					*puiFieldPath, FLM_CONTEXT_TYPE, &pvValueField)))
+			if (RC_BAD( rc = pFieldRecord->insertLast( uiLevel++, *puiFieldPath,
+						  FLM_CONTEXT_TYPE, &pvValueField)))
 			{
 				goto Exit;
 			}
 		}
-		
+
 		if (pIfd->uiFlags & IFD_CONTEXT)
 		{
-			/* Create the field and put it into the key list. */
 
-			rc = flmKeyAdd( pDb, pIxd, pFieldRecord, uiContainerNum,
-									pPool, bRemoveDups, ppKeyList);
+			// Create the field and put it into the key list.
+
+			rc = flmKeyAdd( pDb, pIxd, pFieldRecord, uiContainerNum, pPool,
+								bRemoveDups, ppKeyList);
 		}
-		else if ((pIfd->uiFlags & (IFD_EACHWORD|IFD_SUBSTRING)) && 
+		else if ((pIfd->uiFlags & (IFD_EACHWORD | IFD_SUBSTRING)) &&
 					(uiFieldType == FLM_TEXT_TYPE))
 		{
 			const FLMBYTE *	pText = pExportPtr;
 			FLMUINT				uiTextLen = uiExportLen;
 			FLMUINT				uiKeyLen;
 			FLMBOOL				bReturn;
-			FLMBOOL				bFirstSubstring = (pIfd->uiFlags & IFD_SUBSTRING)
-												? TRUE : FALSE;
+			FLMBOOL				bFirstSubstring = (pIfd->uiFlags & IFD_SUBSTRING) 
+																	? TRUE 
+																	: FALSE;
 
 			if (!pbyTmpBuf)
 			{
@@ -278,23 +279,24 @@ FSTATIC RCODE flmGetFieldKeys(
 				}
 			}
 
-			/* Get each word out of the key and save as a separate key. */
+			// Get each word out of the key and save as a separate key.
 
-			for( pText = pExportPtr;;)
+			for (pText = pExportPtr;;)
 			{
-				bReturn = (pIfd->uiFlags & IFD_EACHWORD)
-								? (FLMBOOL) KYEachWordParse( &pText, &uiTextLen,
-												pIfd->uiLimit,
-												pbyTmpBuf, &uiKeyLen)
-								: (FLMBOOL) KYSubstringParse( &pText, &uiTextLen,
-												pIfd->uiFlags, pIfd->uiLimit,
-												pbyTmpBuf, &uiKeyLen);
-				if( !bReturn)
+				bReturn = (pIfd->uiFlags & IFD_EACHWORD) 
+									? (FLMBOOL) KYEachWordParse( &pText, &uiTextLen, 
+											pIfd->uiLimit, pbyTmpBuf, &uiKeyLen) 
+									: (FLMBOOL) KYSubstringParse( &pText, &uiTextLen, 
+											pIfd->uiFlags, pIfd->uiLimit, pbyTmpBuf,
+											&uiKeyLen);
+				if (!bReturn)
+				{
 					break;
+				}
 
 				if (!pFieldRecord)
 				{
-					if( (pFieldRecord = f_new FlmRecord) == NULL)
+					if ((pFieldRecord = f_new FlmRecord) == NULL)
 					{
 						rc = RC_SET( FERR_MEM);
 						goto Exit;
@@ -303,66 +305,61 @@ FSTATIC RCODE flmGetFieldKeys(
 					pFieldRecord->setContainerID( uiContainerNum);
 					puiFieldPath = pIfd->pFieldPathPToC;
 
-					for( uiLevel = 0; *puiFieldPath; puiFieldPath++)
+					for (uiLevel = 0; *puiFieldPath; puiFieldPath++)
 					{
-						if (RC_BAD( rc = pFieldRecord->insertLast( uiLevel++, 
-								*puiFieldPath, FLM_CONTEXT_TYPE, &pvValueField)))
+						if (RC_BAD( rc = pFieldRecord->insertLast( uiLevel++,
+									  *puiFieldPath, FLM_CONTEXT_TYPE, &pvValueField)))
 						{
 							goto Exit;
 						}
 					}
 				}
 
-				if( RC_BAD( rc = pFieldRecord->allocStorageSpace( pvValueField,
-																				 FLM_TEXT_TYPE,
-																				 uiKeyLen,
-																				 0, 0, 0,
-																				 &pImportDataPtr,
-																				 NULL)))
+				if (RC_BAD( rc = pFieldRecord->allocStorageSpace( pvValueField,
+						FLM_TEXT_TYPE, uiKeyLen, 0, 0, 0, &pImportDataPtr, NULL)))
 				{
 					goto Exit;
 				}
+
 				f_memcpy( pImportDataPtr, pbyTmpBuf, uiKeyLen);
 
-				if( (pIfd->uiFlags & IFD_SUBSTRING) && !bFirstSubstring)
+				if ((pIfd->uiFlags & IFD_SUBSTRING) && !bFirstSubstring)
 				{
 					pFieldRecord->setLeftTruncated( pvValueField, TRUE);
 				}
-				if( RC_BAD( rc = flmKeyAdd( pDb, pIxd, pFieldRecord,
-					uiContainerNum, pPool, bRemoveDups, ppKeyList)))
+
+				if (RC_BAD( rc = flmKeyAdd( pDb, pIxd, pFieldRecord, uiContainerNum,
+							  pPool, bRemoveDups, ppKeyList)))
 				{
 					goto Exit;
 				}
+
 				pFieldRecord->Release();
 				pFieldRecord = NULL;
 
-				if( (pIfd->uiFlags & IFD_SUBSTRING) && 
-					  uiTextLen == 1 &&
-					  !(uiLanguage >= FIRST_DBCS_LANG && 
-					    uiLanguage <= LAST_DBCS_LANG))
+				if ((pIfd->uiFlags & IFD_SUBSTRING) &&
+					 uiTextLen == 1 && !(uiLanguage >= FLM_FIRST_DBCS_LANG && 
+							uiLanguage <= FLM_LAST_DBCS_LANG))
 				{
 					break;
 				}
+
 				bFirstSubstring = FALSE;
 			}
 		}
 		else
 		{
-			/* Oct98 - Accept zero length fields. */
-			/* Copy the field and put it into the key list. */
-
-			if( RC_BAD( rc = pFieldRecord->allocStorageSpace(
-								pvValueField,
-								pRecord->getDataType( pvField),
-								uiExportLen,
-								0, 0, 0, &pImportDataPtr, NULL)))
+			if (RC_BAD( rc = pFieldRecord->allocStorageSpace( pvValueField,
+						  pRecord->getDataType( pvField), uiExportLen, 0, 0, 0,
+						  &pImportDataPtr, NULL)))
 			{
 				goto Exit;
 			}
+
 			f_memcpy( pImportDataPtr, pExportPtr, uiExportLen);
 
-			if( RC_BAD( rc = flmKeyAdd( pDb, pIxd, pFieldRecord,
-					uiContainerNum, pPool, bRemoveDups, ppKeyList)))
+			if (RC_BAD( rc = flmKeyAdd( pDb, pIxd, pFieldRecord, uiContainerNum,
+						  pPool, bRemoveDups, ppKeyList)))
 			{
 				goto Exit;
 			}
@@ -380,18 +377,19 @@ Exit:
 	{
 		f_free( &pbyTmpBuf);
 	}
-	return( rc);
+
+	return (rc);
 }
 
-/***************************************************************************
+/****************************************************************************
 Desc:	This routine builds a compound key and saves it into the key list.
-*****************************************************************************/
+****************************************************************************/
 FSTATIC RCODE flmBuildCompoundKey(
-	FDB_p				pDb,
-	IXD_p				pIxd,		
-	CMP_KEY_ELM_p	pCmpKeyElm,
+	FDB *				pDb,
+	IXD *				pIxd,
+	CMP_KEY_ELM *	pCmpKeyElm,
 	FLMBOOL			bRemoveDups,
-	POOL *			pPool,
+	F_Pool *			pPool,
 	FLMUINT			uiContainerNum,
 	REC_KEY **		ppKeyList)
 {
@@ -410,7 +408,7 @@ FSTATIC RCODE flmBuildCompoundKey(
 
 			if (!pRecord)
 			{
-				if( (pRecord = f_new FlmRecord) == NULL)
+				if ((pRecord = f_new FlmRecord) == NULL)
 				{
 					rc = RC_SET( FERR_MEM);
 					goto Exit;
@@ -420,42 +418,42 @@ FSTATIC RCODE flmBuildCompoundKey(
 			}
 
 			// VISIT: Add full path of each key.
-			if( RC_BAD( rc = pRecord->insertLast( 0, 
-					pCmpKeyElm->uiTagNum, pCmpKeyElm->uiType, &pvValueField)))
-				goto Exit;
 
-			// VISIT: Don't know what type.
-
-			if( RC_BAD( rc = pRecord->allocStorageSpace( pvValueField,
-																	  pCmpKeyElm->uiType,
-																	  uiExportLen,
-																	  0, 0, 0,
-																	  &pImportDataPtr,
-																	  NULL)))
+			if (RC_BAD( rc = pRecord->insertLast( 0, pCmpKeyElm->uiTagNum,
+						  pCmpKeyElm->uiType, &pvValueField)))
 			{
 				goto Exit;
 			}
 
-			if( uiExportLen)
+			// VISIT: Don't know what type.
+
+			if (RC_BAD( rc = pRecord->allocStorageSpace( pvValueField,
+						  pCmpKeyElm->uiType, uiExportLen, 0, 0, 0, &pImportDataPtr,
+						  NULL)))
+			{
+				goto Exit;
+			}
+
+			if (uiExportLen)
 			{
 				f_memcpy( pImportDataPtr, pCmpKeyElm->pValue, uiExportLen);
 			}
 
-			if( pCmpKeyElm->bSubstringComponent &&
-				 !pCmpKeyElm->bFirstSubstring)
+			if (pCmpKeyElm->bSubstringComponent && !pCmpKeyElm->bFirstSubstring)
 			{
 				pRecord->setLeftTruncated( pvValueField, TRUE);
 			}
 		}
+
 		pCmpKeyElm = pCmpKeyElm->pParent;
 	}
 
-	/* Add the key to the key list. */
+	// Add the key to the key list.
 
-	if( pRecord)
+	if (pRecord)
 	{
-		if (RC_BAD( rc = flmKeyAdd( pDb, pIxd, pRecord, uiContainerNum,
-				pPool, bRemoveDups, ppKeyList)))
+		if (RC_BAD( rc = flmKeyAdd( pDb, pIxd, pRecord, uiContainerNum, pPool,
+					  bRemoveDups, ppKeyList)))
 		{
 			goto Exit;
 		}
@@ -468,43 +466,41 @@ Exit:
 		pRecord->Release();
 	}
 
-	return( rc);
+	return (rc);
 }
 
-/***************************************************************************
-Desc:	This routine gets an element of a compound key and links it to
-		the previous element in the compound key.
-Note: This routine recursively calls itself.		
-		The code is very similar to KYCmpKeyElmBld() in kycompnd.cpp.
-*****************************************************************************/
+/****************************************************************************
+Desc:	This routine gets an element of a compound key and links it to the
+		previous element in the compound key.
+****************************************************************************/
 FSTATIC RCODE flmGetCmpKeyElement(
-	FDB_p				pDb,
-	IXD_p				pIxd,		
-	IFD_p				pIfd,
+	FDB *				pDb,
+	IXD *				pIxd,
+	IFD *				pIfd,
 	FLMUINT			uiCdlEntry,
 	FLMUINT			uiCompoundPos,
-	CMP_KEY_ELM_p	pParent,
+	CMP_KEY_ELM *	pParent,
 	FLMBOOL			bRemoveDups,
-	POOL *			pPool,
+	F_Pool *			pPool,
 	REC_KEY **		ppKeyList,
 	FlmRecord *		pRecord,
 	FLMUINT			uiContainerNum,
 	FLD_CONTEXT *	pFldContext)
 {
 	RCODE				rc = FERR_OK;
-	CDL_p  *			ppCdlTbl = pDb->KrefCntrl.ppCdlTbl;
-	CDL_p				pCdl = ppCdlTbl [uiCdlEntry];
-	CMP_KEY_ELM		CmpKeyElm;
+	CDL **		 	ppCdlTbl = pDb->KrefCntrl.ppCdlTbl;
+	CDL *				pCdl = ppCdlTbl[uiCdlEntry];
+	CMP_KEY_ELM 	CmpKeyElm;
 	void *			pvField;
 	void *			pSaveParentAnchor;
 	FLMBYTE *		pbyTmpBuf = NULL;
-	IFD_p				pNextIfdPiece;
+	IFD *				pNextIfdPiece;
 	FLMUINT			uiNextCdlEntry;
-	FLMUINT			uiNextPiecePos;			// 0 if this is the last piece.
+	FLMUINT			uiNextPiecePos;
 	FLMUINT			uiLanguage = pIxd->uiLanguage;
 	FLMBOOL			bBuiltKeyPiece;
 
-	/* If there are no values, see if we are on the last IFD. */
+	// If there are no values, see if we are on the last IFD.
 
 	CmpKeyElm.pParent = pParent;
 	CmpKeyElm.pValue = NULL;
@@ -514,60 +510,62 @@ FSTATIC RCODE flmGetCmpKeyElement(
 	CmpKeyElm.bFirstSubstring = FALSE;
 	CmpKeyElm.bSubstringComponent = FALSE;
 
-	// New 05/06/96
 	// Determine the next IFD compound piece.
 
-	for( pNextIfdPiece = (IFD_p)NULL, 
-			uiNextCdlEntry = uiCdlEntry + 1,
-			uiNextPiecePos = 0
-		; ((pIfd+uiNextPiecePos)->uiFlags & IFD_LAST) == 0
-		; )
+	for (pNextIfdPiece = (IFD*) NULL, uiNextCdlEntry = uiCdlEntry +
+		  1, uiNextPiecePos = 0;
+	  ((pIfd + uiNextPiecePos)->uiFlags & IFD_LAST) == 0;)
 	{
-		if ((pIfd+uiNextPiecePos)->uiCompoundPos != 
-			 (pIfd+uiNextPiecePos+1)->uiCompoundPos)
+		if ((pIfd + uiNextPiecePos)->uiCompoundPos !=
+				 (pIfd + uiNextPiecePos + 1)->uiCompoundPos)
 		{
 			pNextIfdPiece = pIfd + uiNextPiecePos + 1;
 			uiNextCdlEntry = uiCdlEntry + uiNextPiecePos + 1;
 			break;
 		}
-		if( !pCdl)
+
+		if (!pCdl)
 		{
 			pIfd++;
-			pCdl = ppCdlTbl [++uiCdlEntry];
+			pCdl = ppCdlTbl[++uiCdlEntry];
 			uiNextCdlEntry = uiCdlEntry + 1;
 		}
 		else
+		{
 			uiNextPiecePos++;
+		}
 	}
 
 	pSaveParentAnchor = pFldContext->pParentAnchor;
-	bBuiltKeyPiece = FALSE;	
+	bBuiltKeyPiece = FALSE;
 
-	/* Loop through all of the values in this IFD. */
+	// Loop through all of the values in this IFD.
 
 	while (pCdl || !bBuiltKeyPiece)
 	{
-	
+
 		// Restore context values for each iteration.
+
 		pFldContext->pParentAnchor = pSaveParentAnchor;
 
-		/*
-		If there is a field to process, verify that its path is
-		relative to the previous non-null compound pieces.
-		*/
-		if( pCdl)
+		// If there is a field to process, verify that its path is relative
+		// to the previous non-null compound pieces.
+
+		if (pCdl)
 		{
 			pvField = pCdl->pField;
-			
+
 			// Validate the current and previous root contexts.
 
-			if( KYValidatePathRelation( pRecord, pCdl->pRootContext, pvField,
-										pFldContext, uiCompoundPos) == FERR_FAILURE)
+			if (KYValidatePathRelation( pRecord, pCdl->pRootContext, pvField,
+												pFldContext, uiCompoundPos) == FERR_FAILURE)
 			{
+
 				// This field didn't pass the test, get the next field.
+
 				goto Next_CDL_Node;
 			}
-			
+
 			CmpKeyElm.pValue = pRecord->getDataPtr( pvField);
 			CmpKeyElm.uiValueLen = pRecord->getDataLength( pvField);
 			CmpKeyElm.uiType = pRecord->getDataType( pvField);
@@ -579,8 +577,9 @@ FSTATIC RCODE flmGetCmpKeyElement(
 		{
 			pvField = NULL;
 		}
+
 		if (pRecord &&
-			 (pIfd->uiFlags & (IFD_EACHWORD|IFD_SUBSTRING)) && 
+			 (pIfd->uiFlags & (IFD_EACHWORD | IFD_SUBSTRING)) &&
 			 CmpKeyElm.uiType == FLM_TEXT_TYPE &&
 			 pRecord->getDataLength( pvField))
 		{
@@ -588,8 +587,9 @@ FSTATIC RCODE flmGetCmpKeyElement(
 			FLMUINT				uiTextLen = pRecord->getDataLength( pvField);
 			FLMUINT				uiKeyLen;
 			FLMBOOL				bReturn;
-			FLMBOOL				bFirstSubstring = (pIfd->uiFlags & IFD_SUBSTRING)
-										? TRUE : FALSE;
+			FLMBOOL				bFirstSubstring = (pIfd->uiFlags & IFD_SUBSTRING) 
+																		? TRUE 
+																		: FALSE;
 
 			if (!pbyTmpBuf)
 			{
@@ -598,43 +598,53 @@ FSTATIC RCODE flmGetCmpKeyElement(
 					goto Exit;
 				}
 			}
-			
-			for(;;)
+
+			for (;;)
 			{
-				bReturn = (pIfd->uiFlags & IFD_EACHWORD)
-								? (FLMBOOL) KYEachWordParse( &pText, &uiTextLen,
-												pIfd->uiLimit,
-												pbyTmpBuf, &uiKeyLen)
-								: (FLMBOOL) KYSubstringParse( &pText, &uiTextLen,
-												pIfd->uiFlags, pIfd->uiLimit,
-												pbyTmpBuf, &uiKeyLen);
-				if( !bReturn)
+				bReturn = (pIfd->uiFlags & IFD_EACHWORD) 
+										? (FLMBOOL) KYEachWordParse( &pText, &uiTextLen,
+												pIfd->uiLimit, pbyTmpBuf, &uiKeyLen) 
+										: (FLMBOOL) KYSubstringParse( &pText, &uiTextLen,
+												pIfd->uiFlags, pIfd->uiLimit, pbyTmpBuf,
+												&uiKeyLen);
+				if (!bReturn)
+				{
 					break;
-			
+				}
+
 				CmpKeyElm.pValue = pbyTmpBuf;
 				CmpKeyElm.uiValueLen = uiKeyLen;
 				CmpKeyElm.uiType = FLM_TEXT_TYPE;
 				CmpKeyElm.bFirstSubstring = bFirstSubstring;
-				CmpKeyElm.bSubstringComponent =
-					(pIfd->uiFlags & IFD_SUBSTRING) ? TRUE : FALSE;
+				CmpKeyElm.bSubstringComponent = (pIfd->uiFlags & IFD_SUBSTRING) 
+																	? TRUE 
+																	: FALSE;
+				
 				if (pIfd->uiFlags & IFD_LAST)
-					rc = flmBuildCompoundKey( pDb, pIxd, &CmpKeyElm,
-									bRemoveDups, pPool, uiContainerNum, ppKeyList);
+				{
+					rc = flmBuildCompoundKey( pDb, pIxd, &CmpKeyElm, bRemoveDups,
+													 pPool, uiContainerNum, ppKeyList);
+				}
 				else
-					rc = flmGetCmpKeyElement( pDb, pIxd, (pIfd + 1),
-						uiCdlEntry + 1, uiCompoundPos + 1,
-						&CmpKeyElm, bRemoveDups, pPool, ppKeyList, 
-						pRecord, uiContainerNum, pFldContext);
-				if (RC_BAD( rc))
-					goto Exit;
+				{
+					rc = flmGetCmpKeyElement( pDb, pIxd, (pIfd + 1), uiCdlEntry + 1,
+													 uiCompoundPos + 1, &CmpKeyElm,
+													 bRemoveDups, pPool, ppKeyList, pRecord,
+													 uiContainerNum, pFldContext);
+				}
 
-				if( (pIfd->uiFlags & IFD_SUBSTRING) && 
-					  uiTextLen == 1 && 
-					  !(uiLanguage >= FIRST_DBCS_LANG && 
-						 uiLanguage <= LAST_DBCS_LANG))
+				if (RC_BAD( rc))
+				{
+					goto Exit;
+				}
+
+				if ((pIfd->uiFlags & IFD_SUBSTRING) &&
+					 uiTextLen == 1 && !(uiLanguage >= FLM_FIRST_DBCS_LANG && 
+							uiLanguage <= FLM_LAST_DBCS_LANG))
 				{
 					break;
 				}
+
 				bFirstSubstring = FALSE;
 			}
 		}
@@ -642,83 +652,92 @@ FSTATIC RCODE flmGetCmpKeyElement(
 		{
 			CmpKeyElm.bSubstringComponent = FALSE;
 			if (pIfd->uiFlags & IFD_CONTEXT)
+			{
 				CmpKeyElm.uiValueLen = 0;
+			}
+
 			if (pIfd->uiFlags & IFD_LAST)
 			{
-				rc = flmBuildCompoundKey( pDb, pIxd, &CmpKeyElm, bRemoveDups,
-					pPool, uiContainerNum, ppKeyList);
+				rc = flmBuildCompoundKey( pDb, pIxd, &CmpKeyElm, bRemoveDups, pPool,
+												 uiContainerNum, ppKeyList);
 			}
 			else
 			{
-				rc = flmGetCmpKeyElement( pDb, pIxd, pNextIfdPiece,
-					uiNextCdlEntry, uiCompoundPos+1, &CmpKeyElm,
-					bRemoveDups, pPool, ppKeyList, pRecord, uiContainerNum,
-					pFldContext);
+				rc = flmGetCmpKeyElement( pDb, pIxd, pNextIfdPiece, uiNextCdlEntry,
+												 uiCompoundPos + 1, &CmpKeyElm, bRemoveDups,
+												 pPool, ppKeyList, pRecord, uiContainerNum,
+												 pFldContext);
 			}
-			
+
 			if (RC_BAD( rc))
 			{
 				goto Exit;
 			}
 		}
+
 		bBuiltKeyPiece = TRUE;
 
 Next_CDL_Node:
-		/* Go to next cdl. */
+
+		// Go to next cdl.
+
 		if (pCdl)
+		{
 			pCdl = pCdl->pNext;
+		}
 
-		// If the CDL list is empty, goto the next IFD if same uiCompoundPos.
+		// If the CDL list is empty, goto the next IFD if same
+		// uiCompoundPos.
 
-		while ((!pCdl)
-			&& ((pIfd->uiFlags & IFD_LAST) == 0)
-			&&  (pIfd->uiCompoundPos == (pIfd+1)->uiCompoundPos))
+		while( (!pCdl) && ((pIfd->uiFlags & IFD_LAST) == 0) &&
+				 (pIfd->uiCompoundPos == (pIfd + 1)->uiCompoundPos))
 		{
 			pIfd++;
-			pCdl = ppCdlTbl [++uiCdlEntry];
+			pCdl = ppCdlTbl[++uiCdlEntry];
 		}
-		/*
-		Here is the tough part of the new compound indexing strategy (Aug98).
-		If all nodes failed the validate field path test and this piece of
-		the compound key is required, then goto exit NOW which will not
-		build any key with the previous built key pieces.
-		*/
 
-		if( !pCdl && !bBuiltKeyPiece && ((pIfd->uiFlags & IFD_OPTIONAL) == 0))
+		// If all nodes failed the validate field path test and this piece
+		// of the compound key is required, then goto exit NOW which will
+		// not build any key with the previous built key pieces.
+
+		if (!pCdl && !bBuiltKeyPiece && ((pIfd->uiFlags & IFD_OPTIONAL) == 0))
 		{
 			goto Exit;
 		}
 	}
+
 Exit:
+
 	if (pbyTmpBuf)
 	{
 		f_free( &pbyTmpBuf);
 	}
-	return( rc);
+
+	return (rc);
 }
 
-/***************************************************************************
-Desc:	This routine builds all of the compound keys whose elements have
+/****************************************************************************
+Desc: This routine builds all of the compound keys whose elements have
 		been previously saved off of the index's IFD structures.
 Note:	Already knows that there are compound keys.
-*****************************************************************************/
+****************************************************************************/
 FSTATIC RCODE flmGetCompoundKeys(
-	FDB_p				pDb,
-	IXD_p				pIxd,		
+	FDB *				pDb,
+	IXD *				pIxd,
 	FLMBOOL			bRemoveDups,
-	POOL *			pPool,
+	F_Pool *			pPool,
 	FlmRecord *		pRecord,
 	FLMUINT			uiContainerNum,
-	REC_KEY **		ppKeyList)
+	REC_KEY **	 	ppKeyList)
 {
-	RCODE			rc = FERR_OK;
-	IFD_p			pFirstIfd;
-	IFD_p			pIfd;
-	CDL_p  *		ppCdlTbl = pDb->KrefCntrl.ppCdlTbl;
-	FLMUINT		uiFirstCdlEntry;
-	FLMUINT		uiCdlEntry;
-	FLMUINT		wIfdCnt;
-	FLMBOOL		bBuildCmpKeys = TRUE;
+	RCODE				rc = FERR_OK;
+	IFD *				pFirstIfd;
+	IFD *				pIfd;
+	CDL **	 		ppCdlTbl = pDb->KrefCntrl.ppCdlTbl;
+	FLMUINT			uiFirstCdlEntry;
+	FLMUINT			uiCdlEntry;
+	FLMUINT			wIfdCnt;
+	FLMBOOL			bBuildCmpKeys = TRUE;
 
 	pFirstIfd = pIxd->pFirstIfd;
 	uiFirstCdlEntry = (FLMUINT) (pFirstIfd - pDb->pDict->pIfdTbl);
@@ -730,68 +749,73 @@ FSTATIC RCODE flmGetCompoundKeys(
 		  pIfd++, wIfdCnt++, uiCdlEntry++)
 	{
 
-		/*
-		If field is not optional and no data list found,
-		there are no compound keys to build.
-		*/
-		FLMUINT		uiCompoundPos;
-		FLMBOOL 		bHitFound;
-				
+		// If field is not optional and no data list found, there are no
+		// compound keys to build.
+
+		FLMUINT	uiCompoundPos;
+		FLMBOOL	bHitFound;
+
 		// Loop on each compound field piece looking for REQUIRED field
 		// without any data.
-				
+
 		bHitFound = (pIfd->uiFlags & IFD_OPTIONAL) ? TRUE : FALSE;
 		uiCompoundPos = pIfd->uiCompoundPos;
-		for(;;)
+		
+		for (;;)
 		{
 			if (!bHitFound)
 			{
-				if (ppCdlTbl [uiCdlEntry])
+				if (ppCdlTbl[uiCdlEntry])
 				{
-					bHitFound = TRUE;						// Loop through all ixds
-				}	
+					bHitFound = TRUE;
+				}
 			}
-			if ((pIfd->uiFlags & IFD_LAST) 
-			||  ((pIfd+1)->uiCompoundPos != uiCompoundPos))
+
+			if ((pIfd->uiFlags & IFD_LAST) ||
+				 ((pIfd + 1)->uiCompoundPos != uiCompoundPos))
+			{
 				break;
+			}
+
 			pIfd++;
 			uiCdlEntry++;
 			wIfdCnt++;
 		}
-		if( !bHitFound)
+
+		if (!bHitFound)
 		{
 			bBuildCmpKeys = FALSE;
 			break;
 		}
 	}
 
-	/* Build the individual compound keys. */
+	// Build the individual compound keys.
 
 	if (bBuildCmpKeys)
 	{
-		FLD_CONTEXT		fldContext;
+		FLD_CONTEXT fldContext;
 
 		f_memset( &fldContext, 0, sizeof(FLD_CONTEXT));
-		rc = flmGetCmpKeyElement( pDb, pIxd, pFirstIfd,
-				uiFirstCdlEntry, 0, NULL, bRemoveDups, pPool, ppKeyList, pRecord,
-				uiContainerNum, &fldContext);
+		rc = flmGetCmpKeyElement( pDb, pIxd, pFirstIfd, uiFirstCdlEntry, 0, NULL,
+										 bRemoveDups, pPool, ppKeyList, pRecord,
+										 uiContainerNum, &fldContext);
 	}
 
-	return( rc);
+	return (rc);
 }
 
-/***************************************************************************
+/****************************************************************************
 Desc:	This routine builds all of the keys in a record for a particular
 		index in the database.
-*****************************************************************************/
+****************************************************************************/
 RCODE flmGetRecKeys(
-	FDB_p				pDb,
-	IXD_p				pIxd,		
+	FDB *				pDb,
+	IXD *				pIxd,
 	FlmRecord *		pRecord,
 	FLMUINT			uiContainerNum,
 	FLMBOOL			bRemoveDups,
-	POOL *			pPool,
-	REC_KEY **		ppKeyList)
+	F_Pool *			pPool,
+	REC_KEY **	 	ppKeyList)
 {
 	RCODE				rc = FERR_OK;
 	void *			pvField;
@@ -801,30 +825,29 @@ RCODE flmGetRecKeys(
 	FLMBOOL			bResetID = FALSE;
 	FLMBOOL			bHasCmpKeys = FALSE;
 	FLMBOOL			bDictIx = FALSE;
-	void *			pathFlds[ GED_MAXLVLNUM + 1];
+	void *			pathFlds[GED_MAXLVLNUM + 1];
 	FLMUINT			uiLeafFieldLevel;
 
 	*ppKeyList = NULL;
 
-	if( pIxd->uiIndexNum == FLM_DICT_INDEX)
+	if (pIxd->uiIndexNum == FLM_DICT_INDEX)
 	{
 		bDictIx = TRUE;
 
-		/*
-		Temporary convert the record's tag number to FLM_NAME_TAG so
-		that we will generate the appropriate name key.
-		*/
+		// Temporary convert the record's tag number to FLM_NAME_TAG so that
+		// we will generate the appropriate name key.
 
 		if ((uiSaveFieldID >= FLM_DICT_FIELD_NUMS) &&
 			 (uiSaveFieldID <= FLM_LAST_DICT_FIELD_NUM))
 		{
-			if( pRecord->isReadOnly())
+			if (pRecord->isReadOnly())
 			{
-				if( (pTmpRec = pRecord->copy()) == NULL)
+				if ((pTmpRec = pRecord->copy()) == NULL)
 				{
 					rc = RC_SET( FERR_MEM);
 					goto Exit;
 				}
+
 				pRecord = pTmpRec;
 			}
 
@@ -832,40 +855,39 @@ RCODE flmGetRecKeys(
 			bResetID = TRUE;
 		}
 	}
-	
-	/* Process all fields in the tree. */
+
+	// Process all fields in the tree.
 
 	uiFieldCount = 256;
-	for( pvField = pRecord->root(); pvField; pvField = pRecord->next( pvField))
+	for (pvField = pRecord->root(); pvField; pvField = pRecord->next( pvField))
 	{
+
 		// Is if field is indexed before building the keys.
 
-		uiLeafFieldLevel = (FLMINT)pRecord->getLevel( pvField);
-		pathFlds[ uiLeafFieldLevel] = pvField;
-		if( RC_BAD( rc = flmGetFieldKeys( pDb, pIxd, pRecord, uiContainerNum,
-			pathFlds, uiLeafFieldLevel,
-			pvField, bRemoveDups,
-			pPool, ppKeyList, &bHasCmpKeys)))
+		uiLeafFieldLevel = (FLMINT) pRecord->getLevel( pvField);
+		pathFlds[uiLeafFieldLevel] = pvField;
+		if (RC_BAD( rc = flmGetFieldKeys( pDb, pIxd, pRecord, uiContainerNum,
+					  pathFlds, uiLeafFieldLevel, pvField, bRemoveDups, pPool,
+					  ppKeyList, &bHasCmpKeys)))
 		{
 			goto Exit;
 		}
 
-		/*	Release the CPU periodically to prevent CPU hog problems. */
-		
-		if( uiFieldCount-- == 0)
+		// Release the CPU periodically to prevent CPU hog problems.
+
+		if (uiFieldCount-- == 0)
 		{
 			f_yieldCPU();
 			uiFieldCount = 128;
 		}
-
 	}
 
-	/* If OK, get the compound keys. */
+	// If OK, get the compound keys.
 
 	if (bHasCmpKeys)
 	{
-		if (RC_BAD( rc = flmGetCompoundKeys( pDb, pIxd, bRemoveDups,
-			pPool, pRecord, uiContainerNum, ppKeyList)))
+		if (RC_BAD( rc = flmGetCompoundKeys( pDb, pIxd, bRemoveDups, pPool,
+					  pRecord, uiContainerNum, ppKeyList)))
 		{
 			goto Exit;
 		}
@@ -873,14 +895,14 @@ RCODE flmGetRecKeys(
 
 Exit:
 
-	if( pTmpRec)
+	if (pTmpRec)
 	{
 		pTmpRec->Release();
 	}
-	else if( bResetID)
+	else if (bResetID)
 	{
 		pRecord->setFieldID( pRecord->root(), uiSaveFieldID);
 	}
 
-	return( rc);
+	return (rc);
 }
