@@ -24,21 +24,78 @@
 
 #include "flaimsys.h"
 
-#if defined( FLM_NLM) && !defined( __MWERKS__)
-// Disable "Warning! W549: col(XX) 'sizeof' operand contains
-// compiler generated information"
-	#pragma warning 549 9
-#endif
+/****************************************************************************
+Desc:
+****************************************************************************/
+class F_RCacheRelocator : public IF_Relocator
+{
+public:
 
-FSTATIC FLMBOOL rcaCanRelocate(
-	void *		pvAlloc);
-
-FSTATIC void rcaRelocate(
-	void *		pvOldAlloc,
-	void *		pvNewAlloc);
+	F_RCacheRelocator()
+	{
+	}
 	
-// Extended record object for accessing private members of FlmRecord
+	virtual ~F_RCacheRelocator()
+	{
+	}
 
+	void FLMAPI relocate(
+		void *	pvOldAlloc,
+		void *	pvNewAlloc);
+
+	FLMBOOL FLMAPI canRelocate(
+		void *	pvOldAlloc);
+};
+
+/****************************************************************************
+Desc:
+****************************************************************************/
+class F_RecRelocator : public IF_Relocator
+{
+public:
+
+	F_RecRelocator()
+	{
+	}
+	
+	virtual ~F_RecRelocator()
+	{
+	}
+
+	void FLMAPI relocate(
+		void *	pvOldAlloc,
+		void *	pvNewAlloc);
+
+	FLMBOOL FLMAPI canRelocate(
+		void *	pvOldAlloc);
+};
+
+/****************************************************************************
+Desc:
+****************************************************************************/
+class F_RecBufferRelocator : public IF_Relocator
+{
+public:
+
+	F_RecBufferRelocator()
+	{
+	}
+	
+	virtual ~F_RecBufferRelocator()
+	{
+	}
+
+	void FLMAPI relocate(
+		void *	pvOldAlloc,
+		void *	pvNewAlloc);
+
+	FLMBOOL FLMAPI canRelocate(
+		void *	pvOldAlloc);
+};
+
+/****************************************************************************
+Desc:	Extended record object for accessing private members of FlmRecord
+****************************************************************************/
 struct FlmRecordExt
 {
 	static FINLINE void clearCached(
@@ -59,14 +116,7 @@ struct FlmRecordExt
 		pRec->setReadOnly();
 	}
 
-	static FINLINE FLMUINT AddRef(
-		FlmRecord *			pRec,
-		FLMBOOL				bMutexLocked)
-	{
-		return( pRec->AddRef( bMutexLocked));
-	}
-
-	static FINLINE FLMUINT Release(
+	static FINLINE FLMINT Release(
 		FlmRecord *			pRec,
 		FLMBOOL				bMutexLocked)
 	{
@@ -90,27 +140,16 @@ struct FlmRecordExt
 	{
 		return( pRec->m_uiFlags);
 	}
-
-	static FLMBOOL canRelocateRec(
-		void *		pvAlloc);
-
-	static void relocateRec(
-		void *		pvOldAlloc,
-		void *		pvNewAlloc);
-
-	static FLMBOOL canRelocateRecBuffer(
-		void *		pvAlloc);
-
-	static void relocateRecBuffer(
-		void *		pvOldAlloc,
-		void *		pvNewAlloc);
 };
 
 // Functions for calculating minimum and maximum record counts for a
 // given hash table size.
 
-#define FLM_RCA_MIN_REC_CNT(uiHashTblSz)	((uiHashTblSz) / 4)
-#define FLM_RCA_MAX_REC_CNT(uiHashTblSz)	((uiHashTblSz) * 4)
+#define FLM_RCA_MIN_REC_CNT(uiHashTblSz) \
+	((uiHashTblSz) / 4)
+	
+#define FLM_RCA_MAX_REC_CNT(uiHashTblSz) \
+	((uiHashTblSz) * 4)
 
 // Hash function for hashing to records in record cache.
 
@@ -118,7 +157,7 @@ struct FlmRecordExt
 	(RCACHE **)(&(gv_FlmSysData.RCacheMgr.ppHashBuckets[(uiDrn) & \
 						(gv_FlmSysData.RCacheMgr.uiHashMask)]))
 
-/* LOCAL STATIC FUNCTION PROTOTYPES */
+// Local functions
 
 FSTATIC void flmRcaFreePurged(
 	RCACHE *			pRCache);
@@ -135,13 +174,10 @@ FSTATIC RCODE flmRcaRehash( void);
 FSTATIC RCODE flmRcaSetMemLimit(
 	FLMUINT			uiMaxCacheBytes);
 
-FSTATIC RCODE flmRcaWaitNotify(
-	FNOTIFY **			ppNotifyListRV);
-
 FSTATIC void flmRcaNotify(
-	FNOTIFY *			pNotify,
-	RCACHE *				pUseRCache,
-	RCODE					NotifyRc);
+	F_NOTIFY_LIST_ITEM *		pNotify,
+	RCACHE *						pUseRCache,
+	RCODE							NotifyRc);
 
 FSTATIC RCODE flmRcaAllocCacheStruct(
 	RCACHE **		ppRCache);
@@ -161,16 +197,16 @@ FSTATIC void flmRcaLinkIntoRCache(
 
 FSTATIC void flmRcaLinkToFFILE(
 	RCACHE *			pRCache,
-	FFILE_p			pFile,
-	FDB_p				pDb,
+	FFILE *			pFile,
+	FDB *				pDb,
 	FLMUINT			uiLowTransId,
 	FLMBOOL			bMostCurrent);
 
 #ifdef FLM_DEBUG
 FSTATIC RCODE flmRcaCheck(
-	FDB_p			pDb,
-	FLMUINT		uiContainer,
-	FLMUINT		uiDrn);
+	FDB *				pDb,
+	FLMUINT			uiContainer,
+	FLMUINT			uiDrn);
 #endif
 
 /****************************************************************************
@@ -395,7 +431,7 @@ Desc:	This routine links a record to an FFILE list at the head of the list.
 ****************************************************************************/
 FINLINE void flmRcaLinkToFileAtHead(
 	RCACHE *		pRCache,
-	FFILE_p		pFile)
+	FFILE *		pFile)
 {
 	pRCache->pPrevInFile = NULL;
 	if ((pRCache->pNextInFile = pFile->pFirstRecord) != NULL)
@@ -419,7 +455,7 @@ Desc:	This routine links a record to an FFILE list at the end of the list.
 ****************************************************************************/
 FINLINE void flmRcaLinkToFileAtEnd(
 	RCACHE *		pRCache,
-	FFILE_p		pFile)
+	FFILE *		pFile)
 {
 	pRCache->pNextInFile = NULL;
 	if( (pRCache->pPrevInFile = pFile->pLastRecord) != NULL)
@@ -452,6 +488,7 @@ FINLINE void flmRcaUnlinkFromFile(
 		{
 			pRCache->pFile->pLastRecord = pRCache->pPrevInFile;
 		}
+		
 		if( pRCache->pPrevInFile)
 		{
 			pRCache->pPrevInFile->pNextInFile = pRCache->pNextInFile;
@@ -460,6 +497,7 @@ FINLINE void flmRcaUnlinkFromFile(
 		{
 			pRCache->pFile->pFirstRecord = pRCache->pNextInFile;
 		}
+		
 		pRCache->pPrevInFile = pRCache->pNextInFile = NULL;
 		RCA_UNSET_LINKED_TO_FILE( pRCache->uiFlags);
 	}
@@ -496,6 +534,7 @@ FINLINE void flmRcaUnlinkFromHashBucket(
 	{
 		pRCache->pNextInBucket->pPrevInBucket = pRCache->pPrevInBucket;
 	}
+	
 	if (pRCache->pPrevInBucket)
 	{
 		pRCache->pPrevInBucket->pNextInBucket = pRCache->pNextInBucket;
@@ -521,6 +560,7 @@ FINLINE void flmRcaLinkToVerList(
 	{
 		pNewerVer->pOlderVersion = pRCache;
 	}
+	
 	if ((pRCache->pOlderVersion = pOlderVer) != NULL)
 	{
 		pOlderVer->pNewerVersion = pRCache;
@@ -538,6 +578,7 @@ FINLINE void flmRcaUnlinkFromVerList(
 	{
 		pRCache->pNewerVersion->pOlderVersion = pRCache->pOlderVersion;
 	}
+	
 	if (pRCache->pOlderVersion)
 	{
 		pRCache->pOlderVersion->pNewerVersion = pRCache->pNewerVersion;
@@ -706,9 +747,13 @@ FSTATIC void flmRcaFreeCache(
 Desc:	This routine initializes record cache manager.
 ****************************************************************************/
 RCODE flmRcaInit(
-	FLMUINT	uiMaxRecordCacheBytes)
+	FLMUINT		uiMaxRecordCacheBytes)
 {
-	RCODE		rc = FERR_OK;
+	RCODE							rc = FERR_OK;
+	F_RCacheRelocator *		pRCacheRelocator = NULL;
+	F_RecRelocator *			pRecRelocator = NULL;
+	F_RecBufferRelocator *	pRecBufferRelocator = NULL;
+	
 
 	f_memset( &gv_FlmSysData.RCacheMgr, 0, sizeof( RCACHE_MGR));
 	gv_FlmSysData.RCacheMgr.Usage.uiMaxBytes = uiMaxRecordCacheBytes;
@@ -739,67 +784,91 @@ RCODE flmRcaInit(
 	
 	// Set up the RCACHE struct allocator
 	
-	if( (gv_FlmSysData.RCacheMgr.pRCacheAlloc = f_new F_FixedAlloc) == NULL)
+	if( RC_BAD( rc = FlmAllocFixedAllocator( 
+		&gv_FlmSysData.RCacheMgr.pRCacheAlloc)))
+	{
+		goto Exit;
+	}
+	
+	if( (pRCacheRelocator = f_new F_RCacheRelocator) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
-
+	
 	if( RC_BAD( rc = gv_FlmSysData.RCacheMgr.pRCacheAlloc->setup(
-		gv_FlmSysData.pSlabManager, TRUE, sizeof( RCACHE), 
+		FALSE, gv_FlmSysData.pSlabManager, pRCacheRelocator, sizeof( RCACHE), 
+		&gv_FlmSysData.RCacheMgr.Usage.SlabUsage, 
 		&gv_FlmSysData.RCacheMgr.Usage.uiTotalBytesAllocated)))
 	{
 		goto Exit;
 	}
-
-	gv_FlmSysData.RCacheMgr.pRCacheAlloc->setRelocationFuncs(
-		rcaCanRelocate, rcaRelocate);
-		
+	
 	// Set up the record object allocator
-
-	if( (gv_FlmSysData.RCacheMgr.pRecAlloc = f_new F_FixedAlloc) == NULL)
+	
+	if( RC_BAD( rc = FlmAllocFixedAllocator(
+		&gv_FlmSysData.RCacheMgr.pRecAlloc)))
+	{
+		goto Exit;
+	}
+	
+	if( (pRecRelocator = f_new F_RecRelocator) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
 
 	if( RC_BAD( rc = gv_FlmSysData.RCacheMgr.pRecAlloc->setup(
-		gv_FlmSysData.pSlabManager,
-		gv_FlmSysData.RCacheMgr.pRCacheAlloc->getMutex(),
-		sizeof( FlmRecord),
+		TRUE, gv_FlmSysData.pSlabManager, pRecRelocator, sizeof( FlmRecord),
+		&gv_FlmSysData.RCacheMgr.Usage.SlabUsage,
 		&gv_FlmSysData.RCacheMgr.Usage.uiTotalBytesAllocated)))
 	{
 		goto Exit;
 	}
 
-	gv_FlmSysData.RCacheMgr.pRecAlloc->setRelocationFuncs(
-		FlmRecordExt::canRelocateRec, FlmRecordExt::relocateRec);
-
 	// Set up the record buffer allocator
+	
+	if( RC_BAD( rc = FlmAllocBufferAllocator(
+		&gv_FlmSysData.RCacheMgr.pRecBufAlloc)))
+	{
+		goto Exit;
+	}
 
-	if( (gv_FlmSysData.RCacheMgr.pRecBufAlloc = f_new F_BufferAlloc) == NULL)
+	if( (pRecBufferRelocator = f_new F_RecBufferRelocator) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
-
+	
 	if( RC_BAD( rc = gv_FlmSysData.RCacheMgr.pRecBufAlloc->setup( 
-		gv_FlmSysData.pSlabManager, 
-		gv_FlmSysData.RCacheMgr.pRCacheAlloc->getMutex(),
+		TRUE, gv_FlmSysData.pSlabManager, pRecBufferRelocator,
+		&gv_FlmSysData.RCacheMgr.Usage.SlabUsage,
 		&gv_FlmSysData.RCacheMgr.Usage.uiTotalBytesAllocated))) 
 	{
 		goto Exit;
 	}
 
-	gv_FlmSysData.RCacheMgr.pRecBufAlloc->setRelocationFuncs(
-		FlmRecordExt::canRelocateRecBuffer, 
-		FlmRecordExt::relocateRecBuffer);
-
 #ifdef FLM_DEBUG
 	gv_FlmSysData.RCacheMgr.bDebug = TRUE;
 #endif
 
 Exit:
+
+	if( pRCacheRelocator)
+	{
+		pRCacheRelocator->Release();
+	}
+
+	if( pRecRelocator)
+	{
+		pRecRelocator->Release();
+	}
+	
+	if( pRecBufferRelocator)
+	{
+		pRecBufferRelocator->Release();
+	}
+	
 	if (RC_BAD( rc))
 	{
 		flmRcaExit();
@@ -814,15 +883,15 @@ Desc:	This routine determines what hash table size best fits the current
 		the minimum and maximum range is closest to the record count.
 ****************************************************************************/
 FSTATIC FLMUINT flmRcaGetBestHashTblSize(
-	FLMUINT	uiCurrRecCount)
+	FLMUINT		uiCurrRecCount)
 {
-	FLMUINT	uiHashTblSize;
-	FLMUINT	uiMaxRecsForHashTblSize;
-	FLMUINT	uiMinRecsForHashTblSize;
-	FLMUINT	uiClosestHashTblSize = 0;
-	FLMUINT	uiDistanceFromMidpoint;
-	FLMUINT	uiLowestDistanceFromMidpoint;
-	FLMUINT	uiHashTblRecsMidpoint;
+	FLMUINT		uiHashTblSize;
+	FLMUINT		uiMaxRecsForHashTblSize;
+	FLMUINT		uiMinRecsForHashTblSize;
+	FLMUINT		uiClosestHashTblSize = 0;
+	FLMUINT		uiDistanceFromMidpoint;
+	FLMUINT		uiLowestDistanceFromMidpoint;
+	FLMUINT		uiHashTblRecsMidpoint;
 
 	uiLowestDistanceFromMidpoint = 0xFFFFFFFF;
 	for (uiHashTblSize = MIN_RCACHE_BUCKETS;
@@ -877,9 +946,10 @@ FSTATIC FLMUINT flmRcaGetBestHashTblSize(
 		// we are either below the lowest minimum, or higher than the
 		// highest maximum.
 
-		uiHashTblSize = (FLMUINT)((uiCurrRecCount < FLM_RCA_MIN_REC_CNT( MIN_RCACHE_BUCKETS))
-										  ? (FLMUINT)MIN_RCACHE_BUCKETS
-										  : (FLMUINT)MAX_RCACHE_BUCKETS);
+		uiHashTblSize = 
+			(FLMUINT)((uiCurrRecCount < FLM_RCA_MIN_REC_CNT( MIN_RCACHE_BUCKETS))
+									  ? (FLMUINT)MIN_RCACHE_BUCKETS
+									  : (FLMUINT)MAX_RCACHE_BUCKETS);
 
 	}
 	else
@@ -929,13 +999,6 @@ FSTATIC RCODE flmRcaRehash( void)
 		goto Exit;
 	}
 
-	// Subtract off old size and add in new size.
-
-	gv_FlmSysData.RCacheMgr.pRCacheAlloc->decrementTotalBytesAllocated(
-			(sizeof( RCACHE *) * uiOldHashTblSize));
-	gv_FlmSysData.RCacheMgr.pRCacheAlloc->incrementTotalBytesAllocated(
-			(sizeof( RCACHE *) * uiNewHashTblSize));
-
 	gv_FlmSysData.RCacheMgr.uiNumBuckets = uiNewHashTblSize;
 	gv_FlmSysData.RCacheMgr.uiHashMask = uiNewHashTblSize - 1;
 
@@ -978,7 +1041,7 @@ FSTATIC RCODE flmRcaSetMemLimit(
 	// defragment cache first
 
 	gv_FlmSysData.RCacheMgr.Usage.uiMaxBytes = uiMaxCacheBytes;
-	if (gv_FlmSysData.RCacheMgr.pRCacheAlloc->getTotalBytesAllocated() >
+	if (gv_FlmSysData.RCacheMgr.Usage.uiTotalBytesAllocated >
 				uiMaxCacheBytes)
 	{
 		flmRcaCleanupCache( ~((FLMUINT)0), TRUE);
@@ -1011,11 +1074,11 @@ Desc:	This routine configures the record cache manager.  NOTE: This routine
 		assumes that the record cache mutex has been locked.
 ****************************************************************************/
 RCODE flmRcaConfig(
-	FLMUINT			uiType,
-	void *			Value1,
-	void *			Value2)
+	FLMUINT		uiType,
+	void *		Value1,
+	void *		Value2)
 {
-	RCODE		rc = FERR_OK;
+	RCODE			rc = FERR_OK;
 
 	F_UNREFERENCED_PARM( Value2);
 
@@ -1046,6 +1109,8 @@ Desc:	This routine shuts down the record cache manager and frees all
 ****************************************************************************/
 void flmRcaExit( void)
 {
+	FLMUINT		uiCount;
+	
 	if (gv_FlmSysData.RCacheMgr.hMutex != F_MUTEX_NULL)
 	{
 		f_mutexLock( gv_FlmSysData.RCacheMgr.hMutex);
@@ -1053,17 +1118,26 @@ void flmRcaExit( void)
 
 	// Free all of the record cache objects.
 
+	uiCount = 0;
 	while (gv_FlmSysData.RCacheMgr.pMRURecord)
 	{
-		f_yieldCPU();
+		if( (++uiCount & 0xFF) == 0)
+		{
+			f_yieldCPU();
+		}
+		
 		flmRcaFreeCache( gv_FlmSysData.RCacheMgr.pMRURecord, FALSE);
 	}
 
 	// Must free those in the purge list too.
 
+	uiCount = 0;
 	while (gv_FlmSysData.RCacheMgr.pPurgeList)
 	{
-		f_yieldCPU();
+		if( (++uiCount & 0xFF) == 0)
+		{
+			f_yieldCPU();
+		}
 		flmRcaFreePurged( gv_FlmSysData.RCacheMgr.pPurgeList);
 	}
 
@@ -1078,8 +1152,6 @@ void flmRcaExit( void)
 	if (gv_FlmSysData.RCacheMgr.ppHashBuckets)
 	{
 		f_free( &gv_FlmSysData.RCacheMgr.ppHashBuckets);
-		gv_FlmSysData.RCacheMgr.pRCacheAlloc->decrementTotalBytesAllocated(
-			(sizeof( RCACHE *) * gv_FlmSysData.RCacheMgr.uiNumBuckets));
 	}
 
 	// Free the mutex that controls access to record cache.
@@ -1117,83 +1189,15 @@ void flmRcaExit( void)
 	f_memset( &gv_FlmSysData.RCacheMgr, 0, sizeof( RCACHE_MGR));
 }
 
-/****************************************************************************
-Desc: This routine links a notify request into a notification list and
-		then waits to be notified that the event has occurred.
-		NOTE: This routine assumes that the record cache mutex is locked and that
-		it is supposed to unlock it.  It will relock the mutex on its way out.
-****************************************************************************/
-FSTATIC RCODE flmRcaWaitNotify(
-	FNOTIFY **			ppNotifyListRV)
-{
-	FNOTIFY *      pNotify = NULL;
-	RCODE          TempRc;
-	RCODE          rc = FERR_OK;
-	F_SEM				hSem;
-
-	// First create a notify request and link it into the list.
-
-	if (RC_OK( rc = f_calloc( (FLMUINT)(sizeof( FNOTIFY)), &pNotify)))
-	{
-		// Allocate a semaphore for the notify request.
-
-		pNotify->uiThreadId = f_threadId();
-		pNotify->hSem = F_SEM_NULL;
-		rc = f_semCreate( &pNotify->hSem);
-	}
-
-	if (RC_BAD( rc))
-	{
-		if (pNotify)
-		{
-			if (pNotify->hSem != F_SEM_NULL)
-			{
-				f_semDestroy( &pNotify->hSem);
-			}
-
-			f_free( &pNotify);
-		}
-
-		goto Exit;
-	}
-
-	pNotify->pRc = &rc;
-	pNotify->UserData = NULL;
-	pNotify->pNext = *ppNotifyListRV;
-	*ppNotifyListRV = pNotify;
-	hSem = pNotify->hSem;
-
-	// Unlock the mutex and wait on the semaphore.
-
-	f_mutexUnlock( gv_FlmSysData.RCacheMgr.hMutex);
-	if (RC_BAD( TempRc = f_semWait( hSem, F_SEM_WAITFOREVER)))
-	{
-		rc = TempRc;
-	}
-
-	// Free the semaphore and the notify structure.
-
-	f_semDestroy( &hSem);
-	f_free( &pNotify);
-
-	// Relock the record cache mutex
-
-	f_mutexLock( gv_FlmSysData.RCacheMgr.hMutex);
-
-Exit:
-
-	return( rc);
-}
-
 /****************************************************************************
 Desc:	This routine notifies threads waiting for a pending read to complete.
 		NOTE:  This routine assumes that the record cache mutex is already
 		locked.
 ****************************************************************************/
 FSTATIC void flmRcaNotify(
-	FNOTIFY *			pNotify,
-	RCACHE *				pUseRCache,
-	RCODE					NotifyRc)
+	F_NOTIFY_LIST_ITEM *	pNotify,
+	RCACHE *					pUseRCache,
+	RCODE						NotifyRc)
 {
 	while (pNotify)
 	{
@@ -1219,8 +1223,11 @@ FSTATIC RCODE flmRcaAllocCacheStruct(
 {
 	RCODE				rc = FERR_OK;
 	
+	f_assertMutexLocked( gv_FlmSysData.RCacheMgr.hMutex);
+	
 	if( (*ppRCache = 
-		(RCACHE *)gv_FlmSysData.RCacheMgr.pRCacheAlloc->allocCell()) == NULL)
+		(RCACHE *)gv_FlmSysData.RCacheMgr.pRCacheAlloc->allocCell( 
+		NULL, NULL)) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
@@ -1250,6 +1257,7 @@ FSTATIC void flmRcaFreeCacheStruct(
 	RCACHE **		ppRCache)
 {
 	flmAssert( !RCA_IS_IN_HEAP_LIST( (*ppRCache)->uiFlags));
+	f_assertMutexLocked( gv_FlmSysData.RCacheMgr.hMutex);
 	
 	gv_FlmSysData.RCacheMgr.pRCacheAlloc->freeCell( *ppRCache);
 	*ppRCache = NULL;	
@@ -1263,8 +1271,8 @@ Desc:	Cleanup old records in cache that are no longer needed by any
 		transaction.
 ****************************************************************************/
 void flmRcaCleanupCache(
-	FLMUINT	uiMaxLockTime,
-	FLMBOOL	bMutexesLocked)
+	FLMUINT			uiMaxLockTime,
+	FLMBOOL			bMutexesLocked)
 {
 	RCACHE *			pTmpRCache;
 	RCACHE *			pPrevRCache;
@@ -1357,11 +1365,7 @@ void flmRcaCleanupCache(
 					// Shortest possible pause - to allow other threads
 					// to do work.
 
-	#ifdef FLM_NLM
 					f_yieldCPU();
-	#else
-					f_sleep( 0);
-	#endif
 
 					// Relock the mutexes
 
@@ -1454,7 +1458,7 @@ void flmRcaReduceCache(
 
 	// Free things until we get down below our memory limit.
 
-	while( gv_FlmSysData.RCacheMgr.pRCacheAlloc->getTotalBytesAllocated() >
+	while( gv_FlmSysData.RCacheMgr.Usage.uiTotalBytesAllocated >
 		gv_FlmSysData.RCacheMgr.Usage.uiMaxBytes)
 	{
 		if( !pRCache)
@@ -1465,7 +1469,7 @@ void flmRcaReduceCache(
 		// If the total of block and record cache is below the global
 		// cache maximum, there is no need to reduce record cache.
 
-		if( (gv_FlmSysData.RCacheMgr.pRCacheAlloc->getTotalBytesAllocated() + 
+		if( (gv_FlmSysData.RCacheMgr.Usage.uiTotalBytesAllocated + 
 			gv_FlmSysData.SCacheMgr.Usage.uiTotalBytesAllocated) <=
 			gv_FlmSysData.uiMaxCache)
 		{
@@ -1494,9 +1498,10 @@ Desc:	This routine finds a record in the record cache.  If it cannot
 		has been locked.
 ****************************************************************************/
 void flmRcaFindRec(
+	FFILE *			pFile,
+	F_SEM				hWaitSem,
 	FLMUINT			uiContainer,
 	FLMUINT			uiDrn,
-	FFILE_p			pFile,
 	FLMUINT			uiVersionNeeded,
 	FLMBOOL			bDontPoisonCache,
 	FLMUINT *		puiNumLooks,
@@ -1504,11 +1509,11 @@ void flmRcaFindRec(
 	RCACHE **		ppNewerRCache,
 	RCACHE **		ppOlderRCache)
 {
-	RCACHE *		pRCache;
-	FLMUINT		uiNumLooks = 0;
-	FLMBOOL		bFound;
-	RCACHE *		pNewerRCache;
-	RCACHE *		pOlderRCache;
+	RCACHE *			pRCache;
+	FLMUINT			uiNumLooks = 0;
+	FLMBOOL			bFound;
+	RCACHE *			pNewerRCache;
+	RCACHE *			pOlderRCache;
 
 	// Search down the hash bucket for the matching item.
 
@@ -1544,9 +1549,9 @@ Start_Find:
 	{
 		pNewerRCache = NULL;
 		pOlderRCache = pRCache;
+		
 		for (;;)
 		{
-
 			// If this one is being read in, we need to wait on it.
 
 			if (RCA_IS_READING_IN( pRCache->uiFlags))
@@ -1556,7 +1561,8 @@ Start_Find:
 				// in a version that satisfies our request.
 
 				gv_FlmSysData.RCacheMgr.uiIoWaits++;
-				if (RC_BAD( flmRcaWaitNotify( &pRCache->pNotifyList)))
+				if( RC_BAD( f_notifyWait( gv_FlmSysData.RCacheMgr.hMutex, 
+					hWaitSem, NULL, &pRCache->pNotifyList)))
 				{
 
 					// Don't care what error the other thread had reading
@@ -1696,8 +1702,8 @@ FSTATIC void flmRcaSetRecord(
 	pRCache->pRecord = pNewRecord;
 	flmAssert( !pNewRecord->isCached());
 	FlmRecordExt::setCached( pNewRecord);
-	FlmRecordExt::AddRef( pNewRecord, TRUE);
 	FlmRecordExt::setReadOnly( pNewRecord);
+	pNewRecord->AddRef();
 	
 	if( FlmRecordExt::getFlags( pNewRecord) & RCA_HEAP_BUFFER)
 	{
@@ -1761,8 +1767,8 @@ Desc:	This routine links a new record to its FFILE according to whether
 ****************************************************************************/
 FSTATIC void flmRcaLinkToFFILE(
 	RCACHE *			pRCache,
-	FFILE_p			pFile,
-	FDB_p				pDb,
+	FFILE *			pFile,
+	FDB *				pDb,
 	FLMUINT			uiLowTransId,
 	FLMBOOL			bMostCurrent)
 {
@@ -1948,32 +1954,32 @@ FSTATIC void flmRcaLinkToFFILE(
 Desc:	This routine retrieves a record from the record cache.
 ****************************************************************************/
 RCODE flmRcaRetrieveRec(
-	FDB *				pDb,
-	FLMBOOL *		pbTransStarted,
-	FLMUINT			uiContainer,			// Container record is in.
-	FLMUINT			uiDrn,					// DRN of record.
-	FLMBOOL			bOkToGetFromDisk,		// If not in cache, OK to get from disk?
-	BTSK *			pStack,					// Use stack to retrieve, if NON-NULL.
-	LFILE *			pLFile,					// LFILE to use, if retrieving with stack
-	FlmRecord **	ppRecord)
+	FDB *						pDb,
+	FLMBOOL *				pbTransStarted,
+	FLMUINT					uiContainer,			// Container record is in.
+	FLMUINT					uiDrn,					// DRN of record.
+	FLMBOOL					bOkToGetFromDisk,		// If not in cache, OK to get from disk?
+	BTSK *					pStack,					// Use stack to retrieve, if NON-NULL.
+	LFILE *					pLFile,					// LFILE to use, if retrieving with stack
+	FlmRecord **			ppRecord)
 {
-	RCODE					rc = FERR_OK;
-	FLMBOOL				bRCacheMutexLocked = FALSE;
-	FFILE_p				pFile = pDb->pFile;
-	RCACHE *				pRCache;
-	RCACHE *				pNewerRCache;
-	RCACHE *				pOlderRCache;
-	FlmRecord *			pRecord = NULL;
-	FLMBOOL				bGotFromDisk = FALSE;
-	FlmRecord *			pNewRecord = NULL;
-	FlmRecord *			pOldRecord = NULL;
-	FLMUINT				uiLowTransId;
-	FLMBOOL				bMostCurrent;
-	FLMUINT				uiCurrTransId;
-	FNOTIFY_p			pNotify;
-	FLMUINT				uiNumLooks;
-	FLMBOOL				bInitializedFdb = FALSE;
-	FLMBOOL				bDontPoisonCache = pDb->uiFlags & FDB_DONT_POISON_CACHE
+	RCODE						rc = FERR_OK;
+	FLMBOOL					bRCacheMutexLocked = FALSE;
+	FFILE *					pFile = pDb->pFile;
+	RCACHE *					pRCache;
+	RCACHE *					pNewerRCache;
+	RCACHE *					pOlderRCache;
+	FlmRecord *				pRecord = NULL;
+	FLMBOOL					bGotFromDisk = FALSE;
+	FlmRecord *				pNewRecord = NULL;
+	FlmRecord *				pOldRecord = NULL;
+	FLMUINT					uiLowTransId;
+	FLMBOOL					bMostCurrent;
+	FLMUINT					uiCurrTransId;
+	F_NOTIFY_LIST_ITEM *	pNotify;
+	FLMUINT					uiNumLooks;
+	FLMBOOL					bInitializedFdb = FALSE;
+	FLMBOOL					bDontPoisonCache = pDb->uiFlags & FDB_DONT_POISON_CACHE
 														? TRUE 
 														: FALSE;
 
@@ -2030,10 +2036,9 @@ RCODE flmRcaRetrieveRec(
 
 Start_Find:
 
-	flmRcaFindRec( uiContainer, uiDrn, pFile,
-						uiCurrTransId, bDontPoisonCache, 
-						&uiNumLooks, &pRCache,
-						&pNewerRCache, &pOlderRCache);
+	flmRcaFindRec( pFile, pDb->hWaitSem, uiContainer, uiDrn, 
+		uiCurrTransId, bDontPoisonCache, &uiNumLooks, &pRCache, 
+		&pNewerRCache, &pOlderRCache);
 
 	if (pRCache)
 	{
@@ -2096,6 +2101,7 @@ Start_Find:
 	// because they won't match a NULL FFILE.  The result of not setting
 	// the FFILE is that multiple copies of the same version of a particular
 	// record could end up in cache.
+	
 	pRCache->pFile = pFile;
 
 	flmRcaLinkIntoRCache( pNewerRCache, pOlderRCache, 
@@ -2220,13 +2226,13 @@ Found_Record:
 			}
 
 			pRecord = *ppRecord = pRCache->pRecord;
-			FlmRecordExt::AddRef( pRecord, bRCacheMutexLocked);
+			pRecord->AddRef();
 		}
 	}
 
 	// Clean up cache, if necessary.
 
-	if (gv_FlmSysData.RCacheMgr.pRCacheAlloc->getTotalBytesAllocated() >
+	if (gv_FlmSysData.RCacheMgr.Usage.uiTotalBytesAllocated >
 			 gv_FlmSysData.RCacheMgr.Usage.uiMaxBytes)
 	{
 		flmRcaReduceCache( bRCacheMutexLocked);
@@ -2259,21 +2265,44 @@ Desc:	This routine inserts a record into the record cache.  This is ONLY
 		have been put there by a prior call to FlmRecordModify.
 ****************************************************************************/
 RCODE flmRcaInsertRec(
-	FDB *			pDb,
-	FLMUINT		uiContainer,				// Container record is in.
-	FLMUINT		uiDrn,						// DRN of record
-	FlmRecord *	pRecord)						// Record to be inserted.
+	FDB *				pDb,
+	LFILE *			pLFile,
+	FLMUINT			uiDrn,
+	FlmRecord *		pRecord)
 {
-	RCODE					rc = FERR_OK;
-	FFILE_p				pFile = pDb->pFile;
-	FLMBOOL				bMutexLocked = FALSE;
-	RCACHE *				pRCache;
-	RCACHE *				pNewerRCache;
-	RCACHE *				pOlderRCache;
-	FLMBOOL				bDontPoisonCache = pDb->uiFlags & FDB_DONT_POISON_CACHE
+	RCODE				rc = FERR_OK;
+	FFILE *			pFile = pDb->pFile;
+	FLMUINT			uiContainer = pLFile->uiLfNum;
+	FLMBOOL			bMutexLocked = FALSE;
+	RCACHE *			pRCache;
+	RCACHE *			pNewerRCache;
+	RCACHE *			pOlderRCache;
+	FLMBOOL			bDontPoisonCache = pDb->uiFlags & FDB_DONT_POISON_CACHE
 														? TRUE
 														: FALSE;
 
+	if (pLFile->bMakeFieldIdTable && !pRecord->fieldIdTableEnabled())
+	{
+		
+		// NOTE: createFieldIdTable will call sortFieldIdTable().
+		
+		if (RC_BAD( rc = pRecord->createFieldIdTable( TRUE)))
+		{
+			goto Exit;
+		}
+	}
+	else
+	{
+		pRecord->sortFieldIdTable();
+		if (getFieldIdTableItemCount( pRecord->getFieldIdTbl()) !=
+			 getFieldIdTableArraySize( pRecord->getFieldIdTbl()))
+		{
+			if (RC_BAD( rc = pRecord->truncateFieldIdTable()))
+			{
+				goto Exit;
+			}
+		}
+	}
 	flmAssert( uiDrn != 0);
 	
 	// Lock the mutex
@@ -2296,7 +2325,7 @@ RCODE flmRcaInsertRec(
 
 	// See if we can find the record in cache
 
-	flmRcaFindRec( uiContainer, uiDrn, pFile,
+	flmRcaFindRec( pFile, pDb->hWaitSem, uiContainer, uiDrn,
 						pDb->LogHdr.uiCurrTransID,	bDontPoisonCache, NULL, &pRCache,
 						&pNewerRCache, &pOlderRCache);
 
@@ -2330,25 +2359,11 @@ RCODE flmRcaInsertRec(
 		{
 			// Found latest UNCOMMITTED VERSION - replace it.
 
-#ifdef FLM_CHECK_RECORD
-			if (RC_BAD( rc = pRecord->checkRecord()))
-			{
-				goto Exit;
-			}
-#endif
-
 			if (RC_BAD( rc = pRecord->compressMemory()))
 			{
 				goto Exit;
 			}
 
-#ifdef FLM_CHECK_RECORD
-			if (RC_BAD( rc = pRecord->checkRecord()))
-			{
-				goto Exit;
-			}
-#endif
-
 			// Replace the old record data with the new record data.
 
 			flmRcaSetRecord( pRCache, pRecord);
@@ -2378,27 +2393,13 @@ RCODE flmRcaInsertRec(
 	// We are positioned to insert the new record.  For an update, it
 	// must always be the newest version.
 
-	flmAssert( pNewerRCache == NULL);
-
-#ifdef FLM_CHECK_RECORD
-	if (RC_BAD( rc = pRecord->checkRecord()))
-	{
-		goto Exit;
-	}
-#endif
+	flmAssert( !pNewerRCache);
 
 	if (RC_BAD( rc = pRecord->compressMemory()))
 	{
 		goto Exit;
 	}
 
-#ifdef FLM_CHECK_RECORD
-	if (RC_BAD( rc = pRecord->checkRecord()))
-	{
-		goto Exit;
-	}
-#endif
-
 	// Allocate a new RCACHE structure.
 
 	if (RC_BAD( rc = flmRcaAllocCacheStruct( &pRCache)))
@@ -2455,12 +2456,12 @@ RCODE flmRcaRemoveRec(
 	FLMUINT		uiContainer,
 	FLMUINT		uiDrn)
 {
-	RCODE					rc = FERR_OK;
-	FLMBOOL				bMutexLocked = FALSE;
-	RCACHE *				pRCache;
-	RCACHE *				pNewerRCache;
-	RCACHE *				pOlderRCache;
-	FFILE_p				pFile = pDb->pFile;
+	RCODE			rc = FERR_OK;
+	FLMBOOL		bMutexLocked = FALSE;
+	RCACHE *		pRCache;
+	RCACHE *		pNewerRCache;
+	RCACHE *		pOlderRCache;
+	FFILE *		pFile = pDb->pFile;
 
 	flmAssert( uiDrn != 0);
 
@@ -2484,7 +2485,7 @@ RCODE flmRcaRemoveRec(
 
 	// See if we can find the record in cache
 
-	flmRcaFindRec( uiContainer, uiDrn, pFile,
+	flmRcaFindRec( pFile, pDb->hWaitSem, uiContainer, uiDrn,
 						pDb->LogHdr.uiCurrTransID, FALSE, NULL, &pRCache,
 						&pNewerRCache, &pOlderRCache);
 
@@ -2541,7 +2542,7 @@ Desc:	This routine is called when an FFILE structure is going to be removed
 		of all records that have been cached for that FFILE.
 ****************************************************************************/
 void flmRcaFreeFileRecs(
-	FFILE_p			pFile)
+	FFILE *			pFile)
 {
 	FLMUINT	uiNumFreed = 0;
 
@@ -2576,16 +2577,15 @@ Desc:	This routine is called when an update transaction aborts.  At that
 		the record cache.
 ****************************************************************************/
 void flmRcaAbortTrans(
-	FDB *		pDb
-	)
+	FDB *			pDb)
 {
-	FFILE_p			pFile = pDb->pFile;
-	RCACHE *			pRCache;
-	RCACHE *			pOlderVersion;
-	FLMUINT			uiOlderTransId =
-							pDb->LogHdr.uiCurrTransID - 1;
+	FFILE *		pFile = pDb->pFile;
+	RCACHE *		pRCache;
+	RCACHE *		pOlderVersion;
+	FLMUINT		uiOlderTransId = pDb->LogHdr.uiCurrTransID - 1;
 
 	f_mutexLock( gv_FlmSysData.RCacheMgr.hMutex);
+	
 	pRCache = pFile->pFirstRecord;
 	while (pRCache)
 	{
@@ -2636,6 +2636,7 @@ void flmRcaAbortTrans(
 			break;
 		}
 	}
+	
 	f_mutexUnlock( gv_FlmSysData.RCacheMgr.hMutex);
 }
 
@@ -2645,11 +2646,12 @@ Desc:	This routine is called when an update transaction commits.  At that
 		currently in record cache for the FFILE.
 ****************************************************************************/
 void flmRcaCommitTrans(
-	FDB *		pDb)
+	FDB *			pDb)
 {
-	RCACHE *			pRCache;
+	RCACHE *		pRCache;
 
 	f_mutexLock( gv_FlmSysData.RCacheMgr.hMutex);
+	
 	pRCache = pDb->pFile->pFirstRecord;
 	while (pRCache)
 	{
@@ -2669,6 +2671,7 @@ void flmRcaCommitTrans(
 			break;
 		}
 	}
+	
 	f_mutexUnlock( gv_FlmSysData.RCacheMgr.hMutex);
 }
 
@@ -2678,13 +2681,13 @@ Desc:	This routine is called when a container in the database is deleted.
 		removed from cache.
 ****************************************************************************/
 void flmRcaRemoveContainerRecs(
-	FDB *		pDb,
-	FLMUINT	uiContainer)
+	FDB *			pDb,
+	FLMUINT		uiContainer)
 {
-	FFILE *			pFile = pDb->pFile;
-	RCACHE *			pRCache;
-	RCACHE *			pPrevRCache;
-	FLMUINT			uiTransId = pDb->LogHdr.uiCurrTransID;
+	FFILE *		pFile = pDb->pFile;
+	RCACHE *		pRCache;
+	RCACHE *		pPrevRCache;
+	FLMUINT		uiTransId = pDb->LogHdr.uiCurrTransID;
 
 	f_mutexLock( gv_FlmSysData.RCacheMgr.hMutex);
 	pRCache = gv_FlmSysData.RCacheMgr.pLRURecord;
@@ -2753,6 +2756,7 @@ void flmRcaRemoveContainerRecs(
 		pRCache = pPrevRCache;
 
 	}
+	
 	f_mutexUnlock( gv_FlmSysData.RCacheMgr.hMutex);
 }
 
@@ -2761,9 +2765,9 @@ Desc:
 ****************************************************************************/
 #ifdef FLM_DEBUG
 FSTATIC RCODE flmRcaCheck(
-	FDB_p			pDb,
-	FLMUINT		uiContainer,
-	FLMUINT		uiDrn)
+	FDB *				pDb,
+	FLMUINT			uiContainer,
+	FLMUINT			uiDrn)
 {
 	LFILE *			pLFile;
 	FlmRecord *		pRecord = NULL;
@@ -2789,8 +2793,8 @@ FSTATIC RCODE flmRcaCheck(
 /****************************************************************************
 Desc:	
 ****************************************************************************/
-FLMBOOL FlmRecordExt::canRelocateRec(
-	void *		pvAlloc)
+FLMBOOL F_RecRelocator::canRelocate(
+	void *			pvAlloc)
 {
 	FlmRecord *		pRec = (FlmRecord *)pvAlloc;
 
@@ -2805,9 +2809,9 @@ FLMBOOL FlmRecordExt::canRelocateRec(
 /****************************************************************************
 Desc:	
 ****************************************************************************/
-void FlmRecordExt::relocateRec(
-	void *		pvOldAlloc,
-	void *		pvNewAlloc)
+void F_RecRelocator::relocate(
+	void *			pvOldAlloc,
+	void *			pvNewAlloc)
 {
 	FlmRecord *		pOldRec = (FlmRecord *)pvOldAlloc;
 	FlmRecord *		pNewRec = (FlmRecord *)pvNewAlloc;
@@ -2825,6 +2829,12 @@ void FlmRecordExt::relocateRec(
 		flmAssert( *((FlmRecord **)pOldRec->m_pucBuffer) == pOldRec);
 		*((FlmRecord **)pNewRec->m_pucBuffer) = pNewRec;
 	}
+	
+	if( pNewRec->m_pucFieldIdTable)
+	{
+		flmAssert( *((FlmRecord **)pOldRec->m_pucFieldIdTable) == pOldRec);
+		*((FlmRecord **)pNewRec->m_pucFieldIdTable) = pNewRec;
+	}
 
 	// Find the record
 
@@ -2859,12 +2869,13 @@ Done:
 /****************************************************************************
 Desc:	
 ****************************************************************************/
-FLMBOOL FlmRecordExt::canRelocateRecBuffer(
-	void *		pvAlloc)
+FLMBOOL F_RecBufferRelocator::canRelocate(
+	void *			pvAlloc)
 {
 	FlmRecord *		pRec = *((FlmRecord **)pvAlloc);
 
-	flmAssert( pRec->m_pucBuffer == pvAlloc);
+	flmAssert( pRec->m_pucBuffer == pvAlloc || 
+				  pRec->m_pucFieldIdTable == pvAlloc);
 
 	if( pRec->getRefCount() == 1 && pRec->isCached())
 	{
@@ -2877,27 +2888,37 @@ FLMBOOL FlmRecordExt::canRelocateRecBuffer(
 /****************************************************************************
 Desc:	
 ****************************************************************************/
-void FlmRecordExt::relocateRecBuffer(
-	void *		pvOldAlloc,
-	void *		pvNewAlloc)
+void F_RecBufferRelocator::relocate(
+	void *			pvOldAlloc,
+	void *			pvNewAlloc)
 {
 	FlmRecord *		pRec = *((FlmRecord **)pvOldAlloc);
 
 	flmAssert( pRec->getRefCount() == 1);
 	flmAssert( pRec->isCached());
-	flmAssert( pRec->m_pucBuffer == pvOldAlloc);
 	flmAssert( pvNewAlloc < pvOldAlloc);
 
 	// Update the buffer pointer in the record
 
-	pRec->m_pucBuffer = (FLMBYTE *)pvNewAlloc;
+	if (pRec->m_pucBuffer == pvOldAlloc)
+	{
+		pRec->m_pucBuffer = (FLMBYTE *)pvNewAlloc;
+	}
+	else if (pRec->m_pucFieldIdTable == pvOldAlloc)
+	{
+		pRec->m_pucFieldIdTable = (FLMBYTE *)pvNewAlloc;
+	}
+	else
+	{
+		flmAssert( 0);
+	}
 }
 
 /****************************************************************************
 Desc:		
 Notes:	This routine assumes the rcache mutex is locked
 ****************************************************************************/
-FSTATIC FLMBOOL rcaCanRelocate(
+FLMBOOL F_RCacheRelocator::canRelocate(
 	void *		pvAlloc)
 {
 	RCACHE *		pRCache = (RCACHE *)pvAlloc;
@@ -2916,9 +2937,9 @@ Desc:		Fixes up all pointers needed to allow an RCACHE struct to be
 			moved to a different location in memory
 Notes:	This routine assumes the rcache mutex is locked
 ****************************************************************************/
-FSTATIC void rcaRelocate(
-	void *		pvOldAlloc,
-	void *		pvNewAlloc)
+void F_RCacheRelocator::relocate(
+	void *			pvOldAlloc,
+	void *			pvNewAlloc)
 {
 	RCACHE *			pOldRCache = (RCACHE *)pvOldAlloc;
 	RCACHE *			pNewRCache = (RCACHE *)pvNewAlloc;
@@ -2981,6 +3002,7 @@ FSTATIC void rcaRelocate(
 	}
 	
 	ppBucket = FLM_RCA_HASH( pOldRCache->uiDrn);
+	
 	if( *ppBucket == pOldRCache)
 	{
 		*ppBucket = pNewRCache;
