@@ -22,17 +22,12 @@
 // $Id: flm_edit.h 12334 2006-01-23 12:45:35 -0700 (Mon, 23 Jan 2006) dsanders $
 //-------------------------------------------------------------------------
 
-#ifndef FLM_EDIT_HPP
-#define FLM_EDIT_HPP
+#ifndef FLM_EDIT_H
+#define FLM_EDIT_H
 
 #include "flaim.h"
 
-#ifdef __cplusplus
-	class F_RecEditor;
-	typedef F_RecEditor *	F_RecEditor_p;
-#else
-	typedef void *				F_RecEditor_p;
-#endif
+class F_RecEditor;
 
 #define F_RECEDIT_BUF_SIZE				0x0000FFFF
 #define F_RECEDIT_MAX_TITLE_SIZE		64
@@ -135,8 +130,8 @@ typedef struct
 {
 	char			pucString[ 128];
 	FLMUINT		uiCol;
-	FLMUINT		uiForeground;
-	FLMUINT		uiBackground;
+	eColorType	foreground;
+	eColorType	background;
 } DBE_DISP_COLUMN;
 
 /*
@@ -166,7 +161,7 @@ typedef RCODE (* F_RECEDIT_KEY_HOOK)(
 typedef RCODE (* F_RECEDIT_HELP_HOOK)(
 	F_RecEditor *		pRecEditor,
 	F_RecEditor *		pHelpEditor,
-	POOL *				pPool,
+	F_Pool *				pPool,
 	void *				UserData,
 	NODE **				ppRootNd);
 
@@ -180,20 +175,18 @@ typedef RCODE (* F_RECEDIT_EVENT_HOOK)(
 Class definitions
 */
 
-#ifdef __cplusplus
-
-class F_RecEditor : public F_Base
+class F_RecEditor : public F_Object
 {
 	private:
 
-		F_FileSystem *				m_pFileSystem;
+		IF_FileSystem *			m_pFileSystem;
 		char *						m_pucTmpBuf;
 		F_NameTable *				m_pNameTable;
 		NODE * 						m_pTree;
 		NODE *						m_pCurNd;
 		NODE *						m_pScrFirstNd;
-		POOL							m_scratchPool;
-		POOL							m_treePool;
+		F_Pool						m_scratchPool;
+		F_Pool						m_treePool;
 		HFDB							m_hDefaultDb;
 		FLMUINT						m_uiDefaultCont;
 		FLMUINT						m_uiDefaultStore;
@@ -211,9 +204,9 @@ class F_RecEditor : public F_Base
 		FLMBOOL *					m_pbShutdown;
 		FLMBOOL						m_bOwnNameTable;
 		FLMBOOL						m_bMonochrome;
-		FTX_SCREEN_p				m_pScreen;
-		FTX_WINDOW_p				m_pEditWindow;
-		FTX_WINDOW_p				m_pEditStatusWin;
+		FTX_SCREEN *				m_pScreen;
+		FTX_WINDOW *				m_pEditWindow;
+		FTX_WINDOW *				m_pEditStatusWin;
 		F_RecEditor *				m_pParent;
 		F_RecEditor *				m_pNameList;
 		F_RECEDIT_DISP_HOOK		m_pDisplayHook;
@@ -263,7 +256,7 @@ class F_RecEditor : public F_Base
 			FLMBOOL *		pbModified);
 
 		RCODE editBinaryNode(
-			FTX_WINDOW_p		pWindow,
+			FTX_WINDOW *		pWindow,
 			NODE *				pNd,
 			FLMBOOL *			pbModified);
 
@@ -355,7 +348,7 @@ class F_RecEditor : public F_Base
 		void reset( void);
 
 		RCODE Setup(
-			FTX_SCREEN_p	pScreen);
+			FTX_SCREEN *	pScreen);
 
 		void setParent(
 			F_RecEditor *	pParent);
@@ -408,12 +401,12 @@ class F_RecEditor : public F_Base
 			FLMBOOL		bReadOnly);
 
 		RCODE copyCleanRecord(
-			POOL *		pPool,
+			F_Pool *		pPool,
 			NODE *		pRecNd,
 			NODE **		ppCopiedRec);
 
 		RCODE copyCleanTree(
-			POOL *		pPool,
+			F_Pool *		pPool,
 			NODE *		pTreeNd,
 			NODE **		ppCopiedTree);
 
@@ -425,7 +418,7 @@ class F_RecEditor : public F_Base
 			FLMBOOL		bBorder = TRUE,
 			FLMBOOL		bStatus = TRUE);
 
-		FTX_SCREEN_p getScreen( void);
+		FTX_SCREEN * getScreen( void);
 
 		FLMBOOL isMonochrome( void);
 
@@ -525,7 +518,7 @@ class F_RecEditor : public F_Base
 		
 		FLMUINT getLastKey( void);
 		
-		F_FileSystem * getFileSystem( void);
+		IF_FileSystem * getFileSystem( void);
 
 		RCODE getNumber(
 			const char *	pucBuf,
@@ -608,7 +601,7 @@ class F_RecEditor : public F_Base
 			FLMUINT *		puiTermChar);
 
 		RCODE copyBuffer(
-			POOL *			pPool,
+			F_Pool *			pPool,
 			NODE *			pStartNd,
 			NODE **			ppNewTree);
 
@@ -616,19 +609,19 @@ class F_RecEditor : public F_Base
 			const char *	pucMessage,
 			RCODE				rcOfMessage,
 			FLMUINT *		puiTermChar,
-			FLMUINT			uiBackground,
-			FLMUINT			uiForeground);
+			eColorType		background,
+			eColorType		foreground);
 
 		RCODE globalConfig(
 			FLMUINT			uiOption);
 
 		RCODE createStatusWindow(
 			const char *	pucTitle,
-			FLMUINT			uiBack,
-			FLMUINT			uiFore,
+			eColorType		back,
+			eColorType		fore,
 			FLMUINT *		puiCols,
 			FLMUINT *		puiRows,
-			FTX_WINDOW_pp	ppWindow);
+			FTX_WINDOW **	ppWindow);
 
 		RCODE asciiUCMixToUC(
 			char *			pucAscii,
@@ -655,20 +648,20 @@ class F_RecEditor : public F_Base
 		RCODE openNewDb();
 };
 
-inline void F_RecEditor::setShutdown(
+FINLINE void F_RecEditor::setShutdown(
 	FLMBOOL *		pbShutdown)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	m_pbShutdown = pbShutdown;
 }
 
-inline FLMBOOL * F_RecEditor::getShutdown( void)
+FINLINE FLMBOOL * F_RecEditor::getShutdown( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_pbShutdown);
 }
 
-inline FLMBOOL F_RecEditor::isExiting( void)
+FINLINE FLMBOOL F_RecEditor::isExiting( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	if( m_pbShutdown && *m_pbShutdown)
@@ -679,13 +672,13 @@ inline FLMBOOL F_RecEditor::isExiting( void)
 	return( FALSE);
 }
 
-inline FLMBOOL F_RecEditor::isMonochrome( void)
+FINLINE FLMBOOL F_RecEditor::isMonochrome( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_bMonochrome);
 }
 
-inline RCODE F_RecEditor::setNameTable(
+FINLINE RCODE F_RecEditor::setNameTable(
 	F_NameTable *			pNameTable)
 {
 	flmAssert( m_bSetupCalled == TRUE);
@@ -701,99 +694,99 @@ inline RCODE F_RecEditor::setNameTable(
 	return( FERR_OK);
 }
 
-inline void F_RecEditor::setParent(
+FINLINE void F_RecEditor::setParent(
 	F_RecEditor *		pParent)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	m_pParent = pParent;
 }
 
-inline F_RecEditor * F_RecEditor::getParentEditor( void)
+FINLINE F_RecEditor * F_RecEditor::getParentEditor( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_pParent);
 }
 
-inline void F_RecEditor::setReadOnly(
+FINLINE void F_RecEditor::setReadOnly(
 	FLMBOOL		bReadOnly)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	m_bReadOnly = bReadOnly;
 }
 
-inline NODE * F_RecEditor::getTree( void)
+FINLINE NODE * F_RecEditor::getTree( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_pTree);
 }
 
-inline NODE * F_RecEditor::getCurrentNode( void)
+FINLINE NODE * F_RecEditor::getCurrentNode( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_pCurNd);
 }
 
-inline NODE * F_RecEditor::getFirstNode( void)
+FINLINE NODE * F_RecEditor::getFirstNode( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_pScrFirstNd);
 }
 
-inline FLMUINT F_RecEditor::getCursorRow( void)
+FINLINE FLMUINT F_RecEditor::getCursorRow( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_uiCurRow);
 }
 
-inline FLMUINT F_RecEditor::getNumRows( void)
+FINLINE FLMUINT F_RecEditor::getNumRows( void)
 {
 	flmAssert( m_bSetupCalled == TRUE && m_pEditWindow != NULL);
 	return( m_uiEditCanvasRows);
 }
 
-inline HFDB F_RecEditor::getDb( void)
+FINLINE HFDB F_RecEditor::getDb( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_hDefaultDb);
 }
 
-inline FLMUINT F_RecEditor::getContainer( void)
+FINLINE FLMUINT F_RecEditor::getContainer( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_uiDefaultCont);
 }
 
-inline FTX_SCREEN_p F_RecEditor::getScreen( void)
+FINLINE FTX_SCREEN * F_RecEditor::getScreen( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_pScreen);
 }
 
-inline FLMUINT F_RecEditor::getLastKey( void)
+FINLINE FLMUINT F_RecEditor::getLastKey( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_uiLastKey);
 }
 
-inline FLMUINT F_RecEditor::getULX( void)
+FINLINE FLMUINT F_RecEditor::getULX( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_uiULX);
 }
 
-inline FLMUINT F_RecEditor::getULY( void)
+FINLINE FLMUINT F_RecEditor::getULY( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_uiULY);
 }
 
-inline F_FileSystem * F_RecEditor::getFileSystem( void)
+FINLINE IF_FileSystem * F_RecEditor::getFileSystem( void)
 {
 	flmAssert( m_bSetupCalled == TRUE);
 	return( m_pFileSystem);
 }
 
-inline void F_RecEditor::setDisplayHook(
+FINLINE void F_RecEditor::setDisplayHook(
 	F_RECEDIT_DISP_HOOK		pDispHook,
 	void *						DispData)
 {
@@ -802,7 +795,7 @@ inline void F_RecEditor::setDisplayHook(
 	m_DisplayData = DispData;
 }
 
-inline void F_RecEditor::setLinkHook(
+FINLINE void F_RecEditor::setLinkHook(
 	F_RECEDIT_LINK_HOOK		pLinkHook,
 	void *						LinkData)
 {
@@ -811,7 +804,7 @@ inline void F_RecEditor::setLinkHook(
 	m_LinkData = LinkData;
 }
 
-inline void F_RecEditor::setKeyHook(
+FINLINE void F_RecEditor::setKeyHook(
 	F_RECEDIT_KEY_HOOK		pKeyHook,
 	void *						KeyData)
 {
@@ -820,7 +813,7 @@ inline void F_RecEditor::setKeyHook(
 	m_KeyData = KeyData;
 }
 
-inline void F_RecEditor::setHelpHook(
+FINLINE void F_RecEditor::setHelpHook(
 	F_RECEDIT_HELP_HOOK		pHelpHook,
 	void *						HelpData)
 {
@@ -829,7 +822,7 @@ inline void F_RecEditor::setHelpHook(
 	m_HelpData = HelpData;
 }
 
-inline void F_RecEditor::setEventHook(
+FINLINE void F_RecEditor::setEventHook(
 	F_RECEDIT_EVENT_HOOK		pEventHook,
 	void *						EventData)
 {
@@ -872,5 +865,4 @@ RCODE f_RecEditorFileKeyHook(
 	void *				UserData,
 	FLMUINT *			puiKeyOut);
 
-#endif	// __cplusplus
-#endif	// FLM_EDIT_HPP
+#endif	// FLM_EDIT_H
