@@ -24,11 +24,11 @@
 
 #include "flm_dlst.h"
 
-RCODE flstIndexManagerThread(
-	F_Thread *		pThread);
+RCODE FLMAPI flstIndexManagerThread(
+	IF_Thread *		pThread);
 
-RCODE flstMemoryManagerThread(
-	F_Thread *		pThread);
+RCODE FLMAPI flstMemoryManagerThread(
+	IF_Thread *		pThread);
 
-RCODE flstTrackerMonitorThread(
-	F_Thread *		pThread);
+RCODE FLMAPI flstTrackerMonitorThread(
+	IF_Thread *		pThread);
