@@ -25,34 +25,11 @@
 
 #include "flmunittest.h"
 
-#if defined( FLM_WIN)
-	#if defined( FLM_64BIT)
-		#define PLATPROC_STR		"w64ia64"
-	#else
-		#define PLATPROC_STR		"w32x86"
-	#endif
-#elif defined( FLM_NLM)
-	#define PLATPROC_STR			"nwx86"
-#elif defined( FLM_LINUX)
-	#define PLATPROC_STR			"lxx86"
-#elif defined( FLM_OSX)
-	#define PLATPROC_STR			"osx"
-#elif defined( FLM_SOLARIS)
-	#define PLATPROC_STR			"solaris"
-#endif
-
 extern RCODE getTest( 
 	IFlmTest **		ppTest);
-
-#ifdef FLM_NLM
-	extern "C"
-	{
-		void flmUnittestFatalRuntimeError( void);
 	
-		int flmUnittestLoad( void);
-		
-		int flmUnittestUnload( void);
-	}
+#ifndef FLM_NLM
+	#define f_conPrintf				f_printf
 #endif
 
 FLMBOOL gv_bShutdown = FALSE;
@@ -65,7 +42,6 @@ struct TEST_INFO
 	bool 				bLog;
 	char 				pszLogfile[ 256];
 	bool 				bDisplay;
-	bool 				bVerboseDisplay;
 	char 				pszEnvironment[ 32];
 	char 				pszBuild[ 32];
 	char 				pszUser[ 32];
@@ -76,12 +52,11 @@ struct TEST_INFO
 	{
 		bLog = FALSE;
 		bDisplay = FALSE;
-		bVerboseDisplay = FALSE;
 		pNext = NULL;
 		pszLogfile[ 0] = 0;
 		pszConfig[ 0] = 0;
 		
-		f_strcpy( pszEnvironment, PLATPROC_STR);
+		f_strcpy( pszEnvironment, FLM_OSTYPE_STR);
 		f_strcpy( pszBuild, __DATE__);
 		f_strcpy( pszUser, "defaultUser");
 	}
@@ -122,14 +97,12 @@ ITestReporter::~ITestReporter()
 Desc:
 ****************************************************************************/
 RCODE ITestReporter::recordUnitTestResults(
-	const char *		testName,
-	const char *		testDescr,
-	const char *		steps,
-	const char *		status,
-	const char *		resultDetails)
+	const char *	pszTestName,
+	FLMBOOL			bPassed,
+	const char *	pszFailInfo)
 {
-	return ::recordUnitTestResults( &(this->m_uTD), testName, testDescr,
-		steps, status, resultDetails);
+	return ::recordUnitTestResults( &(this->m_uTD), pszTestName, bPassed,
+						pszFailInfo);
 }
 
 /****************************************************************************
@@ -195,11 +168,7 @@ Desc:
 void IFlmTestDisplayer::appendString( 
 	const char * 	pszString)
 {
-#ifdef FLM_NLM
-	F_UNREFERENCED_PARM( pszString);
-#else
-	printf( pszString);
-#endif
+	f_conPrintf( pszString);
 }
 
 /****************************************************************************
@@ -207,21 +176,19 @@ Desc:
 ****************************************************************************/
 void printHelp()
 {
-#ifndef FLM_NLM
-	printf( "\nCommand-line usage:");
-	printf( "\n\n[-l<log file>] [-d]");
-	printf( "[-c<config>] [-b<build>] [-u<user>]");
-	printf( "\n-l - Specifies a log file to print to");
-	printf( "\n-d - Display output");
-	printf( "\n-t - Specifies configuration file for reporting");
-	printf( "\n-b - Specifies the build number");
-	printf( "\n-u - Specifies the user running the unit test");
-	printf( "\n-i - Interactive mode (pause before exit)");
-	printf( "\n-h - Shows this screen");
-#endif
+	f_conPrintf( "\nCommand-line usage:");
+	f_conPrintf( "\n\n[-l<log file>] [-d]");
+	f_conPrintf( "[-c<config>] [-b<build>] [-u<user>]");
+	f_conPrintf( "\n-l - Specifies a log file to print to");
+	f_conPrintf( "\n-d - Display output");
+	f_conPrintf( "\n-t - Specifies configuration file for reporting");
+	f_conPrintf( "\n-b - Specifies the build number");
+	f_conPrintf( "\n-u - Specifies the user running the unit test");
+	f_conPrintf( "\n-i - Interactive mode (pause before exit)");
+	f_conPrintf( "\n-h - Shows this screen");
 }
 
-#if defined( FLM_NLM)
+#if defined( FLM_RING_ZERO_NLM)
 	#define main		nlm_main
 	
 	extern "C"
@@ -242,9 +209,23 @@ int main(
 	RCODE				rc = FERR_OK;
 	IFlmTest *		pTest = NULL;
 	unsigned int	i = 1;
-	ArgList			args;
+	ArgList *		pArgs = NULL;
 	TEST_INFO		testInfo;
-	FLMBOOL			bPauseBeforeExit = FALSE;
+	
+	if( RC_BAD( rc = FlmStartup()))
+	{
+		goto Exit;
+	}
+	
+	if( (pArgs = f_new ArgList) == NULL)
+	{
+		rc = RC_SET( FERR_MEM);
+		goto Exit;
+	}
+	
+#ifdef FLM_NLM
+	f_conInit( 0, 0, "FLAIM Unit Test");
+#endif	
 
 	if( argc > 1)
 	{
@@ -256,75 +237,59 @@ int main(
 		}
 	}
 
-	args.expandArgs( argv, argc);
+	pArgs->expandArgs( argv, argc);
 
-	while( i < args.getNumEntries())
+	while( i < pArgs->getNumEntries())
 	{
-		if ( args[i][0] != '-')
+		if( (*pArgs)[i][0] != '-')
 		{
 			goto Exit;
 		}
 				
-		if( (args[i][1] == 'l') || (args[i][1] == 'L'))
+		if( ((*pArgs)[i][1] == 'l') || ((*pArgs)[i][1] == 'L'))
 		{
 			testInfo.bLog = true;
-			f_strcpy( testInfo.pszLogfile, &args[i][2]);
+			f_strcpy( testInfo.pszLogfile, &((*pArgs)[i][2]));
 		}
-		else if( (args[i][1] == 'd') || (args[i][1] == 'D'))
+		else if( ((*pArgs)[i][1] == 'd') || ((*pArgs)[i][1] == 'D'))
 		{
 			testInfo.bDisplay = true;
 		}
-		else if( (args[i][1] == 'c') || (args[i][1] == 'C'))
+		else if( ((*pArgs)[i][1] == 'c') || ((*pArgs)[i][1] == 'C'))
 		{
-			f_strcpy( testInfo.pszConfig, &args[i][2]);
+			f_strcpy( testInfo.pszConfig, &((*pArgs)[i][2]));
 		}
-		else if( (args[i][1] == 'b') || (args[i][1] == 'B'))
+		else if( ((*pArgs)[i][1] == 'b') || ((*pArgs)[i][1] == 'B'))
 		{
-			f_strcpy( testInfo.pszBuild, &args[i][2]);
+			f_strcpy( testInfo.pszBuild, &((*pArgs)[i][2]));
 		}
-		else if( (args[i][1] == 'u') || (args[i][1] == 'U'))
+		else if( ((*pArgs)[i][1] == 'u') || ((*pArgs)[i][1] == 'U'))
 		{
-			f_strcpy( testInfo.pszUser, &args[i][2]);
+			f_strcpy( testInfo.pszUser, &((*pArgs)[i][2]));
 		}
-		else if( (args[i][1] == 'v') || (args[i][1] == 'V'))
-		{
-			testInfo.bVerboseDisplay = TRUE;
-		}
-		else if( (args[i][1] == 'i') || (args[i][1] == 'I'))
-		{
-			bPauseBeforeExit = TRUE;
-		}		
 		else
 		{
-#ifndef FLM_NLM
-			printf( "\nInvalid parameter");
+			f_conPrintf( "\nInvalid parameter");
 			printHelp();
-#endif
 			goto Exit;
 		}
 		
 		i++;
 	}
 
-#ifndef FLM_NLM
-	printf("Running %s\n", argv[0]);
-#endif
+	f_conPrintf( "Running %s\n", argv[0]);
 
 	if( RC_BAD( rc = getTest( &pTest)))
 	{
-#ifndef FLM_NLM
-		printf( "ERROR: Unable to create test instance\n");
-#endif
+		f_conPrintf( "ERROR: Unable to create test instance\n");
 		goto Exit;
 	}
 
 	if( pTest->init( testInfo.bLog, testInfo.pszLogfile, testInfo.bDisplay,
-		testInfo.bVerboseDisplay, testInfo.pszConfig, testInfo.pszEnvironment,
+		testInfo.pszConfig, testInfo.pszEnvironment,
 		testInfo.pszBuild, testInfo.pszUser) != 0)
 	{
-#ifndef FLM_NLM
-		printf( "\nTest initialization failed");
-#endif
+		f_conPrintf( "\nTest initialization failed");
 		goto Exit;
 	}
 
@@ -332,21 +297,28 @@ int main(
 	{
 		goto Exit;
 	}
-
+	
 Exit:
 
 	if( pTest)
 	{
 		pTest->Release();
 	}
-
-	if( bPauseBeforeExit)
+	
+	if( pArgs)
 	{
-#ifndef FLM_NLM
-		printf( "Press any key to exit.\n");
-		getchar();
-#endif
+		pArgs->Release();
 	}
+	
+#ifdef FLM_NLM
+	f_conPrintf( "\nPress any key to exit ... ");
+	f_conGetKey();
+#endif
+
+#ifdef FLM_NLM
+	f_conExit();
+#endif
+	FlmShutdown();
 
 	return( (int)rc);
 }
@@ -608,19 +580,21 @@ void FlagSet::init(
 Desc:
 ****************************************************************************/
 RCODE createUnitTest(
-	const char *	configPath, 
-	const char *	buildNum, 
-	const char *	environment,  
-	const char *	user, 
-	unitTestData *	uTD)
+	const char *		configPath, 
+	const char *		buildNum, 
+	const char *		environment,  
+	const char *		user, 
+	unitTestData *		uTD)
 {
-	RCODE				rc = FERR_OK;
-	F_FileHdl *		pConfigFileHdl = NULL;
-	F_FileHdl *		pCSVFileHdl = NULL;
-	FLMBYTE			buffer[ MAX_BUFFER_SIZE] = "";
-	FLMUINT			size = MAX_BUFFER_SIZE;
-	char *			strPos1 = NULL;
-	char *			strPos2 = NULL;
+	RCODE					rc = FERR_OK;
+	IF_FileHdl *		pConfigFileHdl = NULL;
+	IF_FileHdl *		pCSVFileHdl = NULL;
+	FLMBYTE				buffer[ MAX_BUFFER_SIZE] = "";
+	FLMUINT				uiSize = MAX_BUFFER_SIZE;
+	FLMUINT64			ui64Tmp;
+	char *				strPos1 = NULL;
+	char *				strPos2 = NULL;
+	IF_FileSystem *	pFileSystem = NULL;
 
 	if( !configPath || !buildNum || !environment || !uTD || !user)
 	{
@@ -657,43 +631,45 @@ RCODE createUnitTest(
 		f_strcpy( uTD->buildNumber, buildNum);
 	}
 	
+	if( RC_BAD( rc = FlmGetFileSystem( &pFileSystem)))
+	{
+		goto Exit;
+	}
+	
 	if( configPath[ 0])
 	{
-		if( RC_BAD( rc = FlmAllocFileHandle( &pConfigFileHdl)))
-		{
-			goto Exit;
-		}
-		
-		if( RC_BAD( rc = pConfigFileHdl->Open(
-			configPath, F_IO_RDONLY | F_IO_SH_DENYNONE)))
+		if( RC_BAD( rc = pFileSystem->openFile(
+			configPath, FLM_IO_RDONLY | FLM_IO_SH_DENYNONE, &pConfigFileHdl)))
 		{
 			goto Exit;
 		}
 	
-		if( RC_BAD( rc = pConfigFileHdl->Size( &size)))
+		if( RC_BAD( rc = pConfigFileHdl->size( &ui64Tmp)))
 		{
 			goto Exit;
 		}
 		
-		if( RC_BAD( rc = pConfigFileHdl->Read( 0, size, buffer, &size)))
+		uiSize = (FLMUINT)ui64Tmp;
+		
+		if( RC_BAD( rc = pConfigFileHdl->read( 0, uiSize, buffer, &uiSize)))
 		{
 			goto Exit;
 		}
 	
 		#ifdef FLM_WIN
 		{
-			char		szTemp[ MAX_BUFFER_SIZE];
-			char *	pszTemp = szTemp;
-			size_t	newsize = size;
+			char			szTemp[ MAX_BUFFER_SIZE];
+			char *		pszTemp = szTemp;
+			FLMUINT		uiNewSize = uiSize;
 		
-			for( unsigned int i = 0; i < size; i++)
+			for( unsigned int i = 0; i < uiSize; i++)
 			{
-				if( ((i + 1) < size) 
+				if( ((i + 1) < uiSize) 
 					&& (buffer[i] == 0x0D && buffer[ i + 1] == 0x0A))
 				{
 					*pszTemp++ = 0x0A;
 					i++;
-					newsize--;
+					uiNewSize--;
 				}
 				else
 				{
@@ -701,8 +677,8 @@ RCODE createUnitTest(
 				}
 			}
 				
-			f_memcpy( buffer, szTemp, (FLMSIZET)newsize);
-			size = newsize;
+			f_memcpy( buffer, szTemp, uiNewSize);
+			uiSize = uiNewSize;
 		}
 		#endif
 		
@@ -779,13 +755,8 @@ RCODE createUnitTest(
 		f_strncpy( uTD->csvFilename, strPos1, strPos2-strPos1);
 		uTD->csvFilename[ strPos2 - strPos1] = '\0';
 
-		if( RC_BAD( rc = FlmAllocFileHandle( &pCSVFileHdl)))
-		{
-			goto Exit;
-		}
-		
-		if( RC_BAD( rc = pCSVFileHdl->Open( uTD->csvFilename,
-			F_IO_RDWR | F_IO_SH_DENYNONE)))
+		if( RC_BAD( rc = pFileSystem->openFile( uTD->csvFilename,
+			FLM_IO_RDWR | FLM_IO_SH_DENYNONE, &pCSVFileHdl)))
 		{
 			if ( rc == FERR_IO_PATH_NOT_FOUND)
 			{
@@ -815,6 +786,11 @@ Exit:
 		pCSVFileHdl->Release();
 	}
 	
+	if( pFileSystem)
+	{
+		pFileSystem->Release();
+	}
+	
 	return( rc);
 }
 
@@ -822,33 +798,27 @@ Exit:
 Desc:	After each unit test call this to record the unit test status
 		to a CSV file.
 			uTD - contains the configuration information
-			testName - a Unique for this module unite test name.
-			testDescr - A description of the unit test.
-			steps - The steps the unit test performs.
-			status - Maybe be PASS or FAIL
-			resultDetails - details that explain the result status.
+			pszTestName - a unique name for this unit test.
+			bPassed - Did unit test pass?
+			pszFailInfo - If unit test failed, reason is here
 ****************************************************************************/
 RCODE recordUnitTestResults(
 	unitTestData *		uTD, 
-	const char *		testName, 
-	const char *		testDescr, 
-	const char *		steps, 
-	const char *		status, 
-	const char *		resultDetails) 
+	const char *		pszTestName, 
+	FLMBOOL				bPassed,
+	const char *		pszFailInfo) 
 {
 	RCODE		rc = FERR_OK;
 	char		buffer[ MAX_BUFFER_SIZE];
 	
-	if( !testName || !testDescr || !steps || !status || !resultDetails || !uTD )
-	{
-		flmAssert(0);
-	}
+	flmAssert( pszTestName && uTD);
 
 	if( uTD->csvFilename[ 0])
 	{
 		f_sprintf( buffer, "%s,%s,%s,%s,%s,%s,%s,%s,"/*%s,*/"%s,%s\n", 
-			testName, uTD->userName, testDescr, steps, uTD->buildNumber, status, 
-			uTD->environment, resultDetails, uTD->attrs, uTD->folder);
+			pszTestName, uTD->userName, pszTestName, pszTestName, uTD->buildNumber,
+			(const char *)(bPassed ? "PASS" : "FAIL"), 
+			uTD->environment, pszFailInfo, uTD->attrs, uTD->folder);
 
 		if( RC_BAD( rc = f_filecat( uTD->csvFilename, buffer)))
 		{
@@ -868,7 +838,6 @@ RCODE TestBase::init(
 	FLMBOOL			bLog,
 	const char *	pszLogfile,
 	FLMBOOL			bDisplay,
-	FLMBOOL			bVerboseDisplay,
 	const char *	pszConfigFile,
 	const char *	pszEnvironment,
 	const char *	pszBuild,
@@ -876,11 +845,6 @@ RCODE TestBase::init(
 {
 	RCODE		rc = FERR_MEM;
 
-	if( RC_BAD( rc = FlmStartup()))
-	{
-		goto Exit;
-	}
-	
 	// VISIT: here -- disable asserts on FLAIM errors via a config call!!!
 
 	m_bLog = bLog;
@@ -927,7 +891,6 @@ RCODE TestBase::init(
 	{
 		goto Exit;
 	}
-	m_bDisplayVerbose = bVerboseDisplay;
 
 Exit:
 
@@ -938,48 +901,12 @@ Exit:
 Desc:
 ****************************************************************************/
 void TestBase::beginTest( 
-	const char * 	pszTestName, 
-	const char * 	pszTestDesc,
-	const char * 	pszTestSteps,
-	const char * 	pszDetails)
+	const char * 	pszTestName) 
 {
-	char		szTemp[ 256];
-
 	m_pszTestName = pszTestName;
-	m_pszTestDesc = pszTestDesc;
-	m_pszSteps = pszTestSteps;
-
-	if( m_bDisplayVerbose)
-	{
-		displayLine(
-			"========================================"
-			"=======================================");
-			
-		f_sprintf( szTemp, "Test Name: %s", m_pszTestName);
-		displayLine( szTemp);
-		
-		f_sprintf( szTemp, "Test Description: %s", m_pszTestDesc);
-		displayLine( szTemp);
-		
-		f_sprintf( szTemp, "Steps: %s", m_pszSteps);
-		displayLine( szTemp);
-	}
-	else
-	{
-		f_sprintf( szTemp, "Test Name: %s ... ", m_pszTestName);
-		display( szTemp);
-	}
-
-	f_strcpy( m_szDetails, pszDetails);
-}
-
-/****************************************************************************
-Desc:
-****************************************************************************/
-void TestBase::endTest( 
-	const char * 	pszTestResult)
-{
-	outputAll( pszTestResult);
+	display( m_pszTestName);
+	display( " ... ");
+	m_uiStartTime = FLM_GET_TIMER();
 }
 
 /****************************************************************************
@@ -1065,7 +992,7 @@ RCODE TestBase::openTestState(
 	RCODE					rc = FERR_OK;
 	CREATE_OPTS			createOpts;
 
-	if( RC_BAD( rc = gv_FlmSysData.pFileSystem->Exists( pszDibName)))
+	if( RC_BAD( rc = gv_FlmSysData.pFileSystem->doesFileExist( pszDibName)))
 	{
 		// Create the database
 
@@ -1123,119 +1050,68 @@ Exit:
 /****************************************************************************
 Desc:
 ****************************************************************************/
-RCODE TestBase::logTestResults(
-	const char * 	pszTestResult)
+void TestBase::logTestResults(
+	FLMBOOL	bPassed)
 {
-	RCODE			rc = FERR_OK;
-	char *		pszTemp = NULL;
+	char	szMsg [300];
 
-	if( RC_BAD( rc = f_alloc( DETAILS_BUF_SIZ + 64, &pszTemp)))
+	if (m_bLog)
 	{
-		goto Exit;
+		log( "===============================================================================");
+				
+		f_sprintf( szMsg, "Test Name: %s", m_pszTestName);
+		log( szMsg);
+		
+		f_sprintf( szMsg, "Test Result: %s", (char *)(bPassed ? "PASS" : "FAIL"));
+		log( szMsg);
+	
+		if (!bPassed)
+		{
+			log( m_szFailInfo);
+		}
+		
+		log( "===============================================================================");
 	}
-
-	log(
-			"========================================"
-			"=======================================");
-			
-	f_sprintf( pszTemp, "Test Name: %s", m_pszTestName);
-	log( pszTemp);
-	
-	f_sprintf( pszTemp, "Test Description: %s", m_pszTestDesc);
-	log( pszTemp);
-	
-	f_sprintf( pszTemp, "Steps: %s", m_pszSteps);
-	log( pszTemp);
-	
-	f_sprintf( pszTemp, "Test Result: %s", pszTestResult);
-	log( pszTemp);
-	
-	f_sprintf( pszTemp, "Details: %s", m_szDetails);
-	log( pszTemp);
-	
-	log(
-			"========================================"
-			"=======================================");
-
-Exit:
-
-	if( pszTemp)
-	{
-		f_free( &pszTemp);
-	}
-	
-	return( rc);
 }
 
 /****************************************************************************
 Desc:
 ****************************************************************************/
-RCODE TestBase::displayTestResults(
-	const char *	pszTestResult)
+void TestBase::displayTestResults(
+	FLMBOOL	bPassed,
+	FLMUINT	uiElapsedMilli)
 {
-	RCODE			rc = FERR_OK;
-	char *		pszTemp = NULL;
+	char		szResult [60];
 
-	if( RC_BAD( rc = f_alloc( DETAILS_BUF_SIZ + 64, &pszTemp)))
+	f_sprintf( szResult, "%s (%u.%03u secs)",
+		(char *)(bPassed ? (char *)"PASS" : (char *)"FAIL"),
+		(unsigned)(uiElapsedMilli / 1000), (unsigned)(uiElapsedMilli % 1000));
+	
+	displayLine( szResult);
+	if (!bPassed)
 	{
-		goto Exit;
+		displayLine( m_szFailInfo);
 	}
-
-	if( m_bDisplayVerbose)
-	{
-		f_sprintf( pszTemp, "Test Result: %s", pszTestResult);
-		displayLine( pszTemp);
-		
-		f_sprintf( pszTemp, "Details: %s", m_szDetails);
-		displayLine( pszTemp);
-		
-		displayLine(
-			"========================================"
-			"=======================================");
-	}
-	else
-	{
-		f_sprintf( pszTemp, "Result: %s", pszTestResult);
-		displayLine( pszTestResult);
-	}
-
-Exit:
-
-	if( pszTemp)
-	{
-		f_free( &pszTemp);
-	}
-
-	return( rc);
 }
 
 /****************************************************************************
 Desc:
 ****************************************************************************/
-RCODE TestBase::outputAll( 
-	const char * 	pszTestResult)
+void TestBase::endTest(
+	FLMBOOL	bPassed)
 {
-	RCODE			rc = FERR_OK;
+	FLMUINT	uiEndTime = FLM_GET_TIMER();
+	FLMUINT	uiElapsedMilli = FLM_TIMER_UNITS_TO_MILLI( 
+										FLM_ELAPSED_TIME( uiEndTime, m_uiStartTime));
 
-	if( RC_BAD( rc = displayTestResults( pszTestResult)))
+	displayTestResults( bPassed, uiElapsedMilli);
+	if (m_bLog)
 	{
-		goto Exit;
+		logTestResults( bPassed);
 	}
 
-	if( RC_BAD( rc = logTestResults( pszTestResult)))
-	{
-		goto Exit;
-	}
-
-	if( RC_BAD( rc = m_pReporter->recordUnitTestResults(
-		m_pszTestName, m_pszTestDesc, m_pszSteps, pszTestResult, m_szDetails)))
-	{
-		goto Exit;
-	}
-
-Exit:
-
-	return( rc);
+	(void)m_pReporter->recordUnitTestResults(
+		m_pszTestName, bPassed, m_szFailInfo);
 }
 
 /****************************************************************************
@@ -1271,7 +1147,6 @@ ArgList::ArgList()
 {
 	m_uiCapacity = INIT_SIZE;
 	m_uiNumEntries = 0;
-	
 	f_alloc( m_uiCapacity * sizeof( char *), &m_ppszArgs);
 }
 
@@ -1286,7 +1161,7 @@ ArgList::~ArgList()
 	{
 		for( uiLoop = 0; uiLoop < m_uiNumEntries; uiLoop++)
 		{
-			f_free( &( m_ppszArgs[uiLoop]));
+			f_free( &m_ppszArgs[ uiLoop]);
 		}
 		
 		f_free( &m_ppszArgs);
@@ -1312,8 +1187,8 @@ RCODE ArgList::resize( void)
 	
 	for( uiLoop = 0; uiLoop < m_uiNumEntries; uiLoop++)
 	{
-		if( RC_BAD( rc = f_alloc( f_strlen( m_ppszArgs[uiLoop]) + 1, 
-			&ppszTemp[uiLoop])))
+		if( RC_BAD( rc = f_alloc( f_strlen( m_ppszArgs[ uiLoop]) + 1, 
+			&ppszTemp[ uiLoop])))
 		{
 			f_free( &ppszTemp);
 			goto Exit;
@@ -1355,7 +1230,7 @@ RCODE ArgList::addArg(
 	}
 
 	if( RC_BAD( rc = f_alloc( f_strlen( pszArg) + 1,
-		&m_ppszArgs[m_uiNumEntries])))
+		&m_ppszArgs[ m_uiNumEntries])))
 	{
 		goto Exit;
 	}
@@ -1384,10 +1259,10 @@ RCODE ArgList::expandFileArgs(
 {
 	RCODE				rc = FERR_OK;
 	char				token[64];
-	F_FileHdl *		pFileHdl = NULL;
+	IF_FileHdl *	pFileHdl = NULL;
 
-	if( RC_BAD( rc = gv_FlmSysData.pFileSystem->Open(
-		pszFilename, F_IO_RDWR, &pFileHdl)))
+	if( RC_BAD( rc = gv_FlmSysData.pFileSystem->openFile(
+		pszFilename, FLM_IO_RDWR, &pFileHdl)))
 	{
 		goto Exit;
 	}
@@ -1472,19 +1347,19 @@ Desc:
 ****************************************************************************/
 RCODE ArgList::getTokenFromFile(
 	char * 			pszToken,
-	F_FileHdl * 	pFileHdl)
+	IF_FileHdl * 	pFileHdl)
 {
 	RCODE			rc = FERR_OK;
 	FLMUINT		uiSize = 1;
-	FLMUINT		uiOffset = 0;
-	FLMUINT		uiTrueOffset = 0;
+	FLMUINT64	ui64Offset = 0;
+	FLMUINT64	ui64TrueOffset = 0;
 	char			c;
 
 	for(;;)
 	{
 Skip_WS_And_Comments:
 
-		if ( RC_BAD( rc = pFileHdl->Read( 0, 1, &c, &uiSize)))
+		if ( RC_BAD( rc = pFileHdl->read( 0, 1, &c, &uiSize)))
 		{
 			goto Exit;
 		}
@@ -1493,7 +1368,7 @@ Skip_WS_And_Comments:
 		
 		while( isWhitespace(c))
 		{
-			if( RC_BAD( rc = pFileHdl->Read( 0, 1, &c, &uiSize)))
+			if( RC_BAD( rc = pFileHdl->read( 0, 1, &c, &uiSize)))
 			{
 				goto Exit;
 			}
@@ -1505,7 +1380,7 @@ Skip_WS_And_Comments:
 
 			for (;;)
 			{
-				if( RC_BAD( rc = pFileHdl->Read( 0, 1, &c, &uiSize)))
+				if( RC_BAD( rc = pFileHdl->read( 0, 1, &c, &uiSize)))
 				{
 					goto Exit;
 				}
@@ -1523,7 +1398,7 @@ Skip_WS_And_Comments:
 				if( c == 0x0D)
 				{
 
-					if( RC_BAD( rc = pFileHdl->Read( 0, 1, &c, &uiSize)))
+					if( RC_BAD( rc = pFileHdl->read( 0, 1, &c, &uiSize)))
 					{
 						goto Exit;
 					}
@@ -1538,18 +1413,18 @@ Skip_WS_And_Comments:
 					{
 						// Rewind
 						
-						uiOffset = 0;
-						uiTrueOffset = 0;
+						ui64Offset = 0;
+						ui64TrueOffset = 0;
 
-						if( RC_BAD( rc = pFileHdl->Tell( &uiOffset)))
+						if( RC_BAD( rc = pFileHdl->tell( &ui64Offset)))
 						{
 							goto Exit;
 						}
 						
-						uiOffset--;
+						ui64Offset--;
 
-						if( RC_BAD( rc = pFileHdl->Seek( uiOffset, 
-							F_IO_SEEK_SET, &uiTrueOffset)))
+						if( RC_BAD( rc = pFileHdl->seek( ui64Offset, 
+							FLM_IO_SEEK_SET, &ui64TrueOffset)))
 						{
 							goto Exit;
 						}
@@ -1569,7 +1444,7 @@ Skip_WS_And_Comments:
 			}
 
 			*pszToken++ = c;
-			if( RC_BAD( rc = pFileHdl->Read( 0, 1, &c, &uiSize)))
+			if( RC_BAD( rc = pFileHdl->read( 0, 1, &c, &uiSize)))
 			{
 				goto Exit;
 			}
@@ -1577,14 +1452,15 @@ Skip_WS_And_Comments:
 
 		// Put the char back
 		
-		if( RC_BAD( rc = pFileHdl->Tell( &uiOffset)))
+		if( RC_BAD( rc = pFileHdl->tell( &ui64Offset)))
 		{
 			goto Exit;
 		}
-		uiOffset--;
+		
+		ui64Offset--;
 
-		if( RC_BAD( rc = pFileHdl->Seek( uiOffset, 
-			F_IO_SEEK_SET, &uiTrueOffset)))
+		if( RC_BAD( rc = pFileHdl->seek( ui64Offset, 
+			FLM_IO_SEEK_SET, &ui64TrueOffset)))
 		{
 			goto Exit;
 		}
@@ -1678,33 +1554,3 @@ void FilenameIterator::produceFilename(
 	f_sprintf( pszTemp, "%03x", (unsigned)m_uiExtension);
 	f_strcat( pszBuffer, pszTemp);
 }
-
-/***************************************************************************
-Desc:
-****************************************************************************/
-#ifdef FLM_NLM
-void flmUnittestFatalRuntimeError( void)
-{
-}
-#endif
-
-/***************************************************************************
-Desc:
-****************************************************************************/
-#ifdef FLM_NLM
-int flmUnittestLoad( void)
-{
-	return (int)FlmStartup();
-}
-#endif
-
-/***************************************************************************
-Desc:
-****************************************************************************/
-#ifdef FLM_NLM
-int flmUnittestUnload( void)
-{
-	FlmShutdown();
-	return 0;
-}
-#endif
