@@ -22,7 +22,7 @@
 // $Id: viewrfl.cpp 12329 2006-01-20 17:49:30 -0700 (Fri, 20 Jan 2006) ahodgkinson $
 //-------------------------------------------------------------------------
 
-#include "ftx.h"
+#include "flaimsys.h"
 #include "sharutil.h"
 #include "flm_edit.h"
 #include "flmarg.h"
@@ -79,102 +79,13 @@ FSTATIC RCODE rflOpenNewFile(
 	F_RecEditor *		pRecEditor,
 	const char *		pszFileName,
 	FLMBOOL				bPosAtBOF,
-	POOL *				pTmpPool,
+	F_Pool *				pTmpPool,
 	NODE **				ppNd);
 
 /*
 NetWare hooks
 */
 
-// Data
-
-typedef struct RflTagName
-{
-	const char *	pszTagName;
-	FLMUINT			uiTagNum;
-} RFL_TAG_NAME;
-
-RFL_TAG_NAME RflDictTags[] =
-{
-	{ "TransBegin", RFL_TRNS_BEGIN_FIELD},
-	{ "TransCommit", RFL_TRNS_COMMIT_FIELD},
-	{ "TransAbort", RFL_TRNS_ABORT_FIELD},
-	{ "RecAdd", RFL_RECORD_ADD_FIELD},
-	{ "RecModify", RFL_RECORD_MODIFY_FIELD},
-	{ "RecDelete", RFL_RECORD_DELETE_FIELD},
-	{ "ReserveDRN", RFL_RESERVE_DRN_FIELD},
-	{ "ChangeFields", RFL_CHANGE_FIELDS_FIELD},
-	{ "DataRecord", RFL_DATA_RECORD_FIELD},
-	{ "IndexNum", RFL_INDEX_NUM_FIELD},
-	{ "StartDRN", RFL_START_DRN_FIELD},
-	{ "EndDRN", RFL_END_DRN_FIELD},
-	{ "UnknownPacket", RFL_UNKNOWN_PACKET_FIELD},
-	{ "NumBytesValid", RFL_NUM_BYTES_VALID_FIELD},
-	{ "PacketAddress", RFL_PACKET_ADDRESS_FIELD},
-	{ "PacketChecksum", RFL_PACKET_CHECKSUM_FIELD},
-	{ "PacketChecksumValid", RFL_PACKET_CHECKSUM_VALID_FIELD},
-	{ "PacketBodyLength", RFL_PACKET_BODY_LENGTH_FIELD},
-	{ "NextPacketAddress", RFL_NEXT_PACKET_ADDRESS_FIELD},
-	{ "PrevPacketAddress", RFL_PREV_PACKET_ADDRESS_FIELD},
-	{ "TransID", RFL_TRANS_ID_FIELD},
-	{ "StartSeconds", RFL_START_SECONDS_FIELD},
-	{ "StartMillisec", RFL_START_MSEC_FIELD},
-	{ "EndSeconds", RFL_END_SECONDS_FIELD},
-	{ "EndMillisec", RFL_END_MSEC_FIELD},
-	{ "StartTransAddr", RFL_START_TRNS_ADDR_FIELD},
-	{ "ContainerNum", RFL_CONTAINER_FIELD},
-	{ "RecordID", RFL_DRN_FIELD},
-	{ "TagNum", RFL_TAG_NUM_FIELD},
-	{ "FieldType", RFL_TYPE_FIELD},
-	{ "Level", RFL_LEVEL_FIELD},
-	{ "DataLen", RFL_DATA_LEN_FIELD},
-	{ "Data", RFL_DATA_FIELD},
-	{ "MoreData", RFL_MORE_DATA_FIELD},
-	{ "InsertFld", RFL_INSERT_FLD_FIELD},
-	{ "ModifyFld", RFL_MODIFY_FLD_FIELD},
-	{ "DeleteFld", RFL_DELETE_FLD_FIELD},
-	{ "EndChanges", RFL_END_CHANGES_FIELD},
-	{ "UnknownChangeType", RFL_UNKNOWN_CHANGE_TYPE_FIELD},
-	{ "Position", RFL_POSITION_FIELD},
-	{ "ReplaceBytes", RFL_REPLACE_BYTES_FIELD},
-	{ "UnknownChangeBytes", RFL_UNKNOWN_CHANGE_BYTES_FIELD},
-	{ "IndexSet", RFL_INDEX_SET_FIELD},
-	{ "IndexSet2", RFL_INDEX_SET2_FIELD},
-	{ "StartUnknown", RFL_START_UNKNOWN_FIELD},
-	{ "UserUnknown", RFL_UNKNOWN_USER_PACKET_FIELD},
-	{ "RFLName", RFL_HDR_NAME_FIELD},
-	{ "RFLVersion", RFL_HDR_VERSION_FIELD},
-	{ "FileNumber", RFL_HDR_FILE_NUMBER_FIELD},
-	{ "FileEOF", RFL_HDR_EOF_FIELD},
-	{ "DBSerialNum", RFL_HDR_DB_SERIAL_NUM_FIELD},
-	{ "FileSerialNum", RFL_HDR_FILE_SERIAL_NUM_FIELD},
-	{ "NextFileSerialNum", RFL_HDR_NEXT_FILE_SERIAL_NUM_FIELD},
-	{ "KeepSignature", RFL_HDR_KEEP_SIGNATURE_FIELD},
-	{ "TransBeginEx", RFL_TRNS_BEGIN_EX_FIELD},
-	{ "UpgradeDB", RFL_UPGRADE_PACKET_FIELD},
-	{ "OldDbVersion", RFL_OLD_DB_VERSION_FIELD},
-	{ "NewDbVersion", RFL_NEW_DB_VERSION_FIELD},
-	{ "ReduceDb", RFL_REDUCE_PACKET_FIELD},
-	{ "BlockCount", RFL_BLOCK_COUNT_FIELD},
-	{ "LastCommitTransID", RFL_LAST_COMMITTED_TRANS_ID_FIELD},
-	{ "IndexSuspend", RFL_INDEX_SUSPEND_FIELD},
-	{ "IndexResume", RFL_INDEX_RESUME_FIELD},
-	{ "BlockChainFree", RFL_BLK_CHAIN_FREE_FIELD},
-	{ "TrackerRecDRN", RFL_TRACKER_REC_FIELD},
-	{ "EndBlockAddr", RFL_END_BLK_ADDR_FIELD},
-	{ "Flags", RFL_FLAGS_FIELD},
-	{ "InsertEncrypted",  RFL_INSERT_ENC_FLD_FIELD},
-	{ "ModifyEncrypted",  RFL_MODIFY_ENC_FLD_FIELD},
-	{ "Encrypted", RFL_ENC_FIELD},
-	{ "EncryptedDefId", RFL_ENC_DEF_ID_FIELD},
-	{ "EncryptedDataLen", RFL_ENC_DATA_LEN_FIELD},
-	{ "DataBaseKeyLen", RFL_DB_KEY_LEN_FIELD},
-	{ "DataBaseKey", RFL_DB_KEY_FIELD},
-	{ "WrapKey", RFL_WRAP_KEY_FIELD},
-	{ "EnableEncryption", RFL_ENABLE_ENCRYPTION_FIELD},
-	{ NULL, 0}
-};
-
 // Local Prototypes
 
 void UIMain(
@@ -191,7 +102,7 @@ RCODE viewRflMainKeyHook(
 RCODE viewRflMainHelpHook(
 	F_RecEditor *		pRecEditor,
 	F_RecEditor *		pHelpEditor,
-	POOL *				pPool,
+	F_Pool *				pPool,
 	void *				UserData,
 	NODE **				ppRootNd);
 
@@ -241,6 +152,11 @@ FSTATIC FLMBOOL editSearchFormCB(
 	FLMUINT *			puiKeyOut,
 	void *				pvAppData);
 
+FSTATIC RCODE addPullDownPacketType(
+	FlmForm *		pForm,
+	FLMUINT			uiPacketType,
+	const char *	pszPacketTypeName);
+	
 FSTATIC RCODE getSearchCriteria(
 	F_RecEditor *	pRecEditor,
 	RFL_PACKET *	pSrchCriteria,
@@ -257,8 +173,7 @@ RFL_PACKET						gv_SrchCriteria;
 FLMBOOL							gv_bSrchForward;
 FLMBOOL							gv_bDoRefresh = TRUE;
 FLMBOOL							gv_bShutdown = FALSE;
-FTX_INFO *						gv_pFtxInfo = NULL;
-const char *					gv_pucTitle = "FLAIM RFL Viewer v1.00";
+const char *					gv_pszTitle = "FLAIM RFL Viewer v1.00";
 char								gv_szRflPath [F_PATH_MAX_SIZE];
 static F_NameTable *			gv_pNameTable = NULL;
 #ifdef FLM_NLM
@@ -336,60 +251,42 @@ void UIMain(
 	RCODE					rc = FERR_OK;
 
 	gv_pRflFileHdl = NULL;
-	gv_uiRflEof = 0;
+	gv_ui64RflEof = 0;
 	f_memset( &gv_SrchCriteria, 0, sizeof( gv_SrchCriteria));
 	gv_bSrchForward = TRUE;
 	gv_SrchCriteria.uiPacketType = 0xFFFFFFFF;
 	gv_SrchCriteria.uiMultiFileSearch = 1;
 
-	if( FTXInit( gv_pucTitle, (FLMUINT)80, (FLMUINT)50,
-		WPS_BLUE, WPS_WHITE, NULL, NULL,
-		&gv_pFtxInfo) != FTXRC_SUCCESS)
+	if( RC_BAD( rc = FTXInit( gv_pszTitle, (FLMUINT)80, (FLMUINT)50,
+		FLM_BLUE, FLM_WHITE, NULL, NULL)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
 
-	FTXSetShutdownFlag( gv_pFtxInfo, &gv_bShutdown);
+	FTXSetShutdownFlag( &gv_bShutdown);
 
-	if( FTXScreenInit( gv_pFtxInfo, gv_pucTitle, &pScreen) != FTXRC_SUCCESS)
+	if( RC_BAD( rc = FTXScreenInit( gv_pszTitle, &pScreen)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
 
-	if( FTXWinInit( pScreen, 0, 1, &pTitleWin) != FTXRC_SUCCESS)
+	if( RC_BAD( rc = FTXWinInit( pScreen, 0, 1, &pTitleWin)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
 
-	if( FTXWinPaintBackground( pTitleWin, WPS_RED) != FTXRC_SUCCESS)
+	FTXWinPaintBackground( pTitleWin, FLM_RED);
+
+	FTXWinPrintStr( pTitleWin, gv_pszTitle);
+
+	FTXWinSetCursorType( pTitleWin, FLM_CURSOR_INVISIBLE);
+
+	if( RC_BAD( rc = FTXWinOpen( pTitleWin)))
 	{
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
 
-	if( FTXWinPrintStr( pTitleWin, gv_pucTitle) != FTXRC_SUCCESS)
-	{
-		rc = RC_SET( FERR_MEM);
-		goto Exit;
-	}
-
-	if( FTXWinSetCursorType( pTitleWin,
-		WPS_CURSOR_INVISIBLE) != FTXRC_SUCCESS)
-	{
-		rc = RC_SET( FERR_MEM);
-		goto Exit;
-	}
-
-	if( FTXWinOpen( pTitleWin) != FTXRC_SUCCESS)
-	{
-		rc = RC_SET( FERR_MEM);
-		goto Exit;
-	}
-
-	if( (pRecEditor = new F_RecEditor) == NULL)
+	if( (pRecEditor = f_new F_RecEditor) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
@@ -423,17 +320,17 @@ void UIMain(
 				"Log File Name", gv_szRflPath,
 				sizeof( gv_szRflPath), &uiTermChar);
 
-		if( uiTermChar == WPK_ESCAPE)
+		if( uiTermChar == FKB_ESCAPE)
 		{
 			goto Exit;
 		}
 	}
 
-	if( RC_BAD( rc = pRecEditor->getFileSystem()->Open( gv_szRflPath,
-			  			F_IO_RDWR | F_IO_SH_DENYNONE, &gv_pRflFileHdl)))
+	if( RC_BAD( rc = pRecEditor->getFileSystem()->openFile( gv_szRflPath,
+			  			FLM_IO_RDWR | FLM_IO_SH_DENYNONE, &gv_pRflFileHdl)))
 	{
 		pRecEditor->displayMessage( "Unable to open file", rc,
-			NULL, WPS_RED, WPS_WHITE);
+			NULL, FLM_RED, FLM_WHITE);
 		rc = FERR_OK;
 	}
 	else
@@ -466,7 +363,7 @@ Exit:
 		gv_pRflFileHdl->Release();
 	}
 
-	FTXFree( &gv_pFtxInfo);
+	FTXExit();
 }
 
 
@@ -499,7 +396,7 @@ FSTATIC RCODE addLabel(
 
 	return( pForm->addTextObject( uiObjectId, pszLabel,
 		uiLen, uiLen,
-		0, TRUE, WPS_BLUE, WPS_WHITE,
+		0, TRUE, FLM_BLUE, FLM_WHITE,
 		uiRow, SRCH_LABEL_COLUMN));
 }
 
@@ -524,18 +421,18 @@ FSTATIC FLMBOOL editSearchFormCB(
 	{
 		switch (uiKeyIn)
 		{
-			case WPK_F1:
-			case WPK_F2:
-			case WPK_F3:
-			case WPK_F4:
-			case WPK_F5:
-			case WPK_F6:
-			case WPK_F7:
-			case WPK_F8:
-			case WPK_F9:
-			case WPK_F10:
-			case WPK_F11:
-			case WPK_F12:
+			case FKB_F1:
+			case FKB_F2:
+			case FKB_F3:
+			case FKB_F4:
+			case FKB_F5:
+			case FKB_F6:
+			case FKB_F7:
+			case FKB_F8:
+			case FKB_F9:
+			case FKB_F10:
+			case FKB_F11:
+			case FKB_F12:
 				return( FALSE);
 			default:
 				return( TRUE);
@@ -544,6 +441,22 @@ FSTATIC FLMBOOL editSearchFormCB(
 	return( TRUE);
 }
 
+/********************************************************************
+Desc: Add a packet type to a pulldown list
+*********************************************************************/
+FSTATIC RCODE addPullDownPacketType(
+	FlmForm *		pForm,
+	FLMUINT			uiPacketType,
+	const char *	pszPacketTypeName)
+{
+	char	szDisplayValue [100];
+	
+	f_sprintf( szDisplayValue, "%s (%u)", pszPacketTypeName,
+			(unsigned)uiPacketType);
+	return( pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG, uiPacketType,
+								szDisplayValue, 0));
+}
+
 /********************************************************************
 Desc: Add a label to a form.
 *********************************************************************/
@@ -564,15 +477,13 @@ FSTATIC RCODE getSearchCriteria(
 	FLMUINT			uiCurrObjectId;
 	const char *	pszWhat = NULL;
 
-	if (FTXScreenGetSize( pScreen,
-			&uiScreenCols, &uiScreenRows) != FTXRC_SUCCESS)
+	if (RC_BAD( rc = FTXScreenGetSize( pScreen, &uiScreenCols, &uiScreenRows)))
 	{
 		pszWhat = "getting screen size";
-		rc = RC_SET( FERR_MEM);
 		goto Exit;
 	}
 
-	if ((pForm = new FlmForm) == NULL)
+	if ((pForm = f_new FlmForm) == NULL)
 	{
 		pszWhat = "allocating form";
 		rc = RC_SET( FERR_MEM);
@@ -581,12 +492,12 @@ FSTATIC RCODE getSearchCriteria(
 
 	if (RC_BAD( rc = pForm->init( pScreen, NULL,
 						"Search Criteria",
-						WPS_BLUE, WPS_WHITE,
+						FLM_BLUE, FLM_WHITE,
 						"ESC=Quit, F1=search forward, other=search backward",
-						WPS_BLUE, WPS_WHITE,
+						FLM_BLUE, FLM_WHITE,
 						0, 0,
 						uiScreenCols - 1, uiScreenRows - 1, TRUE, TRUE,
-						WPS_BLUE, WPS_LIGHTGRAY)))
+						FLM_BLUE, FLM_LIGHTGRAY)))
 	{
 		pszWhat = "initializing form";
 		goto Exit;
@@ -602,127 +513,147 @@ FSTATIC RCODE getSearchCriteria(
 	}
 	if (RC_BAD( rc = pForm->addPulldownObject( SRCH_PACKET_TYPE_TAG,
 									20, 10,
-									WPS_LIGHTGRAY, WPS_RED, uiRow, SRCH_ENTER_COLUMN)))
+									FLM_LIGHTGRAY, FLM_RED, uiRow, SRCH_ENTER_COLUMN)))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_TRNS_BEGIN_PACKET,
-								"B=Transaction Begin", (FLMUINT)'B')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_TRNS_BEGIN_PACKET,
+								"Transaction Begin")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_TRNS_BEGIN_EX_PACKET,
-								"X=Transaction Begin (Extended)", (FLMUINT)'X')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_TRNS_BEGIN_EX_PACKET,
+								"Transaction Begin Ext")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_TRNS_COMMIT_PACKET,
-								"C=Transaction Commit", (FLMUINT)'C')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_TRNS_COMMIT_PACKET,
+								"Transaction Commit")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_TRNS_ABORT_PACKET,
-								"A=Transaction Abort", (FLMUINT)'A')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_TRNS_ABORT_PACKET,
+								"Transaction Abort")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_ADD_RECORD_PACKET,
-								"E=Add Record", (FLMUINT)'E')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_ADD_RECORD_PACKET,
+								"Add Record")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_MODIFY_RECORD_PACKET,
-								"M=Modify Record", (FLMUINT)'M')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_MODIFY_RECORD_PACKET,
+								"Modify Record")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_DELETE_RECORD_PACKET,
-								"D=Delete Record", (FLMUINT)'D')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_DELETE_RECORD_PACKET,
+								"Delete Record")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_RESERVE_DRN_PACKET,
-								"R=Reserve DRN", (FLMUINT)'R')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_RESERVE_DRN_PACKET,
+								"Reserve DRN")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_CHANGE_FIELDS_PACKET,
-								"F=Change Fields", (FLMUINT)'F')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_CHANGE_FIELDS_PACKET,
+								"Change Fields")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_DATA_RECORD_PACKET,
-								"T=Data Record", (FLMUINT)'T')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_DATA_RECORD_PACKET,
+								"Data Record")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_INDEX_SET_PACKET,
-								"I=Index Set", (FLMUINT)'I')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_INDEX_SET_PACKET,
+								"Index Set")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_INDEX_SET_PACKET_VER_2,
-								"2=Index Set2", (FLMUINT)'2')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_INDEX_SET_PACKET_VER_2,
+								"Index Set V2")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_BLK_CHAIN_FREE_PACKET,
-								"L=Block Chain Free", (FLMUINT)'L')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_BLK_CHAIN_FREE_PACKET,
+								"Block Chain Free")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_START_UNKNOWN_PACKET,
-								"S=Start Unknown", (FLMUINT)'S')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_START_UNKNOWN_PACKET,
+								"Start Unknown")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_UNKNOWN_PACKET,
-								"U=User Unknown", (FLMUINT)'U')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_UNKNOWN_PACKET,
+								"User Unknown")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_REDUCE_PACKET,
-								"K=Reduce", (FLMUINT)'K')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_REDUCE_PACKET,
+								"Reduce")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_UPGRADE_PACKET,
-								"G=Upgrade", (FLMUINT)'G')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_UPGRADE_PACKET,
+								"Upgrade")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_INDEX_SUSPEND_PACKET,
-								"P=Index Suspend", (FLMUINT)'P')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_INDEX_SUSPEND_PACKET,
+								"Index Suspend")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								RFL_INDEX_RESUME_PACKET,
-								"J=Index Resume", (FLMUINT)'J')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_INDEX_RESUME_PACKET,
+								"Index Resume")))
 	{
 		goto Exit;
 	}
-	if (RC_BAD( rc = pForm->addPulldownItem( SRCH_PACKET_TYPE_TAG,
-								0xFFFFFFFF,
-								"*=All packet types", (FLMUINT)'*')))
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_ADD_RECORD_PACKET_VER_2,
+								"Add Record V2")))
+	{
+		goto Exit;
+	}
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_MODIFY_RECORD_PACKET_VER_2,
+								"Modify Record V2")))
+	{
+		goto Exit;
+	}
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_DELETE_RECORD_PACKET_VER_2,
+								"Delete Record V2")))
+	{
+		goto Exit;
+	}
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_ENC_DATA_RECORD_PACKET,
+								"Data Record Encrypted")))
+	{
+		goto Exit;
+	}
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_DATA_RECORD_PACKET_VER_3,
+								"Data Record V3")))
+	{
+		goto Exit;
+	}
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_WRAP_KEY_PACKET,
+								"Wrap Encryption Key")))
+	{
+		goto Exit;
+	}
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_ENABLE_ENCRYPTION_PACKET,
+								"Enable Encryption")))
+	{
+		goto Exit;
+	}
+	if (RC_BAD( rc = addPullDownPacketType( pForm, RFL_CONFIG_SIZE_EVENT_PACKET,
+								"Configure RFL Size")))
+	{
+		goto Exit;
+	}
+	if (RC_BAD( rc = addPullDownPacketType( pForm, 0xFFFFFFFF,
+								"All packet types")))
 	{
 		goto Exit;
 	}
@@ -749,7 +680,7 @@ FSTATIC RCODE getSearchCriteria(
 	if (RC_BAD( rc = pForm->addUnsignedObject( SRCH_TRANS_ID_TAG,
 					pSrchCriteria->uiTransID,
 					0, 0xFFFFFFFF, 10,
-					0, FALSE, WPS_LIGHTGRAY, WPS_RED, uiRow, SRCH_ENTER_COLUMN)))
+					0, FALSE, FLM_LIGHTGRAY, FLM_RED, uiRow, SRCH_ENTER_COLUMN)))
 	{
 		goto Exit;
 	}
@@ -777,7 +708,7 @@ FSTATIC RCODE getSearchCriteria(
 	if (RC_BAD( rc = pForm->addUnsignedObject( SRCH_CONTAINER_TAG,
 					pSrchCriteria->uiContainer,
 					0, 0xFFFF, 5,
-					0, FALSE, WPS_LIGHTGRAY, WPS_RED, uiRow, SRCH_ENTER_COLUMN)))
+					0, FALSE, FLM_LIGHTGRAY, FLM_RED, uiRow, SRCH_ENTER_COLUMN)))
 	{
 		goto Exit;
 	}
@@ -805,7 +736,7 @@ FSTATIC RCODE getSearchCriteria(
 	if (RC_BAD( rc = pForm->addUnsignedObject( SRCH_INDEX_TAG,
 					pSrchCriteria->uiIndex,
 					0, 0xFFFF, 5,
-					0, FALSE, WPS_LIGHTGRAY, WPS_RED, uiRow, SRCH_ENTER_COLUMN)))
+					0, FALSE, FLM_LIGHTGRAY, FLM_RED, uiRow, SRCH_ENTER_COLUMN)))
 	{
 		goto Exit;
 	}
@@ -833,7 +764,7 @@ FSTATIC RCODE getSearchCriteria(
 	if (RC_BAD( rc = pForm->addUnsignedObject( SRCH_DRN_TAG,
 					pSrchCriteria->uiDrn,
 					0, 0xFFFFFFFF, 10,
-					0, FALSE, WPS_LIGHTGRAY, WPS_RED, uiRow, SRCH_ENTER_COLUMN)))
+					0, FALSE, FLM_LIGHTGRAY, FLM_RED, uiRow, SRCH_ENTER_COLUMN)))
 	{
 		goto Exit;
 	}
@@ -861,7 +792,7 @@ FSTATIC RCODE getSearchCriteria(
 	if (RC_BAD( rc = pForm->addUnsignedObject( SRCH_END_DRN_TAG,
 					pSrchCriteria->uiEndDrn,
 					0, 0xFFFFFFFF, 10,
-					0, FALSE, WPS_LIGHTGRAY, WPS_RED, uiRow, SRCH_ENTER_COLUMN)))
+					0, FALSE, FLM_LIGHTGRAY, FLM_RED, uiRow, SRCH_ENTER_COLUMN)))
 	{
 		goto Exit;
 	}
@@ -888,7 +819,7 @@ FSTATIC RCODE getSearchCriteria(
 	}
 	if (RC_BAD( rc = pForm->addPulldownObject( SRCH_MULTI_FILE_TAG,
 									20, 10,
-									WPS_LIGHTGRAY, WPS_RED, uiRow, SRCH_ENTER_COLUMN)))
+									FLM_LIGHTGRAY, FLM_RED, uiRow, SRCH_ENTER_COLUMN)))
 	{
 		goto Exit;
 	}
@@ -918,12 +849,12 @@ FSTATIC RCODE getSearchCriteria(
 	pForm->setFormEventCB( editSearchFormCB, NULL, TRUE);
 	uiChar = pForm->interact( &bValuesChanged, &uiCurrObjectId);
 
-	if (uiChar == WPK_ESC)
+	if (uiChar == FKB_ESCAPE)
 	{
 		rc = RC_SET( FERR_FAILURE);
 		goto Exit;
 	}
-	*pbForward = (FLMBOOL)((uiChar == WPK_F1)
+	*pbForward = (FLMBOOL)((uiChar == FKB_F1)
 								  ? TRUE
 								  : FALSE);
 
@@ -934,13 +865,13 @@ FSTATIC RCODE getSearchCriteria(
 	}
 
 Exit:
-	if (RC_BAD( rc) && uiChar != WPK_ESC)
+	if (RC_BAD( rc) && uiChar != FKB_ESCAPE)
 	{
 		char	szErrMsg [100];
 
 		f_sprintf( (char *)szErrMsg, "Error %s", pszWhat);
 		pRecEditor->displayMessage( szErrMsg, rc,
-						NULL, WPS_RED, WPS_WHITE);
+						NULL, FLM_RED, FLM_WHITE);
 	}
 	if (pForm)
 	{
@@ -1091,16 +1022,16 @@ FSTATIC RCODE viewRflHeaderDispHook(
 		pszTmp [LABEL_WIDTH] = ' ';
 		pszTmp [LABEL_WIDTH + 1] = 0;
 		pDispVals[ *puiNumVals].uiCol = uiCol;
-		pDispVals[ *puiNumVals].uiForeground = WPS_WHITE;
-		pDispVals[ *puiNumVals].uiBackground = WPS_BLUE;
+		pDispVals[ *puiNumVals].foreground = FLM_WHITE;
+		pDispVals[ *puiNumVals].background = FLM_BLUE;
 		(*puiNumVals)++;
 		uiCol += (LABEL_WIDTH + 1);
 
 		// Output the value.
 
 		pDispVals[ *puiNumVals].uiCol = uiCol;
-		pDispVals[ *puiNumVals].uiForeground = WPS_YELLOW;
-		pDispVals[ *puiNumVals].uiBackground = WPS_BLUE;
+		pDispVals[ *puiNumVals].foreground = FLM_YELLOW;
+		pDispVals[ *puiNumVals].background = FLM_BLUE;
 
 		(void)pRecEditor->getDisplayValue( pNd,
 								F_RECEDIT_DEFAULT_TYPE,
@@ -1126,12 +1057,12 @@ FSTATIC RCODE viewRflShowHeader(
 	FLMUINT				uiBytesRead;
 	FLMBYTE				szTmp [100];
 	FLMUINT				uiTmp;
-	POOL					tmpPool;
+	F_Pool				tmpPool;
 	RCODE					rc = FERR_OK;
 
-	GedPoolInit( &tmpPool, 1024);
+	tmpPool.poolInit( 1024);
 
-	if( (pRecEditor = new F_RecEditor) == NULL)
+	if( (pRecEditor = f_new F_RecEditor) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
@@ -1152,14 +1083,15 @@ FSTATIC RCODE viewRflShowHeader(
 
 	// Read the header from the file.
 
-	if (RC_BAD( rc = gv_pRflFileHdl->Read( 0, 512, ucHdrBuf, &uiBytesRead)))
+	if (RC_BAD( rc = gv_pRflFileHdl->read( 0, 512, ucHdrBuf, &uiBytesRead)))
 	{
 		goto Exit;
 	}
 
 	// Create the name field
 
-	if ((pNode = GedNodeCreate( &tmpPool, RFL_HDR_NAME_FIELD, 0, &rc)) == NULL)
+	if ((pNode = GedNodeCreate( &tmpPool, makeTagNum( RFL_HDR_NAME_FIELD),
+							0, &rc)) == NULL)
 	{
 		goto Exit;
 	}
@@ -1173,7 +1105,8 @@ FSTATIC RCODE viewRflShowHeader(
 
 	// Create the version field
 
-	if ((pNode = GedNodeCreate( &tmpPool, RFL_HDR_VERSION_FIELD, 0, &rc)) == NULL)
+	if ((pNode = GedNodeCreate( &tmpPool,
+							makeTagNum( RFL_HDR_VERSION_FIELD), 0, &rc)) == NULL)
 	{
 		goto Exit;
 	}
@@ -1187,7 +1120,7 @@ FSTATIC RCODE viewRflShowHeader(
 
 	// Create the file number field
 
-	if ((pNode = GedNodeCreate( &tmpPool, RFL_HDR_FILE_NUMBER_FIELD,
+	if ((pNode = GedNodeCreate( &tmpPool, makeTagNum( RFL_HDR_FILE_NUMBER_FIELD),
 							0, &rc)) == NULL)
 	{
 		goto Exit;
@@ -1201,7 +1134,7 @@ FSTATIC RCODE viewRflShowHeader(
 
 	// Create the EOF field
 
-	if ((pNode = GedNodeCreate( &tmpPool, RFL_HDR_EOF_FIELD,
+	if ((pNode = GedNodeCreate( &tmpPool, makeTagNum( RFL_HDR_EOF_FIELD),
 							0, &rc)) == NULL)
 	{
 		goto Exit;
@@ -1215,7 +1148,7 @@ FSTATIC RCODE viewRflShowHeader(
 
 	// Create the database serial number field
 
-	if ((pNode = GedNodeCreate( &tmpPool, RFL_HDR_DB_SERIAL_NUM_FIELD,
+	if ((pNode = GedNodeCreate( &tmpPool, makeTagNum( RFL_HDR_DB_SERIAL_NUM_FIELD),
 								0, &rc)) == NULL)
 	{
 		goto Exit;
@@ -1229,7 +1162,7 @@ FSTATIC RCODE viewRflShowHeader(
 
 	// Create the file serial number field
 
-	if ((pNode = GedNodeCreate( &tmpPool, RFL_HDR_FILE_SERIAL_NUM_FIELD,
+	if ((pNode = GedNodeCreate( &tmpPool, makeTagNum( RFL_HDR_FILE_SERIAL_NUM_FIELD),
 								0, &rc)) == NULL)
 	{
 		goto Exit;
@@ -1243,7 +1176,7 @@ FSTATIC RCODE viewRflShowHeader(
 
 	// Create the next file serial number field
 
-	if ((pNode = GedNodeCreate( &tmpPool, RFL_HDR_NEXT_FILE_SERIAL_NUM_FIELD,
+	if ((pNode = GedNodeCreate( &tmpPool, makeTagNum( RFL_HDR_NEXT_FILE_SERIAL_NUM_FIELD),
 								0, &rc)) == NULL)
 	{
 		goto Exit;
@@ -1257,7 +1190,7 @@ FSTATIC RCODE viewRflShowHeader(
 
 	// Create the next file serial number field
 
-	if ((pNode = GedNodeCreate( &tmpPool, RFL_HDR_KEEP_SIGNATURE_FIELD,
+	if ((pNode = GedNodeCreate( &tmpPool, makeTagNum( RFL_HDR_KEEP_SIGNATURE_FIELD),
 								0, &rc)) == NULL)
 	{
 		goto Exit;
@@ -1284,7 +1217,7 @@ Exit:
 		pRecEditor->Release();
 	}
 
-	GedPoolFree( &tmpPool);
+	tmpPool.poolFree();
 	return( rc);
 }
 
@@ -1295,23 +1228,23 @@ FSTATIC RCODE viewRflGetEOF( void)
 {
 	RCODE			rc = FERR_OK;
 	NODE *		pTmpNd;
-	POOL			tmpPool;
+	F_Pool		tmpPool;
 	FLMBYTE		ucHdrBuf [512];
 	FLMUINT		uiBytesRead;
 	FLMUINT		uiEof;
 
-	GedPoolInit( &tmpPool, 4096);
+	tmpPool.poolInit( 4096);
 
 	// First try to get the EOF from the file's header.
 
-	if (RC_BAD( rc = gv_pRflFileHdl->Read( 0, 512, ucHdrBuf, &uiBytesRead)))
+	if (RC_BAD( rc = gv_pRflFileHdl->read( 0, 512, ucHdrBuf, &uiBytesRead)))
 	{
 		goto Exit;
 	}
 	uiEof = (FLMUINT)FB2UD( &ucHdrBuf [RFL_EOF_POS]);
 	if (uiEof)
 	{
-		gv_uiRflEof = uiEof;
+		gv_ui64RflEof = (FLMUINT64)uiEof;
 	}
 	else
 	{
@@ -1327,16 +1260,16 @@ FSTATIC RCODE viewRflGetEOF( void)
 
 		// If we still didn't get an EOF value, set it to the file size.
 
-		if (!gv_uiRflEof)
+		if (!gv_ui64RflEof)
 		{
-			if (RC_BAD( rc = gv_pRflFileHdl->Size( &gv_uiRflEof)))
+			if (RC_BAD( rc = gv_pRflFileHdl->size( &gv_ui64RflEof)))
 			{
 				goto Exit;
 			}
 		}
 	}
 Exit:
-	GedPoolFree( &tmpPool);
+	tmpPool.poolFree();
 	return( rc);
 }
 
@@ -1347,16 +1280,16 @@ FSTATIC RCODE rflOpenNewFile(
 	F_RecEditor *		pRecEditor,
 	const char *		pszFileName,
 	FLMBOOL				bPosAtBOF,
-	POOL *				pTmpPool,
+	F_Pool *				pTmpPool,
 	NODE **				ppNd)
 {
 	RCODE			rc = FERR_OK;
-	F_FileHdl *	pFileHdl = NULL;
-	F_FileHdl *	pSaveFileHdl = NULL;
+	IF_FileHdl *	pFileHdl = NULL;
+	IF_FileHdl *	pSaveFileHdl = NULL;
 	char			szPath [F_PATH_MAX_SIZE];
 	char			szBaseName [F_FILENAME_SIZE];
 	char			szPrefix [F_FILENAME_SIZE];
-	FLMUINT		uiDbVersion = FLM_VER_4_3;
+	FLMUINT		uiDbVersion = FLM_FILE_FORMAT_VER_4_3;
 	FLMUINT		uiFileNum;
 
 	// If no file name was specified, go to the next or previous file from
@@ -1371,11 +1304,11 @@ FSTATIC RCODE rflOpenNewFile(
 
 		// See if it is version 4.3 or greater first.
 
-		uiDbVersion = FLM_VER_4_3;
+		uiDbVersion = FLM_FILE_FORMAT_VER_4_3;
 		if (!rflGetFileNum( uiDbVersion, szPrefix, gv_szRflPath, &uiFileNum))
 		{
 			szPrefix [3] = 0;
-			uiDbVersion = FLM_VER_4_0;
+			uiDbVersion = FLM_FILE_FORMAT_VER_4_0;
 			if (!rflGetFileNum( uiDbVersion, szPrefix, gv_szRflPath, &uiFileNum))
 			{
 				rc = RC_SET( FERR_IO_PATH_NOT_FOUND);
@@ -1397,8 +1330,8 @@ FSTATIC RCODE rflOpenNewFile(
 
 	// See if we can open the next file.
 
-	if( RC_BAD( rc = pRecEditor->getFileSystem()->Open( pszFileName,
-			  			F_IO_RDWR | F_IO_SH_DENYNONE, &pFileHdl)))
+	if( RC_BAD( rc = pRecEditor->getFileSystem()->openFile( pszFileName,
+			  			FLM_IO_RDWR | FLM_IO_SH_DENYNONE, &pFileHdl)))
 	{
 		goto Exit;
 	}
@@ -1464,9 +1397,9 @@ RCODE viewRflMainKeyHook(
 	NODE *			pRootNd = NULL;
 	NODE *			pTmpNd = NULL;
 	NODE *			pNewNd;
-	POOL				tmpPool;
-	POOL				tmp2Pool;
-	FTX_WINDOW_p	pWindow = NULL;
+	F_Pool			tmpPool;
+	F_Pool			tmp2Pool;
+	FTX_WINDOW *	pWindow = NULL;
 	NODE *			pLastNd;
 	NODE *			pFirstNd;
 	RFL_PACKET *	pPacket;
@@ -1478,8 +1411,8 @@ RCODE viewRflMainKeyHook(
 	FLMUINT			uiOffset;
 
 	F_UNREFERENCED_PARM( UserData);
-	GedPoolInit( &tmpPool, 4096);
-	GedPoolInit( &tmp2Pool, 4096);
+	tmpPool.poolInit( 4096);
+	tmp2Pool.poolInit( 4096);
 
 	if( puiKeyOut)
 	{
@@ -1489,17 +1422,17 @@ RCODE viewRflMainKeyHook(
 	pRootNd = pRecEditor->getRootNode( pCurNd);
 	switch( uiKeyIn)
 	{
-		case WPK_DOWN:
-		case WPK_UP:
-		case WPK_PGDN:
-		case WPK_PGUP:
+		case FKB_DOWN:
+		case FKB_UP:
+		case FKB_PGDN:
+		case FKB_PGUP:
 		case '?':
 		{
 			*puiKeyOut = uiKeyIn;
 			break;
 		}
 
-		case WPK_END:
+		case FKB_END:
 		{
 			FLMUINT		uiLoop;
 
@@ -1531,13 +1464,13 @@ RCODE viewRflMainKeyHook(
 				{
 					break;
 				}
-				GedPoolReset( &tmpPool, NULL);
+				tmpPool.poolReset( NULL);
 			}
 			pRecEditor->setCurrentAtBottom();
 			break;
 		}
 
-		case WPK_HOME:
+		case FKB_HOME:
 		{
 			pRecEditor->setTree( NULL);
 			if( RC_BAD( rc = RflGetNextNode( NULL, FALSE, &tmpPool, 
@@ -1557,7 +1490,7 @@ RCODE viewRflMainKeyHook(
 		View a specific entry
 		*/
 
-		case WPK_ENTER:
+		case FKB_ENTER:
 		{
 			viewRflInspectEntry( pRecEditor);
 			break;
@@ -1574,7 +1507,7 @@ RCODE viewRflMainKeyHook(
 			pRecEditor->requestInput(
 				"Log File Name",
 				szResponse, sizeof( szResponse), &uiTermChar);
-			if( uiTermChar == WPK_ESCAPE || !szResponse [0])
+			if( uiTermChar == FKB_ESCAPE || !szResponse [0])
 			{
 				break;
 			}
@@ -1583,7 +1516,7 @@ RCODE viewRflMainKeyHook(
 									&tmpPool, &pTmpNd)))
 			{
 				pRecEditor->displayMessage( "Unable to open file", rc,
-					NULL, WPS_RED, WPS_WHITE);
+					NULL, FLM_RED, FLM_WHITE);
 			}
 			break;
 
@@ -1593,7 +1526,7 @@ RCODE viewRflMainKeyHook(
 									&tmpPool, &pTmpNd)))
 			{
 				pRecEditor->displayMessage( "Unable to open file", rc,
-					NULL, WPS_RED, WPS_WHITE);
+					NULL, FLM_RED, FLM_WHITE);
 			}
 			break;
 
@@ -1603,7 +1536,7 @@ RCODE viewRflMainKeyHook(
 									&tmpPool, &pTmpNd)))
 			{
 				pRecEditor->displayMessage( "Unable to open file", rc,
-					NULL, WPS_RED, WPS_WHITE);
+					NULL, FLM_RED, FLM_WHITE);
 			}
 			break;
 
@@ -1620,7 +1553,7 @@ RCODE viewRflMainKeyHook(
 				"Offset",
 				szResponse, sizeof( szResponse), &uiTermChar);
 
-			if( uiTermChar == WPK_ESCAPE)
+			if( uiTermChar == FKB_ESCAPE)
 			{
 				break;
 			}
@@ -1634,7 +1567,7 @@ RCODE viewRflMainKeyHook(
 				if( RC_BAD( rc = pRecEditor->getNumber( szResponse, &uiOffset, NULL)))
 				{
 					pRecEditor->displayMessage( "Invalid offset", rc,
-						NULL, WPS_RED, WPS_WHITE);
+						NULL, FLM_RED, FLM_WHITE);
 					break;
 				}
 
@@ -1654,12 +1587,12 @@ RCODE viewRflMainKeyHook(
 		Find something in the RFL log.
 		*/
 
-		case WPK_F1:
-		case WPK_F3:
+		case FKB_F1:
+		case FKB_F3:
 			gv_bSrchForward = TRUE;
 			bSkipCurrent = TRUE;
 			goto Do_Search;
-		case WPK_F2:
+		case FKB_F2:
 			gv_bSrchForward = FALSE;
 			bSkipCurrent = TRUE;
 			goto Do_Search;
@@ -1677,7 +1610,7 @@ RCODE viewRflMainKeyHook(
 Do_Search:
 			if (RC_BAD( rc = pRecEditor->createStatusWindow(
 				" Searching ... (press ESC to interrupt) ",
-				WPS_GREEN, WPS_WHITE, NULL, NULL, &pWindow)))
+				FLM_GREEN, FLM_WHITE, NULL, NULL, &pWindow)))
 			{
 				goto Exit;
 			}
@@ -1717,11 +1650,11 @@ Do_Search:
 
 					// Test for the escape key
 
-					if (FTXWinTestKB( pWindow) == FTXRC_SUCCESS)
+					if (RC_OK( FTXWinTestKB( pWindow)))
 					{
 						FLMUINT	uiChar;
 						FTXWinInputChar( pWindow, &uiChar);
-						if( uiChar == WPK_ESCAPE)
+						if( uiChar == FKB_ESCAPE)
 						{
 							goto Exit;
 						}
@@ -1751,7 +1684,7 @@ Do_Search:
 			// If we do not have an EOF, determine one.  We don't
 			// want to continue our search past this point.
 
-			if (!gv_uiRflEof)
+			if (!gv_ui64RflEof)
 			{
 				if (RC_BAD( rc = viewRflGetEOF()))
 				{
@@ -1761,7 +1694,7 @@ Do_Search:
 
 			for (;;)
 			{
-				GedPoolReset( &tmpPool, NULL);
+				tmpPool.poolReset( NULL);
 				if (gv_bSrchForward)
 				{
 					if (RC_BAD( rc = RflGetNextNode( pLastNd, FALSE,
@@ -1832,17 +1765,17 @@ Do_Search:
 
 					// Test for the escape key
 
-					if (FTXWinTestKB( pWindow) == FTXRC_SUCCESS)
+					if (RC_OK( FTXWinTestKB( pWindow)))
 					{
 						FLMUINT	uiChar;
 						FTXWinInputChar( pWindow, &uiChar);
-						if( uiChar == WPK_ESCAPE)
+						if( uiChar == FKB_ESCAPE)
 						{
 							goto Exit;
 						}
 					}
 				}
-				GedPoolReset( &tmp2Pool, NULL);
+				tmp2Pool.poolReset( NULL);
 				if ((pLastNd = GedCopy( &tmp2Pool, 1, pCurNd)) == NULL)
 				{
 					rc = RC_SET( FERR_MEM);
@@ -1856,10 +1789,10 @@ Do_Search:
 			break;
 		}
 
-		case WPK_ALT_Q:
-		case WPK_ESCAPE:
+		case FKB_ALT_Q:
+		case FKB_ESCAPE:
 		{
-			*puiKeyOut = WPK_ESCAPE;
+			*puiKeyOut = FKB_ESCAPE;
 			break;
 		}
 	}
@@ -1869,8 +1802,8 @@ Exit:
 	{
 		FTXWinFree( &pWindow);
 	}
-	GedPoolFree( &tmpPool);
-	GedPoolFree( &tmp2Pool);
+	tmpPool.poolFree();
+	tmp2Pool.poolFree();
 	return( rc);
 }
 
@@ -1882,7 +1815,7 @@ Desc:
 RCODE viewRflMainHelpHook(
 	F_RecEditor *		pRecEditor,
 	F_RecEditor *		pHelpEditor,
-	POOL *				pPool,
+	F_Pool *				pPool,
 	void *				UserData,
 	NODE **				ppRootNd)
 {
@@ -1913,42 +1846,42 @@ RCODE viewRflMainHelpHook(
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_UP, (void *)"UP              Move cursor up",
+		FKB_UP, (void *)"UP              Move cursor up",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_DOWN, (void *)"DOWN            Move cursor down",
+		FKB_DOWN, (void *)"DOWN            Move cursor down",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_PGUP, (void *)"PG UP           Page up",
+		FKB_PGUP, (void *)"PG UP           Page up",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_PGDN, (void *)"PG DOWN         Page down",
+		FKB_PGDN, (void *)"PG DOWN         Page down",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_HOME, (void *)"HOME            Position to beginning of file",
+		FKB_HOME, (void *)"HOME            Position to beginning of file",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_END, (void *)"END             Position to end of file",
+		FKB_END, (void *)"END             Position to end of file",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
@@ -1983,14 +1916,14 @@ RCODE viewRflMainHelpHook(
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_F1, (void *)"F1 or F3        Search forward (using last criteria entered)",
+		FKB_F1, (void *)"F1 or F3        Search forward (using last criteria entered)",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_F2, (void *)"F2              Search backward (using last criteria entered)",
+		FKB_F2, (void *)"F2              Search backward (using last criteria entered)",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
@@ -2011,7 +1944,7 @@ RCODE viewRflMainHelpHook(
 	}
 
 	if( RC_BAD( rc = gedAddField( pPool, pNewTree,
-		WPK_ESCAPE, (void *)"ESC, ALT-Q      Exit",
+		FKB_ESCAPE, (void *)"ESC, ALT-Q      Exit",
 		0, FLM_TEXT_TYPE)))
 	{
 		goto Exit;
@@ -2035,13 +1968,13 @@ RCODE viewRflMainEventHook(
 	void *				EventData,
 	void *				UserData)
 {
-	POOL					tmpPool;
+	F_Pool				tmpPool;
 	NODE *				pTmpNd;
 	RCODE					rc = FERR_OK;
 
 	F_UNREFERENCED_PARM( UserData);
 
-	GedPoolInit( &tmpPool, 4096);
+	tmpPool.poolInit( 4096);
 
 	switch( eEventType)
 	{
@@ -2246,7 +2179,7 @@ RCODE viewRflMainEventHook(
 
 Exit:
 
-	GedPoolFree( &tmpPool);
+	tmpPool.poolFree();
 	return( rc);
 }
 
@@ -2260,12 +2193,12 @@ RCODE viewRflInspectEntry(
 {
 	F_RecEditor *		pRecEditor;
 	NODE *				pExpandNd;
-	POOL					tmpPool;
+	F_Pool				tmpPool;
 	RCODE					rc = FERR_OK;
 
-	GedPoolInit( &tmpPool, 1024);
+	tmpPool.poolInit( 1024);
 
-	if( (pRecEditor = new F_RecEditor) == NULL)
+	if( (pRecEditor = f_new F_RecEditor) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
@@ -2300,7 +2233,7 @@ Exit:
 		pRecEditor->Release();
 	}
 
-	GedPoolFree( &tmpPool);
+	tmpPool.poolFree();
 	return( rc);
 }
 
@@ -2347,8 +2280,8 @@ RCODE viewRflInspectDispHook(
 			f_sprintf( (char *)pDispVals[ *puiNumVals].pucString,
 				"%8.8X", (unsigned)uiOffset);
 			pDispVals[ *puiNumVals].uiCol = uiCol;
-			pDispVals[ *puiNumVals].uiForeground = WPS_WHITE;
-			pDispVals[ *puiNumVals].uiBackground = WPS_BLUE;
+			pDispVals[ *puiNumVals].foreground = FLM_WHITE;
+			pDispVals[ *puiNumVals].background = FLM_BLUE;
 			(*puiNumVals)++;
 		}
 		uiCol += 10;
@@ -2360,8 +2293,8 @@ RCODE viewRflInspectDispHook(
 		f_sprintf( (char *)pDispVals[ *puiNumVals].pucString,
 			"%u", (unsigned)GedNodeLevel( pNd));
 		pDispVals[ *puiNumVals].uiCol = uiCol + (GedNodeLevel( pNd) * 2);
-		pDispVals[ *puiNumVals].uiForeground = WPS_WHITE;
-		pDispVals[ *puiNumVals].uiBackground = WPS_BLUE;
+		pDispVals[ *puiNumVals].foreground = FLM_WHITE;
+		pDispVals[ *puiNumVals].background = FLM_BLUE;
 		uiCol += (FLMUINT)(f_strlen( pDispVals[ *puiNumVals].pucString) +
 			(GedNodeLevel( pNd) * 2) + 1);
 		(*puiNumVals)++;
@@ -2422,17 +2355,17 @@ RCODE viewRflInspectDispHook(
 
 		if( bBadField)
 		{
-			pDispVals[ *puiNumVals].uiForeground = WPS_RED;
-			pDispVals[ *puiNumVals].uiBackground = WPS_WHITE;
+			pDispVals[ *puiNumVals].foreground = FLM_RED;
+			pDispVals[ *puiNumVals].background = FLM_WHITE;
 		}
 		else
 		{
 #ifdef FLM_WIN
-			pDispVals[ *puiNumVals].uiForeground = WPS_LIGHTGREEN;
+			pDispVals[ *puiNumVals].foreground = FLM_LIGHTGREEN;
 #else
-			pDispVals[ *puiNumVals].uiForeground = WPS_GREEN;
+			pDispVals[ *puiNumVals].foreground = FLM_GREEN;
 #endif
-			pDispVals[ *puiNumVals].uiBackground = WPS_BLUE;
+			pDispVals[ *puiNumVals].background = FLM_BLUE;
 		}
 
 		pDispVals[ *puiNumVals].uiCol = uiCol;
@@ -2465,8 +2398,8 @@ RCODE viewRflInspectDispHook(
 				}
 
 				pDispVals[ *puiNumVals].uiCol = uiCol;
-				pDispVals[ *puiNumVals].uiForeground = WPS_YELLOW;
-				pDispVals[ *puiNumVals].uiBackground = WPS_BLUE;
+				pDispVals[ *puiNumVals].foreground = FLM_YELLOW;
+				pDispVals[ *puiNumVals].background = FLM_BLUE;
 				uiCol += (FLMUINT)(f_strlen( pDispVals[ *puiNumVals].pucString) + 1);
 				(*puiNumVals)++;
 			}
@@ -2539,14 +2472,14 @@ RCODE viewRflInspectKeyHook(
 
 	switch( uiKeyIn)
 	{
-		case WPK_DOWN:
-		case WPK_UP:
-		case WPK_PGDN:
-		case WPK_PGUP:
-		case WPK_ESCAPE:
-		case WPK_ENTER:
-		case WPK_END:
-		case WPK_HOME:
+		case FKB_DOWN:
+		case FKB_UP:
+		case FKB_PGDN:
+		case FKB_PGUP:
+		case FKB_ESCAPE:
+		case FKB_ENTER:
+		case FKB_END:
+		case FKB_HOME:
 		case '?':
 		{
 			*puiKeyOut = uiKeyIn;
@@ -2571,12 +2504,10 @@ RCODE viewRflNameTableInit(
 	char					szFileName[ F_PATH_MAX_SIZE];
 	HFDB					hDb = HFDB_NULL;
 	F_NameTable *		pNameTable = NULL;
-	RFL_TAG_NAME *		pTag;
+	FLMUINT				uiTagNum;
 	RCODE					rc = FERR_OK;
 
-	/*
-	Try to open the database
-	*/
+	// Try to open the database
 
 	if( RC_BAD( f_pathReduce( gv_szRflPath, szIoDbPath, szFileName)))
 	{
@@ -2612,7 +2543,7 @@ RCODE viewRflNameTableInit(
 		}
 	}
 
-	if( (pNameTable = new F_NameTable) == NULL)
+	if( (pNameTable = f_new F_NameTable) == NULL)
 	{
 		rc = RC_SET( FERR_MEM);
 		goto Exit;
@@ -2625,16 +2556,16 @@ RCODE viewRflNameTableInit(
 
 	// Build the name table
 
-	pTag = &RflDictTags[ 0];
-	while( pTag->pszTagName)
+	uiTagNum = 0;
+	while (gv_szTagNames [uiTagNum])
 	{
-		if( RC_BAD( rc = pNameTable->addTag( NULL, pTag->pszTagName,
-			pTag->uiTagNum, FLM_FIELD_TAG, 0)))
+		if( RC_BAD( rc = pNameTable->addTag( NULL, gv_szTagNames [uiTagNum],
+			uiTagNum + 32769, FLM_FIELD_TAG, 0)))
 		{
 			flmAssert( 0);
 			goto Exit;
 		}
-		pTag++;
+		uiTagNum++;
 	}
 
 	*ppNameTable = pNameTable;
@@ -2654,3 +2585,4 @@ Exit:
 
 	return( rc);
 }
+
